\ the additional Forth 200x words and their wordsets and other info

\ Copyright (C) 2014 Free Software Foundation, Inc.

\ This file is part of Gforth.

\ Gforth is free software; you can redistribute it and/or
\ modify it under the terms of the GNU General Public License
\ as published by the Free Software Foundation, either version 3
\ of the License, or (at your option) any later version.

\ This program is distributed in the hope that it will be useful,
\ but WITHOUT ANY WARRANTY; without even the implied warranty of
\ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
\ GNU General Public License for more details.

\ You should have received a copy of the GNU General Public License
\ along with this program. If not, see http://www.gnu.org/licenses/.

xword action-of core-ext-2012
xword buffer: core-ext-2012
xword defer core-ext-2012
xword defer! core-ext-2012
xword defer@ core-ext-2012
xword holds core-ext-2012
xword is core-ext-2012
xword parse-name core-ext-2012
xword s\" core-ext-2012

xword 2value double-ext-2012

xword +field facility-ext-2012
xword begin-structure facility-ext-2012
xword cfield: facility-ext-2012
xword ekey>fkey facility-ext-2012
xword end-structure facility-ext-2012
xword field: facility-ext-2012
xword k-alt-mask facility-ext-2012
xword k-ctrl-mask facility-ext-2012
xword k-delete facility-ext-2012
xword k-down facility-ext-2012
xword k-end facility-ext-2012
xword k-f1 facility-ext-2012
xword k-f10 facility-ext-2012
xword k-f11 facility-ext-2012
xword k-f12 facility-ext-2012
xword k-f2 facility-ext-2012
xword k-f3 facility-ext-2012
xword k-f4 facility-ext-2012
xword k-f5 facility-ext-2012
xword k-f6 facility-ext-2012
xword k-f7 facility-ext-2012
xword k-f8 facility-ext-2012
xword k-f9 facility-ext-2012
xword k-home facility-ext-2012
xword k-insert facility-ext-2012
xword k-left facility-ext-2012
xword k-next facility-ext-2012
xword k-prior facility-ext-2012
xword k-right facility-ext-2012
xword k-shift-mask facility-ext-2012
xword k-up facility-ext-2012

xword include file-ext-2012
xword require file-ext-2012
xword required file-ext-2012

xword dffield: float-ext-2012
xword f>s float-ext-2012
xword ffield: float-ext-2012
xword ftrunc float-ext-2012
xword fvalue float-ext-2012
xword s>f float-ext-2012
xword sffield: float-ext-2012
xword ffield: float-ext-2012

xword {: local-ext-2012

xword n>r tools-ext-2012
xword name>compile tools-ext-2012
xword name>interpret tools-ext-2012
xword name>string tools-ext-2012
xword nr> tools-ext-2012
xword synonym tools-ext-2012
xword traverse-wordlist tools-ext-2012
xword [defined] tools-ext-2012
xword [undefined] tools-ext-2012

xword replaces string-ext-2012
xword substitute string-ext-2012
xword unescape string-ext-2012

xword x-size xchar-2012
xword xc!+ xchar-2012
xword xc!+? xchar-2012
xword xc, xchar-2012
xword xc-size xchar-2012
xword xc@+ xchar-2012
xword xchar+ xchar-2012
xword xemit xchar-2012
xword xkey xchar-2012
xword xkey? xchar-2012
xword +x/string xchar-2012
xword -trailing-garbage xchar-2012

xword ekey>xchar xchar-ext-2012
xword x-width xchar-ext-2012
xword xc-width xchar-ext-2012
xword xchar- xchar-ext-2012
xword xhold xchar-ext-2012
xword x\string- xchar-ext-2012
