#include <gforth/0.7.9_20150820/libcc.h>
ptrpair libgfcstr_LTX_gforth_c_cstr_an_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)cstr((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfcstr_LTX_gforth_c_tilde_cstr_an_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)tilde_cstr((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
hash_128 gflibcc_hash_cstr = "\xB4\xE2\x6F\xE9\x18\x32\x52\x08\xBD\x02\xD6\xDB\x5D\x68\x8C\xAB";
