\ This file has been generated using SWIG and fsi,
\ and is already platform dependent, search for the corresponding
\ fsi-file to compile it where no one has compiled it before ;)
\ GForth has its own dynamic loader and doesn't need addional C-Code.
\ That's why this file contains normal Gforth-code( version 0.6.9 or higher )
\ and could be used directly with include or require.
\ As all comments are stripped during the compilation, please
\ insert the copyright notice of the original file here.

\ ----===< int constants ===>-----
1	constant __gl2_h_
1	constant GL_ES_VERSION_2_0
256	constant GL_DEPTH_BUFFER_BIT
1024	constant GL_STENCIL_BUFFER_BIT
16384	constant GL_COLOR_BUFFER_BIT
0	constant GL_FALSE
1	constant GL_TRUE
0	constant GL_POINTS
1	constant GL_LINES
2	constant GL_LINE_LOOP
3	constant GL_LINE_STRIP
4	constant GL_TRIANGLES
5	constant GL_TRIANGLE_STRIP
6	constant GL_TRIANGLE_FAN
0	constant GL_ZERO
1	constant GL_ONE
768	constant GL_SRC_COLOR
769	constant GL_ONE_MINUS_SRC_COLOR
770	constant GL_SRC_ALPHA
771	constant GL_ONE_MINUS_SRC_ALPHA
772	constant GL_DST_ALPHA
773	constant GL_ONE_MINUS_DST_ALPHA
774	constant GL_DST_COLOR
775	constant GL_ONE_MINUS_DST_COLOR
776	constant GL_SRC_ALPHA_SATURATE
32774	constant GL_FUNC_ADD
32777	constant GL_BLEND_EQUATION
32777	constant GL_BLEND_EQUATION_RGB
34877	constant GL_BLEND_EQUATION_ALPHA
32778	constant GL_FUNC_SUBTRACT
32779	constant GL_FUNC_REVERSE_SUBTRACT
32968	constant GL_BLEND_DST_RGB
32969	constant GL_BLEND_SRC_RGB
32970	constant GL_BLEND_DST_ALPHA
32971	constant GL_BLEND_SRC_ALPHA
32769	constant GL_CONSTANT_COLOR
32770	constant GL_ONE_MINUS_CONSTANT_COLOR
32771	constant GL_CONSTANT_ALPHA
32772	constant GL_ONE_MINUS_CONSTANT_ALPHA
32773	constant GL_BLEND_COLOR
34962	constant GL_ARRAY_BUFFER
34963	constant GL_ELEMENT_ARRAY_BUFFER
34964	constant GL_ARRAY_BUFFER_BINDING
34965	constant GL_ELEMENT_ARRAY_BUFFER_BINDING
35040	constant GL_STREAM_DRAW
35044	constant GL_STATIC_DRAW
35048	constant GL_DYNAMIC_DRAW
34660	constant GL_BUFFER_SIZE
34661	constant GL_BUFFER_USAGE
34342	constant GL_CURRENT_VERTEX_ATTRIB
1028	constant GL_FRONT
1029	constant GL_BACK
1032	constant GL_FRONT_AND_BACK
3553	constant GL_TEXTURE_2D
2884	constant GL_CULL_FACE
3042	constant GL_BLEND
3024	constant GL_DITHER
2960	constant GL_STENCIL_TEST
2929	constant GL_DEPTH_TEST
3089	constant GL_SCISSOR_TEST
32823	constant GL_POLYGON_OFFSET_FILL
32926	constant GL_SAMPLE_ALPHA_TO_COVERAGE
32928	constant GL_SAMPLE_COVERAGE
0	constant GL_NO_ERROR
1280	constant GL_INVALID_ENUM
1281	constant GL_INVALID_VALUE
1282	constant GL_INVALID_OPERATION
1285	constant GL_OUT_OF_MEMORY
2304	constant GL_CW
2305	constant GL_CCW
2849	constant GL_LINE_WIDTH
33901	constant GL_ALIASED_POINT_SIZE_RANGE
33902	constant GL_ALIASED_LINE_WIDTH_RANGE
2885	constant GL_CULL_FACE_MODE
2886	constant GL_FRONT_FACE
2928	constant GL_DEPTH_RANGE
2930	constant GL_DEPTH_WRITEMASK
2931	constant GL_DEPTH_CLEAR_VALUE
2932	constant GL_DEPTH_FUNC
2961	constant GL_STENCIL_CLEAR_VALUE
2962	constant GL_STENCIL_FUNC
2964	constant GL_STENCIL_FAIL
2965	constant GL_STENCIL_PASS_DEPTH_FAIL
2966	constant GL_STENCIL_PASS_DEPTH_PASS
2967	constant GL_STENCIL_REF
2963	constant GL_STENCIL_VALUE_MASK
2968	constant GL_STENCIL_WRITEMASK
34816	constant GL_STENCIL_BACK_FUNC
34817	constant GL_STENCIL_BACK_FAIL
34818	constant GL_STENCIL_BACK_PASS_DEPTH_FAIL
34819	constant GL_STENCIL_BACK_PASS_DEPTH_PASS
36003	constant GL_STENCIL_BACK_REF
36004	constant GL_STENCIL_BACK_VALUE_MASK
36005	constant GL_STENCIL_BACK_WRITEMASK
2978	constant GL_VIEWPORT
3088	constant GL_SCISSOR_BOX
3106	constant GL_COLOR_CLEAR_VALUE
3107	constant GL_COLOR_WRITEMASK
3317	constant GL_UNPACK_ALIGNMENT
3333	constant GL_PACK_ALIGNMENT
3379	constant GL_MAX_TEXTURE_SIZE
3386	constant GL_MAX_VIEWPORT_DIMS
3408	constant GL_SUBPIXEL_BITS
3410	constant GL_RED_BITS
3411	constant GL_GREEN_BITS
3412	constant GL_BLUE_BITS
3413	constant GL_ALPHA_BITS
3414	constant GL_DEPTH_BITS
3415	constant GL_STENCIL_BITS
10752	constant GL_POLYGON_OFFSET_UNITS
32824	constant GL_POLYGON_OFFSET_FACTOR
32873	constant GL_TEXTURE_BINDING_2D
32936	constant GL_SAMPLE_BUFFERS
32937	constant GL_SAMPLES
32938	constant GL_SAMPLE_COVERAGE_VALUE
32939	constant GL_SAMPLE_COVERAGE_INVERT
34466	constant GL_NUM_COMPRESSED_TEXTURE_FORMATS
34467	constant GL_COMPRESSED_TEXTURE_FORMATS
4352	constant GL_DONT_CARE
4353	constant GL_FASTEST
4354	constant GL_NICEST
33170	constant GL_GENERATE_MIPMAP_HINT
5120	constant GL_BYTE
5121	constant GL_UNSIGNED_BYTE
5122	constant GL_SHORT
5123	constant GL_UNSIGNED_SHORT
5124	constant GL_INT
5125	constant GL_UNSIGNED_INT
5126	constant GL_FLOAT
5132	constant GL_FIXED
6402	constant GL_DEPTH_COMPONENT
6406	constant GL_ALPHA
6407	constant GL_RGB
6408	constant GL_RGBA
6409	constant GL_LUMINANCE
6410	constant GL_LUMINANCE_ALPHA
32819	constant GL_UNSIGNED_SHORT_4_4_4_4
32820	constant GL_UNSIGNED_SHORT_5_5_5_1
33635	constant GL_UNSIGNED_SHORT_5_6_5
35632	constant GL_FRAGMENT_SHADER
35633	constant GL_VERTEX_SHADER
34921	constant GL_MAX_VERTEX_ATTRIBS
36347	constant GL_MAX_VERTEX_UNIFORM_VECTORS
36348	constant GL_MAX_VARYING_VECTORS
35661	constant GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS
35660	constant GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS
34930	constant GL_MAX_TEXTURE_IMAGE_UNITS
36349	constant GL_MAX_FRAGMENT_UNIFORM_VECTORS
35663	constant GL_SHADER_TYPE
35712	constant GL_DELETE_STATUS
35714	constant GL_LINK_STATUS
35715	constant GL_VALIDATE_STATUS
35717	constant GL_ATTACHED_SHADERS
35718	constant GL_ACTIVE_UNIFORMS
35719	constant GL_ACTIVE_UNIFORM_MAX_LENGTH
35721	constant GL_ACTIVE_ATTRIBUTES
35722	constant GL_ACTIVE_ATTRIBUTE_MAX_LENGTH
35724	constant GL_SHADING_LANGUAGE_VERSION
35725	constant GL_CURRENT_PROGRAM
512	constant GL_NEVER
513	constant GL_LESS
514	constant GL_EQUAL
515	constant GL_LEQUAL
516	constant GL_GREATER
517	constant GL_NOTEQUAL
518	constant GL_GEQUAL
519	constant GL_ALWAYS
7680	constant GL_KEEP
7681	constant GL_REPLACE
7682	constant GL_INCR
7683	constant GL_DECR
5386	constant GL_INVERT
34055	constant GL_INCR_WRAP
34056	constant GL_DECR_WRAP
7936	constant GL_VENDOR
7937	constant GL_RENDERER
7938	constant GL_VERSION
7939	constant GL_EXTENSIONS
9728	constant GL_NEAREST
9729	constant GL_LINEAR
9984	constant GL_NEAREST_MIPMAP_NEAREST
9985	constant GL_LINEAR_MIPMAP_NEAREST
9986	constant GL_NEAREST_MIPMAP_LINEAR
9987	constant GL_LINEAR_MIPMAP_LINEAR
10240	constant GL_TEXTURE_MAG_FILTER
10241	constant GL_TEXTURE_MIN_FILTER
10242	constant GL_TEXTURE_WRAP_S
10243	constant GL_TEXTURE_WRAP_T
5890	constant GL_TEXTURE
34067	constant GL_TEXTURE_CUBE_MAP
34068	constant GL_TEXTURE_BINDING_CUBE_MAP
34069	constant GL_TEXTURE_CUBE_MAP_POSITIVE_X
34070	constant GL_TEXTURE_CUBE_MAP_NEGATIVE_X
34071	constant GL_TEXTURE_CUBE_MAP_POSITIVE_Y
34072	constant GL_TEXTURE_CUBE_MAP_NEGATIVE_Y
34073	constant GL_TEXTURE_CUBE_MAP_POSITIVE_Z
34074	constant GL_TEXTURE_CUBE_MAP_NEGATIVE_Z
34076	constant GL_MAX_CUBE_MAP_TEXTURE_SIZE
33984	constant GL_TEXTURE0
33985	constant GL_TEXTURE1
33986	constant GL_TEXTURE2
33987	constant GL_TEXTURE3
33988	constant GL_TEXTURE4
33989	constant GL_TEXTURE5
33990	constant GL_TEXTURE6
33991	constant GL_TEXTURE7
33992	constant GL_TEXTURE8
33993	constant GL_TEXTURE9
33994	constant GL_TEXTURE10
33995	constant GL_TEXTURE11
33996	constant GL_TEXTURE12
33997	constant GL_TEXTURE13
33998	constant GL_TEXTURE14
33999	constant GL_TEXTURE15
34000	constant GL_TEXTURE16
34001	constant GL_TEXTURE17
34002	constant GL_TEXTURE18
34003	constant GL_TEXTURE19
34004	constant GL_TEXTURE20
34005	constant GL_TEXTURE21
34006	constant GL_TEXTURE22
34007	constant GL_TEXTURE23
34008	constant GL_TEXTURE24
34009	constant GL_TEXTURE25
34010	constant GL_TEXTURE26
34011	constant GL_TEXTURE27
34012	constant GL_TEXTURE28
34013	constant GL_TEXTURE29
34014	constant GL_TEXTURE30
34015	constant GL_TEXTURE31
34016	constant GL_ACTIVE_TEXTURE
10497	constant GL_REPEAT
33071	constant GL_CLAMP_TO_EDGE
33648	constant GL_MIRRORED_REPEAT
35664	constant GL_FLOAT_VEC2
35665	constant GL_FLOAT_VEC3
35666	constant GL_FLOAT_VEC4
35667	constant GL_INT_VEC2
35668	constant GL_INT_VEC3
35669	constant GL_INT_VEC4
35670	constant GL_BOOL
35671	constant GL_BOOL_VEC2
35672	constant GL_BOOL_VEC3
35673	constant GL_BOOL_VEC4
35674	constant GL_FLOAT_MAT2
35675	constant GL_FLOAT_MAT3
35676	constant GL_FLOAT_MAT4
35678	constant GL_SAMPLER_2D
35680	constant GL_SAMPLER_CUBE
34338	constant GL_VERTEX_ATTRIB_ARRAY_ENABLED
34339	constant GL_VERTEX_ATTRIB_ARRAY_SIZE
34340	constant GL_VERTEX_ATTRIB_ARRAY_STRIDE
34341	constant GL_VERTEX_ATTRIB_ARRAY_TYPE
34922	constant GL_VERTEX_ATTRIB_ARRAY_NORMALIZED
34373	constant GL_VERTEX_ATTRIB_ARRAY_POINTER
34975	constant GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING
35738	constant GL_IMPLEMENTATION_COLOR_READ_TYPE
35739	constant GL_IMPLEMENTATION_COLOR_READ_FORMAT
35713	constant GL_COMPILE_STATUS
35716	constant GL_INFO_LOG_LENGTH
35720	constant GL_SHADER_SOURCE_LENGTH
36346	constant GL_SHADER_COMPILER
36344	constant GL_SHADER_BINARY_FORMATS
36345	constant GL_NUM_SHADER_BINARY_FORMATS
36336	constant GL_LOW_FLOAT
36337	constant GL_MEDIUM_FLOAT
36338	constant GL_HIGH_FLOAT
36339	constant GL_LOW_INT
36340	constant GL_MEDIUM_INT
36341	constant GL_HIGH_INT
36160	constant GL_FRAMEBUFFER
36161	constant GL_RENDERBUFFER
32854	constant GL_RGBA4
32855	constant GL_RGB5_A1
36194	constant GL_RGB565
33189	constant GL_DEPTH_COMPONENT16
36168	constant GL_STENCIL_INDEX8
36162	constant GL_RENDERBUFFER_WIDTH
36163	constant GL_RENDERBUFFER_HEIGHT
36164	constant GL_RENDERBUFFER_INTERNAL_FORMAT
36176	constant GL_RENDERBUFFER_RED_SIZE
36177	constant GL_RENDERBUFFER_GREEN_SIZE
36178	constant GL_RENDERBUFFER_BLUE_SIZE
36179	constant GL_RENDERBUFFER_ALPHA_SIZE
36180	constant GL_RENDERBUFFER_DEPTH_SIZE
36181	constant GL_RENDERBUFFER_STENCIL_SIZE
36048	constant GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE
36049	constant GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME
36050	constant GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL
36051	constant GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE
36064	constant GL_COLOR_ATTACHMENT0
36096	constant GL_DEPTH_ATTACHMENT
36128	constant GL_STENCIL_ATTACHMENT
0	constant GL_NONE
36053	constant GL_FRAMEBUFFER_COMPLETE
36054	constant GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT
36055	constant GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT
36057	constant GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS
36061	constant GL_FRAMEBUFFER_UNSUPPORTED
36006	constant GL_FRAMEBUFFER_BINDING
36007	constant GL_RENDERBUFFER_BINDING
34024	constant GL_MAX_RENDERBUFFER_SIZE
1286	constant GL_INVALID_FRAMEBUFFER_OPERATION
1	constant __gl2ext_h_
1	constant GL_KHR_blend_equation_advanced
37524	constant GL_MULTIPLY_KHR
37525	constant GL_SCREEN_KHR
37526	constant GL_OVERLAY_KHR
37527	constant GL_DARKEN_KHR
37528	constant GL_LIGHTEN_KHR
37529	constant GL_COLORDODGE_KHR
37530	constant GL_COLORBURN_KHR
37531	constant GL_HARDLIGHT_KHR
37532	constant GL_SOFTLIGHT_KHR
37534	constant GL_DIFFERENCE_KHR
37536	constant GL_EXCLUSION_KHR
37549	constant GL_HSL_HUE_KHR
37550	constant GL_HSL_SATURATION_KHR
37551	constant GL_HSL_COLOR_KHR
37552	constant GL_HSL_LUMINOSITY_KHR
1	constant GL_KHR_blend_equation_advanced_coherent
37509	constant GL_BLEND_ADVANCED_COHERENT_KHR
1	constant GL_KHR_context_flush_control
33531	constant GL_CONTEXT_RELEASE_BEHAVIOR_KHR
33532	constant GL_CONTEXT_RELEASE_BEHAVIOR_FLUSH_KHR
1	constant GL_KHR_debug
33510	constant GL_SAMPLER
33346	constant GL_DEBUG_OUTPUT_SYNCHRONOUS_KHR
33347	constant GL_DEBUG_NEXT_LOGGED_MESSAGE_LENGTH_KHR
33348	constant GL_DEBUG_CALLBACK_FUNCTION_KHR
33349	constant GL_DEBUG_CALLBACK_USER_PARAM_KHR
33350	constant GL_DEBUG_SOURCE_API_KHR
33351	constant GL_DEBUG_SOURCE_WINDOW_SYSTEM_KHR
33352	constant GL_DEBUG_SOURCE_SHADER_COMPILER_KHR
33353	constant GL_DEBUG_SOURCE_THIRD_PARTY_KHR
33354	constant GL_DEBUG_SOURCE_APPLICATION_KHR
33355	constant GL_DEBUG_SOURCE_OTHER_KHR
33356	constant GL_DEBUG_TYPE_ERROR_KHR
33357	constant GL_DEBUG_TYPE_DEPRECATED_BEHAVIOR_KHR
33358	constant GL_DEBUG_TYPE_UNDEFINED_BEHAVIOR_KHR
33359	constant GL_DEBUG_TYPE_PORTABILITY_KHR
33360	constant GL_DEBUG_TYPE_PERFORMANCE_KHR
33361	constant GL_DEBUG_TYPE_OTHER_KHR
33384	constant GL_DEBUG_TYPE_MARKER_KHR
33385	constant GL_DEBUG_TYPE_PUSH_GROUP_KHR
33386	constant GL_DEBUG_TYPE_POP_GROUP_KHR
33387	constant GL_DEBUG_SEVERITY_NOTIFICATION_KHR
33388	constant GL_MAX_DEBUG_GROUP_STACK_DEPTH_KHR
33389	constant GL_DEBUG_GROUP_STACK_DEPTH_KHR
33504	constant GL_BUFFER_KHR
33505	constant GL_SHADER_KHR
33506	constant GL_PROGRAM_KHR
32884	constant GL_VERTEX_ARRAY_KHR
33507	constant GL_QUERY_KHR
33510	constant GL_SAMPLER_KHR
33512	constant GL_MAX_LABEL_LENGTH_KHR
37187	constant GL_MAX_DEBUG_MESSAGE_LENGTH_KHR
37188	constant GL_MAX_DEBUG_LOGGED_MESSAGES_KHR
37189	constant GL_DEBUG_LOGGED_MESSAGES_KHR
37190	constant GL_DEBUG_SEVERITY_HIGH_KHR
37191	constant GL_DEBUG_SEVERITY_MEDIUM_KHR
37192	constant GL_DEBUG_SEVERITY_LOW_KHR
37600	constant GL_DEBUG_OUTPUT_KHR
2	constant GL_CONTEXT_FLAG_DEBUG_BIT_KHR
1283	constant GL_STACK_OVERFLOW_KHR
1284	constant GL_STACK_UNDERFLOW_KHR
1	constant GL_KHR_robust_buffer_access_behavior
1	constant GL_KHR_robustness
37107	constant GL_CONTEXT_ROBUST_ACCESS_KHR
33362	constant GL_LOSE_CONTEXT_ON_RESET_KHR
33363	constant GL_GUILTY_CONTEXT_RESET_KHR
33364	constant GL_INNOCENT_CONTEXT_RESET_KHR
33365	constant GL_UNKNOWN_CONTEXT_RESET_KHR
33366	constant GL_RESET_NOTIFICATION_STRATEGY_KHR
33377	constant GL_NO_RESET_NOTIFICATION_KHR
1287	constant GL_CONTEXT_LOST_KHR
1	constant GL_KHR_texture_compression_astc_hdr
37808	constant GL_COMPRESSED_RGBA_ASTC_4x4_KHR
37809	constant GL_COMPRESSED_RGBA_ASTC_5x4_KHR
37810	constant GL_COMPRESSED_RGBA_ASTC_5x5_KHR
37811	constant GL_COMPRESSED_RGBA_ASTC_6x5_KHR
37812	constant GL_COMPRESSED_RGBA_ASTC_6x6_KHR
37813	constant GL_COMPRESSED_RGBA_ASTC_8x5_KHR
37814	constant GL_COMPRESSED_RGBA_ASTC_8x6_KHR
37815	constant GL_COMPRESSED_RGBA_ASTC_8x8_KHR
37816	constant GL_COMPRESSED_RGBA_ASTC_10x5_KHR
37817	constant GL_COMPRESSED_RGBA_ASTC_10x6_KHR
37818	constant GL_COMPRESSED_RGBA_ASTC_10x8_KHR
37819	constant GL_COMPRESSED_RGBA_ASTC_10x10_KHR
37820	constant GL_COMPRESSED_RGBA_ASTC_12x10_KHR
37821	constant GL_COMPRESSED_RGBA_ASTC_12x12_KHR
37840	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR
37841	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR
37842	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR
37843	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR
37844	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR
37845	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR
37846	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR
37847	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR
37848	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR
37849	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR
37850	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x8_KHR
37851	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR
37852	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR
37853	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR
1	constant GL_KHR_texture_compression_astc_ldr
1	constant GL_OES_EGL_image
1	constant GL_OES_EGL_image_external
36197	constant GL_TEXTURE_EXTERNAL_OES
36199	constant GL_TEXTURE_BINDING_EXTERNAL_OES
36200	constant GL_REQUIRED_TEXTURE_IMAGE_UNITS_OES
36198	constant GL_SAMPLER_EXTERNAL_OES
1	constant GL_OES_compressed_ETC1_RGB8_sub_texture
1	constant GL_OES_compressed_ETC1_RGB8_texture
36196	constant GL_ETC1_RGB8_OES
1	constant GL_OES_compressed_paletted_texture
35728	constant GL_PALETTE4_RGB8_OES
35729	constant GL_PALETTE4_RGBA8_OES
35730	constant GL_PALETTE4_R5_G6_B5_OES
35731	constant GL_PALETTE4_RGBA4_OES
35732	constant GL_PALETTE4_RGB5_A1_OES
35733	constant GL_PALETTE8_RGB8_OES
35734	constant GL_PALETTE8_RGBA8_OES
35735	constant GL_PALETTE8_R5_G6_B5_OES
35736	constant GL_PALETTE8_RGBA4_OES
35737	constant GL_PALETTE8_RGB5_A1_OES
1	constant GL_OES_depth24
33190	constant GL_DEPTH_COMPONENT24_OES
1	constant GL_OES_depth32
33191	constant GL_DEPTH_COMPONENT32_OES
1	constant GL_OES_depth_texture
1	constant GL_OES_element_index_uint
1	constant GL_OES_fbo_render_mipmap
1	constant GL_OES_fragment_precision_high
1	constant GL_OES_get_program_binary
34625	constant GL_PROGRAM_BINARY_LENGTH_OES
34814	constant GL_NUM_PROGRAM_BINARY_FORMATS_OES
34815	constant GL_PROGRAM_BINARY_FORMATS_OES
1	constant GL_OES_mapbuffer
35001	constant GL_WRITE_ONLY_OES
35003	constant GL_BUFFER_ACCESS_OES
35004	constant GL_BUFFER_MAPPED_OES
35005	constant GL_BUFFER_MAP_POINTER_OES
1	constant GL_OES_packed_depth_stencil
34041	constant GL_DEPTH_STENCIL_OES
34042	constant GL_UNSIGNED_INT_24_8_OES
35056	constant GL_DEPTH24_STENCIL8_OES
1	constant GL_OES_required_internalformat
32828	constant GL_ALPHA8_OES
33189	constant GL_DEPTH_COMPONENT16_OES
32835	constant GL_LUMINANCE4_ALPHA4_OES
32837	constant GL_LUMINANCE8_ALPHA8_OES
32832	constant GL_LUMINANCE8_OES
32854	constant GL_RGBA4_OES
32855	constant GL_RGB5_A1_OES
36194	constant GL_RGB565_OES
32849	constant GL_RGB8_OES
32856	constant GL_RGBA8_OES
32850	constant GL_RGB10_EXT
32857	constant GL_RGB10_A2_EXT
1	constant GL_OES_rgb8_rgba8
1	constant GL_OES_sample_shading
35894	constant GL_SAMPLE_SHADING_OES
35895	constant GL_MIN_SAMPLE_SHADING_VALUE_OES
1	constant GL_OES_sample_variables
1	constant GL_OES_shader_image_atomic
1	constant GL_OES_shader_multisample_interpolation
36443	constant GL_MIN_FRAGMENT_INTERPOLATION_OFFSET_OES
36444	constant GL_MAX_FRAGMENT_INTERPOLATION_OFFSET_OES
36445	constant GL_FRAGMENT_INTERPOLATION_OFFSET_BITS_OES
1	constant GL_OES_standard_derivatives
35723	constant GL_FRAGMENT_SHADER_DERIVATIVE_HINT_OES
1	constant GL_OES_stencil1
36166	constant GL_STENCIL_INDEX1_OES
1	constant GL_OES_stencil4
36167	constant GL_STENCIL_INDEX4_OES
1	constant GL_OES_surfaceless_context
33305	constant GL_FRAMEBUFFER_UNDEFINED_OES
1	constant GL_OES_texture_3D
32882	constant GL_TEXTURE_WRAP_R_OES
32879	constant GL_TEXTURE_3D_OES
32874	constant GL_TEXTURE_BINDING_3D_OES
32883	constant GL_MAX_3D_TEXTURE_SIZE_OES
35679	constant GL_SAMPLER_3D_OES
36052	constant GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET_OES
1	constant GL_OES_texture_compression_astc
37824	constant GL_COMPRESSED_RGBA_ASTC_3x3x3_OES
37825	constant GL_COMPRESSED_RGBA_ASTC_4x3x3_OES
37826	constant GL_COMPRESSED_RGBA_ASTC_4x4x3_OES
37827	constant GL_COMPRESSED_RGBA_ASTC_4x4x4_OES
37828	constant GL_COMPRESSED_RGBA_ASTC_5x4x4_OES
37829	constant GL_COMPRESSED_RGBA_ASTC_5x5x4_OES
37830	constant GL_COMPRESSED_RGBA_ASTC_5x5x5_OES
37831	constant GL_COMPRESSED_RGBA_ASTC_6x5x5_OES
37832	constant GL_COMPRESSED_RGBA_ASTC_6x6x5_OES
37833	constant GL_COMPRESSED_RGBA_ASTC_6x6x6_OES
37856	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_3x3x3_OES
37857	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x3x3_OES
37858	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x4x3_OES
37859	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x4x4_OES
37860	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x4x4_OES
37861	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x5x4_OES
37862	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x5x5_OES
37863	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x5x5_OES
37864	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x6x5_OES
37865	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x6x6_OES
1	constant GL_OES_texture_float
1	constant GL_OES_texture_float_linear
1	constant GL_OES_texture_half_float
36193	constant GL_HALF_FLOAT_OES
1	constant GL_OES_texture_half_float_linear
1	constant GL_OES_texture_npot
1	constant GL_OES_texture_stencil8
6401	constant GL_STENCIL_INDEX_OES
36168	constant GL_STENCIL_INDEX8_OES
1	constant GL_OES_texture_storage_multisample_2d_array
37122	constant GL_TEXTURE_2D_MULTISAMPLE_ARRAY_OES
37125	constant GL_TEXTURE_BINDING_2D_MULTISAMPLE_ARRAY_OES
37131	constant GL_SAMPLER_2D_MULTISAMPLE_ARRAY_OES
37132	constant GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY_OES
37133	constant GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY_OES
1	constant GL_OES_vertex_array_object
34229	constant GL_VERTEX_ARRAY_BINDING_OES
1	constant GL_OES_vertex_half_float
1	constant GL_OES_vertex_type_10_10_10_2
36342	constant GL_UNSIGNED_INT_10_10_10_2_OES
36343	constant GL_INT_10_10_10_2_OES
1	constant GL_AMD_compressed_3DC_texture
34809	constant GL_3DC_X_AMD
34810	constant GL_3DC_XY_AMD
1	constant GL_AMD_compressed_ATC_texture
35986	constant GL_ATC_RGB_AMD
35987	constant GL_ATC_RGBA_EXPLICIT_ALPHA_AMD
34798	constant GL_ATC_RGBA_INTERPOLATED_ALPHA_AMD
1	constant GL_AMD_performance_monitor
35776	constant GL_COUNTER_TYPE_AMD
35777	constant GL_COUNTER_RANGE_AMD
35778	constant GL_UNSIGNED_INT64_AMD
35779	constant GL_PERCENTAGE_AMD
35780	constant GL_PERFMON_RESULT_AVAILABLE_AMD
35781	constant GL_PERFMON_RESULT_SIZE_AMD
35782	constant GL_PERFMON_RESULT_AMD
1	constant GL_AMD_program_binary_Z400
34624	constant GL_Z400_BINARY_AMD
1	constant GL_ANDROID_extension_pack_es31a
1	constant GL_ANGLE_depth_texture
1	constant GL_ANGLE_framebuffer_blit
36008	constant GL_READ_FRAMEBUFFER_ANGLE
36009	constant GL_DRAW_FRAMEBUFFER_ANGLE
36006	constant GL_DRAW_FRAMEBUFFER_BINDING_ANGLE
36010	constant GL_READ_FRAMEBUFFER_BINDING_ANGLE
1	constant GL_ANGLE_framebuffer_multisample
36011	constant GL_RENDERBUFFER_SAMPLES_ANGLE
36182	constant GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE_ANGLE
36183	constant GL_MAX_SAMPLES_ANGLE
1	constant GL_ANGLE_instanced_arrays
35070	constant GL_VERTEX_ATTRIB_ARRAY_DIVISOR_ANGLE
1	constant GL_ANGLE_pack_reverse_row_order
37796	constant GL_PACK_REVERSE_ROW_ORDER_ANGLE
1	constant GL_ANGLE_program_binary
37798	constant GL_PROGRAM_BINARY_ANGLE
1	constant GL_ANGLE_texture_compression_dxt3
33778	constant GL_COMPRESSED_RGBA_S3TC_DXT3_ANGLE
1	constant GL_ANGLE_texture_compression_dxt5
33779	constant GL_COMPRESSED_RGBA_S3TC_DXT5_ANGLE
1	constant GL_ANGLE_texture_usage
37794	constant GL_TEXTURE_USAGE_ANGLE
37795	constant GL_FRAMEBUFFER_ATTACHMENT_ANGLE
1	constant GL_ANGLE_translated_shader_source
37792	constant GL_TRANSLATED_SHADER_SOURCE_LENGTH_ANGLE
1	constant GL_APPLE_clip_distance
3378	constant GL_MAX_CLIP_DISTANCES_APPLE
12288	constant GL_CLIP_DISTANCE0_APPLE
12289	constant GL_CLIP_DISTANCE1_APPLE
12290	constant GL_CLIP_DISTANCE2_APPLE
12291	constant GL_CLIP_DISTANCE3_APPLE
12292	constant GL_CLIP_DISTANCE4_APPLE
12293	constant GL_CLIP_DISTANCE5_APPLE
12294	constant GL_CLIP_DISTANCE6_APPLE
12295	constant GL_CLIP_DISTANCE7_APPLE
1	constant GL_APPLE_color_buffer_packed_float
1	constant GL_APPLE_copy_texture_levels
1	constant GL_APPLE_framebuffer_multisample
36011	constant GL_RENDERBUFFER_SAMPLES_APPLE
36182	constant GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE_APPLE
36183	constant GL_MAX_SAMPLES_APPLE
36008	constant GL_READ_FRAMEBUFFER_APPLE
36009	constant GL_DRAW_FRAMEBUFFER_APPLE
36006	constant GL_DRAW_FRAMEBUFFER_BINDING_APPLE
36010	constant GL_READ_FRAMEBUFFER_BINDING_APPLE
1	constant GL_APPLE_rgb_422
35359	constant GL_RGB_422_APPLE
34234	constant GL_UNSIGNED_SHORT_8_8_APPLE
34235	constant GL_UNSIGNED_SHORT_8_8_REV_APPLE
35409	constant GL_RGB_RAW_422_APPLE
1	constant GL_APPLE_sync
35411	constant GL_SYNC_OBJECT_APPLE
37137	constant GL_MAX_SERVER_WAIT_TIMEOUT_APPLE
37138	constant GL_OBJECT_TYPE_APPLE
37139	constant GL_SYNC_CONDITION_APPLE
37140	constant GL_SYNC_STATUS_APPLE
37141	constant GL_SYNC_FLAGS_APPLE
37142	constant GL_SYNC_FENCE_APPLE
37143	constant GL_SYNC_GPU_COMMANDS_COMPLETE_APPLE
37144	constant GL_UNSIGNALED_APPLE
37145	constant GL_SIGNALED_APPLE
37146	constant GL_ALREADY_SIGNALED_APPLE
37147	constant GL_TIMEOUT_EXPIRED_APPLE
37148	constant GL_CONDITION_SATISFIED_APPLE
37149	constant GL_WAIT_FAILED_APPLE
1	constant GL_SYNC_FLUSH_COMMANDS_BIT_APPLE
1	constant GL_APPLE_texture_format_BGRA8888
32993	constant GL_BGRA_EXT
37793	constant GL_BGRA8_EXT
1	constant GL_APPLE_texture_max_level
33085	constant GL_TEXTURE_MAX_LEVEL_APPLE
1	constant GL_APPLE_texture_packed_float
35899	constant GL_UNSIGNED_INT_10F_11F_11F_REV_APPLE
35902	constant GL_UNSIGNED_INT_5_9_9_9_REV_APPLE
35898	constant GL_R11F_G11F_B10F_APPLE
35901	constant GL_RGB9_E5_APPLE
1	constant GL_ARM_mali_program_binary
36705	constant GL_MALI_PROGRAM_BINARY_ARM
1	constant GL_ARM_mali_shader_binary
36704	constant GL_MALI_SHADER_BINARY_ARM
1	constant GL_ARM_rgba8
1	constant GL_ARM_shader_framebuffer_fetch
36709	constant GL_FETCH_PER_SAMPLE_ARM
36710	constant GL_FRAGMENT_SHADER_FRAMEBUFFER_FETCH_MRT_ARM
1	constant GL_ARM_shader_framebuffer_fetch_depth_stencil
1	constant GL_DMP_program_binary
37457	constant GL_SMAPHS30_PROGRAM_BINARY_DMP
37458	constant GL_SMAPHS_PROGRAM_BINARY_DMP
37459	constant GL_DMP_PROGRAM_BINARY_DMP
1	constant GL_DMP_shader_binary
37456	constant GL_SHADER_BINARY_DMP
1	constant GL_EXT_blend_minmax
32775	constant GL_MIN_EXT
32776	constant GL_MAX_EXT
1	constant GL_EXT_color_buffer_half_float
34842	constant GL_RGBA16F_EXT
34843	constant GL_RGB16F_EXT
33327	constant GL_RG16F_EXT
33325	constant GL_R16F_EXT
33297	constant GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE_EXT
35863	constant GL_UNSIGNED_NORMALIZED_EXT
1	constant GL_EXT_copy_image
1	constant GL_EXT_debug_label
35407	constant GL_PROGRAM_PIPELINE_OBJECT_EXT
35648	constant GL_PROGRAM_OBJECT_EXT
35656	constant GL_SHADER_OBJECT_EXT
37201	constant GL_BUFFER_OBJECT_EXT
37203	constant GL_QUERY_OBJECT_EXT
37204	constant GL_VERTEX_ARRAY_OBJECT_EXT
36386	constant GL_TRANSFORM_FEEDBACK
1	constant GL_EXT_debug_marker
1	constant GL_EXT_discard_framebuffer
6144	constant GL_COLOR_EXT
6145	constant GL_DEPTH_EXT
6146	constant GL_STENCIL_EXT
1	constant GL_EXT_disjoint_timer_query
34916	constant GL_QUERY_COUNTER_BITS_EXT
34917	constant GL_CURRENT_QUERY_EXT
34918	constant GL_QUERY_RESULT_EXT
34919	constant GL_QUERY_RESULT_AVAILABLE_EXT
35007	constant GL_TIME_ELAPSED_EXT
36392	constant GL_TIMESTAMP_EXT
36795	constant GL_GPU_DISJOINT_EXT
1	constant GL_EXT_draw_buffers
36063	constant GL_MAX_COLOR_ATTACHMENTS_EXT
34852	constant GL_MAX_DRAW_BUFFERS_EXT
34853	constant GL_DRAW_BUFFER0_EXT
34854	constant GL_DRAW_BUFFER1_EXT
34855	constant GL_DRAW_BUFFER2_EXT
34856	constant GL_DRAW_BUFFER3_EXT
34857	constant GL_DRAW_BUFFER4_EXT
34858	constant GL_DRAW_BUFFER5_EXT
34859	constant GL_DRAW_BUFFER6_EXT
34860	constant GL_DRAW_BUFFER7_EXT
34861	constant GL_DRAW_BUFFER8_EXT
34862	constant GL_DRAW_BUFFER9_EXT
34863	constant GL_DRAW_BUFFER10_EXT
34864	constant GL_DRAW_BUFFER11_EXT
34865	constant GL_DRAW_BUFFER12_EXT
34866	constant GL_DRAW_BUFFER13_EXT
34867	constant GL_DRAW_BUFFER14_EXT
34868	constant GL_DRAW_BUFFER15_EXT
36064	constant GL_COLOR_ATTACHMENT0_EXT
36065	constant GL_COLOR_ATTACHMENT1_EXT
36066	constant GL_COLOR_ATTACHMENT2_EXT
36067	constant GL_COLOR_ATTACHMENT3_EXT
36068	constant GL_COLOR_ATTACHMENT4_EXT
36069	constant GL_COLOR_ATTACHMENT5_EXT
36070	constant GL_COLOR_ATTACHMENT6_EXT
36071	constant GL_COLOR_ATTACHMENT7_EXT
36072	constant GL_COLOR_ATTACHMENT8_EXT
36073	constant GL_COLOR_ATTACHMENT9_EXT
36074	constant GL_COLOR_ATTACHMENT10_EXT
36075	constant GL_COLOR_ATTACHMENT11_EXT
36076	constant GL_COLOR_ATTACHMENT12_EXT
36077	constant GL_COLOR_ATTACHMENT13_EXT
36078	constant GL_COLOR_ATTACHMENT14_EXT
36079	constant GL_COLOR_ATTACHMENT15_EXT
1	constant GL_EXT_draw_buffers_indexed
32775	constant GL_MIN
32776	constant GL_MAX
1	constant GL_EXT_draw_instanced
1	constant GL_EXT_geometry_point_size
1	constant GL_EXT_geometry_shader
36313	constant GL_GEOMETRY_SHADER_EXT
4	constant GL_GEOMETRY_SHADER_BIT_EXT
35094	constant GL_GEOMETRY_LINKED_VERTICES_OUT_EXT
35095	constant GL_GEOMETRY_LINKED_INPUT_TYPE_EXT
35096	constant GL_GEOMETRY_LINKED_OUTPUT_TYPE_EXT
34943	constant GL_GEOMETRY_SHADER_INVOCATIONS_EXT
33374	constant GL_LAYER_PROVOKING_VERTEX_EXT
10	constant GL_LINES_ADJACENCY_EXT
11	constant GL_LINE_STRIP_ADJACENCY_EXT
12	constant GL_TRIANGLES_ADJACENCY_EXT
13	constant GL_TRIANGLE_STRIP_ADJACENCY_EXT
36319	constant GL_MAX_GEOMETRY_UNIFORM_COMPONENTS_EXT
35372	constant GL_MAX_GEOMETRY_UNIFORM_BLOCKS_EXT
35378	constant GL_MAX_COMBINED_GEOMETRY_UNIFORM_COMPONENTS_EXT
37155	constant GL_MAX_GEOMETRY_INPUT_COMPONENTS_EXT
37156	constant GL_MAX_GEOMETRY_OUTPUT_COMPONENTS_EXT
36320	constant GL_MAX_GEOMETRY_OUTPUT_VERTICES_EXT
36321	constant GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS_EXT
36442	constant GL_MAX_GEOMETRY_SHADER_INVOCATIONS_EXT
35881	constant GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS_EXT
37583	constant GL_MAX_GEOMETRY_ATOMIC_COUNTER_BUFFERS_EXT
37589	constant GL_MAX_GEOMETRY_ATOMIC_COUNTERS_EXT
37069	constant GL_MAX_GEOMETRY_IMAGE_UNIFORMS_EXT
37079	constant GL_MAX_GEOMETRY_SHADER_STORAGE_BLOCKS_EXT
36429	constant GL_FIRST_VERTEX_CONVENTION_EXT
36430	constant GL_LAST_VERTEX_CONVENTION_EXT
33376	constant GL_UNDEFINED_VERTEX_EXT
35975	constant GL_PRIMITIVES_GENERATED_EXT
37650	constant GL_FRAMEBUFFER_DEFAULT_LAYERS_EXT
37655	constant GL_MAX_FRAMEBUFFER_LAYERS_EXT
36264	constant GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS_EXT
36263	constant GL_FRAMEBUFFER_ATTACHMENT_LAYERED_EXT
37641	constant GL_REFERENCED_BY_GEOMETRY_SHADER_EXT
1	constant GL_EXT_gpu_shader5
1	constant GL_EXT_instanced_arrays
35070	constant GL_VERTEX_ATTRIB_ARRAY_DIVISOR_EXT
1	constant GL_EXT_map_buffer_range
1	constant GL_MAP_READ_BIT_EXT
2	constant GL_MAP_WRITE_BIT_EXT
4	constant GL_MAP_INVALIDATE_RANGE_BIT_EXT
8	constant GL_MAP_INVALIDATE_BUFFER_BIT_EXT
16	constant GL_MAP_FLUSH_EXPLICIT_BIT_EXT
32	constant GL_MAP_UNSYNCHRONIZED_BIT_EXT
1	constant GL_EXT_multi_draw_arrays
1	constant GL_EXT_multisampled_render_to_texture
36204	constant GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_SAMPLES_EXT
36011	constant GL_RENDERBUFFER_SAMPLES_EXT
36182	constant GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE_EXT
36183	constant GL_MAX_SAMPLES_EXT
1	constant GL_EXT_multiview_draw_buffers
37104	constant GL_COLOR_ATTACHMENT_EXT
37105	constant GL_MULTIVIEW_EXT
3073	constant GL_DRAW_BUFFER_EXT
3074	constant GL_READ_BUFFER_EXT
37106	constant GL_MAX_MULTIVIEW_BUFFERS_EXT
1	constant GL_EXT_occlusion_query_boolean
35887	constant GL_ANY_SAMPLES_PASSED_EXT
36202	constant GL_ANY_SAMPLES_PASSED_CONSERVATIVE_EXT
1	constant GL_EXT_primitive_bounding_box
37566	constant GL_PRIMITIVE_BOUNDING_BOX_EXT
1	constant GL_EXT_pvrtc_sRGB
35412	constant GL_COMPRESSED_SRGB_PVRTC_2BPPV1_EXT
35413	constant GL_COMPRESSED_SRGB_PVRTC_4BPPV1_EXT
35414	constant GL_COMPRESSED_SRGB_ALPHA_PVRTC_2BPPV1_EXT
35415	constant GL_COMPRESSED_SRGB_ALPHA_PVRTC_4BPPV1_EXT
37872	constant GL_COMPRESSED_SRGB_ALPHA_PVRTC_2BPPV2_IMG
37873	constant GL_COMPRESSED_SRGB_ALPHA_PVRTC_4BPPV2_IMG
1	constant GL_EXT_read_format_bgra
33637	constant GL_UNSIGNED_SHORT_4_4_4_4_REV_EXT
33638	constant GL_UNSIGNED_SHORT_1_5_5_5_REV_EXT
1	constant GL_EXT_robustness
33363	constant GL_GUILTY_CONTEXT_RESET_EXT
33364	constant GL_INNOCENT_CONTEXT_RESET_EXT
33365	constant GL_UNKNOWN_CONTEXT_RESET_EXT
37107	constant GL_CONTEXT_ROBUST_ACCESS_EXT
33366	constant GL_RESET_NOTIFICATION_STRATEGY_EXT
33362	constant GL_LOSE_CONTEXT_ON_RESET_EXT
33377	constant GL_NO_RESET_NOTIFICATION_EXT
1	constant GL_EXT_sRGB
35904	constant GL_SRGB_EXT
35906	constant GL_SRGB_ALPHA_EXT
35907	constant GL_SRGB8_ALPHA8_EXT
33296	constant GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING_EXT
1	constant GL_EXT_sRGB_write_control
36281	constant GL_FRAMEBUFFER_SRGB_EXT
1	constant GL_EXT_separate_shader_objects
33369	constant GL_ACTIVE_PROGRAM_EXT
1	constant GL_VERTEX_SHADER_BIT_EXT
2	constant GL_FRAGMENT_SHADER_BIT_EXT
4294967295	constant GL_ALL_SHADER_BITS_EXT
33368	constant GL_PROGRAM_SEPARABLE_EXT
33370	constant GL_PROGRAM_PIPELINE_BINDING_EXT
1	constant GL_EXT_shader_framebuffer_fetch
35410	constant GL_FRAGMENT_SHADER_DISCARDS_SAMPLES_EXT
1	constant GL_EXT_shader_implicit_conversions
1	constant GL_EXT_shader_integer_mix
1	constant GL_EXT_shader_io_blocks
1	constant GL_EXT_shader_pixel_local_storage
36707	constant GL_MAX_SHADER_PIXEL_LOCAL_STORAGE_FAST_SIZE_EXT
36711	constant GL_MAX_SHADER_PIXEL_LOCAL_STORAGE_SIZE_EXT
36708	constant GL_SHADER_PIXEL_LOCAL_STORAGE_EXT
1	constant GL_EXT_shader_texture_lod
1	constant GL_EXT_shadow_samplers
34892	constant GL_TEXTURE_COMPARE_MODE_EXT
34893	constant GL_TEXTURE_COMPARE_FUNC_EXT
34894	constant GL_COMPARE_REF_TO_TEXTURE_EXT
35682	constant GL_SAMPLER_2D_SHADOW_EXT
1	constant GL_EXT_tessellation_point_size
1	constant GL_EXT_tessellation_shader
14	constant GL_PATCHES_EXT
36466	constant GL_PATCH_VERTICES_EXT
36469	constant GL_TESS_CONTROL_OUTPUT_VERTICES_EXT
36470	constant GL_TESS_GEN_MODE_EXT
36471	constant GL_TESS_GEN_SPACING_EXT
36472	constant GL_TESS_GEN_VERTEX_ORDER_EXT
36473	constant GL_TESS_GEN_POINT_MODE_EXT
36474	constant GL_ISOLINES_EXT
7	constant GL_QUADS_EXT
36475	constant GL_FRACTIONAL_ODD_EXT
36476	constant GL_FRACTIONAL_EVEN_EXT
36477	constant GL_MAX_PATCH_VERTICES_EXT
36478	constant GL_MAX_TESS_GEN_LEVEL_EXT
36479	constant GL_MAX_TESS_CONTROL_UNIFORM_COMPONENTS_EXT
36480	constant GL_MAX_TESS_EVALUATION_UNIFORM_COMPONENTS_EXT
36481	constant GL_MAX_TESS_CONTROL_TEXTURE_IMAGE_UNITS_EXT
36482	constant GL_MAX_TESS_EVALUATION_TEXTURE_IMAGE_UNITS_EXT
36483	constant GL_MAX_TESS_CONTROL_OUTPUT_COMPONENTS_EXT
36484	constant GL_MAX_TESS_PATCH_COMPONENTS_EXT
36485	constant GL_MAX_TESS_CONTROL_TOTAL_OUTPUT_COMPONENTS_EXT
36486	constant GL_MAX_TESS_EVALUATION_OUTPUT_COMPONENTS_EXT
36489	constant GL_MAX_TESS_CONTROL_UNIFORM_BLOCKS_EXT
36490	constant GL_MAX_TESS_EVALUATION_UNIFORM_BLOCKS_EXT
34924	constant GL_MAX_TESS_CONTROL_INPUT_COMPONENTS_EXT
34925	constant GL_MAX_TESS_EVALUATION_INPUT_COMPONENTS_EXT
36382	constant GL_MAX_COMBINED_TESS_CONTROL_UNIFORM_COMPONENTS_EXT
36383	constant GL_MAX_COMBINED_TESS_EVALUATION_UNIFORM_COMPONENTS_EXT
37581	constant GL_MAX_TESS_CONTROL_ATOMIC_COUNTER_BUFFERS_EXT
37582	constant GL_MAX_TESS_EVALUATION_ATOMIC_COUNTER_BUFFERS_EXT
37587	constant GL_MAX_TESS_CONTROL_ATOMIC_COUNTERS_EXT
37588	constant GL_MAX_TESS_EVALUATION_ATOMIC_COUNTERS_EXT
37067	constant GL_MAX_TESS_CONTROL_IMAGE_UNIFORMS_EXT
37068	constant GL_MAX_TESS_EVALUATION_IMAGE_UNIFORMS_EXT
37080	constant GL_MAX_TESS_CONTROL_SHADER_STORAGE_BLOCKS_EXT
37081	constant GL_MAX_TESS_EVALUATION_SHADER_STORAGE_BLOCKS_EXT
33313	constant GL_PRIMITIVE_RESTART_FOR_PATCHES_SUPPORTED
37607	constant GL_IS_PER_PATCH_EXT
37639	constant GL_REFERENCED_BY_TESS_CONTROL_SHADER_EXT
37640	constant GL_REFERENCED_BY_TESS_EVALUATION_SHADER_EXT
36488	constant GL_TESS_CONTROL_SHADER_EXT
36487	constant GL_TESS_EVALUATION_SHADER_EXT
8	constant GL_TESS_CONTROL_SHADER_BIT_EXT
16	constant GL_TESS_EVALUATION_SHADER_BIT_EXT
1	constant GL_EXT_texture_border_clamp
4100	constant GL_TEXTURE_BORDER_COLOR_EXT
33069	constant GL_CLAMP_TO_BORDER_EXT
1	constant GL_EXT_texture_buffer
35882	constant GL_TEXTURE_BUFFER_EXT
35882	constant GL_TEXTURE_BUFFER_BINDING_EXT
35883	constant GL_MAX_TEXTURE_BUFFER_SIZE_EXT
35884	constant GL_TEXTURE_BINDING_BUFFER_EXT
35885	constant GL_TEXTURE_BUFFER_DATA_STORE_BINDING_EXT
37279	constant GL_TEXTURE_BUFFER_OFFSET_ALIGNMENT_EXT
36290	constant GL_SAMPLER_BUFFER_EXT
36304	constant GL_INT_SAMPLER_BUFFER_EXT
36312	constant GL_UNSIGNED_INT_SAMPLER_BUFFER_EXT
36945	constant GL_IMAGE_BUFFER_EXT
36956	constant GL_INT_IMAGE_BUFFER_EXT
36967	constant GL_UNSIGNED_INT_IMAGE_BUFFER_EXT
37277	constant GL_TEXTURE_BUFFER_OFFSET_EXT
37278	constant GL_TEXTURE_BUFFER_SIZE_EXT
1	constant GL_EXT_texture_compression_dxt1
33776	constant GL_COMPRESSED_RGB_S3TC_DXT1_EXT
33777	constant GL_COMPRESSED_RGBA_S3TC_DXT1_EXT
1	constant GL_EXT_texture_compression_s3tc
33778	constant GL_COMPRESSED_RGBA_S3TC_DXT3_EXT
33779	constant GL_COMPRESSED_RGBA_S3TC_DXT5_EXT
1	constant GL_EXT_texture_cube_map_array
36873	constant GL_TEXTURE_CUBE_MAP_ARRAY_EXT
36874	constant GL_TEXTURE_BINDING_CUBE_MAP_ARRAY_EXT
36876	constant GL_SAMPLER_CUBE_MAP_ARRAY_EXT
36877	constant GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW_EXT
36878	constant GL_INT_SAMPLER_CUBE_MAP_ARRAY_EXT
36879	constant GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY_EXT
36948	constant GL_IMAGE_CUBE_MAP_ARRAY_EXT
36959	constant GL_INT_IMAGE_CUBE_MAP_ARRAY_EXT
36970	constant GL_UNSIGNED_INT_IMAGE_CUBE_MAP_ARRAY_EXT
1	constant GL_EXT_texture_filter_anisotropic
34046	constant GL_TEXTURE_MAX_ANISOTROPY_EXT
34047	constant GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT
1	constant GL_EXT_texture_format_BGRA8888
1	constant GL_EXT_texture_rg
6403	constant GL_RED_EXT
33319	constant GL_RG_EXT
33321	constant GL_R8_EXT
33323	constant GL_RG8_EXT
1	constant GL_EXT_texture_sRGB_decode
35400	constant GL_TEXTURE_SRGB_DECODE_EXT
35401	constant GL_DECODE_EXT
35402	constant GL_SKIP_DECODE_EXT
1	constant GL_EXT_texture_storage
37167	constant GL_TEXTURE_IMMUTABLE_FORMAT_EXT
32828	constant GL_ALPHA8_EXT
32832	constant GL_LUMINANCE8_EXT
32837	constant GL_LUMINANCE8_ALPHA8_EXT
34836	constant GL_RGBA32F_EXT
34837	constant GL_RGB32F_EXT
34838	constant GL_ALPHA32F_EXT
34840	constant GL_LUMINANCE32F_EXT
34841	constant GL_LUMINANCE_ALPHA32F_EXT
34844	constant GL_ALPHA16F_EXT
34846	constant GL_LUMINANCE16F_EXT
34847	constant GL_LUMINANCE_ALPHA16F_EXT
33326	constant GL_R32F_EXT
33328	constant GL_RG32F_EXT
1	constant GL_EXT_texture_type_2_10_10_10_REV
33640	constant GL_UNSIGNED_INT_2_10_10_10_REV_EXT
1	constant GL_EXT_texture_view
33499	constant GL_TEXTURE_VIEW_MIN_LEVEL_EXT
33500	constant GL_TEXTURE_VIEW_NUM_LEVELS_EXT
33501	constant GL_TEXTURE_VIEW_MIN_LAYER_EXT
33502	constant GL_TEXTURE_VIEW_NUM_LAYERS_EXT
33503	constant GL_TEXTURE_IMMUTABLE_LEVELS
1	constant GL_EXT_unpack_subimage
3314	constant GL_UNPACK_ROW_LENGTH_EXT
3315	constant GL_UNPACK_SKIP_ROWS_EXT
3316	constant GL_UNPACK_SKIP_PIXELS_EXT
1	constant GL_FJ_shader_binary_GCCSO
37472	constant GL_GCCSO_SHADER_BINARY_FJ
1	constant GL_IMG_multisampled_render_to_texture
37171	constant GL_RENDERBUFFER_SAMPLES_IMG
37172	constant GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE_IMG
37173	constant GL_MAX_SAMPLES_IMG
37174	constant GL_TEXTURE_SAMPLES_IMG
1	constant GL_IMG_program_binary
37168	constant GL_SGX_PROGRAM_BINARY_IMG
1	constant GL_IMG_read_format
32993	constant GL_BGRA_IMG
33637	constant GL_UNSIGNED_SHORT_4_4_4_4_REV_IMG
1	constant GL_IMG_shader_binary
35850	constant GL_SGX_BINARY_IMG
1	constant GL_IMG_texture_compression_pvrtc
35840	constant GL_COMPRESSED_RGB_PVRTC_4BPPV1_IMG
35841	constant GL_COMPRESSED_RGB_PVRTC_2BPPV1_IMG
35842	constant GL_COMPRESSED_RGBA_PVRTC_4BPPV1_IMG
35843	constant GL_COMPRESSED_RGBA_PVRTC_2BPPV1_IMG
1	constant GL_IMG_texture_compression_pvrtc2
37175	constant GL_COMPRESSED_RGBA_PVRTC_2BPPV2_IMG
37176	constant GL_COMPRESSED_RGBA_PVRTC_4BPPV2_IMG
1	constant GL_INTEL_performance_query
0	constant GL_PERFQUERY_SINGLE_CONTEXT_INTEL
1	constant GL_PERFQUERY_GLOBAL_CONTEXT_INTEL
33787	constant GL_PERFQUERY_WAIT_INTEL
33786	constant GL_PERFQUERY_FLUSH_INTEL
33785	constant GL_PERFQUERY_DONOT_FLUSH_INTEL
38128	constant GL_PERFQUERY_COUNTER_EVENT_INTEL
38129	constant GL_PERFQUERY_COUNTER_DURATION_NORM_INTEL
38130	constant GL_PERFQUERY_COUNTER_DURATION_RAW_INTEL
38131	constant GL_PERFQUERY_COUNTER_THROUGHPUT_INTEL
38132	constant GL_PERFQUERY_COUNTER_RAW_INTEL
38133	constant GL_PERFQUERY_COUNTER_TIMESTAMP_INTEL
38136	constant GL_PERFQUERY_COUNTER_DATA_UINT32_INTEL
38137	constant GL_PERFQUERY_COUNTER_DATA_UINT64_INTEL
38138	constant GL_PERFQUERY_COUNTER_DATA_FLOAT_INTEL
38139	constant GL_PERFQUERY_COUNTER_DATA_DOUBLE_INTEL
38140	constant GL_PERFQUERY_COUNTER_DATA_BOOL32_INTEL
38141	constant GL_PERFQUERY_QUERY_NAME_LENGTH_MAX_INTEL
38142	constant GL_PERFQUERY_COUNTER_NAME_LENGTH_MAX_INTEL
38143	constant GL_PERFQUERY_COUNTER_DESC_LENGTH_MAX_INTEL
38144	constant GL_PERFQUERY_GPA_EXTENDED_COUNTERS_INTEL
1	constant GL_NV_blend_equation_advanced
37505	constant GL_BLEND_OVERLAP_NV
37504	constant GL_BLEND_PREMULTIPLIED_SRC_NV
6405	constant GL_BLUE_NV
37530	constant GL_COLORBURN_NV
37529	constant GL_COLORDODGE_NV
37508	constant GL_CONJOINT_NV
37537	constant GL_CONTRAST_NV
37527	constant GL_DARKEN_NV
37534	constant GL_DIFFERENCE_NV
37507	constant GL_DISJOINT_NV
37519	constant GL_DST_ATOP_NV
37515	constant GL_DST_IN_NV
37511	constant GL_DST_NV
37517	constant GL_DST_OUT_NV
37513	constant GL_DST_OVER_NV
37536	constant GL_EXCLUSION_NV
6404	constant GL_GREEN_NV
37531	constant GL_HARDLIGHT_NV
37545	constant GL_HARDMIX_NV
37551	constant GL_HSL_COLOR_NV
37549	constant GL_HSL_HUE_NV
37552	constant GL_HSL_LUMINOSITY_NV
37550	constant GL_HSL_SATURATION_NV
37556	constant GL_INVERT_OVG_NV
37539	constant GL_INVERT_RGB_NV
37528	constant GL_LIGHTEN_NV
37541	constant GL_LINEARBURN_NV
37540	constant GL_LINEARDODGE_NV
37543	constant GL_LINEARLIGHT_NV
37555	constant GL_MINUS_CLAMPED_NV
37535	constant GL_MINUS_NV
37524	constant GL_MULTIPLY_NV
37526	constant GL_OVERLAY_NV
37544	constant GL_PINLIGHT_NV
37554	constant GL_PLUS_CLAMPED_ALPHA_NV
37553	constant GL_PLUS_CLAMPED_NV
37522	constant GL_PLUS_DARKER_NV
37521	constant GL_PLUS_NV
6403	constant GL_RED_NV
37525	constant GL_SCREEN_NV
37532	constant GL_SOFTLIGHT_NV
37518	constant GL_SRC_ATOP_NV
37514	constant GL_SRC_IN_NV
37510	constant GL_SRC_NV
37516	constant GL_SRC_OUT_NV
37512	constant GL_SRC_OVER_NV
37506	constant GL_UNCORRELATED_NV
37542	constant GL_VIVIDLIGHT_NV
5382	constant GL_XOR_NV
1	constant GL_NV_blend_equation_advanced_coherent
37509	constant GL_BLEND_ADVANCED_COHERENT_NV
1	constant GL_NV_copy_buffer
36662	constant GL_COPY_READ_BUFFER_NV
36663	constant GL_COPY_WRITE_BUFFER_NV
1	constant GL_NV_coverage_sample
36560	constant GL_COVERAGE_COMPONENT_NV
36561	constant GL_COVERAGE_COMPONENT4_NV
36562	constant GL_COVERAGE_ATTACHMENT_NV
36563	constant GL_COVERAGE_BUFFERS_NV
36564	constant GL_COVERAGE_SAMPLES_NV
36565	constant GL_COVERAGE_ALL_FRAGMENTS_NV
36566	constant GL_COVERAGE_EDGE_FRAGMENTS_NV
36567	constant GL_COVERAGE_AUTOMATIC_NV
32768	constant GL_COVERAGE_BUFFER_BIT_NV
1	constant GL_NV_depth_nonlinear
36396	constant GL_DEPTH_COMPONENT16_NONLINEAR_NV
1	constant GL_NV_draw_buffers
34852	constant GL_MAX_DRAW_BUFFERS_NV
34853	constant GL_DRAW_BUFFER0_NV
34854	constant GL_DRAW_BUFFER1_NV
34855	constant GL_DRAW_BUFFER2_NV
34856	constant GL_DRAW_BUFFER3_NV
34857	constant GL_DRAW_BUFFER4_NV
34858	constant GL_DRAW_BUFFER5_NV
34859	constant GL_DRAW_BUFFER6_NV
34860	constant GL_DRAW_BUFFER7_NV
34861	constant GL_DRAW_BUFFER8_NV
34862	constant GL_DRAW_BUFFER9_NV
34863	constant GL_DRAW_BUFFER10_NV
34864	constant GL_DRAW_BUFFER11_NV
34865	constant GL_DRAW_BUFFER12_NV
34866	constant GL_DRAW_BUFFER13_NV
34867	constant GL_DRAW_BUFFER14_NV
34868	constant GL_DRAW_BUFFER15_NV
36064	constant GL_COLOR_ATTACHMENT0_NV
36065	constant GL_COLOR_ATTACHMENT1_NV
36066	constant GL_COLOR_ATTACHMENT2_NV
36067	constant GL_COLOR_ATTACHMENT3_NV
36068	constant GL_COLOR_ATTACHMENT4_NV
36069	constant GL_COLOR_ATTACHMENT5_NV
36070	constant GL_COLOR_ATTACHMENT6_NV
36071	constant GL_COLOR_ATTACHMENT7_NV
36072	constant GL_COLOR_ATTACHMENT8_NV
36073	constant GL_COLOR_ATTACHMENT9_NV
36074	constant GL_COLOR_ATTACHMENT10_NV
36075	constant GL_COLOR_ATTACHMENT11_NV
36076	constant GL_COLOR_ATTACHMENT12_NV
36077	constant GL_COLOR_ATTACHMENT13_NV
36078	constant GL_COLOR_ATTACHMENT14_NV
36079	constant GL_COLOR_ATTACHMENT15_NV
1	constant GL_NV_draw_instanced
1	constant GL_NV_explicit_attrib_location
1	constant GL_NV_fbo_color_attachments
36063	constant GL_MAX_COLOR_ATTACHMENTS_NV
1	constant GL_NV_fence
34034	constant GL_ALL_COMPLETED_NV
34035	constant GL_FENCE_STATUS_NV
34036	constant GL_FENCE_CONDITION_NV
1	constant GL_NV_framebuffer_blit
36008	constant GL_READ_FRAMEBUFFER_NV
36009	constant GL_DRAW_FRAMEBUFFER_NV
36006	constant GL_DRAW_FRAMEBUFFER_BINDING_NV
36010	constant GL_READ_FRAMEBUFFER_BINDING_NV
1	constant GL_NV_framebuffer_multisample
36011	constant GL_RENDERBUFFER_SAMPLES_NV
36182	constant GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE_NV
36183	constant GL_MAX_SAMPLES_NV
1	constant GL_NV_generate_mipmap_sRGB
1	constant GL_NV_instanced_arrays
35070	constant GL_VERTEX_ATTRIB_ARRAY_DIVISOR_NV
1	constant GL_NV_non_square_matrices
35685	constant GL_FLOAT_MAT2x3_NV
35686	constant GL_FLOAT_MAT2x4_NV
35687	constant GL_FLOAT_MAT3x2_NV
35688	constant GL_FLOAT_MAT3x4_NV
35689	constant GL_FLOAT_MAT4x2_NV
35690	constant GL_FLOAT_MAT4x3_NV
1	constant GL_NV_read_buffer
3074	constant GL_READ_BUFFER_NV
1	constant GL_NV_read_buffer_front
1	constant GL_NV_read_depth
1	constant GL_NV_read_depth_stencil
1	constant GL_NV_read_stencil
1	constant GL_NV_sRGB_formats
35910	constant GL_SLUMINANCE_NV
35908	constant GL_SLUMINANCE_ALPHA_NV
35905	constant GL_SRGB8_NV
35911	constant GL_SLUMINANCE8_NV
35909	constant GL_SLUMINANCE8_ALPHA8_NV
35916	constant GL_COMPRESSED_SRGB_S3TC_DXT1_NV
35917	constant GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_NV
35918	constant GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_NV
35919	constant GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_NV
35054	constant GL_ETC1_SRGB8_NV
1	constant GL_NV_shadow_samplers_array
36292	constant GL_SAMPLER_2D_ARRAY_SHADOW_NV
1	constant GL_NV_shadow_samplers_cube
36293	constant GL_SAMPLER_CUBE_SHADOW_NV
1	constant GL_NV_texture_border_clamp
4100	constant GL_TEXTURE_BORDER_COLOR_NV
33069	constant GL_CLAMP_TO_BORDER_NV
1	constant GL_NV_texture_compression_s3tc_update
1	constant GL_NV_texture_npot_2D_mipmap
1	constant GL_QCOM_alpha_test
3008	constant GL_ALPHA_TEST_QCOM
3009	constant GL_ALPHA_TEST_FUNC_QCOM
3010	constant GL_ALPHA_TEST_REF_QCOM
1	constant GL_QCOM_binning_control
36784	constant GL_BINNING_CONTROL_HINT_QCOM
36785	constant GL_CPU_OPTIMIZED_QCOM
36786	constant GL_GPU_OPTIMIZED_QCOM
36787	constant GL_RENDER_DIRECT_TO_FRAMEBUFFER_QCOM
1	constant GL_QCOM_driver_control
1	constant GL_QCOM_extended_get
35794	constant GL_TEXTURE_WIDTH_QCOM
35795	constant GL_TEXTURE_HEIGHT_QCOM
35796	constant GL_TEXTURE_DEPTH_QCOM
35797	constant GL_TEXTURE_INTERNAL_FORMAT_QCOM
35798	constant GL_TEXTURE_FORMAT_QCOM
35799	constant GL_TEXTURE_TYPE_QCOM
35800	constant GL_TEXTURE_IMAGE_VALID_QCOM
35801	constant GL_TEXTURE_NUM_LEVELS_QCOM
35802	constant GL_TEXTURE_TARGET_QCOM
35803	constant GL_TEXTURE_OBJECT_VALID_QCOM
35804	constant GL_STATE_RESTORE
1	constant GL_QCOM_extended_get2
1	constant GL_QCOM_perfmon_global_mode
36768	constant GL_PERFMON_GLOBAL_MODE_QCOM
1	constant GL_QCOM_tiled_rendering
1	constant GL_COLOR_BUFFER_BIT0_QCOM
2	constant GL_COLOR_BUFFER_BIT1_QCOM
4	constant GL_COLOR_BUFFER_BIT2_QCOM
8	constant GL_COLOR_BUFFER_BIT3_QCOM
16	constant GL_COLOR_BUFFER_BIT4_QCOM
32	constant GL_COLOR_BUFFER_BIT5_QCOM
64	constant GL_COLOR_BUFFER_BIT6_QCOM
128	constant GL_COLOR_BUFFER_BIT7_QCOM
256	constant GL_DEPTH_BUFFER_BIT0_QCOM
512	constant GL_DEPTH_BUFFER_BIT1_QCOM
1024	constant GL_DEPTH_BUFFER_BIT2_QCOM
2048	constant GL_DEPTH_BUFFER_BIT3_QCOM
4096	constant GL_DEPTH_BUFFER_BIT4_QCOM
8192	constant GL_DEPTH_BUFFER_BIT5_QCOM
16384	constant GL_DEPTH_BUFFER_BIT6_QCOM
32768	constant GL_DEPTH_BUFFER_BIT7_QCOM
65536	constant GL_STENCIL_BUFFER_BIT0_QCOM
131072	constant GL_STENCIL_BUFFER_BIT1_QCOM
262144	constant GL_STENCIL_BUFFER_BIT2_QCOM
524288	constant GL_STENCIL_BUFFER_BIT3_QCOM
1048576	constant GL_STENCIL_BUFFER_BIT4_QCOM
2097152	constant GL_STENCIL_BUFFER_BIT5_QCOM
4194304	constant GL_STENCIL_BUFFER_BIT6_QCOM
8388608	constant GL_STENCIL_BUFFER_BIT7_QCOM
16777216	constant GL_MULTISAMPLE_BUFFER_BIT0_QCOM
33554432	constant GL_MULTISAMPLE_BUFFER_BIT1_QCOM
67108864	constant GL_MULTISAMPLE_BUFFER_BIT2_QCOM
134217728	constant GL_MULTISAMPLE_BUFFER_BIT3_QCOM
268435456	constant GL_MULTISAMPLE_BUFFER_BIT4_QCOM
536870912	constant GL_MULTISAMPLE_BUFFER_BIT5_QCOM
1073741824	constant GL_MULTISAMPLE_BUFFER_BIT6_QCOM
2147483648	constant GL_MULTISAMPLE_BUFFER_BIT7_QCOM
1	constant GL_QCOM_writeonly_rendering
34851	constant GL_WRITEONLY_RENDERING_QCOM
1	constant GL_VIV_shader_binary
36804	constant GL_SHADER_BINARY_VIV

\ ----===< long constants ===>-----
18446744073709551615.	2constant GL_TIMEOUT_IGNORED_APPLE

\ ------===< functions >===-------
c-function glActiveTexture glActiveTexture u -- void
c-function glAttachShader glAttachShader u u -- void
c-function glBindAttribLocation glBindAttribLocation u u a -- void
c-function glBindBuffer glBindBuffer u u -- void
c-function glBindFramebuffer glBindFramebuffer u u -- void
c-function glBindRenderbuffer glBindRenderbuffer u u -- void
c-function glBindTexture glBindTexture u u -- void
c-function glBlendColor glBlendColor r r r r -- void
c-function glBlendEquation glBlendEquation u -- void
c-function glBlendEquationSeparate glBlendEquationSeparate u u -- void
c-function glBlendFunc glBlendFunc u u -- void
c-function glBlendFuncSeparate glBlendFuncSeparate u u u u -- void
c-function glBufferData glBufferData u n a u -- void
c-function glBufferSubData glBufferSubData u n n a -- void
c-function glCheckFramebufferStatus glCheckFramebufferStatus u -- u
c-function glClear glClear u -- void
c-function glClearColor glClearColor r r r r -- void
c-function glClearDepthf glClearDepthf r -- void
c-function glClearStencil glClearStencil n -- void
c-function glColorMask glColorMask n n n n -- void
c-function glCompileShader glCompileShader u -- void
c-function glCompressedTexImage2D glCompressedTexImage2D u n u n n n n a -- void
c-function glCompressedTexSubImage2D glCompressedTexSubImage2D u n n n n n u n a -- void
c-function glCopyTexImage2D glCopyTexImage2D u n u n n n n n -- void
c-function glCopyTexSubImage2D glCopyTexSubImage2D u n n n n n n n -- void
c-function glCreateProgram glCreateProgram  -- u
c-function glCreateShader glCreateShader u -- u
c-function glCullFace glCullFace u -- void
c-function glDeleteBuffers glDeleteBuffers n a -- void
c-function glDeleteFramebuffers glDeleteFramebuffers n a -- void
c-function glDeleteProgram glDeleteProgram u -- void
c-function glDeleteRenderbuffers glDeleteRenderbuffers n a -- void
c-function glDeleteShader glDeleteShader u -- void
c-function glDeleteTextures glDeleteTextures n a -- void
c-function glDepthFunc glDepthFunc u -- void
c-function glDepthMask glDepthMask n -- void
c-function glDepthRangef glDepthRangef r r -- void
c-function glDetachShader glDetachShader u u -- void
c-function glDisable glDisable u -- void
c-function glDisableVertexAttribArray glDisableVertexAttribArray u -- void
c-function glDrawArrays glDrawArrays u n n -- void
c-function glDrawElements glDrawElements u n u a -- void
c-function glEnable glEnable u -- void
c-function glEnableVertexAttribArray glEnableVertexAttribArray u -- void
c-function glFinish glFinish  -- void
c-function glFlush glFlush  -- void
c-function glFramebufferRenderbuffer glFramebufferRenderbuffer u u u u -- void
c-function glFramebufferTexture2D glFramebufferTexture2D u u u u n -- void
c-function glFrontFace glFrontFace u -- void
c-function glGenBuffers glGenBuffers n a -- void
c-function glGenerateMipmap glGenerateMipmap u -- void
c-function glGenFramebuffers glGenFramebuffers n a -- void
c-function glGenRenderbuffers glGenRenderbuffers n a -- void
c-function glGenTextures glGenTextures n a -- void
c-function glGetActiveAttrib glGetActiveAttrib u u n a a a a -- void
c-function glGetActiveUniform glGetActiveUniform u u n a a a a -- void
c-function glGetAttachedShaders glGetAttachedShaders u n a a -- void
c-function glGetAttribLocation glGetAttribLocation u a -- n
c-function glGetBooleanv glGetBooleanv u a -- void
c-function glGetBufferParameteriv glGetBufferParameteriv u u a -- void
c-function glGetError glGetError  -- u
c-function glGetFloatv glGetFloatv u a -- void
c-function glGetFramebufferAttachmentParameteriv glGetFramebufferAttachmentParameteriv u u u a -- void
c-function glGetIntegerv glGetIntegerv u a -- void
c-function glGetProgramiv glGetProgramiv u u a -- void
c-function glGetProgramInfoLog glGetProgramInfoLog u n a a -- void
c-function glGetRenderbufferParameteriv glGetRenderbufferParameteriv u u a -- void
c-function glGetShaderiv glGetShaderiv u u a -- void
c-function glGetShaderInfoLog glGetShaderInfoLog u n a a -- void
c-function glGetShaderPrecisionFormat glGetShaderPrecisionFormat u u a a -- void
c-function glGetShaderSource glGetShaderSource u n a a -- void
c-function glGetString glGetString u -- a
c-function glGetTexParameterfv glGetTexParameterfv u u a -- void
c-function glGetTexParameteriv glGetTexParameteriv u u a -- void
c-function glGetUniformfv glGetUniformfv u n a -- void
c-function glGetUniformiv glGetUniformiv u n a -- void
c-function glGetUniformLocation glGetUniformLocation u a -- n
c-function glGetVertexAttribfv glGetVertexAttribfv u u a -- void
c-function glGetVertexAttribiv glGetVertexAttribiv u u a -- void
c-function glGetVertexAttribPointerv glGetVertexAttribPointerv u u a -- void
c-function glHint glHint u u -- void
c-function glIsBuffer glIsBuffer u -- n
c-function glIsEnabled glIsEnabled u -- n
c-function glIsFramebuffer glIsFramebuffer u -- n
c-function glIsProgram glIsProgram u -- n
c-function glIsRenderbuffer glIsRenderbuffer u -- n
c-function glIsShader glIsShader u -- n
c-function glIsTexture glIsTexture u -- n
c-function glLineWidth glLineWidth r -- void
c-function glLinkProgram glLinkProgram u -- void
c-function glPixelStorei glPixelStorei u n -- void
c-function glPolygonOffset glPolygonOffset r r -- void
c-function glReadPixels glReadPixels n n n n u u a -- void
c-function glReleaseShaderCompiler glReleaseShaderCompiler  -- void
c-function glRenderbufferStorage glRenderbufferStorage u u n n -- void
c-function glSampleCoverage glSampleCoverage r n -- void
c-function glScissor glScissor n n n n -- void
c-function glShaderBinary glShaderBinary n a u a n -- void
c-function glShaderSource glShaderSource u n a a -- void
c-function glStencilFunc glStencilFunc u n u -- void
c-function glStencilFuncSeparate glStencilFuncSeparate u u n u -- void
c-function glStencilMask glStencilMask u -- void
c-function glStencilMaskSeparate glStencilMaskSeparate u u -- void
c-function glStencilOp glStencilOp u u u -- void
c-function glStencilOpSeparate glStencilOpSeparate u u u u -- void
c-function glTexImage2D glTexImage2D u n n n n n u u a -- void
c-function glTexParameterf glTexParameterf u u r -- void
c-function glTexParameterfv glTexParameterfv u u a -- void
c-function glTexParameteri glTexParameteri u u n -- void
c-function glTexParameteriv glTexParameteriv u u a -- void
c-function glTexSubImage2D glTexSubImage2D u n n n n n u u a -- void
c-function glUniform1f glUniform1f n r -- void
c-function glUniform1fv glUniform1fv n n a -- void
c-function glUniform1i glUniform1i n n -- void
c-function glUniform1iv glUniform1iv n n a -- void
c-function glUniform2f glUniform2f n r r -- void
c-function glUniform2fv glUniform2fv n n a -- void
c-function glUniform2i glUniform2i n n n -- void
c-function glUniform2iv glUniform2iv n n a -- void
c-function glUniform3f glUniform3f n r r r -- void
c-function glUniform3fv glUniform3fv n n a -- void
c-function glUniform3i glUniform3i n n n n -- void
c-function glUniform3iv glUniform3iv n n a -- void
c-function glUniform4f glUniform4f n r r r r -- void
c-function glUniform4fv glUniform4fv n n a -- void
c-function glUniform4i glUniform4i n n n n n -- void
c-function glUniform4iv glUniform4iv n n a -- void
c-function glUniformMatrix2fv glUniformMatrix2fv n n n a -- void
c-function glUniformMatrix3fv glUniformMatrix3fv n n n a -- void
c-function glUniformMatrix4fv glUniformMatrix4fv n n n a -- void
c-function glUseProgram glUseProgram u -- void
c-function glValidateProgram glValidateProgram u -- void
c-function glVertexAttrib1f glVertexAttrib1f u r -- void
c-function glVertexAttrib1fv glVertexAttrib1fv u a -- void
c-function glVertexAttrib2f glVertexAttrib2f u r r -- void
c-function glVertexAttrib2fv glVertexAttrib2fv u a -- void
c-function glVertexAttrib3f glVertexAttrib3f u r r r -- void
c-function glVertexAttrib3fv glVertexAttrib3fv u a -- void
c-function glVertexAttrib4f glVertexAttrib4f u r r r r -- void
c-function glVertexAttrib4fv glVertexAttrib4fv u a -- void
c-function glVertexAttribPointer glVertexAttribPointer u n u n n a -- void
c-function glViewport glViewport n n n n -- void
