#include <gforth/0.7.9_20150820/libcc.h>
#include <termios.h>
#include <sys/ioctl.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <stdio.h>
#include <unistd.h>
#include <fcntl.h>
ptrpair libgfserial_LTX_gforth_c_tcgetattr_na_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=tcgetattr(sp[1],(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfserial_LTX_gforth_c_tcsetattr_nna_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=tcsetattr(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfserial_LTX_gforth_c_cfmakeraw_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  cfmakeraw((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfserial_LTX_gforth_c_cfsetispeed_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=cfsetispeed((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfserial_LTX_gforth_c_cfsetospeed_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=cfsetospeed((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfserial_LTX_gforth_c_tcflow_nn_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=tcflow(sp[1],sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfserial_LTX_gforth_c_ioctl_nna_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=ioctl(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
hash_128 gflibcc_hash_serial = "\x1B\x6E\x9E\xB4\xD0\xF8\xB3\x89\x04\xB5\xFA\xE3\x75\x6C\x70\x21";
