\ This file has been generated using SWIG and fsi,
\ and is already platform dependent, search for the corresponding
\ fsi-file to compile it where no one has compiled it before ;)
\ GForth has its own dynamic loader and doesn't need addional C-Code.
\ That's why this file contains normal Gforth-code( version 0.6.9 or higher )
\ and could be used directly with include or require.
\ As all comments are stripped during the compilation, please
\ insert the copyright notice of the original file here.

\ ----===< int constants ===>-----
11	constant X_PROTOCOL
0	constant X_PROTOCOL_REVISION
0	constant None
1	constant ParentRelative
0	constant CopyFromParent
0	constant PointerWindow
1	constant InputFocus
1	constant PointerRoot
0	constant AnyPropertyType
0	constant AnyKey
0	constant AnyButton
0	constant AllTemporary
0	constant CurrentTime
0	constant NoSymbol
0	constant NoEventMask
1	constant KeyPressMask
2	constant KeyReleaseMask
4	constant ButtonPressMask
8	constant ButtonReleaseMask
16	constant EnterWindowMask
32	constant LeaveWindowMask
64	constant PointerMotionMask
128	constant PointerMotionHintMask
256	constant Button1MotionMask
512	constant Button2MotionMask
1024	constant Button3MotionMask
2048	constant Button4MotionMask
4096	constant Button5MotionMask
8192	constant ButtonMotionMask
16384	constant KeymapStateMask
32768	constant ExposureMask
65536	constant VisibilityChangeMask
131072	constant StructureNotifyMask
262144	constant ResizeRedirectMask
524288	constant SubstructureNotifyMask
1048576	constant SubstructureRedirectMask
2097152	constant FocusChangeMask
4194304	constant PropertyChangeMask
8388608	constant ColormapChangeMask
16777216	constant OwnerGrabButtonMask
2	constant KeyPress
3	constant KeyRelease
4	constant ButtonPress
5	constant ButtonRelease
6	constant MotionNotify
7	constant EnterNotify
8	constant LeaveNotify
9	constant FocusIn
10	constant FocusOut
11	constant KeymapNotify
12	constant Expose
13	constant GraphicsExpose
14	constant NoExpose
15	constant VisibilityNotify
16	constant CreateNotify
17	constant DestroyNotify
18	constant UnmapNotify
19	constant MapNotify
20	constant MapRequest
21	constant ReparentNotify
22	constant ConfigureNotify
23	constant ConfigureRequest
24	constant GravityNotify
25	constant ResizeRequest
26	constant CirculateNotify
27	constant CirculateRequest
28	constant PropertyNotify
29	constant SelectionClear
30	constant SelectionRequest
31	constant SelectionNotify
32	constant ColormapNotify
33	constant ClientMessage
34	constant MappingNotify
35	constant GenericEvent
36	constant LASTEvent
1	constant ShiftMask
2	constant LockMask
4	constant ControlMask
8	constant Mod1Mask
16	constant Mod2Mask
32	constant Mod3Mask
64	constant Mod4Mask
128	constant Mod5Mask
0	constant ShiftMapIndex
1	constant LockMapIndex
2	constant ControlMapIndex
3	constant Mod1MapIndex
4	constant Mod2MapIndex
5	constant Mod3MapIndex
6	constant Mod4MapIndex
7	constant Mod5MapIndex
256	constant Button1Mask
512	constant Button2Mask
1024	constant Button3Mask
2048	constant Button4Mask
4096	constant Button5Mask
32768	constant AnyModifier
1	constant Button1
2	constant Button2
3	constant Button3
4	constant Button4
5	constant Button5
0	constant NotifyNormal
1	constant NotifyGrab
2	constant NotifyUngrab
3	constant NotifyWhileGrabbed
1	constant NotifyHint
0	constant NotifyAncestor
1	constant NotifyVirtual
2	constant NotifyInferior
3	constant NotifyNonlinear
4	constant NotifyNonlinearVirtual
5	constant NotifyPointer
6	constant NotifyPointerRoot
7	constant NotifyDetailNone
0	constant VisibilityUnobscured
1	constant VisibilityPartiallyObscured
2	constant VisibilityFullyObscured
0	constant PlaceOnTop
1	constant PlaceOnBottom
0	constant FamilyInternet
1	constant FamilyDECnet
2	constant FamilyChaos
6	constant FamilyInternet6
5	constant FamilyServerInterpreted
0	constant PropertyNewValue
1	constant PropertyDelete
0	constant ColormapUninstalled
1	constant ColormapInstalled
0	constant GrabModeSync
1	constant GrabModeAsync
0	constant GrabSuccess
1	constant AlreadyGrabbed
2	constant GrabInvalidTime
3	constant GrabNotViewable
4	constant GrabFrozen
0	constant AsyncPointer
1	constant SyncPointer
2	constant ReplayPointer
3	constant AsyncKeyboard
4	constant SyncKeyboard
5	constant ReplayKeyboard
6	constant AsyncBoth
7	constant SyncBoth
2	constant RevertToParent
0	constant Success
1	constant BadRequest
2	constant BadValue
3	constant BadWindow
4	constant BadPixmap
5	constant BadAtom
6	constant BadCursor
7	constant BadFont
8	constant BadMatch
9	constant BadDrawable
10	constant BadAccess
11	constant BadAlloc
12	constant BadColor
13	constant BadGC
14	constant BadIDChoice
15	constant BadName
16	constant BadLength
17	constant BadImplementation
128	constant FirstExtensionError
255	constant LastExtensionError
1	constant InputOutput
2	constant InputOnly
1	constant CWBackPixmap
2	constant CWBackPixel
4	constant CWBorderPixmap
8	constant CWBorderPixel
16	constant CWBitGravity
32	constant CWWinGravity
64	constant CWBackingStore
128	constant CWBackingPlanes
256	constant CWBackingPixel
512	constant CWOverrideRedirect
1024	constant CWSaveUnder
2048	constant CWEventMask
4096	constant CWDontPropagate
8192	constant CWColormap
16384	constant CWCursor
1	constant CWX
2	constant CWY
4	constant CWWidth
8	constant CWHeight
16	constant CWBorderWidth
32	constant CWSibling
64	constant CWStackMode
0	constant ForgetGravity
1	constant NorthWestGravity
2	constant NorthGravity
3	constant NorthEastGravity
4	constant WestGravity
5	constant CenterGravity
6	constant EastGravity
7	constant SouthWestGravity
8	constant SouthGravity
9	constant SouthEastGravity
10	constant StaticGravity
0	constant UnmapGravity
0	constant NotUseful
1	constant WhenMapped
2	constant Always
0	constant IsUnmapped
1	constant IsUnviewable
2	constant IsViewable
0	constant SetModeInsert
1	constant SetModeDelete
0	constant DestroyAll
1	constant RetainPermanent
2	constant RetainTemporary
0	constant Above
1	constant Below
2	constant TopIf
3	constant BottomIf
4	constant Opposite
0	constant RaiseLowest
1	constant LowerHighest
0	constant PropModeReplace
1	constant PropModePrepend
2	constant PropModeAppend
0	constant GXclear
1	constant GXand
2	constant GXandReverse
3	constant GXcopy
4	constant GXandInverted
5	constant GXnoop
6	constant GXxor
7	constant GXor
8	constant GXnor
9	constant GXequiv
10	constant GXinvert
11	constant GXorReverse
12	constant GXcopyInverted
13	constant GXorInverted
14	constant GXnand
15	constant GXset
0	constant LineSolid
1	constant LineOnOffDash
2	constant LineDoubleDash
0	constant CapNotLast
1	constant CapButt
2	constant CapRound
3	constant CapProjecting
0	constant JoinMiter
1	constant JoinRound
2	constant JoinBevel
0	constant FillSolid
1	constant FillTiled
2	constant FillStippled
3	constant FillOpaqueStippled
0	constant EvenOddRule
1	constant WindingRule
0	constant ClipByChildren
1	constant IncludeInferiors
0	constant Unsorted
1	constant YSorted
2	constant YXSorted
3	constant YXBanded
0	constant CoordModeOrigin
1	constant CoordModePrevious
0	constant Complex
1	constant Nonconvex
2	constant Convex
0	constant ArcChord
1	constant ArcPieSlice
1	constant GCFunction
2	constant GCPlaneMask
4	constant GCForeground
8	constant GCBackground
16	constant GCLineWidth
32	constant GCLineStyle
64	constant GCCapStyle
128	constant GCJoinStyle
256	constant GCFillStyle
512	constant GCFillRule
1024	constant GCTile
2048	constant GCStipple
4096	constant GCTileStipXOrigin
8192	constant GCTileStipYOrigin
16384	constant GCFont
32768	constant GCSubwindowMode
65536	constant GCGraphicsExposures
131072	constant GCClipXOrigin
262144	constant GCClipYOrigin
524288	constant GCClipMask
1048576	constant GCDashOffset
2097152	constant GCDashList
4194304	constant GCArcMode
22	constant GCLastBit
0	constant FontLeftToRight
1	constant FontRightToLeft
255	constant FontChange
0	constant XYBitmap
1	constant XYPixmap
2	constant ZPixmap
0	constant AllocNone
1	constant AllocAll
1	constant DoRed
2	constant DoGreen
4	constant DoBlue
0	constant CursorShape
1	constant TileShape
2	constant StippleShape
0	constant AutoRepeatModeOff
1	constant AutoRepeatModeOn
2	constant AutoRepeatModeDefault
0	constant LedModeOff
1	constant LedModeOn
1	constant KBKeyClickPercent
2	constant KBBellPercent
4	constant KBBellPitch
8	constant KBBellDuration
16	constant KBLed
32	constant KBLedMode
64	constant KBKey
128	constant KBAutoRepeatMode
0	constant MappingSuccess
1	constant MappingBusy
2	constant MappingFailed
0	constant MappingModifier
1	constant MappingKeyboard
2	constant MappingPointer
0	constant DontPreferBlanking
1	constant PreferBlanking
2	constant DefaultBlanking
0	constant DisableScreenSaver
0	constant DisableScreenInterval
0	constant DontAllowExposures
1	constant AllowExposures
2	constant DefaultExposures
0	constant ScreenSaverReset
1	constant ScreenSaverActive
0	constant HostInsert
1	constant HostDelete
1	constant EnableAccess
0	constant DisableAccess
0	constant StaticGray
1	constant GrayScale
2	constant StaticColor
3	constant PseudoColor
4	constant TrueColor
5	constant DirectColor
0	constant LSBFirst
1	constant MSBFirst
6	constant XlibSpecificationRelease
1	constant X_HAVE_UTF8_STRING
1	constant True
0	constant False
0	constant QueuedAlready
1	constant QueuedAfterReading
2	constant QueuedAfterFlush
1	constant XIMPreeditArea
2	constant XIMPreeditCallbacks
4	constant XIMPreeditPosition
8	constant XIMPreeditNothing
16	constant XIMPreeditNone
256	constant XIMStatusArea
512	constant XIMStatusCallbacks
1024	constant XIMStatusNothing
2048	constant XIMStatusNone
-1	constant XBufferOverflow
1	constant XLookupNone
2	constant XLookupChars
3	constant XLookupKeySym
4	constant XLookupBoth
1	constant XIMReverse
2	constant XIMUnderline
4	constant XIMHighlight
32	constant XIMPrimary
64	constant XIMSecondary
128	constant XIMTertiary
256	constant XIMVisibleToForward
512	constant XIMVisibleToBackword
1024	constant XIMVisibleToCenter
0	constant XIMPreeditUnKnown
1	constant XIMPreeditEnable
2	constant XIMPreeditDisable
1	constant XIMInitialState
2	constant XIMPreserveState
1	constant XIMStringConversionLeftEdge
2	constant XIMStringConversionRightEdge
4	constant XIMStringConversionTopEdge
8	constant XIMStringConversionBottomEdge
16	constant XIMStringConversionConcealed
32	constant XIMStringConversionWrapped
1	constant XIMStringConversionBuffer
2	constant XIMStringConversionLine
3	constant XIMStringConversionWord
4	constant XIMStringConversionChar
1	constant XIMStringConversionSubstitution
2	constant XIMStringConversionRetrieval
1	constant XIMHotKeyStateON
2	constant XIMHotKeyStateOFF
0	constant NoValue
1	constant XValue
2	constant YValue
4	constant WidthValue
8	constant HeightValue
15	constant AllValues
16	constant XNegative
32	constant YNegative
1	constant USPosition
2	constant USSize
4	constant PPosition
8	constant PSize
16	constant PMinSize
32	constant PMaxSize
64	constant PResizeInc
128	constant PAspect
256	constant PBaseSize
512	constant PWinGravity
252	constant PAllHints
1	constant InputHint
2	constant StateHint
4	constant IconPixmapHint
8	constant IconWindowHint
16	constant IconPositionHint
32	constant IconMaskHint
64	constant WindowGroupHint
127	constant AllHints
256	constant XUrgencyHint
0	constant WithdrawnState
1	constant NormalState
3	constant IconicState
0	constant DontCareState
2	constant ZoomState
4	constant InactiveState
-1	constant XNoMemory
-2	constant XLocaleNotSupported
-3	constant XConverterNotFound
0	constant RectangleOut
1	constant RectangleIn
2	constant RectanglePart
0	constant VisualNoMask
1	constant VisualIDMask
2	constant VisualScreenMask
4	constant VisualDepthMask
8	constant VisualClassMask
16	constant VisualRedMaskMask
32	constant VisualGreenMaskMask
64	constant VisualBlueMaskMask
128	constant VisualColormapSizeMask
256	constant VisualBitsPerRGBMask
511	constant VisualAllMask
0	constant BitmapSuccess
1	constant BitmapOpenFailed
2	constant BitmapFileInvalid
3	constant BitmapNoMemory
0	constant XCSUCCESS
1	constant XCNOMEM
2	constant XCNOENT

\ --------===< enums >===---------
0	constant XOMOrientation_LTR_TTB
1	constant XOMOrientation_RTL_TTB
2	constant XOMOrientation_TTB_LTR
3	constant XOMOrientation_TTB_RTL
4	constant XOMOrientation_Context
0	constant XIMForwardChar
1	constant XIMBackwardChar
2	constant XIMForwardWord
3	constant XIMBackwardWord
4	constant XIMCaretUp
5	constant XIMCaretDown
6	constant XIMNextLine
7	constant XIMPreviousLine
8	constant XIMLineStart
9	constant XIMLineEnd
10	constant XIMAbsolutePosition
11	constant XIMDontChange
0	constant XIMIsInvisible
1	constant XIMIsPrimary
2	constant XIMIsSecondary
0	constant XIMTextType
1	constant XIMBitmapType
0	constant XStringStyle
1	constant XCompoundTextStyle
2	constant XTextStyle
3	constant XStdICCTextStyle
4	constant XUTF8StringStyle

\ -------===< structs >===--------
\ XExtData
begin-structure XExtData
drop 32 end-structure
\ XExtCodes
begin-structure XExtCodes
	drop 0 4 +field XExtCodes-extension
	drop 12 4 +field XExtCodes-first_error
	drop 4 4 +field XExtCodes-major_opcode
	drop 8 4 +field XExtCodes-first_event
drop 16 end-structure
\ XPixmapFormatValues
begin-structure XPixmapFormatValues
	drop 8 4 +field XPixmapFormatValues-scanline_pad
	drop 4 4 +field XPixmapFormatValues-bits_per_pixel
	drop 0 4 +field XPixmapFormatValues-depth
drop 12 end-structure
\ XGCValues
begin-structure XGCValues
	drop 48 4 +field XGCValues-fill_style
	drop 44 4 +field XGCValues-join_style
	drop 40 4 +field XGCValues-cap_style
	drop 80 4 +field XGCValues-ts_x_origin
	drop 84 4 +field XGCValues-ts_y_origin
	drop 88 8 +field XGCValues-font
	drop 104 4 +field XGCValues-clip_x_origin
	drop 108 4 +field XGCValues-clip_y_origin
	drop 72 8 +field XGCValues-stipple
	drop 8 8 +field XGCValues-plane_mask
	drop 96 4 +field XGCValues-subwindow_mode
	drop 36 4 +field XGCValues-line_style
	drop 64 8 +field XGCValues-tile
	drop 24 8 +field XGCValues-background
	drop 16 8 +field XGCValues-foreground
	drop 0 4 +field XGCValues-function
	drop 100 4 +field XGCValues-graphics_exposures
	drop 32 4 +field XGCValues-line_width
	drop 56 4 +field XGCValues-arc_mode
	drop 112 8 +field XGCValues-clip_mask
	drop 52 4 +field XGCValues-fill_rule
	drop 120 4 +field XGCValues-dash_offset
	drop 124 1 +field XGCValues-dashes
drop 128 end-structure
\ Visual
begin-structure Visual
	drop 40 8 +field Visual-blue_mask
	drop 0 8 +field Visual-ext_data
	drop 8 8 +field Visual-visualid
	drop 32 8 +field Visual-green_mask
	drop 24 8 +field Visual-red_mask
	drop 48 4 +field Visual-bits_per_rgb
	drop 52 4 +field Visual-map_entries
	drop 16 4 +field Visual-class
drop 56 end-structure
\ Depth
begin-structure Depth
	drop 4 4 +field Depth-nvisuals
	drop 8 8 +field Depth-visuals
	drop 0 4 +field Depth-depth
drop 16 end-structure
\ Screen
begin-structure Screen
	drop 56 4 +field Screen-root_depth
	drop 116 4 +field Screen-save_unders
	drop 120 8 +field Screen-root_input_mask
	drop 28 4 +field Screen-height
	drop 108 4 +field Screen-min_maps
	drop 112 4 +field Screen-backing_store
	drop 80 8 +field Screen-cmap
	drop 16 8 +field Screen-root
	drop 0 8 +field Screen-ext_data
	drop 104 4 +field Screen-max_maps
	drop 36 4 +field Screen-mheight
	drop 48 8 +field Screen-depths
	drop 40 4 +field Screen-ndepths
	drop 8 8 +field Screen-display
	drop 24 4 +field Screen-width
	drop 72 8 +field Screen-default_gc
	drop 88 8 +field Screen-white_pixel
	drop 96 8 +field Screen-black_pixel
	drop 64 8 +field Screen-root_visual
	drop 32 4 +field Screen-mwidth
drop 128 end-structure
\ ScreenFormat
begin-structure ScreenFormat
	drop 16 4 +field ScreenFormat-scanline_pad
	drop 0 8 +field ScreenFormat-ext_data
	drop 12 4 +field ScreenFormat-bits_per_pixel
	drop 8 4 +field ScreenFormat-depth
drop 24 end-structure
\ XSetWindowAttributes
begin-structure XSetWindowAttributes
	drop 96 8 +field XSetWindowAttributes-colormap
	drop 16 8 +field XSetWindowAttributes-border_pixmap
	drop 0 8 +field XSetWindowAttributes-background_pixmap
	drop 80 8 +field XSetWindowAttributes-do_not_propagate_mask
	drop 36 4 +field XSetWindowAttributes-win_gravity
	drop 32 4 +field XSetWindowAttributes-bit_gravity
	drop 40 4 +field XSetWindowAttributes-backing_store
	drop 104 8 +field XSetWindowAttributes-cursor
	drop 24 8 +field XSetWindowAttributes-border_pixel
	drop 8 8 +field XSetWindowAttributes-background_pixel
	drop 64 4 +field XSetWindowAttributes-save_under
	drop 88 4 +field XSetWindowAttributes-override_redirect
	drop 56 8 +field XSetWindowAttributes-backing_pixel
	drop 48 8 +field XSetWindowAttributes-backing_planes
	drop 72 8 +field XSetWindowAttributes-event_mask
drop 112 end-structure
\ XWindowAttributes
begin-structure XWindowAttributes
	drop 0 4 +field XWindowAttributes-x
	drop 48 4 +field XWindowAttributes-win_gravity
	drop 44 4 +field XWindowAttributes-bit_gravity
	drop 80 8 +field XWindowAttributes-colormap
	drop 112 8 +field XWindowAttributes-do_not_propagate_mask
	drop 4 4 +field XWindowAttributes-y
	drop 12 4 +field XWindowAttributes-height
	drop 52 4 +field XWindowAttributes-backing_store
	drop 16 4 +field XWindowAttributes-border_width
	drop 32 8 +field XWindowAttributes-root
	drop 88 4 +field XWindowAttributes-map_installed
	drop 40 4 +field XWindowAttributes-class
	drop 20 4 +field XWindowAttributes-depth
	drop 92 4 +field XWindowAttributes-map_state
	drop 24 8 +field XWindowAttributes-visual
	drop 8 4 +field XWindowAttributes-width
	drop 64 8 +field XWindowAttributes-backing_pixel
	drop 72 4 +field XWindowAttributes-save_under
	drop 120 4 +field XWindowAttributes-override_redirect
	drop 56 8 +field XWindowAttributes-backing_planes
	drop 96 8 +field XWindowAttributes-all_event_masks
	drop 104 8 +field XWindowAttributes-your_event_mask
	drop 128 8 +field XWindowAttributes-screen
drop 136 end-structure
\ XHostAddress
begin-structure XHostAddress
	drop 4 4 +field XHostAddress-length
	drop 8 8 +field XHostAddress-address
	drop 0 4 +field XHostAddress-family
drop 16 end-structure
\ XServerInterpretedAddress
begin-structure XServerInterpretedAddress
	drop 0 4 +field XServerInterpretedAddress-typelength
	drop 4 4 +field XServerInterpretedAddress-valuelength
	drop 16 8 +field XServerInterpretedAddress-value
	drop 8 8 +field XServerInterpretedAddress-type
drop 24 end-structure
\ XImage
begin-structure XImage
drop 136 end-structure
\ funcs
begin-structure funcs
	drop 0 8 +field funcs-create_image
	drop 8 8 +field funcs-destroy_image
	drop 16 8 +field funcs-get_pixel
	drop 24 8 +field funcs-put_pixel
	drop 40 8 +field funcs-add_pixel
	drop 32 8 +field funcs-sub_image
drop 48 end-structure
\ XWindowChanges
begin-structure XWindowChanges
	drop 0 4 +field XWindowChanges-x
	drop 4 4 +field XWindowChanges-y
	drop 32 4 +field XWindowChanges-stack_mode
	drop 12 4 +field XWindowChanges-height
	drop 16 4 +field XWindowChanges-border_width
	drop 24 8 +field XWindowChanges-sibling
	drop 8 4 +field XWindowChanges-width
drop 40 end-structure
\ XColor
begin-structure XColor
	drop 12 2 +field XColor-blue
	drop 0 8 +field XColor-pixel
	drop 10 2 +field XColor-green
	drop 8 2 +field XColor-red
	drop 14 1 +field XColor-flags
	drop 15 1 +field XColor-pad
drop 16 end-structure
\ XSegment
begin-structure XSegment
	drop 2 2 +field XSegment-y1
	drop 6 2 +field XSegment-y2
	drop 0 2 +field XSegment-x1
	drop 4 2 +field XSegment-x2
drop 8 end-structure
\ XPoint
begin-structure XPoint
	drop 0 2 +field XPoint-x
	drop 2 2 +field XPoint-y
drop 4 end-structure
\ XRectangle
begin-structure XRectangle
	drop 0 2 +field XRectangle-x
	drop 2 2 +field XRectangle-y
	drop 6 2 +field XRectangle-height
	drop 4 2 +field XRectangle-width
drop 8 end-structure
\ XArc
begin-structure XArc
	drop 0 2 +field XArc-x
	drop 2 2 +field XArc-y
	drop 6 2 +field XArc-height
	drop 8 2 +field XArc-angle1
	drop 4 2 +field XArc-width
	drop 10 2 +field XArc-angle2
drop 12 end-structure
\ XKeyboardControl
begin-structure XKeyboardControl
	drop 0 4 +field XKeyboardControl-key_click_percent
	drop 4 4 +field XKeyboardControl-bell_percent
	drop 12 4 +field XKeyboardControl-bell_duration
	drop 20 4 +field XKeyboardControl-led_mode
	drop 8 4 +field XKeyboardControl-bell_pitch
	drop 24 4 +field XKeyboardControl-key
	drop 16 4 +field XKeyboardControl-led
	drop 28 4 +field XKeyboardControl-auto_repeat_mode
drop 32 end-structure
\ XKeyboardState
begin-structure XKeyboardState
	drop 0 4 +field XKeyboardState-key_click_percent
	drop 4 4 +field XKeyboardState-bell_percent
	drop 12 4 +field XKeyboardState-bell_duration
	drop 8 4 +field XKeyboardState-bell_pitch
	drop 28 32 +field XKeyboardState-auto_repeats
	drop 16 8 +field XKeyboardState-led_mask
	drop 24 4 +field XKeyboardState-global_auto_repeat
drop 64 end-structure
\ XTimeCoord
begin-structure XTimeCoord
	drop 8 2 +field XTimeCoord-x
	drop 0 8 +field XTimeCoord-time
	drop 10 2 +field XTimeCoord-y
drop 16 end-structure
\ XModifierKeymap
begin-structure XModifierKeymap
	drop 8 8 +field XModifierKeymap-modifiermap
	drop 0 4 +field XModifierKeymap-max_keypermod
drop 16 end-structure
\ XKeyEvent
begin-structure XKeyEvent
	drop 48 8 +field XKeyEvent-subwindow
	drop 32 8 +field XKeyEvent-window
	drop 8 8 +field XKeyEvent-serial
	drop 64 4 +field XKeyEvent-x
	drop 68 4 +field XKeyEvent-y
	drop 88 4 +field XKeyEvent-same_screen
	drop 84 4 +field XKeyEvent-keycode
	drop 72 4 +field XKeyEvent-x_root
	drop 56 8 +field XKeyEvent-time
	drop 40 8 +field XKeyEvent-root
	drop 76 4 +field XKeyEvent-y_root
	drop 24 8 +field XKeyEvent-display
	drop 0 4 +field XKeyEvent-type
	drop 80 4 +field XKeyEvent-state
	drop 16 4 +field XKeyEvent-send_event
drop 96 end-structure
\ XButtonEvent
begin-structure XButtonEvent
	drop 48 8 +field XButtonEvent-subwindow
	drop 32 8 +field XButtonEvent-window
	drop 8 8 +field XButtonEvent-serial
	drop 64 4 +field XButtonEvent-x
	drop 68 4 +field XButtonEvent-y
	drop 88 4 +field XButtonEvent-same_screen
	drop 84 4 +field XButtonEvent-button
	drop 72 4 +field XButtonEvent-x_root
	drop 56 8 +field XButtonEvent-time
	drop 40 8 +field XButtonEvent-root
	drop 76 4 +field XButtonEvent-y_root
	drop 24 8 +field XButtonEvent-display
	drop 0 4 +field XButtonEvent-type
	drop 80 4 +field XButtonEvent-state
	drop 16 4 +field XButtonEvent-send_event
drop 96 end-structure
\ XMotionEvent
begin-structure XMotionEvent
	drop 48 8 +field XMotionEvent-subwindow
	drop 32 8 +field XMotionEvent-window
	drop 8 8 +field XMotionEvent-serial
	drop 64 4 +field XMotionEvent-x
	drop 68 4 +field XMotionEvent-y
	drop 88 4 +field XMotionEvent-same_screen
	drop 72 4 +field XMotionEvent-x_root
	drop 56 8 +field XMotionEvent-time
	drop 40 8 +field XMotionEvent-root
	drop 84 1 +field XMotionEvent-is_hint
	drop 76 4 +field XMotionEvent-y_root
	drop 24 8 +field XMotionEvent-display
	drop 0 4 +field XMotionEvent-type
	drop 80 4 +field XMotionEvent-state
	drop 16 4 +field XMotionEvent-send_event
drop 96 end-structure
\ XCrossingEvent
begin-structure XCrossingEvent
	drop 80 4 +field XCrossingEvent-mode
	drop 48 8 +field XCrossingEvent-subwindow
	drop 32 8 +field XCrossingEvent-window
	drop 8 8 +field XCrossingEvent-serial
	drop 64 4 +field XCrossingEvent-x
	drop 92 4 +field XCrossingEvent-focus
	drop 68 4 +field XCrossingEvent-y
	drop 88 4 +field XCrossingEvent-same_screen
	drop 72 4 +field XCrossingEvent-x_root
	drop 56 8 +field XCrossingEvent-time
	drop 40 8 +field XCrossingEvent-root
	drop 76 4 +field XCrossingEvent-y_root
	drop 24 8 +field XCrossingEvent-display
	drop 84 4 +field XCrossingEvent-detail
	drop 0 4 +field XCrossingEvent-type
	drop 96 4 +field XCrossingEvent-state
	drop 16 4 +field XCrossingEvent-send_event
drop 104 end-structure
\ XFocusChangeEvent
begin-structure XFocusChangeEvent
	drop 24 8 +field XFocusChangeEvent-display
	drop 8 8 +field XFocusChangeEvent-serial
	drop 32 8 +field XFocusChangeEvent-window
	drop 0 4 +field XFocusChangeEvent-type
	drop 16 4 +field XFocusChangeEvent-send_event
	drop 44 4 +field XFocusChangeEvent-detail
	drop 40 4 +field XFocusChangeEvent-mode
drop 48 end-structure
\ XKeymapEvent
begin-structure XKeymapEvent
	drop 24 8 +field XKeymapEvent-display
	drop 40 32 +field XKeymapEvent-key_vector
	drop 8 8 +field XKeymapEvent-serial
	drop 32 8 +field XKeymapEvent-window
	drop 0 4 +field XKeymapEvent-type
	drop 16 4 +field XKeymapEvent-send_event
drop 72 end-structure
\ XExposeEvent
begin-structure XExposeEvent
	drop 24 8 +field XExposeEvent-display
	drop 40 4 +field XExposeEvent-x
	drop 44 4 +field XExposeEvent-y
	drop 56 4 +field XExposeEvent-count
	drop 8 8 +field XExposeEvent-serial
	drop 32 8 +field XExposeEvent-window
	drop 0 4 +field XExposeEvent-type
	drop 52 4 +field XExposeEvent-height
	drop 16 4 +field XExposeEvent-send_event
	drop 48 4 +field XExposeEvent-width
drop 64 end-structure
\ XGraphicsExposeEvent
begin-structure XGraphicsExposeEvent
	drop 24 8 +field XGraphicsExposeEvent-display
	drop 40 4 +field XGraphicsExposeEvent-x
	drop 44 4 +field XGraphicsExposeEvent-y
	drop 56 4 +field XGraphicsExposeEvent-count
	drop 8 8 +field XGraphicsExposeEvent-serial
	drop 32 8 +field XGraphicsExposeEvent-drawable
	drop 0 4 +field XGraphicsExposeEvent-type
	drop 52 4 +field XGraphicsExposeEvent-height
	drop 16 4 +field XGraphicsExposeEvent-send_event
	drop 48 4 +field XGraphicsExposeEvent-width
	drop 60 4 +field XGraphicsExposeEvent-major_code
	drop 64 4 +field XGraphicsExposeEvent-minor_code
drop 72 end-structure
\ XNoExposeEvent
begin-structure XNoExposeEvent
	drop 24 8 +field XNoExposeEvent-display
	drop 8 8 +field XNoExposeEvent-serial
	drop 32 8 +field XNoExposeEvent-drawable
	drop 0 4 +field XNoExposeEvent-type
	drop 16 4 +field XNoExposeEvent-send_event
	drop 40 4 +field XNoExposeEvent-major_code
	drop 44 4 +field XNoExposeEvent-minor_code
drop 48 end-structure
\ XVisibilityEvent
begin-structure XVisibilityEvent
	drop 24 8 +field XVisibilityEvent-display
	drop 8 8 +field XVisibilityEvent-serial
	drop 32 8 +field XVisibilityEvent-window
	drop 0 4 +field XVisibilityEvent-type
	drop 16 4 +field XVisibilityEvent-send_event
	drop 40 4 +field XVisibilityEvent-state
drop 48 end-structure
\ XCreateWindowEvent
begin-structure XCreateWindowEvent
	drop 24 8 +field XCreateWindowEvent-display
	drop 48 4 +field XCreateWindowEvent-x
	drop 52 4 +field XCreateWindowEvent-y
	drop 8 8 +field XCreateWindowEvent-serial
	drop 40 8 +field XCreateWindowEvent-window
	drop 68 4 +field XCreateWindowEvent-override_redirect
	drop 0 4 +field XCreateWindowEvent-type
	drop 60 4 +field XCreateWindowEvent-height
	drop 64 4 +field XCreateWindowEvent-border_width
	drop 16 4 +field XCreateWindowEvent-send_event
	drop 32 8 +field XCreateWindowEvent-parent
	drop 56 4 +field XCreateWindowEvent-width
drop 72 end-structure
\ XDestroyWindowEvent
begin-structure XDestroyWindowEvent
	drop 24 8 +field XDestroyWindowEvent-display
	drop 8 8 +field XDestroyWindowEvent-serial
	drop 40 8 +field XDestroyWindowEvent-window
	drop 0 4 +field XDestroyWindowEvent-type
	drop 16 4 +field XDestroyWindowEvent-send_event
	drop 32 8 +field XDestroyWindowEvent-event
drop 48 end-structure
\ XUnmapEvent
begin-structure XUnmapEvent
	drop 24 8 +field XUnmapEvent-display
	drop 8 8 +field XUnmapEvent-serial
	drop 40 8 +field XUnmapEvent-window
	drop 0 4 +field XUnmapEvent-type
	drop 48 4 +field XUnmapEvent-from_configure
	drop 16 4 +field XUnmapEvent-send_event
	drop 32 8 +field XUnmapEvent-event
drop 56 end-structure
\ XMapEvent
begin-structure XMapEvent
	drop 24 8 +field XMapEvent-display
	drop 8 8 +field XMapEvent-serial
	drop 40 8 +field XMapEvent-window
	drop 48 4 +field XMapEvent-override_redirect
	drop 0 4 +field XMapEvent-type
	drop 16 4 +field XMapEvent-send_event
	drop 32 8 +field XMapEvent-event
drop 56 end-structure
\ XMapRequestEvent
begin-structure XMapRequestEvent
	drop 24 8 +field XMapRequestEvent-display
	drop 8 8 +field XMapRequestEvent-serial
	drop 40 8 +field XMapRequestEvent-window
	drop 0 4 +field XMapRequestEvent-type
	drop 16 4 +field XMapRequestEvent-send_event
	drop 32 8 +field XMapRequestEvent-parent
drop 48 end-structure
\ XReparentEvent
begin-structure XReparentEvent
	drop 24 8 +field XReparentEvent-display
	drop 56 4 +field XReparentEvent-x
	drop 60 4 +field XReparentEvent-y
	drop 8 8 +field XReparentEvent-serial
	drop 40 8 +field XReparentEvent-window
	drop 64 4 +field XReparentEvent-override_redirect
	drop 0 4 +field XReparentEvent-type
	drop 16 4 +field XReparentEvent-send_event
	drop 48 8 +field XReparentEvent-parent
	drop 32 8 +field XReparentEvent-event
drop 72 end-structure
\ XConfigureEvent
begin-structure XConfigureEvent
	drop 24 8 +field XConfigureEvent-display
	drop 72 8 +field XConfigureEvent-above
	drop 48 4 +field XConfigureEvent-x
	drop 52 4 +field XConfigureEvent-y
	drop 8 8 +field XConfigureEvent-serial
	drop 40 8 +field XConfigureEvent-window
	drop 80 4 +field XConfigureEvent-override_redirect
	drop 0 4 +field XConfigureEvent-type
	drop 60 4 +field XConfigureEvent-height
	drop 64 4 +field XConfigureEvent-border_width
	drop 16 4 +field XConfigureEvent-send_event
	drop 56 4 +field XConfigureEvent-width
	drop 32 8 +field XConfigureEvent-event
drop 88 end-structure
\ XGravityEvent
begin-structure XGravityEvent
	drop 24 8 +field XGravityEvent-display
	drop 48 4 +field XGravityEvent-x
	drop 52 4 +field XGravityEvent-y
	drop 8 8 +field XGravityEvent-serial
	drop 40 8 +field XGravityEvent-window
	drop 0 4 +field XGravityEvent-type
	drop 16 4 +field XGravityEvent-send_event
	drop 32 8 +field XGravityEvent-event
drop 56 end-structure
\ XResizeRequestEvent
begin-structure XResizeRequestEvent
	drop 24 8 +field XResizeRequestEvent-display
	drop 8 8 +field XResizeRequestEvent-serial
	drop 32 8 +field XResizeRequestEvent-window
	drop 0 4 +field XResizeRequestEvent-type
	drop 44 4 +field XResizeRequestEvent-height
	drop 16 4 +field XResizeRequestEvent-send_event
	drop 40 4 +field XResizeRequestEvent-width
drop 48 end-structure
\ XConfigureRequestEvent
begin-structure XConfigureRequestEvent
	drop 40 8 +field XConfigureRequestEvent-window
	drop 8 8 +field XConfigureRequestEvent-serial
	drop 48 4 +field XConfigureRequestEvent-x
	drop 52 4 +field XConfigureRequestEvent-y
	drop 60 4 +field XConfigureRequestEvent-height
	drop 64 4 +field XConfigureRequestEvent-border_width
	drop 88 8 +field XConfigureRequestEvent-value_mask
	drop 72 8 +field XConfigureRequestEvent-above
	drop 24 8 +field XConfigureRequestEvent-display
	drop 80 4 +field XConfigureRequestEvent-detail
	drop 56 4 +field XConfigureRequestEvent-width
	drop 0 4 +field XConfigureRequestEvent-type
	drop 16 4 +field XConfigureRequestEvent-send_event
	drop 32 8 +field XConfigureRequestEvent-parent
drop 96 end-structure
\ XCirculateEvent
begin-structure XCirculateEvent
	drop 24 8 +field XCirculateEvent-display
	drop 48 4 +field XCirculateEvent-place
	drop 8 8 +field XCirculateEvent-serial
	drop 40 8 +field XCirculateEvent-window
	drop 0 4 +field XCirculateEvent-type
	drop 16 4 +field XCirculateEvent-send_event
	drop 32 8 +field XCirculateEvent-event
drop 56 end-structure
\ XCirculateRequestEvent
begin-structure XCirculateRequestEvent
	drop 24 8 +field XCirculateRequestEvent-display
	drop 48 4 +field XCirculateRequestEvent-place
	drop 8 8 +field XCirculateRequestEvent-serial
	drop 40 8 +field XCirculateRequestEvent-window
	drop 0 4 +field XCirculateRequestEvent-type
	drop 16 4 +field XCirculateRequestEvent-send_event
	drop 32 8 +field XCirculateRequestEvent-parent
drop 56 end-structure
\ XPropertyEvent
begin-structure XPropertyEvent
	drop 24 8 +field XPropertyEvent-display
	drop 40 8 +field XPropertyEvent-atom
	drop 48 8 +field XPropertyEvent-time
	drop 8 8 +field XPropertyEvent-serial
	drop 32 8 +field XPropertyEvent-window
	drop 0 4 +field XPropertyEvent-type
	drop 16 4 +field XPropertyEvent-send_event
	drop 56 4 +field XPropertyEvent-state
drop 64 end-structure
\ XSelectionClearEvent
begin-structure XSelectionClearEvent
	drop 24 8 +field XSelectionClearEvent-display
	drop 48 8 +field XSelectionClearEvent-time
	drop 8 8 +field XSelectionClearEvent-serial
	drop 32 8 +field XSelectionClearEvent-window
	drop 0 4 +field XSelectionClearEvent-type
	drop 16 4 +field XSelectionClearEvent-send_event
	drop 40 8 +field XSelectionClearEvent-selection
drop 56 end-structure
\ XSelectionRequestEvent
begin-structure XSelectionRequestEvent
	drop 24 8 +field XSelectionRequestEvent-display
	drop 40 8 +field XSelectionRequestEvent-requestor
	drop 64 8 +field XSelectionRequestEvent-property
	drop 56 8 +field XSelectionRequestEvent-target
	drop 72 8 +field XSelectionRequestEvent-time
	drop 8 8 +field XSelectionRequestEvent-serial
	drop 0 4 +field XSelectionRequestEvent-type
	drop 16 4 +field XSelectionRequestEvent-send_event
	drop 32 8 +field XSelectionRequestEvent-owner
	drop 48 8 +field XSelectionRequestEvent-selection
drop 80 end-structure
\ XSelectionEvent
begin-structure XSelectionEvent
	drop 24 8 +field XSelectionEvent-display
	drop 32 8 +field XSelectionEvent-requestor
	drop 56 8 +field XSelectionEvent-property
	drop 48 8 +field XSelectionEvent-target
	drop 64 8 +field XSelectionEvent-time
	drop 8 8 +field XSelectionEvent-serial
	drop 0 4 +field XSelectionEvent-type
	drop 16 4 +field XSelectionEvent-send_event
	drop 40 8 +field XSelectionEvent-selection
drop 72 end-structure
\ XColormapEvent
begin-structure XColormapEvent
	drop 24 8 +field XColormapEvent-display
	drop 48 4 +field XColormapEvent-new
	drop 8 8 +field XColormapEvent-serial
	drop 32 8 +field XColormapEvent-window
	drop 0 4 +field XColormapEvent-type
	drop 16 4 +field XColormapEvent-send_event
	drop 40 8 +field XColormapEvent-colormap
	drop 52 4 +field XColormapEvent-state
drop 56 end-structure
\ XClientMessageEvent
begin-structure XClientMessageEvent
	drop 24 8 +field XClientMessageEvent-display
	drop 56 40 +field XClientMessageEvent-data
	drop 40 8 +field XClientMessageEvent-message_type
	drop 8 8 +field XClientMessageEvent-serial
	drop 32 8 +field XClientMessageEvent-window
	drop 0 4 +field XClientMessageEvent-type
	drop 16 4 +field XClientMessageEvent-send_event
	drop 48 4 +field XClientMessageEvent-format
drop 96 end-structure
\ XClientMessageEvent_data
begin-structure XClientMessageEvent_data
	drop 0 20 +field XClientMessageEvent_data-b
	drop 0 20 +field XClientMessageEvent_data-s
	drop 0 40 +field XClientMessageEvent_data-l
drop 40 end-structure
\ XMappingEvent
begin-structure XMappingEvent
	drop 24 8 +field XMappingEvent-display
	drop 40 4 +field XMappingEvent-request
	drop 44 4 +field XMappingEvent-first_keycode
	drop 48 4 +field XMappingEvent-count
	drop 8 8 +field XMappingEvent-serial
	drop 32 8 +field XMappingEvent-window
	drop 0 4 +field XMappingEvent-type
	drop 16 4 +field XMappingEvent-send_event
drop 56 end-structure
\ XErrorEvent
begin-structure XErrorEvent
	drop 8 8 +field XErrorEvent-display
	drop 16 8 +field XErrorEvent-resourceid
	drop 24 8 +field XErrorEvent-serial
	drop 33 1 +field XErrorEvent-request_code
	drop 0 4 +field XErrorEvent-type
	drop 32 1 +field XErrorEvent-error_code
	drop 34 1 +field XErrorEvent-minor_code
drop 40 end-structure
\ XAnyEvent
begin-structure XAnyEvent
	drop 24 8 +field XAnyEvent-display
	drop 8 8 +field XAnyEvent-serial
	drop 32 8 +field XAnyEvent-window
	drop 0 4 +field XAnyEvent-type
	drop 16 4 +field XAnyEvent-send_event
drop 40 end-structure
\ XGenericEvent
begin-structure XGenericEvent
	drop 24 8 +field XGenericEvent-display
	drop 32 4 +field XGenericEvent-extension
	drop 8 8 +field XGenericEvent-serial
	drop 0 4 +field XGenericEvent-type
	drop 36 4 +field XGenericEvent-evtype
	drop 16 4 +field XGenericEvent-send_event
drop 40 end-structure
\ XGenericEventCookie
begin-structure XGenericEventCookie
	drop 24 8 +field XGenericEventCookie-display
	drop 32 4 +field XGenericEventCookie-extension
	drop 48 8 +field XGenericEventCookie-data
	drop 40 4 +field XGenericEventCookie-cookie
	drop 8 8 +field XGenericEventCookie-serial
	drop 0 4 +field XGenericEventCookie-type
	drop 36 4 +field XGenericEventCookie-evtype
	drop 16 4 +field XGenericEventCookie-send_event
drop 56 end-structure
\ XEvent
begin-structure XEvent
drop 192 end-structure
\ XCharStruct
begin-structure XCharStruct
	drop 6 2 +field XCharStruct-ascent
	drop 4 2 +field XCharStruct-width
	drop 8 2 +field XCharStruct-descent
	drop 10 2 +field XCharStruct-attributes
	drop 0 2 +field XCharStruct-lbearing
	drop 2 2 +field XCharStruct-rbearing
drop 12 end-structure
\ XFontProp
begin-structure XFontProp
	drop 0 8 +field XFontProp-name
	drop 8 8 +field XFontProp-card32
drop 16 end-structure
\ XFontStruct
begin-structure XFontStruct
	drop 16 4 +field XFontStruct-direction
	drop 88 4 +field XFontStruct-ascent
	drop 32 4 +field XFontStruct-max_byte1
	drop 28 4 +field XFontStruct-min_byte1
	drop 24 4 +field XFontStruct-max_char_or_byte2
	drop 20 4 +field XFontStruct-min_char_or_byte2
	drop 0 8 +field XFontStruct-ext_data
	drop 36 4 +field XFontStruct-all_chars_exist
	drop 68 12 +field XFontStruct-max_bounds
	drop 56 12 +field XFontStruct-min_bounds
	drop 8 8 +field XFontStruct-fid
	drop 48 8 +field XFontStruct-properties
	drop 44 4 +field XFontStruct-n_properties
	drop 92 4 +field XFontStruct-descent
	drop 40 4 +field XFontStruct-default_char
	drop 80 8 +field XFontStruct-per_char
drop 96 end-structure
\ XTextItem
begin-structure XTextItem
	drop 12 4 +field XTextItem-delta
	drop 0 8 +field XTextItem-chars
	drop 16 8 +field XTextItem-font
	drop 8 4 +field XTextItem-nchars
drop 24 end-structure
\ XChar2b
begin-structure XChar2b
	drop 0 1 +field XChar2b-byte1
	drop 1 1 +field XChar2b-byte2
drop 2 end-structure
\ XTextItem16
begin-structure XTextItem16
	drop 12 4 +field XTextItem16-delta
	drop 0 8 +field XTextItem16-chars
	drop 16 8 +field XTextItem16-font
	drop 8 4 +field XTextItem16-nchars
drop 24 end-structure
\ XEDataObject
begin-structure XEDataObject
	drop 0 8 +field XEDataObject-display
	drop 0 8 +field XEDataObject-gc
	drop 0 8 +field XEDataObject-visual
	drop 0 8 +field XEDataObject-pixmap_format
	drop 0 8 +field XEDataObject-screen
	drop 0 8 +field XEDataObject-font
drop 8 end-structure
\ XFontSetExtents
begin-structure XFontSetExtents
	drop 0 8 +field XFontSetExtents-max_ink_extent
	drop 8 8 +field XFontSetExtents-max_logical_extent
drop 16 end-structure
\ XmbTextItem
begin-structure XmbTextItem
	drop 16 8 +field XmbTextItem-font_set
	drop 12 4 +field XmbTextItem-delta
	drop 0 8 +field XmbTextItem-chars
	drop 8 4 +field XmbTextItem-nchars
drop 24 end-structure
\ XwcTextItem
begin-structure XwcTextItem
	drop 16 8 +field XwcTextItem-font_set
	drop 12 4 +field XwcTextItem-delta
	drop 0 8 +field XwcTextItem-chars
	drop 8 4 +field XwcTextItem-nchars
drop 24 end-structure
\ XOMCharSetList
begin-structure XOMCharSetList
	drop 0 4 +field XOMCharSetList-charset_count
	drop 8 8 +field XOMCharSetList-charset_list
drop 16 end-structure
\ XOMOrientation
begin-structure XOMOrientation
	drop 0 4 +field XOMOrientation-num_orientation
	drop 8 8 +field XOMOrientation-orientation
drop 16 end-structure
\ XOMFontInfo
begin-structure XOMFontInfo
	drop 16 8 +field XOMFontInfo-font_name_list
	drop 0 4 +field XOMFontInfo-num_font
	drop 8 8 +field XOMFontInfo-font_struct_list
drop 24 end-structure
\ XIMStyles
begin-structure XIMStyles
	drop 0 2 +field XIMStyles-count_styles
	drop 8 8 +field XIMStyles-supported_styles
drop 16 end-structure
\ XIMCallback
begin-structure XIMCallback
	drop 0 8 +field XIMCallback-client_data
	drop 8 8 +field XIMCallback-callback
drop 16 end-structure
\ XICCallback
begin-structure XICCallback
	drop 0 8 +field XICCallback-client_data
	drop 8 8 +field XICCallback-callback
drop 16 end-structure
\ XIMText
begin-structure XIMText
drop 32 end-structure
\ _XIMText_string
begin-structure _XIMText_string
	drop 0 8 +field _XIMText_string-multi_byte
	drop 0 8 +field _XIMText_string-wide_char
drop 8 end-structure
\ XIMPreeditStateNotifyCallbackStruct
begin-structure XIMPreeditStateNotifyCallbackStruct
drop 8 end-structure
\ XIMStringConversionText
begin-structure XIMStringConversionText
drop 32 end-structure
\ _XIMStringConversionText_string
begin-structure _XIMStringConversionText_string
	drop 0 8 +field _XIMStringConversionText_string-wcs
	drop 0 8 +field _XIMStringConversionText_string-mbs
drop 8 end-structure
\ XIMStringConversionCallbackStruct
begin-structure XIMStringConversionCallbackStruct
drop 24 end-structure
\ XIMPreeditDrawCallbackStruct
begin-structure XIMPreeditDrawCallbackStruct
drop 24 end-structure
\ XIMPreeditCaretCallbackStruct
begin-structure XIMPreeditCaretCallbackStruct
drop 12 end-structure
\ XIMStatusDrawCallbackStruct
begin-structure XIMStatusDrawCallbackStruct
drop 16 end-structure
\ _XIMStatusDrawCallbackStruct_data
begin-structure _XIMStatusDrawCallbackStruct_data
	drop 0 8 +field _XIMStatusDrawCallbackStruct_data-text
	drop 0 8 +field _XIMStatusDrawCallbackStruct_data-bitmap
drop 8 end-structure
\ XIMHotKeyTrigger
begin-structure XIMHotKeyTrigger
drop 16 end-structure
\ XIMHotKeyTriggers
begin-structure XIMHotKeyTriggers
drop 16 end-structure
\ XIMValuesList
begin-structure XIMValuesList
	drop 0 2 +field XIMValuesList-count_values
	drop 8 8 +field XIMValuesList-supported_values
drop 16 end-structure
\ XSizeHints
begin-structure XSizeHints
	drop 44 4 +field XSizeHints-height_inc
	drop 8 4 +field XSizeHints-x
	drop 72 4 +field XSizeHints-win_gravity
	drop 12 4 +field XSizeHints-y
	drop 20 4 +field XSizeHints-height
	drop 32 4 +field XSizeHints-max_width
	drop 24 4 +field XSizeHints-min_width
	drop 36 4 +field XSizeHints-max_height
	drop 28 4 +field XSizeHints-min_height
	drop 68 4 +field XSizeHints-base_height
	drop 64 4 +field XSizeHints-base_width
	drop 16 4 +field XSizeHints-width
	drop 56 8 +field XSizeHints-max_aspect
	drop 48 8 +field XSizeHints-min_aspect
	drop 0 8 +field XSizeHints-flags
	drop 40 4 +field XSizeHints-width_inc
drop 80 end-structure
\ XSizeHints_min_aspect
begin-structure XSizeHints_min_aspect
	drop 0 4 +field XSizeHints_min_aspect-x
	drop 4 4 +field XSizeHints_min_aspect-y
drop 8 end-structure
\ XWMHints
begin-structure XWMHints
	drop 32 4 +field XWMHints-icon_x
	drop 8 4 +field XWMHints-input
	drop 36 4 +field XWMHints-icon_y
	drop 16 8 +field XWMHints-icon_pixmap
	drop 24 8 +field XWMHints-icon_window
	drop 48 8 +field XWMHints-window_group
	drop 12 4 +field XWMHints-initial_state
	drop 40 8 +field XWMHints-icon_mask
	drop 0 8 +field XWMHints-flags
drop 56 end-structure
\ XTextProperty
begin-structure XTextProperty
	drop 8 8 +field XTextProperty-encoding
	drop 24 8 +field XTextProperty-nitems
	drop 0 8 +field XTextProperty-value
	drop 16 4 +field XTextProperty-format
drop 32 end-structure
\ XIconSize
begin-structure XIconSize
	drop 20 4 +field XIconSize-height_inc
	drop 4 4 +field XIconSize-min_height
	drop 12 4 +field XIconSize-max_height
	drop 0 4 +field XIconSize-min_width
	drop 8 4 +field XIconSize-max_width
	drop 16 4 +field XIconSize-width_inc
drop 24 end-structure
\ XClassHint
begin-structure XClassHint
	drop 8 8 +field XClassHint-res_class
	drop 0 8 +field XClassHint-res_name
drop 16 end-structure
\ XComposeStatus
begin-structure XComposeStatus
drop 16 end-structure
\ XVisualInfo
begin-structure XVisualInfo
	drop 48 8 +field XVisualInfo-blue_mask
	drop 0 8 +field XVisualInfo-visual
	drop 8 8 +field XVisualInfo-visualid
	drop 56 4 +field XVisualInfo-colormap_size
	drop 40 8 +field XVisualInfo-green_mask
	drop 16 4 +field XVisualInfo-screen
	drop 20 4 +field XVisualInfo-depth
	drop 32 8 +field XVisualInfo-red_mask
	drop 60 4 +field XVisualInfo-bits_per_rgb
	drop 24 4 +field XVisualInfo-class
drop 64 end-structure
\ XStandardColormap
begin-structure XStandardColormap
	drop 8 8 +field XStandardColormap-red_max
	drop 48 8 +field XStandardColormap-blue_mult
	drop 40 8 +field XStandardColormap-blue_max
	drop 56 8 +field XStandardColormap-base_pixel
	drop 64 8 +field XStandardColormap-visualid
	drop 24 8 +field XStandardColormap-green_max
	drop 32 8 +field XStandardColormap-green_mult
	drop 0 8 +field XStandardColormap-colormap
	drop 16 8 +field XStandardColormap-red_mult
	drop 72 8 +field XStandardColormap-killid
drop 80 end-structure

\ --===< function pointers >===---
c-funptr _XExtData-free_private() {((struct _XExtData*)ptr)->free_private} a -- n
c-funptr funcs-create_image() {((struct funcs*)ptr)->create_image} a a u n n a u u n n -- a
c-funptr funcs-destroy_image() {((struct funcs*)ptr)->destroy_image} a -- n
c-funptr funcs-get_pixel() {((struct funcs*)ptr)->get_pixel} a n n -- u
c-funptr funcs-put_pixel() {((struct funcs*)ptr)->put_pixel} a n n u -- n
c-funptr funcs-sub_image() {((struct funcs*)ptr)->sub_image} a n n u u -- a
c-funptr funcs-add_pixel() {((struct funcs*)ptr)->add_pixel} a n -- n

\ ------===< callbacks >===-------
c-callback XIMProc: a a a -- void
c-callback XICProc: a a a -- n
c-callback XIDProc: a a a -- void
c-callback XErrorHandler: a a -- n
c-callback XIOErrorHandler: a -- n
c-callback XConnectionWatchProc: a a n n a -- void

\ ------===< functions >===-------
c-function _Xmblen _Xmblen a n -- n
c-function XLoadQueryFont XLoadQueryFont a a -- a
c-function XQueryFont XQueryFont a u -- a
c-function XGetMotionEvents XGetMotionEvents a u u u a -- a
c-function XDeleteModifiermapEntry XDeleteModifiermapEntry a n n -- a
c-function XGetModifierMapping XGetModifierMapping a -- a
c-function XInsertModifiermapEntry XInsertModifiermapEntry a n n -- a
c-function XNewModifiermap XNewModifiermap n -- a
c-function XCreateImage XCreateImage a a u n n a u u n n -- a
c-function XInitImage XInitImage a -- n
c-function XGetImage XGetImage a u n n u u u n -- a
c-function XGetSubImage XGetSubImage a u n n u u u n a n n -- a
c-function XOpenDisplay XOpenDisplay a -- a
c-function XrmInitialize XrmInitialize  -- void
c-function XFetchBytes XFetchBytes a a -- a
c-function XFetchBuffer XFetchBuffer a a n -- a
c-function XGetAtomName XGetAtomName a u -- a
c-function XGetAtomNames XGetAtomNames a a n a -- n
c-function XGetDefault XGetDefault a a a -- a
c-function XDisplayName XDisplayName a -- a
c-function XKeysymToString XKeysymToString u -- a
c-function XSynchronize XSynchronize a n -- a
c-function XSetAfterFunction XSetAfterFunction a a -- a
c-function XInternAtom XInternAtom a a n -- u
c-function XInternAtoms XInternAtoms a a n n a -- n
c-function XCopyColormapAndFree XCopyColormapAndFree a u -- u
c-function XCreateColormap XCreateColormap a u a n -- u
c-function XCreatePixmapCursor XCreatePixmapCursor a u u a a u u -- u
c-function XCreateGlyphCursor XCreateGlyphCursor a u u u u a a -- u
c-function XCreateFontCursor XCreateFontCursor a u -- u
c-function XLoadFont XLoadFont a a -- u
c-function XCreateGC XCreateGC a u u a -- a
c-function XGContextFromGC XGContextFromGC a -- u
c-function XFlushGC XFlushGC a a -- void
c-function XCreatePixmap XCreatePixmap a u u u u -- u
c-function XCreateBitmapFromData XCreateBitmapFromData a u a u u -- u
c-function XCreatePixmapFromBitmapData XCreatePixmapFromBitmapData a u a u u u u u -- u
c-function XCreateSimpleWindow XCreateSimpleWindow a u n n u u u u u -- u
c-function XGetSelectionOwner XGetSelectionOwner a u -- u
c-function XCreateWindow XCreateWindow a u n n u u u n u a u a -- u
c-function XListInstalledColormaps XListInstalledColormaps a u a -- a
c-function XListFonts XListFonts a a n a -- a
c-function XListFontsWithInfo XListFontsWithInfo a a n a a -- a
c-function XGetFontPath XGetFontPath a a -- a
c-function XListExtensions XListExtensions a a -- a
c-function XListProperties XListProperties a u a -- a
c-function XListHosts XListHosts a a a -- a
c-function XKeycodeToKeysym XKeycodeToKeysym a n n -- u
c-function XLookupKeysym XLookupKeysym a n -- u
c-function XGetKeyboardMapping XGetKeyboardMapping a n n a -- a
c-function XStringToKeysym XStringToKeysym a -- u
c-function XMaxRequestSize XMaxRequestSize a -- n
c-function XExtendedMaxRequestSize XExtendedMaxRequestSize a -- n
c-function XResourceManagerString XResourceManagerString a -- a
c-function XScreenResourceString XScreenResourceString a -- a
c-function XDisplayMotionBufferSize XDisplayMotionBufferSize a -- u
c-function XVisualIDFromVisual XVisualIDFromVisual a -- u
c-function XInitThreads XInitThreads  -- n
c-function XLockDisplay XLockDisplay a -- void
c-function XUnlockDisplay XUnlockDisplay a -- void
c-function XInitExtension XInitExtension a a -- a
c-function XAddExtension XAddExtension a -- a
c-function XFindOnExtensionList XFindOnExtensionList a n -- a
c-function XEHeadOfExtensionList XEHeadOfExtensionList a{*(XEDataObject*)} -- a
c-function XRootWindow XRootWindow a n -- u
c-function XDefaultRootWindow XDefaultRootWindow a -- u
c-function XRootWindowOfScreen XRootWindowOfScreen a -- u
c-function XDefaultVisual XDefaultVisual a n -- a
c-function XDefaultVisualOfScreen XDefaultVisualOfScreen a -- a
c-function XDefaultGC XDefaultGC a n -- a
c-function XDefaultGCOfScreen XDefaultGCOfScreen a -- a
c-function XBlackPixel XBlackPixel a n -- u
c-function XWhitePixel XWhitePixel a n -- u
c-function XAllPlanes XAllPlanes  -- u
c-function XBlackPixelOfScreen XBlackPixelOfScreen a -- u
c-function XWhitePixelOfScreen XWhitePixelOfScreen a -- u
c-function XNextRequest XNextRequest a -- u
c-function XLastKnownRequestProcessed XLastKnownRequestProcessed a -- u
c-function XServerVendor XServerVendor a -- a
c-function XDisplayString XDisplayString a -- a
c-function XDefaultColormap XDefaultColormap a n -- u
c-function XDefaultColormapOfScreen XDefaultColormapOfScreen a -- u
c-function XDisplayOfScreen XDisplayOfScreen a -- a
c-function XScreenOfDisplay XScreenOfDisplay a n -- a
c-function XDefaultScreenOfDisplay XDefaultScreenOfDisplay a -- a
c-function XEventMaskOfScreen XEventMaskOfScreen a -- n
c-function XScreenNumberOfScreen XScreenNumberOfScreen a -- n
c-function XSetErrorHandler XSetErrorHandler a -- a
c-function XSetIOErrorHandler XSetIOErrorHandler a -- a
c-function XListPixmapFormats XListPixmapFormats a a -- a
c-function XListDepths XListDepths a n a -- a
c-function XReconfigureWMWindow XReconfigureWMWindow a u n u a -- n
c-function XGetWMProtocols XGetWMProtocols a u a a -- n
c-function XSetWMProtocols XSetWMProtocols a u a n -- n
c-function XIconifyWindow XIconifyWindow a u n -- n
c-function XWithdrawWindow XWithdrawWindow a u n -- n
c-function XGetCommand XGetCommand a u a a -- n
c-function XGetWMColormapWindows XGetWMColormapWindows a u a a -- n
c-function XSetWMColormapWindows XSetWMColormapWindows a u a n -- n
c-function XFreeStringList XFreeStringList a -- void
c-function XSetTransientForHint XSetTransientForHint a u u -- n
c-function XActivateScreenSaver XActivateScreenSaver a -- n
c-function XAddHost XAddHost a a -- n
c-function XAddHosts XAddHosts a a n -- n
c-function XAddToExtensionList XAddToExtensionList a a -- n
c-function XAddToSaveSet XAddToSaveSet a u -- n
c-function XAllocColor XAllocColor a u a -- n
c-function XAllocColorCells XAllocColorCells a u n a u a u -- n
c-function XAllocColorPlanes XAllocColorPlanes a u n a n n n n a a a -- n
c-function XAllocNamedColor XAllocNamedColor a u a a a -- n
c-function XAllowEvents XAllowEvents a n u -- n
c-function XAutoRepeatOff XAutoRepeatOff a -- n
c-function XAutoRepeatOn XAutoRepeatOn a -- n
c-function XBell XBell a n -- n
c-function XBitmapBitOrder XBitmapBitOrder a -- n
c-function XBitmapPad XBitmapPad a -- n
c-function XBitmapUnit XBitmapUnit a -- n
c-function XCellsOfScreen XCellsOfScreen a -- n
c-function XChangeActivePointerGrab XChangeActivePointerGrab a u u u -- n
c-function XChangeGC XChangeGC a a u a -- n
c-function XChangeKeyboardControl XChangeKeyboardControl a u a -- n
c-function XChangeKeyboardMapping XChangeKeyboardMapping a n n a n -- n
c-function XChangePointerControl XChangePointerControl a n n n n n -- n
c-function XChangeProperty XChangeProperty a u u u n n a n -- n
c-function XChangeSaveSet XChangeSaveSet a u n -- n
c-function XChangeWindowAttributes XChangeWindowAttributes a u u a -- n
c-function XCheckIfEvent XCheckIfEvent a a a a -- n
c-function XCheckMaskEvent XCheckMaskEvent a n a -- n
c-function XCheckTypedEvent XCheckTypedEvent a n a -- n
c-function XCheckTypedWindowEvent XCheckTypedWindowEvent a u n a -- n
c-function XCheckWindowEvent XCheckWindowEvent a u n a -- n
c-function XCirculateSubwindows XCirculateSubwindows a u n -- n
c-function XCirculateSubwindowsDown XCirculateSubwindowsDown a u -- n
c-function XCirculateSubwindowsUp XCirculateSubwindowsUp a u -- n
c-function XClearArea XClearArea a u n n u u n -- n
c-function XClearWindow XClearWindow a u -- n
c-function XCloseDisplay XCloseDisplay a -- n
c-function XConfigureWindow XConfigureWindow a u u a -- n
c-function XConnectionNumber XConnectionNumber a -- n
c-function XConvertSelection XConvertSelection a u u u u u -- n
c-function XCopyArea XCopyArea a u u a n n u u n n -- n
c-function XCopyGC XCopyGC a a u a -- n
c-function XCopyPlane XCopyPlane a u u a n n u u n n u -- n
c-function XDefaultDepth XDefaultDepth a n -- n
c-function XDefaultDepthOfScreen XDefaultDepthOfScreen a -- n
c-function XDefaultScreen XDefaultScreen a -- n
c-function XDefineCursor XDefineCursor a u u -- n
c-function XDeleteProperty XDeleteProperty a u u -- n
c-function XDestroyWindow XDestroyWindow a u -- n
c-function XDestroySubwindows XDestroySubwindows a u -- n
c-function XDoesBackingStore XDoesBackingStore a -- n
c-function XDoesSaveUnders XDoesSaveUnders a -- n
c-function XDisableAccessControl XDisableAccessControl a -- n
c-function XDisplayCells XDisplayCells a n -- n
c-function XDisplayHeight XDisplayHeight a n -- n
c-function XDisplayHeightMM XDisplayHeightMM a n -- n
c-function XDisplayKeycodes XDisplayKeycodes a a a -- n
c-function XDisplayPlanes XDisplayPlanes a n -- n
c-function XDisplayWidth XDisplayWidth a n -- n
c-function XDisplayWidthMM XDisplayWidthMM a n -- n
c-function XDrawArc XDrawArc a u a n n u u n n -- n
c-function XDrawArcs XDrawArcs a u a a n -- n
c-function XDrawImageString XDrawImageString a u a n n a n -- n
c-function XDrawImageString16 XDrawImageString16 a u a n n a n -- n
c-function XDrawLine XDrawLine a u a n n n n -- n
c-function XDrawLines XDrawLines a u a a n n -- n
c-function XDrawPoint XDrawPoint a u a n n -- n
c-function XDrawPoints XDrawPoints a u a a n n -- n
c-function XDrawRectangle XDrawRectangle a u a n n u u -- n
c-function XDrawRectangles XDrawRectangles a u a a n -- n
c-function XDrawSegments XDrawSegments a u a a n -- n
c-function XDrawString XDrawString a u a n n a n -- n
c-function XDrawString16 XDrawString16 a u a n n a n -- n
c-function XDrawText XDrawText a u a n n a n -- n
c-function XDrawText16 XDrawText16 a u a n n a n -- n
c-function XEnableAccessControl XEnableAccessControl a -- n
c-function XEventsQueued XEventsQueued a n -- n
c-function XFetchName XFetchName a u a -- n
c-function XFillArc XFillArc a u a n n u u n n -- n
c-function XFillArcs XFillArcs a u a a n -- n
c-function XFillPolygon XFillPolygon a u a a n n n -- n
c-function XFillRectangle XFillRectangle a u a n n u u -- n
c-function XFillRectangles XFillRectangles a u a a n -- n
c-function XFlush XFlush a -- n
c-function XForceScreenSaver XForceScreenSaver a n -- n
c-function XFree XFree a -- n
c-function XFreeColormap XFreeColormap a u -- n
c-function XFreeColors XFreeColors a u a n u -- n
c-function XFreeCursor XFreeCursor a u -- n
c-function XFreeExtensionList XFreeExtensionList a -- n
c-function XFreeFont XFreeFont a a -- n
c-function XFreeFontInfo XFreeFontInfo a a n -- n
c-function XFreeFontNames XFreeFontNames a -- n
c-function XFreeFontPath XFreeFontPath a -- n
c-function XFreeGC XFreeGC a a -- n
c-function XFreeModifiermap XFreeModifiermap a -- n
c-function XFreePixmap XFreePixmap a u -- n
c-function XGeometry XGeometry a n a a u u u n n a a a a -- n
c-function XGetErrorDatabaseText XGetErrorDatabaseText a a a a a n -- n
c-function XGetErrorText XGetErrorText a n a n -- n
c-function XGetFontProperty XGetFontProperty a u a -- n
c-function XGetGCValues XGetGCValues a a u a -- n
c-function XGetGeometry XGetGeometry a u a a a a a a a -- n
c-function XGetIconName XGetIconName a u a -- n
c-function XGetInputFocus XGetInputFocus a a a -- n
c-function XGetKeyboardControl XGetKeyboardControl a a -- n
c-function XGetPointerControl XGetPointerControl a a a a -- n
c-function XGetPointerMapping XGetPointerMapping a a n -- n
c-function XGetScreenSaver XGetScreenSaver a a a a a -- n
c-function XGetTransientForHint XGetTransientForHint a u a -- n
c-function XGetWindowProperty XGetWindowProperty a u u n n n u a a a a a -- n
c-function XGetWindowAttributes XGetWindowAttributes a u a -- n
c-function XGrabButton XGrabButton a u u u n u n n u u -- n
c-function XGrabKey XGrabKey a n u u n n n -- n
c-function XGrabKeyboard XGrabKeyboard a u n n n u -- n
c-function XGrabPointer XGrabPointer a u n u n n u u u -- n
c-function XGrabServer XGrabServer a -- n
c-function XHeightMMOfScreen XHeightMMOfScreen a -- n
c-function XHeightOfScreen XHeightOfScreen a -- n
c-function XIfEvent XIfEvent a a a a -- n
c-function XImageByteOrder XImageByteOrder a -- n
c-function XInstallColormap XInstallColormap a u -- n
c-function XKeysymToKeycode XKeysymToKeycode a u -- n
c-function XKillClient XKillClient a u -- n
c-function XLookupColor XLookupColor a u a a a -- n
c-function XLowerWindow XLowerWindow a u -- n
c-function XMapRaised XMapRaised a u -- n
c-function XMapSubwindows XMapSubwindows a u -- n
c-function XMapWindow XMapWindow a u -- n
c-function XMaskEvent XMaskEvent a n a -- n
c-function XMaxCmapsOfScreen XMaxCmapsOfScreen a -- n
c-function XMinCmapsOfScreen XMinCmapsOfScreen a -- n
c-function XMoveResizeWindow XMoveResizeWindow a u n n u u -- n
c-function XMoveWindow XMoveWindow a u n n -- n
c-function XNextEvent XNextEvent a a -- n
c-function XNoOp XNoOp a -- n
c-function XParseColor XParseColor a u a a -- n
c-function XParseGeometry XParseGeometry a a a a a -- n
c-function XPeekEvent XPeekEvent a a -- n
c-function XPeekIfEvent XPeekIfEvent a a a a -- n
c-function XPending XPending a -- n
c-function XPlanesOfScreen XPlanesOfScreen a -- n
c-function XProtocolRevision XProtocolRevision a -- n
c-function XProtocolVersion XProtocolVersion a -- n
c-function XPutBackEvent XPutBackEvent a a -- n
c-function XPutImage XPutImage a u a a n n n n u u -- n
c-function XQLength XQLength a -- n
c-function XQueryBestCursor XQueryBestCursor a u u u a a -- n
c-function XQueryBestSize XQueryBestSize a n u u u a a -- n
c-function XQueryBestStipple XQueryBestStipple a u u u a a -- n
c-function XQueryBestTile XQueryBestTile a u u u a a -- n
c-function XQueryColor XQueryColor a u a -- n
c-function XQueryColors XQueryColors a u a n -- n
c-function XQueryExtension XQueryExtension a a a a a -- n
c-function XQueryKeymap XQueryKeymap a a -- n
c-function XQueryPointer XQueryPointer a u a a a a a a a -- n
c-function XQueryTextExtents XQueryTextExtents a u a n a a a a -- n
c-function XQueryTextExtents16 XQueryTextExtents16 a u a n a a a a -- n
c-function XQueryTree XQueryTree a u a a a a -- n
c-function XRaiseWindow XRaiseWindow a u -- n
c-function XReadBitmapFile XReadBitmapFile a u a a a a a a -- n
c-function XReadBitmapFileData XReadBitmapFileData a a a a a a -- n
c-function XRebindKeysym XRebindKeysym a u a n a n -- n
c-function XRecolorCursor XRecolorCursor a u a a -- n
c-function XRefreshKeyboardMapping XRefreshKeyboardMapping a -- n
c-function XRemoveFromSaveSet XRemoveFromSaveSet a u -- n
c-function XRemoveHost XRemoveHost a a -- n
c-function XRemoveHosts XRemoveHosts a a n -- n
c-function XReparentWindow XReparentWindow a u u n n -- n
c-function XResetScreenSaver XResetScreenSaver a -- n
c-function XResizeWindow XResizeWindow a u u u -- n
c-function XRestackWindows XRestackWindows a a n -- n
c-function XRotateBuffers XRotateBuffers a n -- n
c-function XRotateWindowProperties XRotateWindowProperties a u a n n -- n
c-function XScreenCount XScreenCount a -- n
c-function XSelectInput XSelectInput a u n -- n
c-function XSendEvent XSendEvent a u n n a -- n
c-function XSetAccessControl XSetAccessControl a n -- n
c-function XSetArcMode XSetArcMode a a n -- n
c-function XSetBackground XSetBackground a a u -- n
c-function XSetClipMask XSetClipMask a a u -- n
c-function XSetClipOrigin XSetClipOrigin a a n n -- n
c-function XSetClipRectangles XSetClipRectangles a a n n a n n -- n
c-function XSetCloseDownMode XSetCloseDownMode a n -- n
c-function XSetCommand XSetCommand a u a n -- n
c-function XSetDashes XSetDashes a a n a n -- n
c-function XSetFillRule XSetFillRule a a n -- n
c-function XSetFillStyle XSetFillStyle a a n -- n
c-function XSetFont XSetFont a a u -- n
c-function XSetFontPath XSetFontPath a a n -- n
c-function XSetForeground XSetForeground a a u -- n
c-function XSetFunction XSetFunction a a n -- n
c-function XSetGraphicsExposures XSetGraphicsExposures a a n -- n
c-function XSetIconName XSetIconName a u a -- n
c-function XSetInputFocus XSetInputFocus a u n u -- n
c-function XSetLineAttributes XSetLineAttributes a a u n n n -- n
c-function XSetModifierMapping XSetModifierMapping a a -- n
c-function XSetPlaneMask XSetPlaneMask a a u -- n
c-function XSetPointerMapping XSetPointerMapping a a n -- n
c-function XSetScreenSaver XSetScreenSaver a n n n n -- n
c-function XSetSelectionOwner XSetSelectionOwner a u u u -- n
c-function XSetState XSetState a a u u n u -- n
c-function XSetStipple XSetStipple a a u -- n
c-function XSetSubwindowMode XSetSubwindowMode a a n -- n
c-function XSetTSOrigin XSetTSOrigin a a n n -- n
c-function XSetTile XSetTile a a u -- n
c-function XSetWindowBackground XSetWindowBackground a u u -- n
c-function XSetWindowBackgroundPixmap XSetWindowBackgroundPixmap a u u -- n
c-function XSetWindowBorder XSetWindowBorder a u u -- n
c-function XSetWindowBorderPixmap XSetWindowBorderPixmap a u u -- n
c-function XSetWindowBorderWidth XSetWindowBorderWidth a u u -- n
c-function XSetWindowColormap XSetWindowColormap a u u -- n
c-function XStoreBuffer XStoreBuffer a a n n -- n
c-function XStoreBytes XStoreBytes a a n -- n
c-function XStoreColor XStoreColor a u a -- n
c-function XStoreColors XStoreColors a u a n -- n
c-function XStoreName XStoreName a u a -- n
c-function XStoreNamedColor XStoreNamedColor a u a u n -- n
c-function XSync XSync a n -- n
c-function XTextExtents XTextExtents a a n a a a a -- n
c-function XTextExtents16 XTextExtents16 a a n a a a a -- n
c-function XTextWidth XTextWidth a a n -- n
c-function XTextWidth16 XTextWidth16 a a n -- n
c-function XTranslateCoordinates XTranslateCoordinates a u u n n a a a -- n
c-function XUndefineCursor XUndefineCursor a u -- n
c-function XUngrabButton XUngrabButton a u u u -- n
c-function XUngrabKey XUngrabKey a n u u -- n
c-function XUngrabKeyboard XUngrabKeyboard a u -- n
c-function XUngrabPointer XUngrabPointer a u -- n
c-function XUngrabServer XUngrabServer a -- n
c-function XUninstallColormap XUninstallColormap a u -- n
c-function XUnloadFont XUnloadFont a u -- n
c-function XUnmapSubwindows XUnmapSubwindows a u -- n
c-function XUnmapWindow XUnmapWindow a u -- n
c-function XVendorRelease XVendorRelease a -- n
c-function XWarpPointer XWarpPointer a u u n n u u n n -- n
c-function XWidthMMOfScreen XWidthMMOfScreen a -- n
c-function XWidthOfScreen XWidthOfScreen a -- n
c-function XWindowEvent XWindowEvent a u n a -- n
c-function XWriteBitmapFile XWriteBitmapFile a a u u u n n -- n
c-function XSupportsLocale XSupportsLocale  -- n
c-function XSetLocaleModifiers XSetLocaleModifiers a -- a
c-function XOpenOM XOpenOM a a a a -- a
c-function XCloseOM XCloseOM a -- n
c-function XSetOMValues XSetOMValues a a a a -- a
c-function XGetOMValues XGetOMValues a a a a -- a
c-function XDisplayOfOM XDisplayOfOM a -- a
c-function XLocaleOfOM XLocaleOfOM a -- a
c-function XCreateOC XCreateOC a a a a -- a
c-function XDestroyOC XDestroyOC a -- void
c-function XOMOfOC XOMOfOC a -- a
c-function XSetOCValues XSetOCValues a a a a -- a
c-function XGetOCValues XGetOCValues a a a a -- a
c-function XCreateFontSet XCreateFontSet a a a a a -- a
c-function XFreeFontSet XFreeFontSet a a -- void
c-function XFontsOfFontSet XFontsOfFontSet a a a -- n
c-function XBaseFontNameListOfFontSet XBaseFontNameListOfFontSet a -- a
c-function XLocaleOfFontSet XLocaleOfFontSet a -- a
c-function XContextDependentDrawing XContextDependentDrawing a -- n
c-function XDirectionalDependentDrawing XDirectionalDependentDrawing a -- n
c-function XContextualDrawing XContextualDrawing a -- n
c-function XExtentsOfFontSet XExtentsOfFontSet a -- a
c-function XmbTextEscapement XmbTextEscapement a a n -- n
c-function XwcTextEscapement XwcTextEscapement a a n -- n
c-function Xutf8TextEscapement Xutf8TextEscapement a a n -- n
c-function XmbTextExtents XmbTextExtents a a n a a -- n
c-function XwcTextExtents XwcTextExtents a a n a a -- n
c-function Xutf8TextExtents Xutf8TextExtents a a n a a -- n
c-function XmbTextPerCharExtents XmbTextPerCharExtents a a n a a n a a a -- n
c-function XwcTextPerCharExtents XwcTextPerCharExtents a a n a a n a a a -- n
c-function Xutf8TextPerCharExtents Xutf8TextPerCharExtents a a n a a n a a a -- n
c-function XmbDrawText XmbDrawText a u a n n a n -- void
c-function XwcDrawText XwcDrawText a u a n n a n -- void
c-function Xutf8DrawText Xutf8DrawText a u a n n a n -- void
c-function XmbDrawString XmbDrawString a u a a n n a n -- void
c-function XwcDrawString XwcDrawString a u a a n n a n -- void
c-function Xutf8DrawString Xutf8DrawString a u a a n n a n -- void
c-function XmbDrawImageString XmbDrawImageString a u a a n n a n -- void
c-function XwcDrawImageString XwcDrawImageString a u a a n n a n -- void
c-function Xutf8DrawImageString Xutf8DrawImageString a u a a n n a n -- void
c-function XOpenIM XOpenIM a a a a -- a
c-function XCloseIM XCloseIM a -- n
c-function XGetIMValues XGetIMValues a a a a -- a
c-function XSetIMValues XSetIMValues a a a a -- a
c-function XDisplayOfIM XDisplayOfIM a -- a
c-function XLocaleOfIM XLocaleOfIM a -- a
c-function XCreateIC XCreateIC a a a a -- a
c-function XDestroyIC XDestroyIC a -- void
c-function XSetICFocus XSetICFocus a -- void
c-function XUnsetICFocus XUnsetICFocus a -- void
c-function XwcResetIC XwcResetIC a -- a
c-function XmbResetIC XmbResetIC a -- a
c-function Xutf8ResetIC Xutf8ResetIC a -- a
c-function XSetICValues XSetICValues a a a a -- a
c-function XGetICValues XGetICValues a a a a -- a
c-function XIMOfIC XIMOfIC a -- a
c-function XFilterEvent XFilterEvent a u -- n
c-function XmbLookupString XmbLookupString a a a n a a -- n
c-function XwcLookupString XwcLookupString a a a n a a -- n
c-function Xutf8LookupString Xutf8LookupString a a a n a a -- n
c-function XVaCreateNestedList XVaCreateNestedList n a a a -- a
c-function XRegisterIMInstantiateCallback XRegisterIMInstantiateCallback a a a a a a -- n
c-function XUnregisterIMInstantiateCallback XUnregisterIMInstantiateCallback a a a a a a -- n
c-function XInternalConnectionNumbers XInternalConnectionNumbers a a a -- n
c-function XProcessInternalConnection XProcessInternalConnection a n -- void
c-function XAddConnectionWatch XAddConnectionWatch a a a -- n
c-function XRemoveConnectionWatch XRemoveConnectionWatch a a a -- void
c-function XSetAuthorization XSetAuthorization a n a n -- void
c-function _Xmbtowc _Xmbtowc a a n -- n
c-function _Xwctomb _Xwctomb a n -- n
c-function XGetEventData XGetEventData a a -- n
c-function XFreeEventData XFreeEventData a a -- void
c-function XAllocClassHint XAllocClassHint  -- a
c-function XAllocIconSize XAllocIconSize  -- a
c-function XAllocSizeHints XAllocSizeHints  -- a
c-function XAllocStandardColormap XAllocStandardColormap  -- a
c-function XAllocWMHints XAllocWMHints  -- a
c-function XClipBox XClipBox a a -- n
c-function XCreateRegion XCreateRegion  -- a
c-function XDefaultString XDefaultString  -- a
c-function XDeleteContext XDeleteContext a u n -- n
c-function XDestroyRegion XDestroyRegion a -- n
c-function XEmptyRegion XEmptyRegion a -- n
c-function XEqualRegion XEqualRegion a a -- n
c-function XFindContext XFindContext a u n a -- n
c-function XGetClassHint XGetClassHint a u a -- n
c-function XGetIconSizes XGetIconSizes a u a a -- n
c-function XGetNormalHints XGetNormalHints a u a -- n
c-function XGetRGBColormaps XGetRGBColormaps a u a a u -- n
c-function XGetSizeHints XGetSizeHints a u a u -- n
c-function XGetStandardColormap XGetStandardColormap a u a u -- n
c-function XGetTextProperty XGetTextProperty a u a u -- n
c-function XGetVisualInfo XGetVisualInfo a n a a -- a
c-function XGetWMClientMachine XGetWMClientMachine a u a -- n
c-function XGetWMHints XGetWMHints a u -- a
c-function XGetWMIconName XGetWMIconName a u a -- n
c-function XGetWMName XGetWMName a u a -- n
c-function XGetWMNormalHints XGetWMNormalHints a u a a -- n
c-function XGetWMSizeHints XGetWMSizeHints a u a a u -- n
c-function XGetZoomHints XGetZoomHints a u a -- n
c-function XIntersectRegion XIntersectRegion a a a -- n
c-function XConvertCase XConvertCase u a a -- void
c-function XLookupString XLookupString a a n a a -- n
c-function XMatchVisualInfo XMatchVisualInfo a n n n a -- n
c-function XOffsetRegion XOffsetRegion a n n -- n
c-function XPointInRegion XPointInRegion a n n -- n
c-function XPolygonRegion XPolygonRegion a n n -- a
c-function XRectInRegion XRectInRegion a n n u u -- n
c-function XSaveContext XSaveContext a u n a -- n
c-function XSetClassHint XSetClassHint a u a -- n
c-function XSetIconSizes XSetIconSizes a u a n -- n
c-function XSetNormalHints XSetNormalHints a u a -- n
c-function XSetRGBColormaps XSetRGBColormaps a u a n u -- void
c-function XSetSizeHints XSetSizeHints a u a u -- n
c-function XSetStandardProperties XSetStandardProperties a u a a u a n a -- n
c-function XSetTextProperty XSetTextProperty a u a u -- void
c-function XSetWMClientMachine XSetWMClientMachine a u a -- void
c-function XSetWMHints XSetWMHints a u a -- n
c-function XSetWMIconName XSetWMIconName a u a -- void
c-function XSetWMName XSetWMName a u a -- void
c-function XSetWMNormalHints XSetWMNormalHints a u a -- void
c-function XSetWMProperties XSetWMProperties a u a a a n a a a -- void
c-function XmbSetWMProperties XmbSetWMProperties a u a a a n a a a -- void
c-function Xutf8SetWMProperties Xutf8SetWMProperties a u a a a n a a a -- void
c-function XSetWMSizeHints XSetWMSizeHints a u a u -- void
c-function XSetRegion XSetRegion a a a -- n
c-function XSetStandardColormap XSetStandardColormap a u a u -- void
c-function XSetZoomHints XSetZoomHints a u a -- n
c-function XShrinkRegion XShrinkRegion a n n -- n
c-function XStringListToTextProperty XStringListToTextProperty a n a -- n
c-function XSubtractRegion XSubtractRegion a a a -- n
c-function XmbTextListToTextProperty XmbTextListToTextProperty a a n n a -- n
c-function XwcTextListToTextProperty XwcTextListToTextProperty a a n n a -- n
c-function Xutf8TextListToTextProperty Xutf8TextListToTextProperty a a n n a -- n
c-function XwcFreeStringList XwcFreeStringList a -- void
c-function XTextPropertyToStringList XTextPropertyToStringList a a a -- n
c-function XmbTextPropertyToTextList XmbTextPropertyToTextList a a a a -- n
c-function XwcTextPropertyToTextList XwcTextPropertyToTextList a a a a -- n
c-function Xutf8TextPropertyToTextList Xutf8TextPropertyToTextList a a a a -- n
c-function XUnionRectWithRegion XUnionRectWithRegion a a a -- n
c-function XUnionRegion XUnionRegion a a a -- n
c-function XWMGeometry XWMGeometry a n a a u a a a a a a -- n
c-function XXorRegion XXorRegion a a a -- n
