#include <gforth/0.7.9_20150820/libcc.h>
#include <netdb.h>
#include <unistd.h>
ptrpair libgfsocket_LTX_gforth_c_gethostname_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=gethostname((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
#include <sys/types.h>
#include <sys/socket.h>
ptrpair libgfsocket_LTX_gforth_c_socket_nnn_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=socket(sp[2],sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfsocket_LTX_gforth_c_connect_nan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=connect(sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfsocket_LTX_gforth_c_send_nann_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=send(sp[3],(void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfsocket_LTX_gforth_c_recv_nann_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=recv(sp[3],(void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfsocket_LTX_gforth_c_recvfrom_nannaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=recvfrom(sp[5],(void *)(sp[4]),sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfsocket_LTX_gforth_c_sendto_nannan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=sendto(sp[5],(void *)(sp[4]),sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfsocket_LTX_gforth_c_listen_nn_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=listen(sp[1],sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfsocket_LTX_gforth_c_bind_nan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=bind(sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfsocket_LTX_gforth_c_accept_naa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=accept(sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
#include <arpa/inet.h>
ptrpair libgfsocket_LTX_gforth_c_htonl_n_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=htonl(sp[0]);
  return x;
}
ptrpair libgfsocket_LTX_gforth_c_htons_n_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=htons(sp[0]);
  return x;
}
ptrpair libgfsocket_LTX_gforth_c_ntohl_n_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=ntohl(sp[0]);
  return x;
}
#include <netdb.h>
ptrpair libgfsocket_LTX_gforth_c_getaddrinfo_aaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=getaddrinfo((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfsocket_LTX_gforth_c_freeaddrinfo_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  freeaddrinfo((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfsocket_LTX_gforth_c_gai_strerror_n_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)gai_strerror(sp[0]);
  return x;
}
ptrpair libgfsocket_LTX_gforth_c_setsockopt_nnnan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=setsockopt(sp[4],sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfsocket_LTX_gforth_c_getsockname_naa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=getsockname(sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
hash_128 gflibcc_hash_socket = "\x1B\x67\x79\x2C\x4D\x13\xF2\xAE\x11\x75\xF2\x48\xAA\x49\x49\x5D";
