#include <gforth/0.7.9_20150820/libcc.h>
#include <stdio.h>
#include <errno.h>
#include <unistd.h>
#include <poll.h>
#include <fcntl.h>
#if HAVE_GETPAGESIZE
#elif HAVE_SYSCONF && defined(_SC_PAGESIZE)
#define getpagesize() sysconf(_SC_PAGESIZE)
#elif PAGESIZE
#define getpagesize() PAGESIZE
#endif
ptrpair libgflibc_LTX_gforth_c_errno__n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=(errno);
  x.sp = sp+-1;
  return x;
}
ptrpair libgflibc_LTX_gforth_c_getpagesize__n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=getpagesize();
  x.sp = sp+-1;
  return x;
}
ptrpair libgflibc_LTX_gforth_c_fileno_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=fileno((FILE*)(sp[0]));
  return x;
}
ptrpair libgflibc_LTX_gforth_c_poll_ann_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=poll((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgflibc_LTX_gforth_c_fdopen_na_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)fdopen(sp[1],(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgflibc_LTX_gforth_c_fcntl_nnn_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=fcntl(sp[2],sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgflibc_LTX_gforth_c_open_ann_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=open((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgflibc_LTX_gforth_c_read_nan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=read(sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgflibc_LTX_gforth_c_write_nan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=write(sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgflibc_LTX_gforth_c_close_n_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=close(sp[0]);
  return x;
}
hash_128 gflibcc_hash_libc = "\x51\x63\xB7\x8A\xCC\x17\xF3\xAC\x2B\xBC\x03\x6C\x69\x11\x64\xD0";
