#include <gforth/0.7.9_20150820/libcc.h>
#include <unistd.h>
#include <sys/mman.h>
#include <limits.h>
ptrpair libgfmmap_LTX_gforth_c_mmap_annnnn_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=(Cell)mmap((void *)(sp[5]),sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfmmap_LTX_gforth_c_munmap_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=munmap((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfmmap_LTX_gforth_c_madvise_ann_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=madvise((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfmmap_LTX_gforth_c_mprotect_ann_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=mprotect((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfmmap_LTX_gforth_c_mlock_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=mlock((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfmmap_LTX_gforth_c_munlock_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=munlock((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
hash_128 gflibcc_hash_mmap = "\x45\xBB\xAF\xC3\x55\x97\xA1\xFB\x22\xE6\x22\x9A\x4E\x89\x03\x59";
