#include <gforth/0.7.9_20150820/libcc.h>
#include <GLES3/gl3.h>
#include <GLES3/gl3ext.h>
#include <EGL/egl.h>
ptrpair libgfopengles3_LTX_gforth_c_glActiveTexture_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glActiveTexture(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glAttachShader_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glAttachShader(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glBindAttribLocation_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glBindAttribLocation(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glBindBuffer_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glBindBuffer(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glBindFramebuffer_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glBindFramebuffer(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glBindRenderbuffer_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glBindRenderbuffer(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glBindTexture_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glBindTexture(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glBlendColor_rrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=3;
  glBlendColor(fp[3],fp[2],fp[1],fp[0]);
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glBlendEquation_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glBlendEquation(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glBlendEquationSeparate_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glBlendEquationSeparate(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glBlendFunc_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glBlendFunc(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glBlendFuncSeparate_uuuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glBlendFuncSeparate(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glBufferData_uaau_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glBufferData(sp[3],(void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glBufferSubData_uaaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glBufferSubData(sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glCheckFramebufferStatus_u_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glCheckFramebufferStatus(sp[0]);
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glClear_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glClear(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glClearColor_rrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=3;
  glClearColor(fp[3],fp[2],fp[1],fp[0]);
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glClearDepthf_r_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=0;
  glClearDepthf(fp[0]);
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glClearStencil_n_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glClearStencil(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glColorMask_nnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glColorMask(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glCompileShader_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glCompileShader(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glCompressedTexImage2D_ununnnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  glCompressedTexImage2D(sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+8;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glCompressedTexSubImage2D_unnnnnuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  glCompressedTexSubImage2D(sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+9;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glCopyTexImage2D_ununnnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  glCopyTexImage2D(sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+8;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glCopyTexSubImage2D_unnnnnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  glCopyTexSubImage2D(sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+8;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glCreateProgram__u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=glCreateProgram();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glCreateShader_u_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glCreateShader(sp[0]);
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glCullFace_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glCullFace(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDeleteBuffers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDeleteBuffers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDeleteFramebuffers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDeleteFramebuffers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDeleteProgram_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glDeleteProgram(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDeleteRenderbuffers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDeleteRenderbuffers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDeleteShader_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glDeleteShader(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDeleteTextures_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDeleteTextures(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDepthFunc_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glDepthFunc(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDepthMask_n_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glDepthMask(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDepthRangef_rr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=1;
  glDepthRangef(fp[1],fp[0]);
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDetachShader_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDetachShader(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDisable_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glDisable(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDisableVertexAttribArray_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glDisableVertexAttribArray(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDrawArrays_unn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glDrawArrays(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDrawElements_unua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glDrawElements(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glEnable_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glEnable(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glEnableVertexAttribArray_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glEnableVertexAttribArray(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glFinish__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glFinish();
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glFlush__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glFlush();
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glFramebufferRenderbuffer_uuuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glFramebufferRenderbuffer(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glFramebufferTexture2D_uuuun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glFramebufferTexture2D(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glFrontFace_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glFrontFace(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGenBuffers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGenBuffers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGenerateMipmap_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glGenerateMipmap(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGenFramebuffers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGenFramebuffers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGenRenderbuffers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGenRenderbuffers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGenTextures_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGenTextures(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetActiveAttrib_uunaaaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glGetActiveAttrib(sp[6],sp[5],sp[4],(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetActiveUniform_uunaaaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glGetActiveUniform(sp[6],sp[5],sp[4],(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetAttachedShaders_unaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetAttachedShaders(sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetAttribLocation_ua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=glGetAttribLocation(sp[1],(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetBooleanv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGetBooleanv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetBufferParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetBufferParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetError__u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=glGetError();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetFloatv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGetFloatv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetFramebufferAttachmentParameteriv_uuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetFramebufferAttachmentParameteriv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetIntegerv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGetIntegerv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetProgramiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetProgramiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetProgramInfoLog_unaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetProgramInfoLog(sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetRenderbufferParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetRenderbufferParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetShaderiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetShaderiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetShaderInfoLog_unaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetShaderInfoLog(sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetShaderPrecisionFormat_uuaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetShaderPrecisionFormat(sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetShaderSource_unaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetShaderSource(sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetString_u_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)glGetString(sp[0]);
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetTexParameterfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetTexParameterfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetTexParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetTexParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetUniformfv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetUniformfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetUniformiv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetUniformiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetUniformLocation_ua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=glGetUniformLocation(sp[1],(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetVertexAttribfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetVertexAttribfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetVertexAttribiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetVertexAttribiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetVertexAttribPointerv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetVertexAttribPointerv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glHint_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glHint(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glIsBuffer_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsBuffer(sp[0]);
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glIsEnabled_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsEnabled(sp[0]);
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glIsFramebuffer_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsFramebuffer(sp[0]);
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glIsProgram_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsProgram(sp[0]);
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glIsRenderbuffer_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsRenderbuffer(sp[0]);
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glIsShader_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsShader(sp[0]);
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glIsTexture_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsTexture(sp[0]);
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glLineWidth_r_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=0;
  glLineWidth(fp[0]);
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glLinkProgram_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glLinkProgram(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glPixelStorei_un_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glPixelStorei(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glPolygonOffset_rr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=1;
  glPolygonOffset(fp[1],fp[0]);
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glReadPixels_nnnnuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glReadPixels(sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glReleaseShaderCompiler__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glReleaseShaderCompiler();
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glRenderbufferStorage_uunn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glRenderbufferStorage(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glSampleCoverage_rn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=0;
  glSampleCoverage(fp[0],sp[0]);
  x.sp = sp+1;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glScissor_nnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glScissor(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glShaderBinary_nauan_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glShaderBinary(sp[4],(void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glShaderSource_unaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glShaderSource(sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glStencilFunc_unu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glStencilFunc(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glStencilFuncSeparate_uunu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glStencilFuncSeparate(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glStencilMask_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glStencilMask(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glStencilMaskSeparate_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glStencilMaskSeparate(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glStencilOp_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glStencilOp(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glStencilOpSeparate_uuuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glStencilOpSeparate(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glTexImage2D_unnnnnuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  glTexImage2D(sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+9;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glTexParameterf_uur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=0;
  glTexParameterf(sp[1],sp[0],fp[0]);
  x.sp = sp+2;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glTexParameterfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTexParameterfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glTexParameteri_uun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTexParameteri(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glTexParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTexParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glTexSubImage2D_unnnnnuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  glTexSubImage2D(sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+9;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform1f_nr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=0;
  glUniform1f(sp[0],fp[0]);
  x.sp = sp+1;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform1fv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform1fv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform1i_nn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glUniform1i(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform1iv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform1iv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform2f_nrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=1;
  glUniform2f(sp[0],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform2fv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform2fv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform2i_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform2i(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform2iv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform2iv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform3f_nrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=2;
  glUniform3f(sp[0],fp[2],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform3fv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform3fv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform3i_nnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniform3i(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform3iv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform3iv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform4f_nrrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=3;
  glUniform4f(sp[0],fp[3],fp[2],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform4fv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform4fv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform4i_nnnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glUniform4i(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform4iv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform4iv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniformMatrix2fv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix2fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniformMatrix3fv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix3fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniformMatrix4fv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix4fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUseProgram_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glUseProgram(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glValidateProgram_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glValidateProgram(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glVertexAttrib1f_ur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=0;
  glVertexAttrib1f(sp[0],fp[0]);
  x.sp = sp+1;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glVertexAttrib1fv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib1fv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glVertexAttrib2f_urr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=1;
  glVertexAttrib2f(sp[0],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glVertexAttrib2fv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib2fv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glVertexAttrib3f_urrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=2;
  glVertexAttrib3f(sp[0],fp[2],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glVertexAttrib3fv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib3fv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glVertexAttrib4f_urrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=3;
  glVertexAttrib4f(sp[0],fp[3],fp[2],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glVertexAttrib4fv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib4fv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glVertexAttribPointer_ununna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glVertexAttribPointer(sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glViewport_nnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glViewport(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glReadBuffer_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glReadBuffer(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDrawRangeElements_uuunua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glDrawRangeElements(sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glTexImage3D_unnnnnnuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=9, farg0=-1;
  glTexImage3D(sp[9],sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+10;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glTexSubImage3D_unnnnnnnuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=10, farg0=-1;
  glTexSubImage3D(sp[10],sp[9],sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+11;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glCopyTexSubImage3D_unnnnnnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  glCopyTexSubImage3D(sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+9;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glCompressedTexImage3D_ununnnnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  glCompressedTexImage3D(sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+9;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glCompressedTexSubImage3D_unnnnnnnuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=10, farg0=-1;
  glCompressedTexSubImage3D(sp[10],sp[9],sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+11;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGenQueries_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGenQueries(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDeleteQueries_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDeleteQueries(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glIsQuery_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsQuery(sp[0]);
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glBeginQuery_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glBeginQuery(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glEndQuery_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glEndQuery(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetQueryiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetQueryiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetQueryObjectuiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetQueryObjectuiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUnmapBuffer_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glUnmapBuffer(sp[0]);
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetBufferPointerv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetBufferPointerv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDrawBuffers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDrawBuffers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniformMatrix2x3fv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix2x3fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniformMatrix3x2fv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix3x2fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniformMatrix2x4fv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix2x4fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniformMatrix4x2fv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix4x2fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniformMatrix3x4fv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix3x4fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniformMatrix4x3fv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix4x3fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glBlitFramebuffer_nnnnnnnnuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=9, farg0=-1;
  glBlitFramebuffer(sp[9],sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+10;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glRenderbufferStorageMultisample_ununn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glRenderbufferStorageMultisample(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glFramebufferTextureLayer_uuunn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glFramebufferTextureLayer(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glMapBufferRange_uaau_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)glMapBufferRange(sp[3],(void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glFlushMappedBufferRange_uaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glFlushMappedBufferRange(sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glBindVertexArray_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glBindVertexArray(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDeleteVertexArrays_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDeleteVertexArrays(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGenVertexArrays_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGenVertexArrays(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glIsVertexArray_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsVertexArray(sp[0]);
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetIntegeri_v_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetIntegeri_v(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glBeginTransformFeedback_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glBeginTransformFeedback(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glEndTransformFeedback__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glEndTransformFeedback();
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glBindBufferRange_uuuaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glBindBufferRange(sp[4],sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glBindBufferBase_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glBindBufferBase(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glTransformFeedbackVaryings_unau_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glTransformFeedbackVaryings(sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetTransformFeedbackVarying_uunaaaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glGetTransformFeedbackVarying(sp[6],sp[5],sp[4],(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glVertexAttribIPointer_ununa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glVertexAttribIPointer(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetVertexAttribIiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetVertexAttribIiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetVertexAttribIuiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetVertexAttribIuiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glVertexAttribI4i_unnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glVertexAttribI4i(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glVertexAttribI4ui_uuuuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glVertexAttribI4ui(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glVertexAttribI4iv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribI4iv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glVertexAttribI4uiv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribI4uiv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetUniformuiv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetUniformuiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetFragDataLocation_ua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=glGetFragDataLocation(sp[1],(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform1ui_nu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glUniform1ui(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform2ui_nuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform2ui(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform3ui_nuuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniform3ui(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform4ui_nuuuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glUniform4ui(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform1uiv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform1uiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform2uiv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform2uiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform3uiv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform3uiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniform4uiv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform4uiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glClearBufferiv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glClearBufferiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glClearBufferuiv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glClearBufferuiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glClearBufferfv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glClearBufferfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glClearBufferfi_unrn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=0;
  glClearBufferfi(sp[2],sp[1],fp[0],sp[0]);
  x.sp = sp+3;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetStringi_uu_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)glGetStringi(sp[1],sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glCopyBufferSubData_uuaaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glCopyBufferSubData(sp[4],sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetUniformIndices_unaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetUniformIndices(sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetActiveUniformsiv_unaua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glGetActiveUniformsiv(sp[4],sp[3],(void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetUniformBlockIndex_ua_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=glGetUniformBlockIndex(sp[1],(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetActiveUniformBlockiv_uuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetActiveUniformBlockiv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetActiveUniformBlockName_uunaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glGetActiveUniformBlockName(sp[4],sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glUniformBlockBinding_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniformBlockBinding(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDrawArraysInstanced_unnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glDrawArraysInstanced(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDrawElementsInstanced_unuan_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glDrawElementsInstanced(sp[4],sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glFenceSync_uu_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)glFenceSync(sp[1],sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glIsSync_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsSync((void *)(sp[0]));
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDeleteSync_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glDeleteSync((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glClientWaitSync_aun_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=glClientWaitSync((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glWaitSync_aun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glWaitSync((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetInteger64v_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGetInteger64v(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetSynciv_aunaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glGetSynciv((void *)(sp[4]),sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetInteger64i_v_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetInteger64i_v(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetBufferParameteri64v_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetBufferParameteri64v(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGenSamplers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGenSamplers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDeleteSamplers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDeleteSamplers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glIsSampler_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsSampler(sp[0]);
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glBindSampler_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glBindSampler(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glSamplerParameteri_uun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glSamplerParameteri(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glSamplerParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glSamplerParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glSamplerParameterf_uur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=0;
  glSamplerParameterf(sp[1],sp[0],fp[0]);
  x.sp = sp+2;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glSamplerParameterfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glSamplerParameterfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetSamplerParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetSamplerParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetSamplerParameterfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetSamplerParameterfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glVertexAttribDivisor_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribDivisor(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glBindTransformFeedback_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glBindTransformFeedback(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glDeleteTransformFeedbacks_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDeleteTransformFeedbacks(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGenTransformFeedbacks_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGenTransformFeedbacks(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glIsTransformFeedback_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsTransformFeedback(sp[0]);
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glPauseTransformFeedback__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glPauseTransformFeedback();
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glResumeTransformFeedback__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glResumeTransformFeedback();
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetProgramBinary_unaaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glGetProgramBinary(sp[4],sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glProgramBinary_uuan_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glProgramBinary(sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glProgramParameteri_uun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glProgramParameteri(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glInvalidateFramebuffer_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glInvalidateFramebuffer(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glInvalidateSubFramebuffer_unannnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glInvalidateSubFramebuffer(sp[6],sp[5],(void *)(sp[4]),sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glTexStorage2D_ununn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glTexStorage2D(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glTexStorage3D_ununnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glTexStorage3D(sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_glGetInternalformativ_uuuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glGetInternalformativ(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
#define CALLBACK___eglMustCastToProperFunctionPointerType_(I) \
void libgfopengles3_LTX_gforth_cb___eglMustCastToProperFunctionPointerType__##I () \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengles3_LTX_gforth_cbips___eglMustCastToProperFunctionPointerType_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
; \
}
Xt* libgfopengles3_LTX_gforth_cbips___eglMustCastToProperFunctionPointerType_[2] = {
  0, 0,};
CALLBACK___eglMustCastToProperFunctionPointerType_(0)
CALLBACK___eglMustCastToProperFunctionPointerType_(1)
const Address libgfopengles3_LTX_gforth_callbacks___eglMustCastToProperFunctionPointerType_[2] = {
  (Address)libgfopengles3_LTX_gforth_cb___eglMustCastToProperFunctionPointerType__0,
  (Address)libgfopengles3_LTX_gforth_cb___eglMustCastToProperFunctionPointerType__1,
};
ptrpair libgfopengles3_LTX_gforth_c_eglGetError__n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=eglGetError();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglGetDisplay_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)eglGetDisplay((void *)(sp[0]));
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglInitialize_aaa_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=eglInitialize((void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglTerminate_a_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=eglTerminate((void *)(sp[0]));
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglQueryString_an_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)eglQueryString((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglGetConfigs_aana_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=eglGetConfigs((void *)(sp[3]),(void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglChooseConfig_aaana_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=eglChooseConfig((void *)(sp[4]),(void *)(sp[3]),(void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglGetConfigAttrib_aana_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=eglGetConfigAttrib((void *)(sp[3]),(void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglCreateWindowSurface_aana_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)eglCreateWindowSurface((void *)(sp[3]),(void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglCreatePbufferSurface_aaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=(Cell)eglCreatePbufferSurface((void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglCreatePixmapSurface_aana_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)eglCreatePixmapSurface((void *)(sp[3]),(void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglDestroySurface_aa_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=eglDestroySurface((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglQuerySurface_aana_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=eglQuerySurface((void *)(sp[3]),(void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglBindAPI_u_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=eglBindAPI(sp[0]);
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglQueryAPI__u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=eglQueryAPI();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglWaitClient__u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=eglWaitClient();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglReleaseThread__u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=eglReleaseThread();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglCreatePbufferFromClientBuffer_auaaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=(Cell)eglCreatePbufferFromClientBuffer((void *)(sp[4]),sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglSurfaceAttrib_aann_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=eglSurfaceAttrib((void *)(sp[3]),(void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglBindTexImage_aan_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=eglBindTexImage((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglReleaseTexImage_aan_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=eglReleaseTexImage((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglSwapInterval_an_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=eglSwapInterval((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglCreateContext_aaaa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)eglCreateContext((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglDestroyContext_aa_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=eglDestroyContext((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglMakeCurrent_aaaa_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=eglMakeCurrent((void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglGetCurrentContext__a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=(Cell)eglGetCurrentContext();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglGetCurrentSurface_n_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)eglGetCurrentSurface(sp[0]);
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglGetCurrentDisplay__a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=(Cell)eglGetCurrentDisplay();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglQueryContext_aana_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=eglQueryContext((void *)(sp[3]),(void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglWaitGL__u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=eglWaitGL();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglWaitNative_n_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=eglWaitNative(sp[0]);
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglSwapBuffers_aa_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=eglSwapBuffers((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglCopyBuffers_aan_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=eglCopyBuffers((void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengles3_LTX_gforth_c_eglGetProcAddress_a_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)eglGetProcAddress((void *)(sp[0]));
  return x;
}
hash_128 gflibcc_hash_opengles3 = "\xEC\x1A\x47\xB9\xCB\xBD\xE1\x3D\x96\xD4\x15\x52\x10\xC4\x48\x32";
