#include <gforth/0.7.9_20150820/libcc.h>
#include <time.h>
ptrpair libgftime_LTX_gforth_c_localtime_r_aa_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)localtime_r((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgftime_LTX_gforth_c_tzset__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  tzset();
  return x;
}
ptrpair libgftime_LTX_gforth_c_tzname__a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=(Cell)(tzname);
  x.sp = sp+-1;
  return x;
}
ptrpair libgftime_LTX_gforth_c_timezone__n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=(timezone);
  x.sp = sp+-1;
  return x;
}
ptrpair libgftime_LTX_gforth_c_daylight__n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=(daylight);
  x.sp = sp+-1;
  return x;
}
hash_128 gflibcc_hash_time = "\x0B\x15\xAA\x7A\x8E\x3F\x03\xDA\x11\x42\xAF\x2A\xE5\x1E\xDF\x04";
