#include <gforth/0.7.9_20150820/libcc.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/time.h>
#include <unistd.h>
ptrpair libgffilestat_LTX_gforth_c_stat_aa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=stat((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgffilestat_LTX_gforth_c_fstat_na_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=fstat(sp[1],(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgffilestat_LTX_gforth_c_lstat_aa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=lstat((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgffilestat_LTX_gforth_c_utimensat_naan_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=utimensat(sp[3],(void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgffilestat_LTX_gforth_c_futimens_na_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=futimens(sp[1],(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgffilestat_LTX_gforth_c_chmod_an_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=chmod((void *)(sp[1]),sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgffilestat_LTX_gforth_c_fchmod_nn_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=fchmod(sp[1],sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgffilestat_LTX_gforth_c_chown_ann_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=chown((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgffilestat_LTX_gforth_c_fchown_nnn_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=fchown(sp[2],sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgffilestat_LTX_gforth_c_lchown_ann_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=lchown((void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
hash_128 gflibcc_hash_filestat = "\x34\xE2\xB8\xCC\x2D\x9D\x1F\xA0\xFF\xB0\x0B\x23\x82\x83\xF0\x5F";
