\ This file has been generated using SWIG and fsi,
\ and is already platform dependent, search for the corresponding
\ fsi-file to compile it where no one has compiled it before ;)
\ GForth has its own dynamic loader and doesn't need addional C-Code.
\ That's why this file contains normal Gforth-code( version 0.6.9 or higher )
\ and could be used directly with include or require.
\ As all comments are stripped during the compilation, please
\ insert the copyright notice of the original file here.

\ ----===< int constants ===>-----
1	constant GL_VERSION_1_1
1	constant GL_VERSION_1_2
1	constant GL_VERSION_1_3
1	constant GL_ARB_imaging
0	constant GL_FALSE
1	constant GL_TRUE
5120	constant GL_BYTE
5121	constant GL_UNSIGNED_BYTE
5122	constant GL_SHORT
5123	constant GL_UNSIGNED_SHORT
5124	constant GL_INT
5125	constant GL_UNSIGNED_INT
5126	constant GL_FLOAT
5127	constant GL_2_BYTES
5128	constant GL_3_BYTES
5129	constant GL_4_BYTES
5130	constant GL_DOUBLE
0	constant GL_POINTS
1	constant GL_LINES
2	constant GL_LINE_LOOP
3	constant GL_LINE_STRIP
4	constant GL_TRIANGLES
5	constant GL_TRIANGLE_STRIP
6	constant GL_TRIANGLE_FAN
7	constant GL_QUADS
8	constant GL_QUAD_STRIP
9	constant GL_POLYGON
32884	constant GL_VERTEX_ARRAY
32885	constant GL_NORMAL_ARRAY
32886	constant GL_COLOR_ARRAY
32887	constant GL_INDEX_ARRAY
32888	constant GL_TEXTURE_COORD_ARRAY
32889	constant GL_EDGE_FLAG_ARRAY
32890	constant GL_VERTEX_ARRAY_SIZE
32891	constant GL_VERTEX_ARRAY_TYPE
32892	constant GL_VERTEX_ARRAY_STRIDE
32894	constant GL_NORMAL_ARRAY_TYPE
32895	constant GL_NORMAL_ARRAY_STRIDE
32897	constant GL_COLOR_ARRAY_SIZE
32898	constant GL_COLOR_ARRAY_TYPE
32899	constant GL_COLOR_ARRAY_STRIDE
32901	constant GL_INDEX_ARRAY_TYPE
32902	constant GL_INDEX_ARRAY_STRIDE
32904	constant GL_TEXTURE_COORD_ARRAY_SIZE
32905	constant GL_TEXTURE_COORD_ARRAY_TYPE
32906	constant GL_TEXTURE_COORD_ARRAY_STRIDE
32908	constant GL_EDGE_FLAG_ARRAY_STRIDE
32910	constant GL_VERTEX_ARRAY_POINTER
32911	constant GL_NORMAL_ARRAY_POINTER
32912	constant GL_COLOR_ARRAY_POINTER
32913	constant GL_INDEX_ARRAY_POINTER
32914	constant GL_TEXTURE_COORD_ARRAY_POINTER
32915	constant GL_EDGE_FLAG_ARRAY_POINTER
10784	constant GL_V2F
10785	constant GL_V3F
10786	constant GL_C4UB_V2F
10787	constant GL_C4UB_V3F
10788	constant GL_C3F_V3F
10789	constant GL_N3F_V3F
10790	constant GL_C4F_N3F_V3F
10791	constant GL_T2F_V3F
10792	constant GL_T4F_V4F
10793	constant GL_T2F_C4UB_V3F
10794	constant GL_T2F_C3F_V3F
10795	constant GL_T2F_N3F_V3F
10796	constant GL_T2F_C4F_N3F_V3F
10797	constant GL_T4F_C4F_N3F_V4F
2976	constant GL_MATRIX_MODE
5888	constant GL_MODELVIEW
5889	constant GL_PROJECTION
5890	constant GL_TEXTURE
2832	constant GL_POINT_SMOOTH
2833	constant GL_POINT_SIZE
2835	constant GL_POINT_SIZE_GRANULARITY
2834	constant GL_POINT_SIZE_RANGE
2848	constant GL_LINE_SMOOTH
2852	constant GL_LINE_STIPPLE
2853	constant GL_LINE_STIPPLE_PATTERN
2854	constant GL_LINE_STIPPLE_REPEAT
2849	constant GL_LINE_WIDTH
2851	constant GL_LINE_WIDTH_GRANULARITY
2850	constant GL_LINE_WIDTH_RANGE
6912	constant GL_POINT
6913	constant GL_LINE
6914	constant GL_FILL
2304	constant GL_CW
2305	constant GL_CCW
1028	constant GL_FRONT
1029	constant GL_BACK
2880	constant GL_POLYGON_MODE
2881	constant GL_POLYGON_SMOOTH
2882	constant GL_POLYGON_STIPPLE
2883	constant GL_EDGE_FLAG
2884	constant GL_CULL_FACE
2885	constant GL_CULL_FACE_MODE
2886	constant GL_FRONT_FACE
32824	constant GL_POLYGON_OFFSET_FACTOR
10752	constant GL_POLYGON_OFFSET_UNITS
10753	constant GL_POLYGON_OFFSET_POINT
10754	constant GL_POLYGON_OFFSET_LINE
32823	constant GL_POLYGON_OFFSET_FILL
4864	constant GL_COMPILE
4865	constant GL_COMPILE_AND_EXECUTE
2866	constant GL_LIST_BASE
2867	constant GL_LIST_INDEX
2864	constant GL_LIST_MODE
512	constant GL_NEVER
513	constant GL_LESS
514	constant GL_EQUAL
515	constant GL_LEQUAL
516	constant GL_GREATER
517	constant GL_NOTEQUAL
518	constant GL_GEQUAL
519	constant GL_ALWAYS
2929	constant GL_DEPTH_TEST
3414	constant GL_DEPTH_BITS
2931	constant GL_DEPTH_CLEAR_VALUE
2932	constant GL_DEPTH_FUNC
2928	constant GL_DEPTH_RANGE
2930	constant GL_DEPTH_WRITEMASK
6402	constant GL_DEPTH_COMPONENT
2896	constant GL_LIGHTING
16384	constant GL_LIGHT0
16385	constant GL_LIGHT1
16386	constant GL_LIGHT2
16387	constant GL_LIGHT3
16388	constant GL_LIGHT4
16389	constant GL_LIGHT5
16390	constant GL_LIGHT6
16391	constant GL_LIGHT7
4613	constant GL_SPOT_EXPONENT
4614	constant GL_SPOT_CUTOFF
4615	constant GL_CONSTANT_ATTENUATION
4616	constant GL_LINEAR_ATTENUATION
4617	constant GL_QUADRATIC_ATTENUATION
4608	constant GL_AMBIENT
4609	constant GL_DIFFUSE
4610	constant GL_SPECULAR
5633	constant GL_SHININESS
5632	constant GL_EMISSION
4611	constant GL_POSITION
4612	constant GL_SPOT_DIRECTION
5634	constant GL_AMBIENT_AND_DIFFUSE
5635	constant GL_COLOR_INDEXES
2898	constant GL_LIGHT_MODEL_TWO_SIDE
2897	constant GL_LIGHT_MODEL_LOCAL_VIEWER
2899	constant GL_LIGHT_MODEL_AMBIENT
1032	constant GL_FRONT_AND_BACK
2900	constant GL_SHADE_MODEL
7424	constant GL_FLAT
7425	constant GL_SMOOTH
2903	constant GL_COLOR_MATERIAL
2901	constant GL_COLOR_MATERIAL_FACE
2902	constant GL_COLOR_MATERIAL_PARAMETER
2977	constant GL_NORMALIZE
12288	constant GL_CLIP_PLANE0
12289	constant GL_CLIP_PLANE1
12290	constant GL_CLIP_PLANE2
12291	constant GL_CLIP_PLANE3
12292	constant GL_CLIP_PLANE4
12293	constant GL_CLIP_PLANE5
3416	constant GL_ACCUM_RED_BITS
3417	constant GL_ACCUM_GREEN_BITS
3418	constant GL_ACCUM_BLUE_BITS
3419	constant GL_ACCUM_ALPHA_BITS
2944	constant GL_ACCUM_CLEAR_VALUE
256	constant GL_ACCUM
260	constant GL_ADD
257	constant GL_LOAD
259	constant GL_MULT
258	constant GL_RETURN
3008	constant GL_ALPHA_TEST
3010	constant GL_ALPHA_TEST_REF
3009	constant GL_ALPHA_TEST_FUNC
3042	constant GL_BLEND
3041	constant GL_BLEND_SRC
3040	constant GL_BLEND_DST
0	constant GL_ZERO
1	constant GL_ONE
768	constant GL_SRC_COLOR
769	constant GL_ONE_MINUS_SRC_COLOR
770	constant GL_SRC_ALPHA
771	constant GL_ONE_MINUS_SRC_ALPHA
772	constant GL_DST_ALPHA
773	constant GL_ONE_MINUS_DST_ALPHA
774	constant GL_DST_COLOR
775	constant GL_ONE_MINUS_DST_COLOR
776	constant GL_SRC_ALPHA_SATURATE
7169	constant GL_FEEDBACK
7168	constant GL_RENDER
7170	constant GL_SELECT
1536	constant GL_2D
1537	constant GL_3D
1538	constant GL_3D_COLOR
1539	constant GL_3D_COLOR_TEXTURE
1540	constant GL_4D_COLOR_TEXTURE
1793	constant GL_POINT_TOKEN
1794	constant GL_LINE_TOKEN
1799	constant GL_LINE_RESET_TOKEN
1795	constant GL_POLYGON_TOKEN
1796	constant GL_BITMAP_TOKEN
1797	constant GL_DRAW_PIXEL_TOKEN
1798	constant GL_COPY_PIXEL_TOKEN
1792	constant GL_PASS_THROUGH_TOKEN
3568	constant GL_FEEDBACK_BUFFER_POINTER
3569	constant GL_FEEDBACK_BUFFER_SIZE
3570	constant GL_FEEDBACK_BUFFER_TYPE
3571	constant GL_SELECTION_BUFFER_POINTER
3572	constant GL_SELECTION_BUFFER_SIZE
2912	constant GL_FOG
2917	constant GL_FOG_MODE
2914	constant GL_FOG_DENSITY
2918	constant GL_FOG_COLOR
2913	constant GL_FOG_INDEX
2915	constant GL_FOG_START
2916	constant GL_FOG_END
9729	constant GL_LINEAR
2048	constant GL_EXP
2049	constant GL_EXP2
3057	constant GL_LOGIC_OP
3057	constant GL_INDEX_LOGIC_OP
3058	constant GL_COLOR_LOGIC_OP
3056	constant GL_LOGIC_OP_MODE
5376	constant GL_CLEAR
5391	constant GL_SET
5379	constant GL_COPY
5388	constant GL_COPY_INVERTED
5381	constant GL_NOOP
5386	constant GL_INVERT
5377	constant GL_AND
5390	constant GL_NAND
5383	constant GL_OR
5384	constant GL_NOR
5382	constant GL_XOR
5385	constant GL_EQUIV
5378	constant GL_AND_REVERSE
5380	constant GL_AND_INVERTED
5387	constant GL_OR_REVERSE
5389	constant GL_OR_INVERTED
3415	constant GL_STENCIL_BITS
2960	constant GL_STENCIL_TEST
2961	constant GL_STENCIL_CLEAR_VALUE
2962	constant GL_STENCIL_FUNC
2963	constant GL_STENCIL_VALUE_MASK
2964	constant GL_STENCIL_FAIL
2965	constant GL_STENCIL_PASS_DEPTH_FAIL
2966	constant GL_STENCIL_PASS_DEPTH_PASS
2967	constant GL_STENCIL_REF
2968	constant GL_STENCIL_WRITEMASK
6401	constant GL_STENCIL_INDEX
7680	constant GL_KEEP
7681	constant GL_REPLACE
7682	constant GL_INCR
7683	constant GL_DECR
0	constant GL_NONE
1030	constant GL_LEFT
1031	constant GL_RIGHT
1024	constant GL_FRONT_LEFT
1025	constant GL_FRONT_RIGHT
1026	constant GL_BACK_LEFT
1027	constant GL_BACK_RIGHT
1033	constant GL_AUX0
1034	constant GL_AUX1
1035	constant GL_AUX2
1036	constant GL_AUX3
6400	constant GL_COLOR_INDEX
6403	constant GL_RED
6404	constant GL_GREEN
6405	constant GL_BLUE
6406	constant GL_ALPHA
6409	constant GL_LUMINANCE
6410	constant GL_LUMINANCE_ALPHA
3413	constant GL_ALPHA_BITS
3410	constant GL_RED_BITS
3411	constant GL_GREEN_BITS
3412	constant GL_BLUE_BITS
3409	constant GL_INDEX_BITS
3408	constant GL_SUBPIXEL_BITS
3072	constant GL_AUX_BUFFERS
3074	constant GL_READ_BUFFER
3073	constant GL_DRAW_BUFFER
3122	constant GL_DOUBLEBUFFER
3123	constant GL_STEREO
6656	constant GL_BITMAP
6144	constant GL_COLOR
6145	constant GL_DEPTH
6146	constant GL_STENCIL
3024	constant GL_DITHER
6407	constant GL_RGB
6408	constant GL_RGBA
2865	constant GL_MAX_LIST_NESTING
3376	constant GL_MAX_EVAL_ORDER
3377	constant GL_MAX_LIGHTS
3378	constant GL_MAX_CLIP_PLANES
3379	constant GL_MAX_TEXTURE_SIZE
3380	constant GL_MAX_PIXEL_MAP_TABLE
3381	constant GL_MAX_ATTRIB_STACK_DEPTH
3382	constant GL_MAX_MODELVIEW_STACK_DEPTH
3383	constant GL_MAX_NAME_STACK_DEPTH
3384	constant GL_MAX_PROJECTION_STACK_DEPTH
3385	constant GL_MAX_TEXTURE_STACK_DEPTH
3386	constant GL_MAX_VIEWPORT_DIMS
3387	constant GL_MAX_CLIENT_ATTRIB_STACK_DEPTH
2992	constant GL_ATTRIB_STACK_DEPTH
2993	constant GL_CLIENT_ATTRIB_STACK_DEPTH
3106	constant GL_COLOR_CLEAR_VALUE
3107	constant GL_COLOR_WRITEMASK
2817	constant GL_CURRENT_INDEX
2816	constant GL_CURRENT_COLOR
2818	constant GL_CURRENT_NORMAL
2820	constant GL_CURRENT_RASTER_COLOR
2825	constant GL_CURRENT_RASTER_DISTANCE
2821	constant GL_CURRENT_RASTER_INDEX
2823	constant GL_CURRENT_RASTER_POSITION
2822	constant GL_CURRENT_RASTER_TEXTURE_COORDS
2824	constant GL_CURRENT_RASTER_POSITION_VALID
2819	constant GL_CURRENT_TEXTURE_COORDS
3104	constant GL_INDEX_CLEAR_VALUE
3120	constant GL_INDEX_MODE
3105	constant GL_INDEX_WRITEMASK
2982	constant GL_MODELVIEW_MATRIX
2979	constant GL_MODELVIEW_STACK_DEPTH
3440	constant GL_NAME_STACK_DEPTH
2983	constant GL_PROJECTION_MATRIX
2980	constant GL_PROJECTION_STACK_DEPTH
3136	constant GL_RENDER_MODE
3121	constant GL_RGBA_MODE
2984	constant GL_TEXTURE_MATRIX
2981	constant GL_TEXTURE_STACK_DEPTH
2978	constant GL_VIEWPORT
3456	constant GL_AUTO_NORMAL
3472	constant GL_MAP1_COLOR_4
3473	constant GL_MAP1_INDEX
3474	constant GL_MAP1_NORMAL
3475	constant GL_MAP1_TEXTURE_COORD_1
3476	constant GL_MAP1_TEXTURE_COORD_2
3477	constant GL_MAP1_TEXTURE_COORD_3
3478	constant GL_MAP1_TEXTURE_COORD_4
3479	constant GL_MAP1_VERTEX_3
3480	constant GL_MAP1_VERTEX_4
3504	constant GL_MAP2_COLOR_4
3505	constant GL_MAP2_INDEX
3506	constant GL_MAP2_NORMAL
3507	constant GL_MAP2_TEXTURE_COORD_1
3508	constant GL_MAP2_TEXTURE_COORD_2
3509	constant GL_MAP2_TEXTURE_COORD_3
3510	constant GL_MAP2_TEXTURE_COORD_4
3511	constant GL_MAP2_VERTEX_3
3512	constant GL_MAP2_VERTEX_4
3536	constant GL_MAP1_GRID_DOMAIN
3537	constant GL_MAP1_GRID_SEGMENTS
3538	constant GL_MAP2_GRID_DOMAIN
3539	constant GL_MAP2_GRID_SEGMENTS
2560	constant GL_COEFF
2561	constant GL_ORDER
2562	constant GL_DOMAIN
3152	constant GL_PERSPECTIVE_CORRECTION_HINT
3153	constant GL_POINT_SMOOTH_HINT
3154	constant GL_LINE_SMOOTH_HINT
3155	constant GL_POLYGON_SMOOTH_HINT
3156	constant GL_FOG_HINT
4352	constant GL_DONT_CARE
4353	constant GL_FASTEST
4354	constant GL_NICEST
3088	constant GL_SCISSOR_BOX
3089	constant GL_SCISSOR_TEST
3344	constant GL_MAP_COLOR
3345	constant GL_MAP_STENCIL
3346	constant GL_INDEX_SHIFT
3347	constant GL_INDEX_OFFSET
3348	constant GL_RED_SCALE
3349	constant GL_RED_BIAS
3352	constant GL_GREEN_SCALE
3353	constant GL_GREEN_BIAS
3354	constant GL_BLUE_SCALE
3355	constant GL_BLUE_BIAS
3356	constant GL_ALPHA_SCALE
3357	constant GL_ALPHA_BIAS
3358	constant GL_DEPTH_SCALE
3359	constant GL_DEPTH_BIAS
3249	constant GL_PIXEL_MAP_S_TO_S_SIZE
3248	constant GL_PIXEL_MAP_I_TO_I_SIZE
3250	constant GL_PIXEL_MAP_I_TO_R_SIZE
3251	constant GL_PIXEL_MAP_I_TO_G_SIZE
3252	constant GL_PIXEL_MAP_I_TO_B_SIZE
3253	constant GL_PIXEL_MAP_I_TO_A_SIZE
3254	constant GL_PIXEL_MAP_R_TO_R_SIZE
3255	constant GL_PIXEL_MAP_G_TO_G_SIZE
3256	constant GL_PIXEL_MAP_B_TO_B_SIZE
3257	constant GL_PIXEL_MAP_A_TO_A_SIZE
3185	constant GL_PIXEL_MAP_S_TO_S
3184	constant GL_PIXEL_MAP_I_TO_I
3186	constant GL_PIXEL_MAP_I_TO_R
3187	constant GL_PIXEL_MAP_I_TO_G
3188	constant GL_PIXEL_MAP_I_TO_B
3189	constant GL_PIXEL_MAP_I_TO_A
3190	constant GL_PIXEL_MAP_R_TO_R
3191	constant GL_PIXEL_MAP_G_TO_G
3192	constant GL_PIXEL_MAP_B_TO_B
3193	constant GL_PIXEL_MAP_A_TO_A
3333	constant GL_PACK_ALIGNMENT
3329	constant GL_PACK_LSB_FIRST
3330	constant GL_PACK_ROW_LENGTH
3332	constant GL_PACK_SKIP_PIXELS
3331	constant GL_PACK_SKIP_ROWS
3328	constant GL_PACK_SWAP_BYTES
3317	constant GL_UNPACK_ALIGNMENT
3313	constant GL_UNPACK_LSB_FIRST
3314	constant GL_UNPACK_ROW_LENGTH
3316	constant GL_UNPACK_SKIP_PIXELS
3315	constant GL_UNPACK_SKIP_ROWS
3312	constant GL_UNPACK_SWAP_BYTES
3350	constant GL_ZOOM_X
3351	constant GL_ZOOM_Y
8960	constant GL_TEXTURE_ENV
8704	constant GL_TEXTURE_ENV_MODE
3552	constant GL_TEXTURE_1D
3553	constant GL_TEXTURE_2D
10242	constant GL_TEXTURE_WRAP_S
10243	constant GL_TEXTURE_WRAP_T
10240	constant GL_TEXTURE_MAG_FILTER
10241	constant GL_TEXTURE_MIN_FILTER
8705	constant GL_TEXTURE_ENV_COLOR
3168	constant GL_TEXTURE_GEN_S
3169	constant GL_TEXTURE_GEN_T
3170	constant GL_TEXTURE_GEN_R
3171	constant GL_TEXTURE_GEN_Q
9472	constant GL_TEXTURE_GEN_MODE
4100	constant GL_TEXTURE_BORDER_COLOR
4096	constant GL_TEXTURE_WIDTH
4097	constant GL_TEXTURE_HEIGHT
4101	constant GL_TEXTURE_BORDER
4099	constant GL_TEXTURE_COMPONENTS
32860	constant GL_TEXTURE_RED_SIZE
32861	constant GL_TEXTURE_GREEN_SIZE
32862	constant GL_TEXTURE_BLUE_SIZE
32863	constant GL_TEXTURE_ALPHA_SIZE
32864	constant GL_TEXTURE_LUMINANCE_SIZE
32865	constant GL_TEXTURE_INTENSITY_SIZE
9984	constant GL_NEAREST_MIPMAP_NEAREST
9986	constant GL_NEAREST_MIPMAP_LINEAR
9985	constant GL_LINEAR_MIPMAP_NEAREST
9987	constant GL_LINEAR_MIPMAP_LINEAR
9217	constant GL_OBJECT_LINEAR
9473	constant GL_OBJECT_PLANE
9216	constant GL_EYE_LINEAR
9474	constant GL_EYE_PLANE
9218	constant GL_SPHERE_MAP
8449	constant GL_DECAL
8448	constant GL_MODULATE
9728	constant GL_NEAREST
10497	constant GL_REPEAT
10496	constant GL_CLAMP
8192	constant GL_S
8193	constant GL_T
8194	constant GL_R
8195	constant GL_Q
7936	constant GL_VENDOR
7937	constant GL_RENDERER
7938	constant GL_VERSION
7939	constant GL_EXTENSIONS
0	constant GL_NO_ERROR
1280	constant GL_INVALID_ENUM
1281	constant GL_INVALID_VALUE
1282	constant GL_INVALID_OPERATION
1283	constant GL_STACK_OVERFLOW
1284	constant GL_STACK_UNDERFLOW
1285	constant GL_OUT_OF_MEMORY
1	constant GL_CURRENT_BIT
2	constant GL_POINT_BIT
4	constant GL_LINE_BIT
8	constant GL_POLYGON_BIT
16	constant GL_POLYGON_STIPPLE_BIT
32	constant GL_PIXEL_MODE_BIT
64	constant GL_LIGHTING_BIT
128	constant GL_FOG_BIT
256	constant GL_DEPTH_BUFFER_BIT
512	constant GL_ACCUM_BUFFER_BIT
1024	constant GL_STENCIL_BUFFER_BIT
2048	constant GL_VIEWPORT_BIT
4096	constant GL_TRANSFORM_BIT
8192	constant GL_ENABLE_BIT
16384	constant GL_COLOR_BUFFER_BIT
32768	constant GL_HINT_BIT
65536	constant GL_EVAL_BIT
131072	constant GL_LIST_BIT
262144	constant GL_TEXTURE_BIT
524288	constant GL_SCISSOR_BIT
4294967295	constant GL_ALL_ATTRIB_BITS
32867	constant GL_PROXY_TEXTURE_1D
32868	constant GL_PROXY_TEXTURE_2D
32870	constant GL_TEXTURE_PRIORITY
32871	constant GL_TEXTURE_RESIDENT
32872	constant GL_TEXTURE_BINDING_1D
32873	constant GL_TEXTURE_BINDING_2D
4099	constant GL_TEXTURE_INTERNAL_FORMAT
32827	constant GL_ALPHA4
32828	constant GL_ALPHA8
32829	constant GL_ALPHA12
32830	constant GL_ALPHA16
32831	constant GL_LUMINANCE4
32832	constant GL_LUMINANCE8
32833	constant GL_LUMINANCE12
32834	constant GL_LUMINANCE16
32835	constant GL_LUMINANCE4_ALPHA4
32836	constant GL_LUMINANCE6_ALPHA2
32837	constant GL_LUMINANCE8_ALPHA8
32838	constant GL_LUMINANCE12_ALPHA4
32839	constant GL_LUMINANCE12_ALPHA12
32840	constant GL_LUMINANCE16_ALPHA16
32841	constant GL_INTENSITY
32842	constant GL_INTENSITY4
32843	constant GL_INTENSITY8
32844	constant GL_INTENSITY12
32845	constant GL_INTENSITY16
10768	constant GL_R3_G3_B2
32847	constant GL_RGB4
32848	constant GL_RGB5
32849	constant GL_RGB8
32850	constant GL_RGB10
32851	constant GL_RGB12
32852	constant GL_RGB16
32853	constant GL_RGBA2
32854	constant GL_RGBA4
32855	constant GL_RGB5_A1
32856	constant GL_RGBA8
32857	constant GL_RGB10_A2
32858	constant GL_RGBA12
32859	constant GL_RGBA16
1	constant GL_CLIENT_PIXEL_STORE_BIT
2	constant GL_CLIENT_VERTEX_ARRAY_BIT
4294967295	constant GL_ALL_CLIENT_ATTRIB_BITS
4294967295	constant GL_CLIENT_ALL_ATTRIB_BITS
32826	constant GL_RESCALE_NORMAL
33071	constant GL_CLAMP_TO_EDGE
33000	constant GL_MAX_ELEMENTS_VERTICES
33001	constant GL_MAX_ELEMENTS_INDICES
32992	constant GL_BGR
32993	constant GL_BGRA
32818	constant GL_UNSIGNED_BYTE_3_3_2
33634	constant GL_UNSIGNED_BYTE_2_3_3_REV
33635	constant GL_UNSIGNED_SHORT_5_6_5
33636	constant GL_UNSIGNED_SHORT_5_6_5_REV
32819	constant GL_UNSIGNED_SHORT_4_4_4_4
33637	constant GL_UNSIGNED_SHORT_4_4_4_4_REV
32820	constant GL_UNSIGNED_SHORT_5_5_5_1
33638	constant GL_UNSIGNED_SHORT_1_5_5_5_REV
32821	constant GL_UNSIGNED_INT_8_8_8_8
33639	constant GL_UNSIGNED_INT_8_8_8_8_REV
32822	constant GL_UNSIGNED_INT_10_10_10_2
33640	constant GL_UNSIGNED_INT_2_10_10_10_REV
33272	constant GL_LIGHT_MODEL_COLOR_CONTROL
33273	constant GL_SINGLE_COLOR
33274	constant GL_SEPARATE_SPECULAR_COLOR
33082	constant GL_TEXTURE_MIN_LOD
33083	constant GL_TEXTURE_MAX_LOD
33084	constant GL_TEXTURE_BASE_LEVEL
33085	constant GL_TEXTURE_MAX_LEVEL
2834	constant GL_SMOOTH_POINT_SIZE_RANGE
2835	constant GL_SMOOTH_POINT_SIZE_GRANULARITY
2850	constant GL_SMOOTH_LINE_WIDTH_RANGE
2851	constant GL_SMOOTH_LINE_WIDTH_GRANULARITY
33901	constant GL_ALIASED_POINT_SIZE_RANGE
33902	constant GL_ALIASED_LINE_WIDTH_RANGE
32875	constant GL_PACK_SKIP_IMAGES
32876	constant GL_PACK_IMAGE_HEIGHT
32877	constant GL_UNPACK_SKIP_IMAGES
32878	constant GL_UNPACK_IMAGE_HEIGHT
32879	constant GL_TEXTURE_3D
32880	constant GL_PROXY_TEXTURE_3D
32881	constant GL_TEXTURE_DEPTH
32882	constant GL_TEXTURE_WRAP_R
32883	constant GL_MAX_3D_TEXTURE_SIZE
32874	constant GL_TEXTURE_BINDING_3D
32769	constant GL_CONSTANT_COLOR
32770	constant GL_ONE_MINUS_CONSTANT_COLOR
32771	constant GL_CONSTANT_ALPHA
32772	constant GL_ONE_MINUS_CONSTANT_ALPHA
32976	constant GL_COLOR_TABLE
32977	constant GL_POST_CONVOLUTION_COLOR_TABLE
32978	constant GL_POST_COLOR_MATRIX_COLOR_TABLE
32979	constant GL_PROXY_COLOR_TABLE
32980	constant GL_PROXY_POST_CONVOLUTION_COLOR_TABLE
32981	constant GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE
32982	constant GL_COLOR_TABLE_SCALE
32983	constant GL_COLOR_TABLE_BIAS
32984	constant GL_COLOR_TABLE_FORMAT
32985	constant GL_COLOR_TABLE_WIDTH
32986	constant GL_COLOR_TABLE_RED_SIZE
32987	constant GL_COLOR_TABLE_GREEN_SIZE
32988	constant GL_COLOR_TABLE_BLUE_SIZE
32989	constant GL_COLOR_TABLE_ALPHA_SIZE
32990	constant GL_COLOR_TABLE_LUMINANCE_SIZE
32991	constant GL_COLOR_TABLE_INTENSITY_SIZE
32784	constant GL_CONVOLUTION_1D
32785	constant GL_CONVOLUTION_2D
32786	constant GL_SEPARABLE_2D
32787	constant GL_CONVOLUTION_BORDER_MODE
32788	constant GL_CONVOLUTION_FILTER_SCALE
32789	constant GL_CONVOLUTION_FILTER_BIAS
32790	constant GL_REDUCE
32791	constant GL_CONVOLUTION_FORMAT
32792	constant GL_CONVOLUTION_WIDTH
32793	constant GL_CONVOLUTION_HEIGHT
32794	constant GL_MAX_CONVOLUTION_WIDTH
32795	constant GL_MAX_CONVOLUTION_HEIGHT
32796	constant GL_POST_CONVOLUTION_RED_SCALE
32797	constant GL_POST_CONVOLUTION_GREEN_SCALE
32798	constant GL_POST_CONVOLUTION_BLUE_SCALE
32799	constant GL_POST_CONVOLUTION_ALPHA_SCALE
32800	constant GL_POST_CONVOLUTION_RED_BIAS
32801	constant GL_POST_CONVOLUTION_GREEN_BIAS
32802	constant GL_POST_CONVOLUTION_BLUE_BIAS
32803	constant GL_POST_CONVOLUTION_ALPHA_BIAS
33105	constant GL_CONSTANT_BORDER
33107	constant GL_REPLICATE_BORDER
33108	constant GL_CONVOLUTION_BORDER_COLOR
32945	constant GL_COLOR_MATRIX
32946	constant GL_COLOR_MATRIX_STACK_DEPTH
32947	constant GL_MAX_COLOR_MATRIX_STACK_DEPTH
32948	constant GL_POST_COLOR_MATRIX_RED_SCALE
32949	constant GL_POST_COLOR_MATRIX_GREEN_SCALE
32950	constant GL_POST_COLOR_MATRIX_BLUE_SCALE
32951	constant GL_POST_COLOR_MATRIX_ALPHA_SCALE
32952	constant GL_POST_COLOR_MATRIX_RED_BIAS
32953	constant GL_POST_COLOR_MATRIX_GREEN_BIAS
32954	constant GL_POST_COLOR_MATRIX_BLUE_BIAS
32955	constant GL_POST_COLOR_MATRIX_ALPHA_BIAS
32804	constant GL_HISTOGRAM
32805	constant GL_PROXY_HISTOGRAM
32806	constant GL_HISTOGRAM_WIDTH
32807	constant GL_HISTOGRAM_FORMAT
32808	constant GL_HISTOGRAM_RED_SIZE
32809	constant GL_HISTOGRAM_GREEN_SIZE
32810	constant GL_HISTOGRAM_BLUE_SIZE
32811	constant GL_HISTOGRAM_ALPHA_SIZE
32812	constant GL_HISTOGRAM_LUMINANCE_SIZE
32813	constant GL_HISTOGRAM_SINK
32814	constant GL_MINMAX
32815	constant GL_MINMAX_FORMAT
32816	constant GL_MINMAX_SINK
32817	constant GL_TABLE_TOO_LARGE
32777	constant GL_BLEND_EQUATION
32775	constant GL_MIN
32776	constant GL_MAX
32774	constant GL_FUNC_ADD
32778	constant GL_FUNC_SUBTRACT
32779	constant GL_FUNC_REVERSE_SUBTRACT
32773	constant GL_BLEND_COLOR
33984	constant GL_TEXTURE0
33985	constant GL_TEXTURE1
33986	constant GL_TEXTURE2
33987	constant GL_TEXTURE3
33988	constant GL_TEXTURE4
33989	constant GL_TEXTURE5
33990	constant GL_TEXTURE6
33991	constant GL_TEXTURE7
33992	constant GL_TEXTURE8
33993	constant GL_TEXTURE9
33994	constant GL_TEXTURE10
33995	constant GL_TEXTURE11
33996	constant GL_TEXTURE12
33997	constant GL_TEXTURE13
33998	constant GL_TEXTURE14
33999	constant GL_TEXTURE15
34000	constant GL_TEXTURE16
34001	constant GL_TEXTURE17
34002	constant GL_TEXTURE18
34003	constant GL_TEXTURE19
34004	constant GL_TEXTURE20
34005	constant GL_TEXTURE21
34006	constant GL_TEXTURE22
34007	constant GL_TEXTURE23
34008	constant GL_TEXTURE24
34009	constant GL_TEXTURE25
34010	constant GL_TEXTURE26
34011	constant GL_TEXTURE27
34012	constant GL_TEXTURE28
34013	constant GL_TEXTURE29
34014	constant GL_TEXTURE30
34015	constant GL_TEXTURE31
34016	constant GL_ACTIVE_TEXTURE
34017	constant GL_CLIENT_ACTIVE_TEXTURE
34018	constant GL_MAX_TEXTURE_UNITS
34065	constant GL_NORMAL_MAP
34066	constant GL_REFLECTION_MAP
34067	constant GL_TEXTURE_CUBE_MAP
34068	constant GL_TEXTURE_BINDING_CUBE_MAP
34069	constant GL_TEXTURE_CUBE_MAP_POSITIVE_X
34070	constant GL_TEXTURE_CUBE_MAP_NEGATIVE_X
34071	constant GL_TEXTURE_CUBE_MAP_POSITIVE_Y
34072	constant GL_TEXTURE_CUBE_MAP_NEGATIVE_Y
34073	constant GL_TEXTURE_CUBE_MAP_POSITIVE_Z
34074	constant GL_TEXTURE_CUBE_MAP_NEGATIVE_Z
34075	constant GL_PROXY_TEXTURE_CUBE_MAP
34076	constant GL_MAX_CUBE_MAP_TEXTURE_SIZE
34025	constant GL_COMPRESSED_ALPHA
34026	constant GL_COMPRESSED_LUMINANCE
34027	constant GL_COMPRESSED_LUMINANCE_ALPHA
34028	constant GL_COMPRESSED_INTENSITY
34029	constant GL_COMPRESSED_RGB
34030	constant GL_COMPRESSED_RGBA
34031	constant GL_TEXTURE_COMPRESSION_HINT
34464	constant GL_TEXTURE_COMPRESSED_IMAGE_SIZE
34465	constant GL_TEXTURE_COMPRESSED
34466	constant GL_NUM_COMPRESSED_TEXTURE_FORMATS
34467	constant GL_COMPRESSED_TEXTURE_FORMATS
32925	constant GL_MULTISAMPLE
32926	constant GL_SAMPLE_ALPHA_TO_COVERAGE
32927	constant GL_SAMPLE_ALPHA_TO_ONE
32928	constant GL_SAMPLE_COVERAGE
32936	constant GL_SAMPLE_BUFFERS
32937	constant GL_SAMPLES
32938	constant GL_SAMPLE_COVERAGE_VALUE
32939	constant GL_SAMPLE_COVERAGE_INVERT
536870912	constant GL_MULTISAMPLE_BIT
34019	constant GL_TRANSPOSE_MODELVIEW_MATRIX
34020	constant GL_TRANSPOSE_PROJECTION_MATRIX
34021	constant GL_TRANSPOSE_TEXTURE_MATRIX
34022	constant GL_TRANSPOSE_COLOR_MATRIX
34160	constant GL_COMBINE
34161	constant GL_COMBINE_RGB
34162	constant GL_COMBINE_ALPHA
34176	constant GL_SOURCE0_RGB
34177	constant GL_SOURCE1_RGB
34178	constant GL_SOURCE2_RGB
34184	constant GL_SOURCE0_ALPHA
34185	constant GL_SOURCE1_ALPHA
34186	constant GL_SOURCE2_ALPHA
34192	constant GL_OPERAND0_RGB
34193	constant GL_OPERAND1_RGB
34194	constant GL_OPERAND2_RGB
34200	constant GL_OPERAND0_ALPHA
34201	constant GL_OPERAND1_ALPHA
34202	constant GL_OPERAND2_ALPHA
34163	constant GL_RGB_SCALE
34164	constant GL_ADD_SIGNED
34165	constant GL_INTERPOLATE
34023	constant GL_SUBTRACT
34166	constant GL_CONSTANT
34167	constant GL_PRIMARY_COLOR
34168	constant GL_PREVIOUS
34478	constant GL_DOT3_RGB
34479	constant GL_DOT3_RGBA
33069	constant GL_CLAMP_TO_BORDER
1	constant GL_ARB_multitexture
33984	constant GL_TEXTURE0_ARB
33985	constant GL_TEXTURE1_ARB
33986	constant GL_TEXTURE2_ARB
33987	constant GL_TEXTURE3_ARB
33988	constant GL_TEXTURE4_ARB
33989	constant GL_TEXTURE5_ARB
33990	constant GL_TEXTURE6_ARB
33991	constant GL_TEXTURE7_ARB
33992	constant GL_TEXTURE8_ARB
33993	constant GL_TEXTURE9_ARB
33994	constant GL_TEXTURE10_ARB
33995	constant GL_TEXTURE11_ARB
33996	constant GL_TEXTURE12_ARB
33997	constant GL_TEXTURE13_ARB
33998	constant GL_TEXTURE14_ARB
33999	constant GL_TEXTURE15_ARB
34000	constant GL_TEXTURE16_ARB
34001	constant GL_TEXTURE17_ARB
34002	constant GL_TEXTURE18_ARB
34003	constant GL_TEXTURE19_ARB
34004	constant GL_TEXTURE20_ARB
34005	constant GL_TEXTURE21_ARB
34006	constant GL_TEXTURE22_ARB
34007	constant GL_TEXTURE23_ARB
34008	constant GL_TEXTURE24_ARB
34009	constant GL_TEXTURE25_ARB
34010	constant GL_TEXTURE26_ARB
34011	constant GL_TEXTURE27_ARB
34012	constant GL_TEXTURE28_ARB
34013	constant GL_TEXTURE29_ARB
34014	constant GL_TEXTURE30_ARB
34015	constant GL_TEXTURE31_ARB
34016	constant GL_ACTIVE_TEXTURE_ARB
34017	constant GL_CLIENT_ACTIVE_TEXTURE_ARB
34018	constant GL_MAX_TEXTURE_UNITS_ARB
1	constant GL_MESA_packed_depth_stencil
34640	constant GL_DEPTH_STENCIL_MESA
34641	constant GL_UNSIGNED_INT_24_8_MESA
34642	constant GL_UNSIGNED_INT_8_24_REV_MESA
34643	constant GL_UNSIGNED_SHORT_15_1_MESA
34644	constant GL_UNSIGNED_SHORT_1_15_REV_MESA
1	constant GL_ATI_blend_equation_separate
34877	constant GL_ALPHA_BLEND_EQUATION_ATI
1	constant GL_OES_EGL_image
1	constant __glext_h_
20150202	constant GL_GLEXT_VERSION
1	constant GL_VERSION_1_4
32968	constant GL_BLEND_DST_RGB
32969	constant GL_BLEND_SRC_RGB
32970	constant GL_BLEND_DST_ALPHA
32971	constant GL_BLEND_SRC_ALPHA
33064	constant GL_POINT_FADE_THRESHOLD_SIZE
33189	constant GL_DEPTH_COMPONENT16
33190	constant GL_DEPTH_COMPONENT24
33191	constant GL_DEPTH_COMPONENT32
33648	constant GL_MIRRORED_REPEAT
34045	constant GL_MAX_TEXTURE_LOD_BIAS
34049	constant GL_TEXTURE_LOD_BIAS
34055	constant GL_INCR_WRAP
34056	constant GL_DECR_WRAP
34890	constant GL_TEXTURE_DEPTH_SIZE
34892	constant GL_TEXTURE_COMPARE_MODE
34893	constant GL_TEXTURE_COMPARE_FUNC
33062	constant GL_POINT_SIZE_MIN
33063	constant GL_POINT_SIZE_MAX
33065	constant GL_POINT_DISTANCE_ATTENUATION
33169	constant GL_GENERATE_MIPMAP
33170	constant GL_GENERATE_MIPMAP_HINT
33872	constant GL_FOG_COORDINATE_SOURCE
33873	constant GL_FOG_COORDINATE
33874	constant GL_FRAGMENT_DEPTH
33875	constant GL_CURRENT_FOG_COORDINATE
33876	constant GL_FOG_COORDINATE_ARRAY_TYPE
33877	constant GL_FOG_COORDINATE_ARRAY_STRIDE
33878	constant GL_FOG_COORDINATE_ARRAY_POINTER
33879	constant GL_FOG_COORDINATE_ARRAY
33880	constant GL_COLOR_SUM
33881	constant GL_CURRENT_SECONDARY_COLOR
33882	constant GL_SECONDARY_COLOR_ARRAY_SIZE
33883	constant GL_SECONDARY_COLOR_ARRAY_TYPE
33884	constant GL_SECONDARY_COLOR_ARRAY_STRIDE
33885	constant GL_SECONDARY_COLOR_ARRAY_POINTER
33886	constant GL_SECONDARY_COLOR_ARRAY
34048	constant GL_TEXTURE_FILTER_CONTROL
34891	constant GL_DEPTH_TEXTURE_MODE
34894	constant GL_COMPARE_R_TO_TEXTURE
1	constant GL_VERSION_1_5
34660	constant GL_BUFFER_SIZE
34661	constant GL_BUFFER_USAGE
34916	constant GL_QUERY_COUNTER_BITS
34917	constant GL_CURRENT_QUERY
34918	constant GL_QUERY_RESULT
34919	constant GL_QUERY_RESULT_AVAILABLE
34962	constant GL_ARRAY_BUFFER
34963	constant GL_ELEMENT_ARRAY_BUFFER
34964	constant GL_ARRAY_BUFFER_BINDING
34965	constant GL_ELEMENT_ARRAY_BUFFER_BINDING
34975	constant GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING
35000	constant GL_READ_ONLY
35001	constant GL_WRITE_ONLY
35002	constant GL_READ_WRITE
35003	constant GL_BUFFER_ACCESS
35004	constant GL_BUFFER_MAPPED
35005	constant GL_BUFFER_MAP_POINTER
35040	constant GL_STREAM_DRAW
35041	constant GL_STREAM_READ
35042	constant GL_STREAM_COPY
35044	constant GL_STATIC_DRAW
35045	constant GL_STATIC_READ
35046	constant GL_STATIC_COPY
35048	constant GL_DYNAMIC_DRAW
35049	constant GL_DYNAMIC_READ
35050	constant GL_DYNAMIC_COPY
35092	constant GL_SAMPLES_PASSED
34185	constant GL_SRC1_ALPHA
34966	constant GL_VERTEX_ARRAY_BUFFER_BINDING
34967	constant GL_NORMAL_ARRAY_BUFFER_BINDING
34968	constant GL_COLOR_ARRAY_BUFFER_BINDING
34969	constant GL_INDEX_ARRAY_BUFFER_BINDING
34970	constant GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING
34971	constant GL_EDGE_FLAG_ARRAY_BUFFER_BINDING
34972	constant GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING
34973	constant GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING
34974	constant GL_WEIGHT_ARRAY_BUFFER_BINDING
33872	constant GL_FOG_COORD_SRC
33873	constant GL_FOG_COORD
33875	constant GL_CURRENT_FOG_COORD
33876	constant GL_FOG_COORD_ARRAY_TYPE
33877	constant GL_FOG_COORD_ARRAY_STRIDE
33878	constant GL_FOG_COORD_ARRAY_POINTER
33879	constant GL_FOG_COORD_ARRAY
34973	constant GL_FOG_COORD_ARRAY_BUFFER_BINDING
34176	constant GL_SRC0_RGB
34177	constant GL_SRC1_RGB
34178	constant GL_SRC2_RGB
34184	constant GL_SRC0_ALPHA
34186	constant GL_SRC2_ALPHA
1	constant GL_VERSION_2_0
32777	constant GL_BLEND_EQUATION_RGB
34338	constant GL_VERTEX_ATTRIB_ARRAY_ENABLED
34339	constant GL_VERTEX_ATTRIB_ARRAY_SIZE
34340	constant GL_VERTEX_ATTRIB_ARRAY_STRIDE
34341	constant GL_VERTEX_ATTRIB_ARRAY_TYPE
34342	constant GL_CURRENT_VERTEX_ATTRIB
34370	constant GL_VERTEX_PROGRAM_POINT_SIZE
34373	constant GL_VERTEX_ATTRIB_ARRAY_POINTER
34816	constant GL_STENCIL_BACK_FUNC
34817	constant GL_STENCIL_BACK_FAIL
34818	constant GL_STENCIL_BACK_PASS_DEPTH_FAIL
34819	constant GL_STENCIL_BACK_PASS_DEPTH_PASS
34852	constant GL_MAX_DRAW_BUFFERS
34853	constant GL_DRAW_BUFFER0
34854	constant GL_DRAW_BUFFER1
34855	constant GL_DRAW_BUFFER2
34856	constant GL_DRAW_BUFFER3
34857	constant GL_DRAW_BUFFER4
34858	constant GL_DRAW_BUFFER5
34859	constant GL_DRAW_BUFFER6
34860	constant GL_DRAW_BUFFER7
34861	constant GL_DRAW_BUFFER8
34862	constant GL_DRAW_BUFFER9
34863	constant GL_DRAW_BUFFER10
34864	constant GL_DRAW_BUFFER11
34865	constant GL_DRAW_BUFFER12
34866	constant GL_DRAW_BUFFER13
34867	constant GL_DRAW_BUFFER14
34868	constant GL_DRAW_BUFFER15
34877	constant GL_BLEND_EQUATION_ALPHA
34921	constant GL_MAX_VERTEX_ATTRIBS
34922	constant GL_VERTEX_ATTRIB_ARRAY_NORMALIZED
34930	constant GL_MAX_TEXTURE_IMAGE_UNITS
35632	constant GL_FRAGMENT_SHADER
35633	constant GL_VERTEX_SHADER
35657	constant GL_MAX_FRAGMENT_UNIFORM_COMPONENTS
35658	constant GL_MAX_VERTEX_UNIFORM_COMPONENTS
35659	constant GL_MAX_VARYING_FLOATS
35660	constant GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS
35661	constant GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS
35663	constant GL_SHADER_TYPE
35664	constant GL_FLOAT_VEC2
35665	constant GL_FLOAT_VEC3
35666	constant GL_FLOAT_VEC4
35667	constant GL_INT_VEC2
35668	constant GL_INT_VEC3
35669	constant GL_INT_VEC4
35670	constant GL_BOOL
35671	constant GL_BOOL_VEC2
35672	constant GL_BOOL_VEC3
35673	constant GL_BOOL_VEC4
35674	constant GL_FLOAT_MAT2
35675	constant GL_FLOAT_MAT3
35676	constant GL_FLOAT_MAT4
35677	constant GL_SAMPLER_1D
35678	constant GL_SAMPLER_2D
35679	constant GL_SAMPLER_3D
35680	constant GL_SAMPLER_CUBE
35681	constant GL_SAMPLER_1D_SHADOW
35682	constant GL_SAMPLER_2D_SHADOW
35712	constant GL_DELETE_STATUS
35713	constant GL_COMPILE_STATUS
35714	constant GL_LINK_STATUS
35715	constant GL_VALIDATE_STATUS
35716	constant GL_INFO_LOG_LENGTH
35717	constant GL_ATTACHED_SHADERS
35718	constant GL_ACTIVE_UNIFORMS
35719	constant GL_ACTIVE_UNIFORM_MAX_LENGTH
35720	constant GL_SHADER_SOURCE_LENGTH
35721	constant GL_ACTIVE_ATTRIBUTES
35722	constant GL_ACTIVE_ATTRIBUTE_MAX_LENGTH
35723	constant GL_FRAGMENT_SHADER_DERIVATIVE_HINT
35724	constant GL_SHADING_LANGUAGE_VERSION
35725	constant GL_CURRENT_PROGRAM
36000	constant GL_POINT_SPRITE_COORD_ORIGIN
36001	constant GL_LOWER_LEFT
36002	constant GL_UPPER_LEFT
36003	constant GL_STENCIL_BACK_REF
36004	constant GL_STENCIL_BACK_VALUE_MASK
36005	constant GL_STENCIL_BACK_WRITEMASK
34371	constant GL_VERTEX_PROGRAM_TWO_SIDE
34913	constant GL_POINT_SPRITE
34914	constant GL_COORD_REPLACE
34929	constant GL_MAX_TEXTURE_COORDS
1	constant GL_VERSION_2_1
35051	constant GL_PIXEL_PACK_BUFFER
35052	constant GL_PIXEL_UNPACK_BUFFER
35053	constant GL_PIXEL_PACK_BUFFER_BINDING
35055	constant GL_PIXEL_UNPACK_BUFFER_BINDING
35685	constant GL_FLOAT_MAT2x3
35686	constant GL_FLOAT_MAT2x4
35687	constant GL_FLOAT_MAT3x2
35688	constant GL_FLOAT_MAT3x4
35689	constant GL_FLOAT_MAT4x2
35690	constant GL_FLOAT_MAT4x3
35904	constant GL_SRGB
35905	constant GL_SRGB8
35906	constant GL_SRGB_ALPHA
35907	constant GL_SRGB8_ALPHA8
35912	constant GL_COMPRESSED_SRGB
35913	constant GL_COMPRESSED_SRGB_ALPHA
33887	constant GL_CURRENT_RASTER_SECONDARY_COLOR
35908	constant GL_SLUMINANCE_ALPHA
35909	constant GL_SLUMINANCE8_ALPHA8
35910	constant GL_SLUMINANCE
35911	constant GL_SLUMINANCE8
35914	constant GL_COMPRESSED_SLUMINANCE
35915	constant GL_COMPRESSED_SLUMINANCE_ALPHA
1	constant GL_VERSION_3_0
34894	constant GL_COMPARE_REF_TO_TEXTURE
12288	constant GL_CLIP_DISTANCE0
12289	constant GL_CLIP_DISTANCE1
12290	constant GL_CLIP_DISTANCE2
12291	constant GL_CLIP_DISTANCE3
12292	constant GL_CLIP_DISTANCE4
12293	constant GL_CLIP_DISTANCE5
12294	constant GL_CLIP_DISTANCE6
12295	constant GL_CLIP_DISTANCE7
3378	constant GL_MAX_CLIP_DISTANCES
33307	constant GL_MAJOR_VERSION
33308	constant GL_MINOR_VERSION
33309	constant GL_NUM_EXTENSIONS
33310	constant GL_CONTEXT_FLAGS
33317	constant GL_COMPRESSED_RED
33318	constant GL_COMPRESSED_RG
1	constant GL_CONTEXT_FLAG_FORWARD_COMPATIBLE_BIT
34836	constant GL_RGBA32F
34837	constant GL_RGB32F
34842	constant GL_RGBA16F
34843	constant GL_RGB16F
35069	constant GL_VERTEX_ATTRIB_ARRAY_INTEGER
35071	constant GL_MAX_ARRAY_TEXTURE_LAYERS
35076	constant GL_MIN_PROGRAM_TEXEL_OFFSET
35077	constant GL_MAX_PROGRAM_TEXEL_OFFSET
35100	constant GL_CLAMP_READ_COLOR
35101	constant GL_FIXED_ONLY
35659	constant GL_MAX_VARYING_COMPONENTS
35864	constant GL_TEXTURE_1D_ARRAY
35865	constant GL_PROXY_TEXTURE_1D_ARRAY
35866	constant GL_TEXTURE_2D_ARRAY
35867	constant GL_PROXY_TEXTURE_2D_ARRAY
35868	constant GL_TEXTURE_BINDING_1D_ARRAY
35869	constant GL_TEXTURE_BINDING_2D_ARRAY
35898	constant GL_R11F_G11F_B10F
35899	constant GL_UNSIGNED_INT_10F_11F_11F_REV
35901	constant GL_RGB9_E5
35902	constant GL_UNSIGNED_INT_5_9_9_9_REV
35903	constant GL_TEXTURE_SHARED_SIZE
35958	constant GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH
35967	constant GL_TRANSFORM_FEEDBACK_BUFFER_MODE
35968	constant GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS
35971	constant GL_TRANSFORM_FEEDBACK_VARYINGS
35972	constant GL_TRANSFORM_FEEDBACK_BUFFER_START
35973	constant GL_TRANSFORM_FEEDBACK_BUFFER_SIZE
35975	constant GL_PRIMITIVES_GENERATED
35976	constant GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN
35977	constant GL_RASTERIZER_DISCARD
35978	constant GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS
35979	constant GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS
35980	constant GL_INTERLEAVED_ATTRIBS
35981	constant GL_SEPARATE_ATTRIBS
35982	constant GL_TRANSFORM_FEEDBACK_BUFFER
35983	constant GL_TRANSFORM_FEEDBACK_BUFFER_BINDING
36208	constant GL_RGBA32UI
36209	constant GL_RGB32UI
36214	constant GL_RGBA16UI
36215	constant GL_RGB16UI
36220	constant GL_RGBA8UI
36221	constant GL_RGB8UI
36226	constant GL_RGBA32I
36227	constant GL_RGB32I
36232	constant GL_RGBA16I
36233	constant GL_RGB16I
36238	constant GL_RGBA8I
36239	constant GL_RGB8I
36244	constant GL_RED_INTEGER
36245	constant GL_GREEN_INTEGER
36246	constant GL_BLUE_INTEGER
36248	constant GL_RGB_INTEGER
36249	constant GL_RGBA_INTEGER
36250	constant GL_BGR_INTEGER
36251	constant GL_BGRA_INTEGER
36288	constant GL_SAMPLER_1D_ARRAY
36289	constant GL_SAMPLER_2D_ARRAY
36291	constant GL_SAMPLER_1D_ARRAY_SHADOW
36292	constant GL_SAMPLER_2D_ARRAY_SHADOW
36293	constant GL_SAMPLER_CUBE_SHADOW
36294	constant GL_UNSIGNED_INT_VEC2
36295	constant GL_UNSIGNED_INT_VEC3
36296	constant GL_UNSIGNED_INT_VEC4
36297	constant GL_INT_SAMPLER_1D
36298	constant GL_INT_SAMPLER_2D
36299	constant GL_INT_SAMPLER_3D
36300	constant GL_INT_SAMPLER_CUBE
36302	constant GL_INT_SAMPLER_1D_ARRAY
36303	constant GL_INT_SAMPLER_2D_ARRAY
36305	constant GL_UNSIGNED_INT_SAMPLER_1D
36306	constant GL_UNSIGNED_INT_SAMPLER_2D
36307	constant GL_UNSIGNED_INT_SAMPLER_3D
36308	constant GL_UNSIGNED_INT_SAMPLER_CUBE
36310	constant GL_UNSIGNED_INT_SAMPLER_1D_ARRAY
36311	constant GL_UNSIGNED_INT_SAMPLER_2D_ARRAY
36371	constant GL_QUERY_WAIT
36372	constant GL_QUERY_NO_WAIT
36373	constant GL_QUERY_BY_REGION_WAIT
36374	constant GL_QUERY_BY_REGION_NO_WAIT
37151	constant GL_BUFFER_ACCESS_FLAGS
37152	constant GL_BUFFER_MAP_LENGTH
37153	constant GL_BUFFER_MAP_OFFSET
36012	constant GL_DEPTH_COMPONENT32F
36013	constant GL_DEPTH32F_STENCIL8
36269	constant GL_FLOAT_32_UNSIGNED_INT_24_8_REV
1286	constant GL_INVALID_FRAMEBUFFER_OPERATION
33296	constant GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING
33297	constant GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE
33298	constant GL_FRAMEBUFFER_ATTACHMENT_RED_SIZE
33299	constant GL_FRAMEBUFFER_ATTACHMENT_GREEN_SIZE
33300	constant GL_FRAMEBUFFER_ATTACHMENT_BLUE_SIZE
33301	constant GL_FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE
33302	constant GL_FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE
33303	constant GL_FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE
33304	constant GL_FRAMEBUFFER_DEFAULT
33305	constant GL_FRAMEBUFFER_UNDEFINED
33306	constant GL_DEPTH_STENCIL_ATTACHMENT
34024	constant GL_MAX_RENDERBUFFER_SIZE
34041	constant GL_DEPTH_STENCIL
34042	constant GL_UNSIGNED_INT_24_8
35056	constant GL_DEPTH24_STENCIL8
35057	constant GL_TEXTURE_STENCIL_SIZE
35856	constant GL_TEXTURE_RED_TYPE
35857	constant GL_TEXTURE_GREEN_TYPE
35858	constant GL_TEXTURE_BLUE_TYPE
35859	constant GL_TEXTURE_ALPHA_TYPE
35862	constant GL_TEXTURE_DEPTH_TYPE
35863	constant GL_UNSIGNED_NORMALIZED
36006	constant GL_FRAMEBUFFER_BINDING
36006	constant GL_DRAW_FRAMEBUFFER_BINDING
36007	constant GL_RENDERBUFFER_BINDING
36008	constant GL_READ_FRAMEBUFFER
36009	constant GL_DRAW_FRAMEBUFFER
36010	constant GL_READ_FRAMEBUFFER_BINDING
36011	constant GL_RENDERBUFFER_SAMPLES
36048	constant GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE
36049	constant GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME
36050	constant GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL
36051	constant GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE
36052	constant GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER
36053	constant GL_FRAMEBUFFER_COMPLETE
36054	constant GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT
36055	constant GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT
36059	constant GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER
36060	constant GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER
36061	constant GL_FRAMEBUFFER_UNSUPPORTED
36063	constant GL_MAX_COLOR_ATTACHMENTS
36064	constant GL_COLOR_ATTACHMENT0
36065	constant GL_COLOR_ATTACHMENT1
36066	constant GL_COLOR_ATTACHMENT2
36067	constant GL_COLOR_ATTACHMENT3
36068	constant GL_COLOR_ATTACHMENT4
36069	constant GL_COLOR_ATTACHMENT5
36070	constant GL_COLOR_ATTACHMENT6
36071	constant GL_COLOR_ATTACHMENT7
36072	constant GL_COLOR_ATTACHMENT8
36073	constant GL_COLOR_ATTACHMENT9
36074	constant GL_COLOR_ATTACHMENT10
36075	constant GL_COLOR_ATTACHMENT11
36076	constant GL_COLOR_ATTACHMENT12
36077	constant GL_COLOR_ATTACHMENT13
36078	constant GL_COLOR_ATTACHMENT14
36079	constant GL_COLOR_ATTACHMENT15
36096	constant GL_DEPTH_ATTACHMENT
36128	constant GL_STENCIL_ATTACHMENT
36160	constant GL_FRAMEBUFFER
36161	constant GL_RENDERBUFFER
36162	constant GL_RENDERBUFFER_WIDTH
36163	constant GL_RENDERBUFFER_HEIGHT
36164	constant GL_RENDERBUFFER_INTERNAL_FORMAT
36166	constant GL_STENCIL_INDEX1
36167	constant GL_STENCIL_INDEX4
36168	constant GL_STENCIL_INDEX8
36169	constant GL_STENCIL_INDEX16
36176	constant GL_RENDERBUFFER_RED_SIZE
36177	constant GL_RENDERBUFFER_GREEN_SIZE
36178	constant GL_RENDERBUFFER_BLUE_SIZE
36179	constant GL_RENDERBUFFER_ALPHA_SIZE
36180	constant GL_RENDERBUFFER_DEPTH_SIZE
36181	constant GL_RENDERBUFFER_STENCIL_SIZE
36182	constant GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE
36183	constant GL_MAX_SAMPLES
33314	constant GL_INDEX
35860	constant GL_TEXTURE_LUMINANCE_TYPE
35861	constant GL_TEXTURE_INTENSITY_TYPE
36281	constant GL_FRAMEBUFFER_SRGB
5131	constant GL_HALF_FLOAT
1	constant GL_MAP_READ_BIT
2	constant GL_MAP_WRITE_BIT
4	constant GL_MAP_INVALIDATE_RANGE_BIT
8	constant GL_MAP_INVALIDATE_BUFFER_BIT
16	constant GL_MAP_FLUSH_EXPLICIT_BIT
32	constant GL_MAP_UNSYNCHRONIZED_BIT
36283	constant GL_COMPRESSED_RED_RGTC1
36284	constant GL_COMPRESSED_SIGNED_RED_RGTC1
36285	constant GL_COMPRESSED_RG_RGTC2
36286	constant GL_COMPRESSED_SIGNED_RG_RGTC2
33319	constant GL_RG
33320	constant GL_RG_INTEGER
33321	constant GL_R8
33322	constant GL_R16
33323	constant GL_RG8
33324	constant GL_RG16
33325	constant GL_R16F
33326	constant GL_R32F
33327	constant GL_RG16F
33328	constant GL_RG32F
33329	constant GL_R8I
33330	constant GL_R8UI
33331	constant GL_R16I
33332	constant GL_R16UI
33333	constant GL_R32I
33334	constant GL_R32UI
33335	constant GL_RG8I
33336	constant GL_RG8UI
33337	constant GL_RG16I
33338	constant GL_RG16UI
33339	constant GL_RG32I
33340	constant GL_RG32UI
34229	constant GL_VERTEX_ARRAY_BINDING
35098	constant GL_CLAMP_VERTEX_COLOR
35099	constant GL_CLAMP_FRAGMENT_COLOR
36247	constant GL_ALPHA_INTEGER
1	constant GL_VERSION_3_1
35683	constant GL_SAMPLER_2D_RECT
35684	constant GL_SAMPLER_2D_RECT_SHADOW
36290	constant GL_SAMPLER_BUFFER
36301	constant GL_INT_SAMPLER_2D_RECT
36304	constant GL_INT_SAMPLER_BUFFER
36309	constant GL_UNSIGNED_INT_SAMPLER_2D_RECT
36312	constant GL_UNSIGNED_INT_SAMPLER_BUFFER
35882	constant GL_TEXTURE_BUFFER
35883	constant GL_MAX_TEXTURE_BUFFER_SIZE
35884	constant GL_TEXTURE_BINDING_BUFFER
35885	constant GL_TEXTURE_BUFFER_DATA_STORE_BINDING
34037	constant GL_TEXTURE_RECTANGLE
34038	constant GL_TEXTURE_BINDING_RECTANGLE
34039	constant GL_PROXY_TEXTURE_RECTANGLE
34040	constant GL_MAX_RECTANGLE_TEXTURE_SIZE
36756	constant GL_R8_SNORM
36757	constant GL_RG8_SNORM
36758	constant GL_RGB8_SNORM
36759	constant GL_RGBA8_SNORM
36760	constant GL_R16_SNORM
36761	constant GL_RG16_SNORM
36762	constant GL_RGB16_SNORM
36763	constant GL_RGBA16_SNORM
36764	constant GL_SIGNED_NORMALIZED
36765	constant GL_PRIMITIVE_RESTART
36766	constant GL_PRIMITIVE_RESTART_INDEX
36662	constant GL_COPY_READ_BUFFER
36663	constant GL_COPY_WRITE_BUFFER
35345	constant GL_UNIFORM_BUFFER
35368	constant GL_UNIFORM_BUFFER_BINDING
35369	constant GL_UNIFORM_BUFFER_START
35370	constant GL_UNIFORM_BUFFER_SIZE
35371	constant GL_MAX_VERTEX_UNIFORM_BLOCKS
35372	constant GL_MAX_GEOMETRY_UNIFORM_BLOCKS
35373	constant GL_MAX_FRAGMENT_UNIFORM_BLOCKS
35374	constant GL_MAX_COMBINED_UNIFORM_BLOCKS
35375	constant GL_MAX_UNIFORM_BUFFER_BINDINGS
35376	constant GL_MAX_UNIFORM_BLOCK_SIZE
35377	constant GL_MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS
35378	constant GL_MAX_COMBINED_GEOMETRY_UNIFORM_COMPONENTS
35379	constant GL_MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS
35380	constant GL_UNIFORM_BUFFER_OFFSET_ALIGNMENT
35381	constant GL_ACTIVE_UNIFORM_BLOCK_MAX_NAME_LENGTH
35382	constant GL_ACTIVE_UNIFORM_BLOCKS
35383	constant GL_UNIFORM_TYPE
35384	constant GL_UNIFORM_SIZE
35385	constant GL_UNIFORM_NAME_LENGTH
35386	constant GL_UNIFORM_BLOCK_INDEX
35387	constant GL_UNIFORM_OFFSET
35388	constant GL_UNIFORM_ARRAY_STRIDE
35389	constant GL_UNIFORM_MATRIX_STRIDE
35390	constant GL_UNIFORM_IS_ROW_MAJOR
35391	constant GL_UNIFORM_BLOCK_BINDING
35392	constant GL_UNIFORM_BLOCK_DATA_SIZE
35393	constant GL_UNIFORM_BLOCK_NAME_LENGTH
35394	constant GL_UNIFORM_BLOCK_ACTIVE_UNIFORMS
35395	constant GL_UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES
35396	constant GL_UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER
35397	constant GL_UNIFORM_BLOCK_REFERENCED_BY_GEOMETRY_SHADER
35398	constant GL_UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER
4294967295	constant GL_INVALID_INDEX
1	constant GL_VERSION_3_2
1	constant GL_CONTEXT_CORE_PROFILE_BIT
2	constant GL_CONTEXT_COMPATIBILITY_PROFILE_BIT
10	constant GL_LINES_ADJACENCY
11	constant GL_LINE_STRIP_ADJACENCY
12	constant GL_TRIANGLES_ADJACENCY
13	constant GL_TRIANGLE_STRIP_ADJACENCY
34370	constant GL_PROGRAM_POINT_SIZE
35881	constant GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS
36263	constant GL_FRAMEBUFFER_ATTACHMENT_LAYERED
36264	constant GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS
36313	constant GL_GEOMETRY_SHADER
35094	constant GL_GEOMETRY_VERTICES_OUT
35095	constant GL_GEOMETRY_INPUT_TYPE
35096	constant GL_GEOMETRY_OUTPUT_TYPE
36319	constant GL_MAX_GEOMETRY_UNIFORM_COMPONENTS
36320	constant GL_MAX_GEOMETRY_OUTPUT_VERTICES
36321	constant GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS
37154	constant GL_MAX_VERTEX_OUTPUT_COMPONENTS
37155	constant GL_MAX_GEOMETRY_INPUT_COMPONENTS
37156	constant GL_MAX_GEOMETRY_OUTPUT_COMPONENTS
37157	constant GL_MAX_FRAGMENT_INPUT_COMPONENTS
37158	constant GL_CONTEXT_PROFILE_MASK
34383	constant GL_DEPTH_CLAMP
36428	constant GL_QUADS_FOLLOW_PROVOKING_VERTEX_CONVENTION
36429	constant GL_FIRST_VERTEX_CONVENTION
36430	constant GL_LAST_VERTEX_CONVENTION
36431	constant GL_PROVOKING_VERTEX
34895	constant GL_TEXTURE_CUBE_MAP_SEAMLESS
37137	constant GL_MAX_SERVER_WAIT_TIMEOUT
37138	constant GL_OBJECT_TYPE
37139	constant GL_SYNC_CONDITION
37140	constant GL_SYNC_STATUS
37141	constant GL_SYNC_FLAGS
37142	constant GL_SYNC_FENCE
37143	constant GL_SYNC_GPU_COMMANDS_COMPLETE
37144	constant GL_UNSIGNALED
37145	constant GL_SIGNALED
37146	constant GL_ALREADY_SIGNALED
37147	constant GL_TIMEOUT_EXPIRED
37148	constant GL_CONDITION_SATISFIED
37149	constant GL_WAIT_FAILED
1	constant GL_SYNC_FLUSH_COMMANDS_BIT
36432	constant GL_SAMPLE_POSITION
36433	constant GL_SAMPLE_MASK
36434	constant GL_SAMPLE_MASK_VALUE
36441	constant GL_MAX_SAMPLE_MASK_WORDS
37120	constant GL_TEXTURE_2D_MULTISAMPLE
37121	constant GL_PROXY_TEXTURE_2D_MULTISAMPLE
37122	constant GL_TEXTURE_2D_MULTISAMPLE_ARRAY
37123	constant GL_PROXY_TEXTURE_2D_MULTISAMPLE_ARRAY
37124	constant GL_TEXTURE_BINDING_2D_MULTISAMPLE
37125	constant GL_TEXTURE_BINDING_2D_MULTISAMPLE_ARRAY
37126	constant GL_TEXTURE_SAMPLES
37127	constant GL_TEXTURE_FIXED_SAMPLE_LOCATIONS
37128	constant GL_SAMPLER_2D_MULTISAMPLE
37129	constant GL_INT_SAMPLER_2D_MULTISAMPLE
37130	constant GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE
37131	constant GL_SAMPLER_2D_MULTISAMPLE_ARRAY
37132	constant GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY
37133	constant GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY
37134	constant GL_MAX_COLOR_TEXTURE_SAMPLES
37135	constant GL_MAX_DEPTH_TEXTURE_SAMPLES
37136	constant GL_MAX_INTEGER_SAMPLES
1	constant GL_VERSION_3_3
35070	constant GL_VERTEX_ATTRIB_ARRAY_DIVISOR
35065	constant GL_SRC1_COLOR
35066	constant GL_ONE_MINUS_SRC1_COLOR
35067	constant GL_ONE_MINUS_SRC1_ALPHA
35068	constant GL_MAX_DUAL_SOURCE_DRAW_BUFFERS
35887	constant GL_ANY_SAMPLES_PASSED
35097	constant GL_SAMPLER_BINDING
36975	constant GL_RGB10_A2UI
36418	constant GL_TEXTURE_SWIZZLE_R
36419	constant GL_TEXTURE_SWIZZLE_G
36420	constant GL_TEXTURE_SWIZZLE_B
36421	constant GL_TEXTURE_SWIZZLE_A
36422	constant GL_TEXTURE_SWIZZLE_RGBA
35007	constant GL_TIME_ELAPSED
36392	constant GL_TIMESTAMP
36255	constant GL_INT_2_10_10_10_REV
1	constant GL_VERSION_4_0
35894	constant GL_SAMPLE_SHADING
35895	constant GL_MIN_SAMPLE_SHADING_VALUE
36446	constant GL_MIN_PROGRAM_TEXTURE_GATHER_OFFSET
36447	constant GL_MAX_PROGRAM_TEXTURE_GATHER_OFFSET
36873	constant GL_TEXTURE_CUBE_MAP_ARRAY
36874	constant GL_TEXTURE_BINDING_CUBE_MAP_ARRAY
36875	constant GL_PROXY_TEXTURE_CUBE_MAP_ARRAY
36876	constant GL_SAMPLER_CUBE_MAP_ARRAY
36877	constant GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW
36878	constant GL_INT_SAMPLER_CUBE_MAP_ARRAY
36879	constant GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY
36671	constant GL_DRAW_INDIRECT_BUFFER
36675	constant GL_DRAW_INDIRECT_BUFFER_BINDING
34943	constant GL_GEOMETRY_SHADER_INVOCATIONS
36442	constant GL_MAX_GEOMETRY_SHADER_INVOCATIONS
36443	constant GL_MIN_FRAGMENT_INTERPOLATION_OFFSET
36444	constant GL_MAX_FRAGMENT_INTERPOLATION_OFFSET
36445	constant GL_FRAGMENT_INTERPOLATION_OFFSET_BITS
36465	constant GL_MAX_VERTEX_STREAMS
36860	constant GL_DOUBLE_VEC2
36861	constant GL_DOUBLE_VEC3
36862	constant GL_DOUBLE_VEC4
36678	constant GL_DOUBLE_MAT2
36679	constant GL_DOUBLE_MAT3
36680	constant GL_DOUBLE_MAT4
36681	constant GL_DOUBLE_MAT2x3
36682	constant GL_DOUBLE_MAT2x4
36683	constant GL_DOUBLE_MAT3x2
36684	constant GL_DOUBLE_MAT3x4
36685	constant GL_DOUBLE_MAT4x2
36686	constant GL_DOUBLE_MAT4x3
36325	constant GL_ACTIVE_SUBROUTINES
36326	constant GL_ACTIVE_SUBROUTINE_UNIFORMS
36423	constant GL_ACTIVE_SUBROUTINE_UNIFORM_LOCATIONS
36424	constant GL_ACTIVE_SUBROUTINE_MAX_LENGTH
36425	constant GL_ACTIVE_SUBROUTINE_UNIFORM_MAX_LENGTH
36327	constant GL_MAX_SUBROUTINES
36328	constant GL_MAX_SUBROUTINE_UNIFORM_LOCATIONS
36426	constant GL_NUM_COMPATIBLE_SUBROUTINES
36427	constant GL_COMPATIBLE_SUBROUTINES
14	constant GL_PATCHES
36466	constant GL_PATCH_VERTICES
36467	constant GL_PATCH_DEFAULT_INNER_LEVEL
36468	constant GL_PATCH_DEFAULT_OUTER_LEVEL
36469	constant GL_TESS_CONTROL_OUTPUT_VERTICES
36470	constant GL_TESS_GEN_MODE
36471	constant GL_TESS_GEN_SPACING
36472	constant GL_TESS_GEN_VERTEX_ORDER
36473	constant GL_TESS_GEN_POINT_MODE
36474	constant GL_ISOLINES
36475	constant GL_FRACTIONAL_ODD
36476	constant GL_FRACTIONAL_EVEN
36477	constant GL_MAX_PATCH_VERTICES
36478	constant GL_MAX_TESS_GEN_LEVEL
36479	constant GL_MAX_TESS_CONTROL_UNIFORM_COMPONENTS
36480	constant GL_MAX_TESS_EVALUATION_UNIFORM_COMPONENTS
36481	constant GL_MAX_TESS_CONTROL_TEXTURE_IMAGE_UNITS
36482	constant GL_MAX_TESS_EVALUATION_TEXTURE_IMAGE_UNITS
36483	constant GL_MAX_TESS_CONTROL_OUTPUT_COMPONENTS
36484	constant GL_MAX_TESS_PATCH_COMPONENTS
36485	constant GL_MAX_TESS_CONTROL_TOTAL_OUTPUT_COMPONENTS
36486	constant GL_MAX_TESS_EVALUATION_OUTPUT_COMPONENTS
36489	constant GL_MAX_TESS_CONTROL_UNIFORM_BLOCKS
36490	constant GL_MAX_TESS_EVALUATION_UNIFORM_BLOCKS
34924	constant GL_MAX_TESS_CONTROL_INPUT_COMPONENTS
34925	constant GL_MAX_TESS_EVALUATION_INPUT_COMPONENTS
36382	constant GL_MAX_COMBINED_TESS_CONTROL_UNIFORM_COMPONENTS
36383	constant GL_MAX_COMBINED_TESS_EVALUATION_UNIFORM_COMPONENTS
34032	constant GL_UNIFORM_BLOCK_REFERENCED_BY_TESS_CONTROL_SHADER
34033	constant GL_UNIFORM_BLOCK_REFERENCED_BY_TESS_EVALUATION_SHADER
36487	constant GL_TESS_EVALUATION_SHADER
36488	constant GL_TESS_CONTROL_SHADER
36386	constant GL_TRANSFORM_FEEDBACK
36387	constant GL_TRANSFORM_FEEDBACK_BUFFER_PAUSED
36388	constant GL_TRANSFORM_FEEDBACK_BUFFER_ACTIVE
36389	constant GL_TRANSFORM_FEEDBACK_BINDING
36464	constant GL_MAX_TRANSFORM_FEEDBACK_BUFFERS
1	constant GL_VERSION_4_1
5132	constant GL_FIXED
35738	constant GL_IMPLEMENTATION_COLOR_READ_TYPE
35739	constant GL_IMPLEMENTATION_COLOR_READ_FORMAT
36336	constant GL_LOW_FLOAT
36337	constant GL_MEDIUM_FLOAT
36338	constant GL_HIGH_FLOAT
36339	constant GL_LOW_INT
36340	constant GL_MEDIUM_INT
36341	constant GL_HIGH_INT
36346	constant GL_SHADER_COMPILER
36344	constant GL_SHADER_BINARY_FORMATS
36345	constant GL_NUM_SHADER_BINARY_FORMATS
36347	constant GL_MAX_VERTEX_UNIFORM_VECTORS
36348	constant GL_MAX_VARYING_VECTORS
36349	constant GL_MAX_FRAGMENT_UNIFORM_VECTORS
36194	constant GL_RGB565
33367	constant GL_PROGRAM_BINARY_RETRIEVABLE_HINT
34625	constant GL_PROGRAM_BINARY_LENGTH
34814	constant GL_NUM_PROGRAM_BINARY_FORMATS
34815	constant GL_PROGRAM_BINARY_FORMATS
1	constant GL_VERTEX_SHADER_BIT
2	constant GL_FRAGMENT_SHADER_BIT
4	constant GL_GEOMETRY_SHADER_BIT
8	constant GL_TESS_CONTROL_SHADER_BIT
16	constant GL_TESS_EVALUATION_SHADER_BIT
4294967295	constant GL_ALL_SHADER_BITS
33368	constant GL_PROGRAM_SEPARABLE
33369	constant GL_ACTIVE_PROGRAM
33370	constant GL_PROGRAM_PIPELINE_BINDING
33371	constant GL_MAX_VIEWPORTS
33372	constant GL_VIEWPORT_SUBPIXEL_BITS
33373	constant GL_VIEWPORT_BOUNDS_RANGE
33374	constant GL_LAYER_PROVOKING_VERTEX
33375	constant GL_VIEWPORT_INDEX_PROVOKING_VERTEX
33376	constant GL_UNDEFINED_VERTEX
1	constant GL_VERSION_4_2
36662	constant GL_COPY_READ_BUFFER_BINDING
36663	constant GL_COPY_WRITE_BUFFER_BINDING
36388	constant GL_TRANSFORM_FEEDBACK_ACTIVE
36387	constant GL_TRANSFORM_FEEDBACK_PAUSED
37159	constant GL_UNPACK_COMPRESSED_BLOCK_WIDTH
37160	constant GL_UNPACK_COMPRESSED_BLOCK_HEIGHT
37161	constant GL_UNPACK_COMPRESSED_BLOCK_DEPTH
37162	constant GL_UNPACK_COMPRESSED_BLOCK_SIZE
37163	constant GL_PACK_COMPRESSED_BLOCK_WIDTH
37164	constant GL_PACK_COMPRESSED_BLOCK_HEIGHT
37165	constant GL_PACK_COMPRESSED_BLOCK_DEPTH
37166	constant GL_PACK_COMPRESSED_BLOCK_SIZE
37760	constant GL_NUM_SAMPLE_COUNTS
37052	constant GL_MIN_MAP_BUFFER_ALIGNMENT
37568	constant GL_ATOMIC_COUNTER_BUFFER
37569	constant GL_ATOMIC_COUNTER_BUFFER_BINDING
37570	constant GL_ATOMIC_COUNTER_BUFFER_START
37571	constant GL_ATOMIC_COUNTER_BUFFER_SIZE
37572	constant GL_ATOMIC_COUNTER_BUFFER_DATA_SIZE
37573	constant GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTERS
37574	constant GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTER_INDICES
37575	constant GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_VERTEX_SHADER
37576	constant GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_CONTROL_SHADER
37577	constant GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_EVALUATION_SHADER
37578	constant GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_GEOMETRY_SHADER
37579	constant GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_FRAGMENT_SHADER
37580	constant GL_MAX_VERTEX_ATOMIC_COUNTER_BUFFERS
37581	constant GL_MAX_TESS_CONTROL_ATOMIC_COUNTER_BUFFERS
37582	constant GL_MAX_TESS_EVALUATION_ATOMIC_COUNTER_BUFFERS
37583	constant GL_MAX_GEOMETRY_ATOMIC_COUNTER_BUFFERS
37584	constant GL_MAX_FRAGMENT_ATOMIC_COUNTER_BUFFERS
37585	constant GL_MAX_COMBINED_ATOMIC_COUNTER_BUFFERS
37586	constant GL_MAX_VERTEX_ATOMIC_COUNTERS
37587	constant GL_MAX_TESS_CONTROL_ATOMIC_COUNTERS
37588	constant GL_MAX_TESS_EVALUATION_ATOMIC_COUNTERS
37589	constant GL_MAX_GEOMETRY_ATOMIC_COUNTERS
37590	constant GL_MAX_FRAGMENT_ATOMIC_COUNTERS
37591	constant GL_MAX_COMBINED_ATOMIC_COUNTERS
37592	constant GL_MAX_ATOMIC_COUNTER_BUFFER_SIZE
37596	constant GL_MAX_ATOMIC_COUNTER_BUFFER_BINDINGS
37593	constant GL_ACTIVE_ATOMIC_COUNTER_BUFFERS
37594	constant GL_UNIFORM_ATOMIC_COUNTER_BUFFER_INDEX
37595	constant GL_UNSIGNED_INT_ATOMIC_COUNTER
1	constant GL_VERTEX_ATTRIB_ARRAY_BARRIER_BIT
2	constant GL_ELEMENT_ARRAY_BARRIER_BIT
4	constant GL_UNIFORM_BARRIER_BIT
8	constant GL_TEXTURE_FETCH_BARRIER_BIT
32	constant GL_SHADER_IMAGE_ACCESS_BARRIER_BIT
64	constant GL_COMMAND_BARRIER_BIT
128	constant GL_PIXEL_BUFFER_BARRIER_BIT
256	constant GL_TEXTURE_UPDATE_BARRIER_BIT
512	constant GL_BUFFER_UPDATE_BARRIER_BIT
1024	constant GL_FRAMEBUFFER_BARRIER_BIT
2048	constant GL_TRANSFORM_FEEDBACK_BARRIER_BIT
4096	constant GL_ATOMIC_COUNTER_BARRIER_BIT
4294967295	constant GL_ALL_BARRIER_BITS
36664	constant GL_MAX_IMAGE_UNITS
36665	constant GL_MAX_COMBINED_IMAGE_UNITS_AND_FRAGMENT_OUTPUTS
36666	constant GL_IMAGE_BINDING_NAME
36667	constant GL_IMAGE_BINDING_LEVEL
36668	constant GL_IMAGE_BINDING_LAYERED
36669	constant GL_IMAGE_BINDING_LAYER
36670	constant GL_IMAGE_BINDING_ACCESS
36940	constant GL_IMAGE_1D
36941	constant GL_IMAGE_2D
36942	constant GL_IMAGE_3D
36943	constant GL_IMAGE_2D_RECT
36944	constant GL_IMAGE_CUBE
36945	constant GL_IMAGE_BUFFER
36946	constant GL_IMAGE_1D_ARRAY
36947	constant GL_IMAGE_2D_ARRAY
36948	constant GL_IMAGE_CUBE_MAP_ARRAY
36949	constant GL_IMAGE_2D_MULTISAMPLE
36950	constant GL_IMAGE_2D_MULTISAMPLE_ARRAY
36951	constant GL_INT_IMAGE_1D
36952	constant GL_INT_IMAGE_2D
36953	constant GL_INT_IMAGE_3D
36954	constant GL_INT_IMAGE_2D_RECT
36955	constant GL_INT_IMAGE_CUBE
36956	constant GL_INT_IMAGE_BUFFER
36957	constant GL_INT_IMAGE_1D_ARRAY
36958	constant GL_INT_IMAGE_2D_ARRAY
36959	constant GL_INT_IMAGE_CUBE_MAP_ARRAY
36960	constant GL_INT_IMAGE_2D_MULTISAMPLE
36961	constant GL_INT_IMAGE_2D_MULTISAMPLE_ARRAY
36962	constant GL_UNSIGNED_INT_IMAGE_1D
36963	constant GL_UNSIGNED_INT_IMAGE_2D
36964	constant GL_UNSIGNED_INT_IMAGE_3D
36965	constant GL_UNSIGNED_INT_IMAGE_2D_RECT
36966	constant GL_UNSIGNED_INT_IMAGE_CUBE
36967	constant GL_UNSIGNED_INT_IMAGE_BUFFER
36968	constant GL_UNSIGNED_INT_IMAGE_1D_ARRAY
36969	constant GL_UNSIGNED_INT_IMAGE_2D_ARRAY
36970	constant GL_UNSIGNED_INT_IMAGE_CUBE_MAP_ARRAY
36971	constant GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE
36972	constant GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE_ARRAY
36973	constant GL_MAX_IMAGE_SAMPLES
36974	constant GL_IMAGE_BINDING_FORMAT
37063	constant GL_IMAGE_FORMAT_COMPATIBILITY_TYPE
37064	constant GL_IMAGE_FORMAT_COMPATIBILITY_BY_SIZE
37065	constant GL_IMAGE_FORMAT_COMPATIBILITY_BY_CLASS
37066	constant GL_MAX_VERTEX_IMAGE_UNIFORMS
37067	constant GL_MAX_TESS_CONTROL_IMAGE_UNIFORMS
37068	constant GL_MAX_TESS_EVALUATION_IMAGE_UNIFORMS
37069	constant GL_MAX_GEOMETRY_IMAGE_UNIFORMS
37070	constant GL_MAX_FRAGMENT_IMAGE_UNIFORMS
37071	constant GL_MAX_COMBINED_IMAGE_UNIFORMS
36492	constant GL_COMPRESSED_RGBA_BPTC_UNORM
36493	constant GL_COMPRESSED_SRGB_ALPHA_BPTC_UNORM
36494	constant GL_COMPRESSED_RGB_BPTC_SIGNED_FLOAT
36495	constant GL_COMPRESSED_RGB_BPTC_UNSIGNED_FLOAT
37167	constant GL_TEXTURE_IMMUTABLE_FORMAT
1	constant GL_VERSION_4_3
33513	constant GL_NUM_SHADING_LANGUAGE_VERSIONS
34638	constant GL_VERTEX_ATTRIB_ARRAY_LONG
37492	constant GL_COMPRESSED_RGB8_ETC2
37493	constant GL_COMPRESSED_SRGB8_ETC2
37494	constant GL_COMPRESSED_RGB8_PUNCHTHROUGH_ALPHA1_ETC2
37495	constant GL_COMPRESSED_SRGB8_PUNCHTHROUGH_ALPHA1_ETC2
37496	constant GL_COMPRESSED_RGBA8_ETC2_EAC
37497	constant GL_COMPRESSED_SRGB8_ALPHA8_ETC2_EAC
37488	constant GL_COMPRESSED_R11_EAC
37489	constant GL_COMPRESSED_SIGNED_R11_EAC
37490	constant GL_COMPRESSED_RG11_EAC
37491	constant GL_COMPRESSED_SIGNED_RG11_EAC
36201	constant GL_PRIMITIVE_RESTART_FIXED_INDEX
36202	constant GL_ANY_SAMPLES_PASSED_CONSERVATIVE
36203	constant GL_MAX_ELEMENT_INDEX
37305	constant GL_COMPUTE_SHADER
37307	constant GL_MAX_COMPUTE_UNIFORM_BLOCKS
37308	constant GL_MAX_COMPUTE_TEXTURE_IMAGE_UNITS
37309	constant GL_MAX_COMPUTE_IMAGE_UNIFORMS
33378	constant GL_MAX_COMPUTE_SHARED_MEMORY_SIZE
33379	constant GL_MAX_COMPUTE_UNIFORM_COMPONENTS
33380	constant GL_MAX_COMPUTE_ATOMIC_COUNTER_BUFFERS
33381	constant GL_MAX_COMPUTE_ATOMIC_COUNTERS
33382	constant GL_MAX_COMBINED_COMPUTE_UNIFORM_COMPONENTS
37099	constant GL_MAX_COMPUTE_WORK_GROUP_INVOCATIONS
37310	constant GL_MAX_COMPUTE_WORK_GROUP_COUNT
37311	constant GL_MAX_COMPUTE_WORK_GROUP_SIZE
33383	constant GL_COMPUTE_WORK_GROUP_SIZE
37100	constant GL_UNIFORM_BLOCK_REFERENCED_BY_COMPUTE_SHADER
37101	constant GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_COMPUTE_SHADER
37102	constant GL_DISPATCH_INDIRECT_BUFFER
37103	constant GL_DISPATCH_INDIRECT_BUFFER_BINDING
32	constant GL_COMPUTE_SHADER_BIT
33346	constant GL_DEBUG_OUTPUT_SYNCHRONOUS
33347	constant GL_DEBUG_NEXT_LOGGED_MESSAGE_LENGTH
33348	constant GL_DEBUG_CALLBACK_FUNCTION
33349	constant GL_DEBUG_CALLBACK_USER_PARAM
33350	constant GL_DEBUG_SOURCE_API
33351	constant GL_DEBUG_SOURCE_WINDOW_SYSTEM
33352	constant GL_DEBUG_SOURCE_SHADER_COMPILER
33353	constant GL_DEBUG_SOURCE_THIRD_PARTY
33354	constant GL_DEBUG_SOURCE_APPLICATION
33355	constant GL_DEBUG_SOURCE_OTHER
33356	constant GL_DEBUG_TYPE_ERROR
33357	constant GL_DEBUG_TYPE_DEPRECATED_BEHAVIOR
33358	constant GL_DEBUG_TYPE_UNDEFINED_BEHAVIOR
33359	constant GL_DEBUG_TYPE_PORTABILITY
33360	constant GL_DEBUG_TYPE_PERFORMANCE
33361	constant GL_DEBUG_TYPE_OTHER
37187	constant GL_MAX_DEBUG_MESSAGE_LENGTH
37188	constant GL_MAX_DEBUG_LOGGED_MESSAGES
37189	constant GL_DEBUG_LOGGED_MESSAGES
37190	constant GL_DEBUG_SEVERITY_HIGH
37191	constant GL_DEBUG_SEVERITY_MEDIUM
37192	constant GL_DEBUG_SEVERITY_LOW
33384	constant GL_DEBUG_TYPE_MARKER
33385	constant GL_DEBUG_TYPE_PUSH_GROUP
33386	constant GL_DEBUG_TYPE_POP_GROUP
33387	constant GL_DEBUG_SEVERITY_NOTIFICATION
33388	constant GL_MAX_DEBUG_GROUP_STACK_DEPTH
33389	constant GL_DEBUG_GROUP_STACK_DEPTH
33504	constant GL_BUFFER
33505	constant GL_SHADER
33506	constant GL_PROGRAM
33507	constant GL_QUERY
33508	constant GL_PROGRAM_PIPELINE
33510	constant GL_SAMPLER
33512	constant GL_MAX_LABEL_LENGTH
37600	constant GL_DEBUG_OUTPUT
2	constant GL_CONTEXT_FLAG_DEBUG_BIT
33390	constant GL_MAX_UNIFORM_LOCATIONS
37648	constant GL_FRAMEBUFFER_DEFAULT_WIDTH
37649	constant GL_FRAMEBUFFER_DEFAULT_HEIGHT
37650	constant GL_FRAMEBUFFER_DEFAULT_LAYERS
37651	constant GL_FRAMEBUFFER_DEFAULT_SAMPLES
37652	constant GL_FRAMEBUFFER_DEFAULT_FIXED_SAMPLE_LOCATIONS
37653	constant GL_MAX_FRAMEBUFFER_WIDTH
37654	constant GL_MAX_FRAMEBUFFER_HEIGHT
37655	constant GL_MAX_FRAMEBUFFER_LAYERS
37656	constant GL_MAX_FRAMEBUFFER_SAMPLES
33391	constant GL_INTERNALFORMAT_SUPPORTED
33392	constant GL_INTERNALFORMAT_PREFERRED
33393	constant GL_INTERNALFORMAT_RED_SIZE
33394	constant GL_INTERNALFORMAT_GREEN_SIZE
33395	constant GL_INTERNALFORMAT_BLUE_SIZE
33396	constant GL_INTERNALFORMAT_ALPHA_SIZE
33397	constant GL_INTERNALFORMAT_DEPTH_SIZE
33398	constant GL_INTERNALFORMAT_STENCIL_SIZE
33399	constant GL_INTERNALFORMAT_SHARED_SIZE
33400	constant GL_INTERNALFORMAT_RED_TYPE
33401	constant GL_INTERNALFORMAT_GREEN_TYPE
33402	constant GL_INTERNALFORMAT_BLUE_TYPE
33403	constant GL_INTERNALFORMAT_ALPHA_TYPE
33404	constant GL_INTERNALFORMAT_DEPTH_TYPE
33405	constant GL_INTERNALFORMAT_STENCIL_TYPE
33406	constant GL_MAX_WIDTH
33407	constant GL_MAX_HEIGHT
33408	constant GL_MAX_DEPTH
33409	constant GL_MAX_LAYERS
33410	constant GL_MAX_COMBINED_DIMENSIONS
33411	constant GL_COLOR_COMPONENTS
33412	constant GL_DEPTH_COMPONENTS
33413	constant GL_STENCIL_COMPONENTS
33414	constant GL_COLOR_RENDERABLE
33415	constant GL_DEPTH_RENDERABLE
33416	constant GL_STENCIL_RENDERABLE
33417	constant GL_FRAMEBUFFER_RENDERABLE
33418	constant GL_FRAMEBUFFER_RENDERABLE_LAYERED
33419	constant GL_FRAMEBUFFER_BLEND
33420	constant GL_READ_PIXELS
33421	constant GL_READ_PIXELS_FORMAT
33422	constant GL_READ_PIXELS_TYPE
33423	constant GL_TEXTURE_IMAGE_FORMAT
33424	constant GL_TEXTURE_IMAGE_TYPE
33425	constant GL_GET_TEXTURE_IMAGE_FORMAT
33426	constant GL_GET_TEXTURE_IMAGE_TYPE
33427	constant GL_MIPMAP
33428	constant GL_MANUAL_GENERATE_MIPMAP
33429	constant GL_AUTO_GENERATE_MIPMAP
33430	constant GL_COLOR_ENCODING
33431	constant GL_SRGB_READ
33432	constant GL_SRGB_WRITE
33434	constant GL_FILTER
33435	constant GL_VERTEX_TEXTURE
33436	constant GL_TESS_CONTROL_TEXTURE
33437	constant GL_TESS_EVALUATION_TEXTURE
33438	constant GL_GEOMETRY_TEXTURE
33439	constant GL_FRAGMENT_TEXTURE
33440	constant GL_COMPUTE_TEXTURE
33441	constant GL_TEXTURE_SHADOW
33442	constant GL_TEXTURE_GATHER
33443	constant GL_TEXTURE_GATHER_SHADOW
33444	constant GL_SHADER_IMAGE_LOAD
33445	constant GL_SHADER_IMAGE_STORE
33446	constant GL_SHADER_IMAGE_ATOMIC
33447	constant GL_IMAGE_TEXEL_SIZE
33448	constant GL_IMAGE_COMPATIBILITY_CLASS
33449	constant GL_IMAGE_PIXEL_FORMAT
33450	constant GL_IMAGE_PIXEL_TYPE
33452	constant GL_SIMULTANEOUS_TEXTURE_AND_DEPTH_TEST
33453	constant GL_SIMULTANEOUS_TEXTURE_AND_STENCIL_TEST
33454	constant GL_SIMULTANEOUS_TEXTURE_AND_DEPTH_WRITE
33455	constant GL_SIMULTANEOUS_TEXTURE_AND_STENCIL_WRITE
33457	constant GL_TEXTURE_COMPRESSED_BLOCK_WIDTH
33458	constant GL_TEXTURE_COMPRESSED_BLOCK_HEIGHT
33459	constant GL_TEXTURE_COMPRESSED_BLOCK_SIZE
33460	constant GL_CLEAR_BUFFER
33461	constant GL_TEXTURE_VIEW
33462	constant GL_VIEW_COMPATIBILITY_CLASS
33463	constant GL_FULL_SUPPORT
33464	constant GL_CAVEAT_SUPPORT
33465	constant GL_IMAGE_CLASS_4_X_32
33466	constant GL_IMAGE_CLASS_2_X_32
33467	constant GL_IMAGE_CLASS_1_X_32
33468	constant GL_IMAGE_CLASS_4_X_16
33469	constant GL_IMAGE_CLASS_2_X_16
33470	constant GL_IMAGE_CLASS_1_X_16
33471	constant GL_IMAGE_CLASS_4_X_8
33472	constant GL_IMAGE_CLASS_2_X_8
33473	constant GL_IMAGE_CLASS_1_X_8
33474	constant GL_IMAGE_CLASS_11_11_10
33475	constant GL_IMAGE_CLASS_10_10_10_2
33476	constant GL_VIEW_CLASS_128_BITS
33477	constant GL_VIEW_CLASS_96_BITS
33478	constant GL_VIEW_CLASS_64_BITS
33479	constant GL_VIEW_CLASS_48_BITS
33480	constant GL_VIEW_CLASS_32_BITS
33481	constant GL_VIEW_CLASS_24_BITS
33482	constant GL_VIEW_CLASS_16_BITS
33483	constant GL_VIEW_CLASS_8_BITS
33484	constant GL_VIEW_CLASS_S3TC_DXT1_RGB
33485	constant GL_VIEW_CLASS_S3TC_DXT1_RGBA
33486	constant GL_VIEW_CLASS_S3TC_DXT3_RGBA
33487	constant GL_VIEW_CLASS_S3TC_DXT5_RGBA
33488	constant GL_VIEW_CLASS_RGTC1_RED
33489	constant GL_VIEW_CLASS_RGTC2_RG
33490	constant GL_VIEW_CLASS_BPTC_UNORM
33491	constant GL_VIEW_CLASS_BPTC_FLOAT
37601	constant GL_UNIFORM
37602	constant GL_UNIFORM_BLOCK
37603	constant GL_PROGRAM_INPUT
37604	constant GL_PROGRAM_OUTPUT
37605	constant GL_BUFFER_VARIABLE
37606	constant GL_SHADER_STORAGE_BLOCK
37608	constant GL_VERTEX_SUBROUTINE
37609	constant GL_TESS_CONTROL_SUBROUTINE
37610	constant GL_TESS_EVALUATION_SUBROUTINE
37611	constant GL_GEOMETRY_SUBROUTINE
37612	constant GL_FRAGMENT_SUBROUTINE
37613	constant GL_COMPUTE_SUBROUTINE
37614	constant GL_VERTEX_SUBROUTINE_UNIFORM
37615	constant GL_TESS_CONTROL_SUBROUTINE_UNIFORM
37616	constant GL_TESS_EVALUATION_SUBROUTINE_UNIFORM
37617	constant GL_GEOMETRY_SUBROUTINE_UNIFORM
37618	constant GL_FRAGMENT_SUBROUTINE_UNIFORM
37619	constant GL_COMPUTE_SUBROUTINE_UNIFORM
37620	constant GL_TRANSFORM_FEEDBACK_VARYING
37621	constant GL_ACTIVE_RESOURCES
37622	constant GL_MAX_NAME_LENGTH
37623	constant GL_MAX_NUM_ACTIVE_VARIABLES
37624	constant GL_MAX_NUM_COMPATIBLE_SUBROUTINES
37625	constant GL_NAME_LENGTH
37626	constant GL_TYPE
37627	constant GL_ARRAY_SIZE
37628	constant GL_OFFSET
37629	constant GL_BLOCK_INDEX
37630	constant GL_ARRAY_STRIDE
37631	constant GL_MATRIX_STRIDE
37632	constant GL_IS_ROW_MAJOR
37633	constant GL_ATOMIC_COUNTER_BUFFER_INDEX
37634	constant GL_BUFFER_BINDING
37635	constant GL_BUFFER_DATA_SIZE
37636	constant GL_NUM_ACTIVE_VARIABLES
37637	constant GL_ACTIVE_VARIABLES
37638	constant GL_REFERENCED_BY_VERTEX_SHADER
37639	constant GL_REFERENCED_BY_TESS_CONTROL_SHADER
37640	constant GL_REFERENCED_BY_TESS_EVALUATION_SHADER
37641	constant GL_REFERENCED_BY_GEOMETRY_SHADER
37642	constant GL_REFERENCED_BY_FRAGMENT_SHADER
37643	constant GL_REFERENCED_BY_COMPUTE_SHADER
37644	constant GL_TOP_LEVEL_ARRAY_SIZE
37645	constant GL_TOP_LEVEL_ARRAY_STRIDE
37646	constant GL_LOCATION
37647	constant GL_LOCATION_INDEX
37607	constant GL_IS_PER_PATCH
37074	constant GL_SHADER_STORAGE_BUFFER
37075	constant GL_SHADER_STORAGE_BUFFER_BINDING
37076	constant GL_SHADER_STORAGE_BUFFER_START
37077	constant GL_SHADER_STORAGE_BUFFER_SIZE
37078	constant GL_MAX_VERTEX_SHADER_STORAGE_BLOCKS
37079	constant GL_MAX_GEOMETRY_SHADER_STORAGE_BLOCKS
37080	constant GL_MAX_TESS_CONTROL_SHADER_STORAGE_BLOCKS
37081	constant GL_MAX_TESS_EVALUATION_SHADER_STORAGE_BLOCKS
37082	constant GL_MAX_FRAGMENT_SHADER_STORAGE_BLOCKS
37083	constant GL_MAX_COMPUTE_SHADER_STORAGE_BLOCKS
37084	constant GL_MAX_COMBINED_SHADER_STORAGE_BLOCKS
37085	constant GL_MAX_SHADER_STORAGE_BUFFER_BINDINGS
37086	constant GL_MAX_SHADER_STORAGE_BLOCK_SIZE
37087	constant GL_SHADER_STORAGE_BUFFER_OFFSET_ALIGNMENT
8192	constant GL_SHADER_STORAGE_BARRIER_BIT
36665	constant GL_MAX_COMBINED_SHADER_OUTPUT_RESOURCES
37098	constant GL_DEPTH_STENCIL_TEXTURE_MODE
37277	constant GL_TEXTURE_BUFFER_OFFSET
37278	constant GL_TEXTURE_BUFFER_SIZE
37279	constant GL_TEXTURE_BUFFER_OFFSET_ALIGNMENT
33499	constant GL_TEXTURE_VIEW_MIN_LEVEL
33500	constant GL_TEXTURE_VIEW_NUM_LEVELS
33501	constant GL_TEXTURE_VIEW_MIN_LAYER
33502	constant GL_TEXTURE_VIEW_NUM_LAYERS
33503	constant GL_TEXTURE_IMMUTABLE_LEVELS
33492	constant GL_VERTEX_ATTRIB_BINDING
33493	constant GL_VERTEX_ATTRIB_RELATIVE_OFFSET
33494	constant GL_VERTEX_BINDING_DIVISOR
33495	constant GL_VERTEX_BINDING_OFFSET
33496	constant GL_VERTEX_BINDING_STRIDE
33497	constant GL_MAX_VERTEX_ATTRIB_RELATIVE_OFFSET
33498	constant GL_MAX_VERTEX_ATTRIB_BINDINGS
36687	constant GL_VERTEX_BINDING_BUFFER
33511	constant GL_DISPLAY_LIST
1	constant GL_VERSION_4_4
33509	constant GL_MAX_VERTEX_ATTRIB_STRIDE
33313	constant GL_PRIMITIVE_RESTART_FOR_PATCHES_SUPPORTED
35882	constant GL_TEXTURE_BUFFER_BINDING
64	constant GL_MAP_PERSISTENT_BIT
128	constant GL_MAP_COHERENT_BIT
256	constant GL_DYNAMIC_STORAGE_BIT
512	constant GL_CLIENT_STORAGE_BIT
16384	constant GL_CLIENT_MAPPED_BUFFER_BARRIER_BIT
33311	constant GL_BUFFER_IMMUTABLE_STORAGE
33312	constant GL_BUFFER_STORAGE_FLAGS
37733	constant GL_CLEAR_TEXTURE
37706	constant GL_LOCATION_COMPONENT
37707	constant GL_TRANSFORM_FEEDBACK_BUFFER_INDEX
37708	constant GL_TRANSFORM_FEEDBACK_BUFFER_STRIDE
37266	constant GL_QUERY_BUFFER
32768	constant GL_QUERY_BUFFER_BARRIER_BIT
37267	constant GL_QUERY_BUFFER_BINDING
37268	constant GL_QUERY_RESULT_NO_WAIT
34627	constant GL_MIRROR_CLAMP_TO_EDGE
1	constant GL_VERSION_4_5
1287	constant GL_CONTEXT_LOST
37726	constant GL_NEGATIVE_ONE_TO_ONE
37727	constant GL_ZERO_TO_ONE
37724	constant GL_CLIP_ORIGIN
37725	constant GL_CLIP_DEPTH_MODE
36375	constant GL_QUERY_WAIT_INVERTED
36376	constant GL_QUERY_NO_WAIT_INVERTED
36377	constant GL_QUERY_BY_REGION_WAIT_INVERTED
36378	constant GL_QUERY_BY_REGION_NO_WAIT_INVERTED
33529	constant GL_MAX_CULL_DISTANCES
33530	constant GL_MAX_COMBINED_CLIP_AND_CULL_DISTANCES
4102	constant GL_TEXTURE_TARGET
33514	constant GL_QUERY_TARGET
33363	constant GL_GUILTY_CONTEXT_RESET
33364	constant GL_INNOCENT_CONTEXT_RESET
33365	constant GL_UNKNOWN_CONTEXT_RESET
33366	constant GL_RESET_NOTIFICATION_STRATEGY
33362	constant GL_LOSE_CONTEXT_ON_RESET
33377	constant GL_NO_RESET_NOTIFICATION
4	constant GL_CONTEXT_FLAG_ROBUST_ACCESS_BIT
33531	constant GL_CONTEXT_RELEASE_BEHAVIOR
33532	constant GL_CONTEXT_RELEASE_BEHAVIOR_FLUSH
1	constant GL_ARB_ES2_compatibility
1	constant GL_ARB_ES3_1_compatibility
1	constant GL_ARB_ES3_compatibility
1	constant GL_ARB_arrays_of_arrays
1	constant GL_ARB_base_instance
1	constant GL_ARB_bindless_texture
5135	constant GL_UNSIGNED_INT64_ARB
1	constant GL_ARB_blend_func_extended
1	constant GL_ARB_buffer_storage
1	constant GL_ARB_cl_event
33344	constant GL_SYNC_CL_EVENT_ARB
33345	constant GL_SYNC_CL_EVENT_COMPLETE_ARB
1	constant GL_ARB_clear_buffer_object
1	constant GL_ARB_clear_texture
1	constant GL_ARB_clip_control
1	constant GL_ARB_color_buffer_float
34848	constant GL_RGBA_FLOAT_MODE_ARB
35098	constant GL_CLAMP_VERTEX_COLOR_ARB
35099	constant GL_CLAMP_FRAGMENT_COLOR_ARB
35100	constant GL_CLAMP_READ_COLOR_ARB
35101	constant GL_FIXED_ONLY_ARB
1	constant GL_ARB_compatibility
1	constant GL_ARB_compressed_texture_pixel_storage
1	constant GL_ARB_compute_shader
1	constant GL_ARB_compute_variable_group_size
37700	constant GL_MAX_COMPUTE_VARIABLE_GROUP_INVOCATIONS_ARB
37099	constant GL_MAX_COMPUTE_FIXED_GROUP_INVOCATIONS_ARB
37701	constant GL_MAX_COMPUTE_VARIABLE_GROUP_SIZE_ARB
37311	constant GL_MAX_COMPUTE_FIXED_GROUP_SIZE_ARB
1	constant GL_ARB_conditional_render_inverted
1	constant GL_ARB_conservative_depth
1	constant GL_ARB_copy_buffer
1	constant GL_ARB_copy_image
1	constant GL_ARB_cull_distance
1	constant GL_ARB_debug_output
33346	constant GL_DEBUG_OUTPUT_SYNCHRONOUS_ARB
33347	constant GL_DEBUG_NEXT_LOGGED_MESSAGE_LENGTH_ARB
33348	constant GL_DEBUG_CALLBACK_FUNCTION_ARB
33349	constant GL_DEBUG_CALLBACK_USER_PARAM_ARB
33350	constant GL_DEBUG_SOURCE_API_ARB
33351	constant GL_DEBUG_SOURCE_WINDOW_SYSTEM_ARB
33352	constant GL_DEBUG_SOURCE_SHADER_COMPILER_ARB
33353	constant GL_DEBUG_SOURCE_THIRD_PARTY_ARB
33354	constant GL_DEBUG_SOURCE_APPLICATION_ARB
33355	constant GL_DEBUG_SOURCE_OTHER_ARB
33356	constant GL_DEBUG_TYPE_ERROR_ARB
33357	constant GL_DEBUG_TYPE_DEPRECATED_BEHAVIOR_ARB
33358	constant GL_DEBUG_TYPE_UNDEFINED_BEHAVIOR_ARB
33359	constant GL_DEBUG_TYPE_PORTABILITY_ARB
33360	constant GL_DEBUG_TYPE_PERFORMANCE_ARB
33361	constant GL_DEBUG_TYPE_OTHER_ARB
37187	constant GL_MAX_DEBUG_MESSAGE_LENGTH_ARB
37188	constant GL_MAX_DEBUG_LOGGED_MESSAGES_ARB
37189	constant GL_DEBUG_LOGGED_MESSAGES_ARB
37190	constant GL_DEBUG_SEVERITY_HIGH_ARB
37191	constant GL_DEBUG_SEVERITY_MEDIUM_ARB
37192	constant GL_DEBUG_SEVERITY_LOW_ARB
1	constant GL_ARB_depth_buffer_float
1	constant GL_ARB_depth_clamp
1	constant GL_ARB_depth_texture
33189	constant GL_DEPTH_COMPONENT16_ARB
33190	constant GL_DEPTH_COMPONENT24_ARB
33191	constant GL_DEPTH_COMPONENT32_ARB
34890	constant GL_TEXTURE_DEPTH_SIZE_ARB
34891	constant GL_DEPTH_TEXTURE_MODE_ARB
1	constant GL_ARB_derivative_control
1	constant GL_ARB_direct_state_access
1	constant GL_ARB_draw_buffers
34852	constant GL_MAX_DRAW_BUFFERS_ARB
34853	constant GL_DRAW_BUFFER0_ARB
34854	constant GL_DRAW_BUFFER1_ARB
34855	constant GL_DRAW_BUFFER2_ARB
34856	constant GL_DRAW_BUFFER3_ARB
34857	constant GL_DRAW_BUFFER4_ARB
34858	constant GL_DRAW_BUFFER5_ARB
34859	constant GL_DRAW_BUFFER6_ARB
34860	constant GL_DRAW_BUFFER7_ARB
34861	constant GL_DRAW_BUFFER8_ARB
34862	constant GL_DRAW_BUFFER9_ARB
34863	constant GL_DRAW_BUFFER10_ARB
34864	constant GL_DRAW_BUFFER11_ARB
34865	constant GL_DRAW_BUFFER12_ARB
34866	constant GL_DRAW_BUFFER13_ARB
34867	constant GL_DRAW_BUFFER14_ARB
34868	constant GL_DRAW_BUFFER15_ARB
1	constant GL_ARB_draw_buffers_blend
1	constant GL_ARB_draw_elements_base_vertex
1	constant GL_ARB_draw_indirect
1	constant GL_ARB_draw_instanced
1	constant GL_ARB_enhanced_layouts
1	constant GL_ARB_explicit_attrib_location
1	constant GL_ARB_explicit_uniform_location
1	constant GL_ARB_fragment_coord_conventions
1	constant GL_ARB_fragment_layer_viewport
1	constant GL_ARB_fragment_program
34820	constant GL_FRAGMENT_PROGRAM_ARB
34933	constant GL_PROGRAM_FORMAT_ASCII_ARB
34343	constant GL_PROGRAM_LENGTH_ARB
34934	constant GL_PROGRAM_FORMAT_ARB
34423	constant GL_PROGRAM_BINDING_ARB
34976	constant GL_PROGRAM_INSTRUCTIONS_ARB
34977	constant GL_MAX_PROGRAM_INSTRUCTIONS_ARB
34978	constant GL_PROGRAM_NATIVE_INSTRUCTIONS_ARB
34979	constant GL_MAX_PROGRAM_NATIVE_INSTRUCTIONS_ARB
34980	constant GL_PROGRAM_TEMPORARIES_ARB
34981	constant GL_MAX_PROGRAM_TEMPORARIES_ARB
34982	constant GL_PROGRAM_NATIVE_TEMPORARIES_ARB
34983	constant GL_MAX_PROGRAM_NATIVE_TEMPORARIES_ARB
34984	constant GL_PROGRAM_PARAMETERS_ARB
34985	constant GL_MAX_PROGRAM_PARAMETERS_ARB
34986	constant GL_PROGRAM_NATIVE_PARAMETERS_ARB
34987	constant GL_MAX_PROGRAM_NATIVE_PARAMETERS_ARB
34988	constant GL_PROGRAM_ATTRIBS_ARB
34989	constant GL_MAX_PROGRAM_ATTRIBS_ARB
34990	constant GL_PROGRAM_NATIVE_ATTRIBS_ARB
34991	constant GL_MAX_PROGRAM_NATIVE_ATTRIBS_ARB
34996	constant GL_MAX_PROGRAM_LOCAL_PARAMETERS_ARB
34997	constant GL_MAX_PROGRAM_ENV_PARAMETERS_ARB
34998	constant GL_PROGRAM_UNDER_NATIVE_LIMITS_ARB
34821	constant GL_PROGRAM_ALU_INSTRUCTIONS_ARB
34822	constant GL_PROGRAM_TEX_INSTRUCTIONS_ARB
34823	constant GL_PROGRAM_TEX_INDIRECTIONS_ARB
34824	constant GL_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB
34825	constant GL_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB
34826	constant GL_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB
34827	constant GL_MAX_PROGRAM_ALU_INSTRUCTIONS_ARB
34828	constant GL_MAX_PROGRAM_TEX_INSTRUCTIONS_ARB
34829	constant GL_MAX_PROGRAM_TEX_INDIRECTIONS_ARB
34830	constant GL_MAX_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB
34831	constant GL_MAX_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB
34832	constant GL_MAX_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB
34344	constant GL_PROGRAM_STRING_ARB
34379	constant GL_PROGRAM_ERROR_POSITION_ARB
34369	constant GL_CURRENT_MATRIX_ARB
34999	constant GL_TRANSPOSE_CURRENT_MATRIX_ARB
34368	constant GL_CURRENT_MATRIX_STACK_DEPTH_ARB
34351	constant GL_MAX_PROGRAM_MATRICES_ARB
34350	constant GL_MAX_PROGRAM_MATRIX_STACK_DEPTH_ARB
34929	constant GL_MAX_TEXTURE_COORDS_ARB
34930	constant GL_MAX_TEXTURE_IMAGE_UNITS_ARB
34932	constant GL_PROGRAM_ERROR_STRING_ARB
35008	constant GL_MATRIX0_ARB
35009	constant GL_MATRIX1_ARB
35010	constant GL_MATRIX2_ARB
35011	constant GL_MATRIX3_ARB
35012	constant GL_MATRIX4_ARB
35013	constant GL_MATRIX5_ARB
35014	constant GL_MATRIX6_ARB
35015	constant GL_MATRIX7_ARB
35016	constant GL_MATRIX8_ARB
35017	constant GL_MATRIX9_ARB
35018	constant GL_MATRIX10_ARB
35019	constant GL_MATRIX11_ARB
35020	constant GL_MATRIX12_ARB
35021	constant GL_MATRIX13_ARB
35022	constant GL_MATRIX14_ARB
35023	constant GL_MATRIX15_ARB
35024	constant GL_MATRIX16_ARB
35025	constant GL_MATRIX17_ARB
35026	constant GL_MATRIX18_ARB
35027	constant GL_MATRIX19_ARB
35028	constant GL_MATRIX20_ARB
35029	constant GL_MATRIX21_ARB
35030	constant GL_MATRIX22_ARB
35031	constant GL_MATRIX23_ARB
35032	constant GL_MATRIX24_ARB
35033	constant GL_MATRIX25_ARB
35034	constant GL_MATRIX26_ARB
35035	constant GL_MATRIX27_ARB
35036	constant GL_MATRIX28_ARB
35037	constant GL_MATRIX29_ARB
35038	constant GL_MATRIX30_ARB
35039	constant GL_MATRIX31_ARB
1	constant GL_ARB_fragment_program_shadow
1	constant GL_ARB_fragment_shader
35632	constant GL_FRAGMENT_SHADER_ARB
35657	constant GL_MAX_FRAGMENT_UNIFORM_COMPONENTS_ARB
35723	constant GL_FRAGMENT_SHADER_DERIVATIVE_HINT_ARB
1	constant GL_ARB_framebuffer_no_attachments
1	constant GL_ARB_framebuffer_object
1	constant GL_ARB_framebuffer_sRGB
1	constant GL_ARB_geometry_shader4
10	constant GL_LINES_ADJACENCY_ARB
11	constant GL_LINE_STRIP_ADJACENCY_ARB
12	constant GL_TRIANGLES_ADJACENCY_ARB
13	constant GL_TRIANGLE_STRIP_ADJACENCY_ARB
34370	constant GL_PROGRAM_POINT_SIZE_ARB
35881	constant GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS_ARB
36263	constant GL_FRAMEBUFFER_ATTACHMENT_LAYERED_ARB
36264	constant GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS_ARB
36265	constant GL_FRAMEBUFFER_INCOMPLETE_LAYER_COUNT_ARB
36313	constant GL_GEOMETRY_SHADER_ARB
36314	constant GL_GEOMETRY_VERTICES_OUT_ARB
36315	constant GL_GEOMETRY_INPUT_TYPE_ARB
36316	constant GL_GEOMETRY_OUTPUT_TYPE_ARB
36317	constant GL_MAX_GEOMETRY_VARYING_COMPONENTS_ARB
36318	constant GL_MAX_VERTEX_VARYING_COMPONENTS_ARB
36319	constant GL_MAX_GEOMETRY_UNIFORM_COMPONENTS_ARB
36320	constant GL_MAX_GEOMETRY_OUTPUT_VERTICES_ARB
36321	constant GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS_ARB
1	constant GL_ARB_get_program_binary
1	constant GL_ARB_get_texture_sub_image
1	constant GL_ARB_gpu_shader5
1	constant GL_ARB_gpu_shader_fp64
1	constant GL_ARB_half_float_pixel
5131	constant GL_HALF_FLOAT_ARB
1	constant GL_ARB_half_float_vertex
1	constant GL_ARB_indirect_parameters
33006	constant GL_PARAMETER_BUFFER_ARB
33007	constant GL_PARAMETER_BUFFER_BINDING_ARB
1	constant GL_ARB_instanced_arrays
35070	constant GL_VERTEX_ATTRIB_ARRAY_DIVISOR_ARB
1	constant GL_ARB_internalformat_query
1	constant GL_ARB_internalformat_query2
33433	constant GL_SRGB_DECODE_ARB
1	constant GL_ARB_invalidate_subdata
1	constant GL_ARB_map_buffer_alignment
1	constant GL_ARB_map_buffer_range
1	constant GL_ARB_matrix_palette
34880	constant GL_MATRIX_PALETTE_ARB
34881	constant GL_MAX_MATRIX_PALETTE_STACK_DEPTH_ARB
34882	constant GL_MAX_PALETTE_MATRICES_ARB
34883	constant GL_CURRENT_PALETTE_MATRIX_ARB
34884	constant GL_MATRIX_INDEX_ARRAY_ARB
34885	constant GL_CURRENT_MATRIX_INDEX_ARB
34886	constant GL_MATRIX_INDEX_ARRAY_SIZE_ARB
34887	constant GL_MATRIX_INDEX_ARRAY_TYPE_ARB
34888	constant GL_MATRIX_INDEX_ARRAY_STRIDE_ARB
34889	constant GL_MATRIX_INDEX_ARRAY_POINTER_ARB
1	constant GL_ARB_multi_bind
1	constant GL_ARB_multi_draw_indirect
1	constant GL_ARB_multisample
32925	constant GL_MULTISAMPLE_ARB
32926	constant GL_SAMPLE_ALPHA_TO_COVERAGE_ARB
32927	constant GL_SAMPLE_ALPHA_TO_ONE_ARB
32928	constant GL_SAMPLE_COVERAGE_ARB
32936	constant GL_SAMPLE_BUFFERS_ARB
32937	constant GL_SAMPLES_ARB
32938	constant GL_SAMPLE_COVERAGE_VALUE_ARB
32939	constant GL_SAMPLE_COVERAGE_INVERT_ARB
536870912	constant GL_MULTISAMPLE_BIT_ARB
1	constant GL_ARB_occlusion_query
34916	constant GL_QUERY_COUNTER_BITS_ARB
34917	constant GL_CURRENT_QUERY_ARB
34918	constant GL_QUERY_RESULT_ARB
34919	constant GL_QUERY_RESULT_AVAILABLE_ARB
35092	constant GL_SAMPLES_PASSED_ARB
1	constant GL_ARB_occlusion_query2
1	constant GL_ARB_pipeline_statistics_query
33518	constant GL_VERTICES_SUBMITTED_ARB
33519	constant GL_PRIMITIVES_SUBMITTED_ARB
33520	constant GL_VERTEX_SHADER_INVOCATIONS_ARB
33521	constant GL_TESS_CONTROL_SHADER_PATCHES_ARB
33522	constant GL_TESS_EVALUATION_SHADER_INVOCATIONS_ARB
33523	constant GL_GEOMETRY_SHADER_PRIMITIVES_EMITTED_ARB
33524	constant GL_FRAGMENT_SHADER_INVOCATIONS_ARB
33525	constant GL_COMPUTE_SHADER_INVOCATIONS_ARB
33526	constant GL_CLIPPING_INPUT_PRIMITIVES_ARB
33527	constant GL_CLIPPING_OUTPUT_PRIMITIVES_ARB
1	constant GL_ARB_pixel_buffer_object
35051	constant GL_PIXEL_PACK_BUFFER_ARB
35052	constant GL_PIXEL_UNPACK_BUFFER_ARB
35053	constant GL_PIXEL_PACK_BUFFER_BINDING_ARB
35055	constant GL_PIXEL_UNPACK_BUFFER_BINDING_ARB
1	constant GL_ARB_point_parameters
33062	constant GL_POINT_SIZE_MIN_ARB
33063	constant GL_POINT_SIZE_MAX_ARB
33064	constant GL_POINT_FADE_THRESHOLD_SIZE_ARB
33065	constant GL_POINT_DISTANCE_ATTENUATION_ARB
1	constant GL_ARB_point_sprite
34913	constant GL_POINT_SPRITE_ARB
34914	constant GL_COORD_REPLACE_ARB
1	constant GL_ARB_program_interface_query
1	constant GL_ARB_provoking_vertex
1	constant GL_ARB_query_buffer_object
1	constant GL_ARB_robust_buffer_access_behavior
1	constant GL_ARB_robustness
4	constant GL_CONTEXT_FLAG_ROBUST_ACCESS_BIT_ARB
33362	constant GL_LOSE_CONTEXT_ON_RESET_ARB
33363	constant GL_GUILTY_CONTEXT_RESET_ARB
33364	constant GL_INNOCENT_CONTEXT_RESET_ARB
33365	constant GL_UNKNOWN_CONTEXT_RESET_ARB
33366	constant GL_RESET_NOTIFICATION_STRATEGY_ARB
33377	constant GL_NO_RESET_NOTIFICATION_ARB
1	constant GL_ARB_robustness_isolation
1	constant GL_ARB_sample_shading
35894	constant GL_SAMPLE_SHADING_ARB
35895	constant GL_MIN_SAMPLE_SHADING_VALUE_ARB
1	constant GL_ARB_sampler_objects
1	constant GL_ARB_seamless_cube_map
1	constant GL_ARB_seamless_cubemap_per_texture
1	constant GL_ARB_separate_shader_objects
1	constant GL_ARB_shader_atomic_counters
1	constant GL_ARB_shader_bit_encoding
1	constant GL_ARB_shader_draw_parameters
1	constant GL_ARB_shader_group_vote
1	constant GL_ARB_shader_image_load_store
1	constant GL_ARB_shader_image_size
1	constant GL_ARB_shader_objects
35648	constant GL_PROGRAM_OBJECT_ARB
35656	constant GL_SHADER_OBJECT_ARB
35662	constant GL_OBJECT_TYPE_ARB
35663	constant GL_OBJECT_SUBTYPE_ARB
35664	constant GL_FLOAT_VEC2_ARB
35665	constant GL_FLOAT_VEC3_ARB
35666	constant GL_FLOAT_VEC4_ARB
35667	constant GL_INT_VEC2_ARB
35668	constant GL_INT_VEC3_ARB
35669	constant GL_INT_VEC4_ARB
35670	constant GL_BOOL_ARB
35671	constant GL_BOOL_VEC2_ARB
35672	constant GL_BOOL_VEC3_ARB
35673	constant GL_BOOL_VEC4_ARB
35674	constant GL_FLOAT_MAT2_ARB
35675	constant GL_FLOAT_MAT3_ARB
35676	constant GL_FLOAT_MAT4_ARB
35677	constant GL_SAMPLER_1D_ARB
35678	constant GL_SAMPLER_2D_ARB
35679	constant GL_SAMPLER_3D_ARB
35680	constant GL_SAMPLER_CUBE_ARB
35681	constant GL_SAMPLER_1D_SHADOW_ARB
35682	constant GL_SAMPLER_2D_SHADOW_ARB
35683	constant GL_SAMPLER_2D_RECT_ARB
35684	constant GL_SAMPLER_2D_RECT_SHADOW_ARB
35712	constant GL_OBJECT_DELETE_STATUS_ARB
35713	constant GL_OBJECT_COMPILE_STATUS_ARB
35714	constant GL_OBJECT_LINK_STATUS_ARB
35715	constant GL_OBJECT_VALIDATE_STATUS_ARB
35716	constant GL_OBJECT_INFO_LOG_LENGTH_ARB
35717	constant GL_OBJECT_ATTACHED_OBJECTS_ARB
35718	constant GL_OBJECT_ACTIVE_UNIFORMS_ARB
35719	constant GL_OBJECT_ACTIVE_UNIFORM_MAX_LENGTH_ARB
35720	constant GL_OBJECT_SHADER_SOURCE_LENGTH_ARB
1	constant GL_ARB_shader_precision
1	constant GL_ARB_shader_stencil_export
1	constant GL_ARB_shader_storage_buffer_object
1	constant GL_ARB_shader_subroutine
1	constant GL_ARB_shader_texture_image_samples
1	constant GL_ARB_shader_texture_lod
1	constant GL_ARB_shading_language_100
35724	constant GL_SHADING_LANGUAGE_VERSION_ARB
1	constant GL_ARB_shading_language_420pack
1	constant GL_ARB_shading_language_include
36270	constant GL_SHADER_INCLUDE_ARB
36329	constant GL_NAMED_STRING_LENGTH_ARB
36330	constant GL_NAMED_STRING_TYPE_ARB
1	constant GL_ARB_shading_language_packing
1	constant GL_ARB_shadow
34892	constant GL_TEXTURE_COMPARE_MODE_ARB
34893	constant GL_TEXTURE_COMPARE_FUNC_ARB
34894	constant GL_COMPARE_R_TO_TEXTURE_ARB
1	constant GL_ARB_shadow_ambient
32959	constant GL_TEXTURE_COMPARE_FAIL_VALUE_ARB
1	constant GL_ARB_sparse_buffer
1024	constant GL_SPARSE_STORAGE_BIT_ARB
33528	constant GL_SPARSE_BUFFER_PAGE_SIZE_ARB
1	constant GL_ARB_sparse_texture
37286	constant GL_TEXTURE_SPARSE_ARB
37287	constant GL_VIRTUAL_PAGE_SIZE_INDEX_ARB
37290	constant GL_NUM_SPARSE_LEVELS_ARB
37288	constant GL_NUM_VIRTUAL_PAGE_SIZES_ARB
37269	constant GL_VIRTUAL_PAGE_SIZE_X_ARB
37270	constant GL_VIRTUAL_PAGE_SIZE_Y_ARB
37271	constant GL_VIRTUAL_PAGE_SIZE_Z_ARB
37272	constant GL_MAX_SPARSE_TEXTURE_SIZE_ARB
37273	constant GL_MAX_SPARSE_3D_TEXTURE_SIZE_ARB
37274	constant GL_MAX_SPARSE_ARRAY_TEXTURE_LAYERS_ARB
37289	constant GL_SPARSE_TEXTURE_FULL_ARRAY_CUBE_MIPMAPS_ARB
1	constant GL_ARB_stencil_texturing
1	constant GL_ARB_sync
1	constant GL_ARB_tessellation_shader
1	constant GL_ARB_texture_barrier
1	constant GL_ARB_texture_border_clamp
33069	constant GL_CLAMP_TO_BORDER_ARB
1	constant GL_ARB_texture_buffer_object
35882	constant GL_TEXTURE_BUFFER_ARB
35883	constant GL_MAX_TEXTURE_BUFFER_SIZE_ARB
35884	constant GL_TEXTURE_BINDING_BUFFER_ARB
35885	constant GL_TEXTURE_BUFFER_DATA_STORE_BINDING_ARB
35886	constant GL_TEXTURE_BUFFER_FORMAT_ARB
1	constant GL_ARB_texture_buffer_object_rgb32
1	constant GL_ARB_texture_buffer_range
1	constant GL_ARB_texture_compression
34025	constant GL_COMPRESSED_ALPHA_ARB
34026	constant GL_COMPRESSED_LUMINANCE_ARB
34027	constant GL_COMPRESSED_LUMINANCE_ALPHA_ARB
34028	constant GL_COMPRESSED_INTENSITY_ARB
34029	constant GL_COMPRESSED_RGB_ARB
34030	constant GL_COMPRESSED_RGBA_ARB
34031	constant GL_TEXTURE_COMPRESSION_HINT_ARB
34464	constant GL_TEXTURE_COMPRESSED_IMAGE_SIZE_ARB
34465	constant GL_TEXTURE_COMPRESSED_ARB
34466	constant GL_NUM_COMPRESSED_TEXTURE_FORMATS_ARB
34467	constant GL_COMPRESSED_TEXTURE_FORMATS_ARB
1	constant GL_ARB_texture_compression_bptc
36492	constant GL_COMPRESSED_RGBA_BPTC_UNORM_ARB
36493	constant GL_COMPRESSED_SRGB_ALPHA_BPTC_UNORM_ARB
36494	constant GL_COMPRESSED_RGB_BPTC_SIGNED_FLOAT_ARB
36495	constant GL_COMPRESSED_RGB_BPTC_UNSIGNED_FLOAT_ARB
1	constant GL_ARB_texture_compression_rgtc
1	constant GL_ARB_texture_cube_map
34065	constant GL_NORMAL_MAP_ARB
34066	constant GL_REFLECTION_MAP_ARB
34067	constant GL_TEXTURE_CUBE_MAP_ARB
34068	constant GL_TEXTURE_BINDING_CUBE_MAP_ARB
34069	constant GL_TEXTURE_CUBE_MAP_POSITIVE_X_ARB
34070	constant GL_TEXTURE_CUBE_MAP_NEGATIVE_X_ARB
34071	constant GL_TEXTURE_CUBE_MAP_POSITIVE_Y_ARB
34072	constant GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_ARB
34073	constant GL_TEXTURE_CUBE_MAP_POSITIVE_Z_ARB
34074	constant GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_ARB
34075	constant GL_PROXY_TEXTURE_CUBE_MAP_ARB
34076	constant GL_MAX_CUBE_MAP_TEXTURE_SIZE_ARB
1	constant GL_ARB_texture_cube_map_array
36873	constant GL_TEXTURE_CUBE_MAP_ARRAY_ARB
36874	constant GL_TEXTURE_BINDING_CUBE_MAP_ARRAY_ARB
36875	constant GL_PROXY_TEXTURE_CUBE_MAP_ARRAY_ARB
36876	constant GL_SAMPLER_CUBE_MAP_ARRAY_ARB
36877	constant GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW_ARB
36878	constant GL_INT_SAMPLER_CUBE_MAP_ARRAY_ARB
36879	constant GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY_ARB
1	constant GL_ARB_texture_env_add
1	constant GL_ARB_texture_env_combine
34160	constant GL_COMBINE_ARB
34161	constant GL_COMBINE_RGB_ARB
34162	constant GL_COMBINE_ALPHA_ARB
34176	constant GL_SOURCE0_RGB_ARB
34177	constant GL_SOURCE1_RGB_ARB
34178	constant GL_SOURCE2_RGB_ARB
34184	constant GL_SOURCE0_ALPHA_ARB
34185	constant GL_SOURCE1_ALPHA_ARB
34186	constant GL_SOURCE2_ALPHA_ARB
34192	constant GL_OPERAND0_RGB_ARB
34193	constant GL_OPERAND1_RGB_ARB
34194	constant GL_OPERAND2_RGB_ARB
34200	constant GL_OPERAND0_ALPHA_ARB
34201	constant GL_OPERAND1_ALPHA_ARB
34202	constant GL_OPERAND2_ALPHA_ARB
34163	constant GL_RGB_SCALE_ARB
34164	constant GL_ADD_SIGNED_ARB
34165	constant GL_INTERPOLATE_ARB
34023	constant GL_SUBTRACT_ARB
34166	constant GL_CONSTANT_ARB
34167	constant GL_PRIMARY_COLOR_ARB
34168	constant GL_PREVIOUS_ARB
1	constant GL_ARB_texture_env_crossbar
1	constant GL_ARB_texture_env_dot3
34478	constant GL_DOT3_RGB_ARB
34479	constant GL_DOT3_RGBA_ARB
1	constant GL_ARB_texture_float
35856	constant GL_TEXTURE_RED_TYPE_ARB
35857	constant GL_TEXTURE_GREEN_TYPE_ARB
35858	constant GL_TEXTURE_BLUE_TYPE_ARB
35859	constant GL_TEXTURE_ALPHA_TYPE_ARB
35860	constant GL_TEXTURE_LUMINANCE_TYPE_ARB
35861	constant GL_TEXTURE_INTENSITY_TYPE_ARB
35862	constant GL_TEXTURE_DEPTH_TYPE_ARB
35863	constant GL_UNSIGNED_NORMALIZED_ARB
34836	constant GL_RGBA32F_ARB
34837	constant GL_RGB32F_ARB
34838	constant GL_ALPHA32F_ARB
34839	constant GL_INTENSITY32F_ARB
34840	constant GL_LUMINANCE32F_ARB
34841	constant GL_LUMINANCE_ALPHA32F_ARB
34842	constant GL_RGBA16F_ARB
34843	constant GL_RGB16F_ARB
34844	constant GL_ALPHA16F_ARB
34845	constant GL_INTENSITY16F_ARB
34846	constant GL_LUMINANCE16F_ARB
34847	constant GL_LUMINANCE_ALPHA16F_ARB
1	constant GL_ARB_texture_gather
36446	constant GL_MIN_PROGRAM_TEXTURE_GATHER_OFFSET_ARB
36447	constant GL_MAX_PROGRAM_TEXTURE_GATHER_OFFSET_ARB
36767	constant GL_MAX_PROGRAM_TEXTURE_GATHER_COMPONENTS_ARB
1	constant GL_ARB_texture_mirror_clamp_to_edge
1	constant GL_ARB_texture_mirrored_repeat
33648	constant GL_MIRRORED_REPEAT_ARB
1	constant GL_ARB_texture_multisample
1	constant GL_ARB_texture_non_power_of_two
1	constant GL_ARB_texture_query_levels
1	constant GL_ARB_texture_query_lod
1	constant GL_ARB_texture_rectangle
34037	constant GL_TEXTURE_RECTANGLE_ARB
34038	constant GL_TEXTURE_BINDING_RECTANGLE_ARB
34039	constant GL_PROXY_TEXTURE_RECTANGLE_ARB
34040	constant GL_MAX_RECTANGLE_TEXTURE_SIZE_ARB
1	constant GL_ARB_texture_rg
1	constant GL_ARB_texture_rgb10_a2ui
1	constant GL_ARB_texture_stencil8
1	constant GL_ARB_texture_storage
1	constant GL_ARB_texture_storage_multisample
1	constant GL_ARB_texture_swizzle
1	constant GL_ARB_texture_view
1	constant GL_ARB_timer_query
1	constant GL_ARB_transform_feedback2
1	constant GL_ARB_transform_feedback3
1	constant GL_ARB_transform_feedback_instanced
1	constant GL_ARB_transform_feedback_overflow_query
33516	constant GL_TRANSFORM_FEEDBACK_OVERFLOW_ARB
33517	constant GL_TRANSFORM_FEEDBACK_STREAM_OVERFLOW_ARB
1	constant GL_ARB_transpose_matrix
34019	constant GL_TRANSPOSE_MODELVIEW_MATRIX_ARB
34020	constant GL_TRANSPOSE_PROJECTION_MATRIX_ARB
34021	constant GL_TRANSPOSE_TEXTURE_MATRIX_ARB
34022	constant GL_TRANSPOSE_COLOR_MATRIX_ARB
1	constant GL_ARB_uniform_buffer_object
1	constant GL_ARB_vertex_array_bgra
1	constant GL_ARB_vertex_array_object
1	constant GL_ARB_vertex_attrib_64bit
1	constant GL_ARB_vertex_attrib_binding
1	constant GL_ARB_vertex_blend
34468	constant GL_MAX_VERTEX_UNITS_ARB
34469	constant GL_ACTIVE_VERTEX_UNITS_ARB
34470	constant GL_WEIGHT_SUM_UNITY_ARB
34471	constant GL_VERTEX_BLEND_ARB
34472	constant GL_CURRENT_WEIGHT_ARB
34473	constant GL_WEIGHT_ARRAY_TYPE_ARB
34474	constant GL_WEIGHT_ARRAY_STRIDE_ARB
34475	constant GL_WEIGHT_ARRAY_SIZE_ARB
34476	constant GL_WEIGHT_ARRAY_POINTER_ARB
34477	constant GL_WEIGHT_ARRAY_ARB
5888	constant GL_MODELVIEW0_ARB
34058	constant GL_MODELVIEW1_ARB
34594	constant GL_MODELVIEW2_ARB
34595	constant GL_MODELVIEW3_ARB
34596	constant GL_MODELVIEW4_ARB
34597	constant GL_MODELVIEW5_ARB
34598	constant GL_MODELVIEW6_ARB
34599	constant GL_MODELVIEW7_ARB
34600	constant GL_MODELVIEW8_ARB
34601	constant GL_MODELVIEW9_ARB
34602	constant GL_MODELVIEW10_ARB
34603	constant GL_MODELVIEW11_ARB
34604	constant GL_MODELVIEW12_ARB
34605	constant GL_MODELVIEW13_ARB
34606	constant GL_MODELVIEW14_ARB
34607	constant GL_MODELVIEW15_ARB
34608	constant GL_MODELVIEW16_ARB
34609	constant GL_MODELVIEW17_ARB
34610	constant GL_MODELVIEW18_ARB
34611	constant GL_MODELVIEW19_ARB
34612	constant GL_MODELVIEW20_ARB
34613	constant GL_MODELVIEW21_ARB
34614	constant GL_MODELVIEW22_ARB
34615	constant GL_MODELVIEW23_ARB
34616	constant GL_MODELVIEW24_ARB
34617	constant GL_MODELVIEW25_ARB
34618	constant GL_MODELVIEW26_ARB
34619	constant GL_MODELVIEW27_ARB
34620	constant GL_MODELVIEW28_ARB
34621	constant GL_MODELVIEW29_ARB
34622	constant GL_MODELVIEW30_ARB
34623	constant GL_MODELVIEW31_ARB
1	constant GL_ARB_vertex_buffer_object
34660	constant GL_BUFFER_SIZE_ARB
34661	constant GL_BUFFER_USAGE_ARB
34962	constant GL_ARRAY_BUFFER_ARB
34963	constant GL_ELEMENT_ARRAY_BUFFER_ARB
34964	constant GL_ARRAY_BUFFER_BINDING_ARB
34965	constant GL_ELEMENT_ARRAY_BUFFER_BINDING_ARB
34966	constant GL_VERTEX_ARRAY_BUFFER_BINDING_ARB
34967	constant GL_NORMAL_ARRAY_BUFFER_BINDING_ARB
34968	constant GL_COLOR_ARRAY_BUFFER_BINDING_ARB
34969	constant GL_INDEX_ARRAY_BUFFER_BINDING_ARB
34970	constant GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING_ARB
34971	constant GL_EDGE_FLAG_ARRAY_BUFFER_BINDING_ARB
34972	constant GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING_ARB
34973	constant GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING_ARB
34974	constant GL_WEIGHT_ARRAY_BUFFER_BINDING_ARB
34975	constant GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING_ARB
35000	constant GL_READ_ONLY_ARB
35001	constant GL_WRITE_ONLY_ARB
35002	constant GL_READ_WRITE_ARB
35003	constant GL_BUFFER_ACCESS_ARB
35004	constant GL_BUFFER_MAPPED_ARB
35005	constant GL_BUFFER_MAP_POINTER_ARB
35040	constant GL_STREAM_DRAW_ARB
35041	constant GL_STREAM_READ_ARB
35042	constant GL_STREAM_COPY_ARB
35044	constant GL_STATIC_DRAW_ARB
35045	constant GL_STATIC_READ_ARB
35046	constant GL_STATIC_COPY_ARB
35048	constant GL_DYNAMIC_DRAW_ARB
35049	constant GL_DYNAMIC_READ_ARB
35050	constant GL_DYNAMIC_COPY_ARB
1	constant GL_ARB_vertex_program
33880	constant GL_COLOR_SUM_ARB
34336	constant GL_VERTEX_PROGRAM_ARB
34338	constant GL_VERTEX_ATTRIB_ARRAY_ENABLED_ARB
34339	constant GL_VERTEX_ATTRIB_ARRAY_SIZE_ARB
34340	constant GL_VERTEX_ATTRIB_ARRAY_STRIDE_ARB
34341	constant GL_VERTEX_ATTRIB_ARRAY_TYPE_ARB
34342	constant GL_CURRENT_VERTEX_ATTRIB_ARB
34370	constant GL_VERTEX_PROGRAM_POINT_SIZE_ARB
34371	constant GL_VERTEX_PROGRAM_TWO_SIDE_ARB
34373	constant GL_VERTEX_ATTRIB_ARRAY_POINTER_ARB
34921	constant GL_MAX_VERTEX_ATTRIBS_ARB
34922	constant GL_VERTEX_ATTRIB_ARRAY_NORMALIZED_ARB
34992	constant GL_PROGRAM_ADDRESS_REGISTERS_ARB
34993	constant GL_MAX_PROGRAM_ADDRESS_REGISTERS_ARB
34994	constant GL_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB
34995	constant GL_MAX_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB
1	constant GL_ARB_vertex_shader
35633	constant GL_VERTEX_SHADER_ARB
35658	constant GL_MAX_VERTEX_UNIFORM_COMPONENTS_ARB
35659	constant GL_MAX_VARYING_FLOATS_ARB
35660	constant GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS_ARB
35661	constant GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS_ARB
35721	constant GL_OBJECT_ACTIVE_ATTRIBUTES_ARB
35722	constant GL_OBJECT_ACTIVE_ATTRIBUTE_MAX_LENGTH_ARB
1	constant GL_ARB_vertex_type_10f_11f_11f_rev
1	constant GL_ARB_vertex_type_2_10_10_10_rev
1	constant GL_ARB_viewport_array
1	constant GL_ARB_window_pos
1	constant GL_KHR_blend_equation_advanced
37524	constant GL_MULTIPLY_KHR
37525	constant GL_SCREEN_KHR
37526	constant GL_OVERLAY_KHR
37527	constant GL_DARKEN_KHR
37528	constant GL_LIGHTEN_KHR
37529	constant GL_COLORDODGE_KHR
37530	constant GL_COLORBURN_KHR
37531	constant GL_HARDLIGHT_KHR
37532	constant GL_SOFTLIGHT_KHR
37534	constant GL_DIFFERENCE_KHR
37536	constant GL_EXCLUSION_KHR
37549	constant GL_HSL_HUE_KHR
37550	constant GL_HSL_SATURATION_KHR
37551	constant GL_HSL_COLOR_KHR
37552	constant GL_HSL_LUMINOSITY_KHR
1	constant GL_KHR_blend_equation_advanced_coherent
37509	constant GL_BLEND_ADVANCED_COHERENT_KHR
1	constant GL_KHR_context_flush_control
1	constant GL_KHR_debug
1	constant GL_KHR_robust_buffer_access_behavior
1	constant GL_KHR_robustness
37107	constant GL_CONTEXT_ROBUST_ACCESS
1	constant GL_KHR_texture_compression_astc_hdr
37808	constant GL_COMPRESSED_RGBA_ASTC_4x4_KHR
37809	constant GL_COMPRESSED_RGBA_ASTC_5x4_KHR
37810	constant GL_COMPRESSED_RGBA_ASTC_5x5_KHR
37811	constant GL_COMPRESSED_RGBA_ASTC_6x5_KHR
37812	constant GL_COMPRESSED_RGBA_ASTC_6x6_KHR
37813	constant GL_COMPRESSED_RGBA_ASTC_8x5_KHR
37814	constant GL_COMPRESSED_RGBA_ASTC_8x6_KHR
37815	constant GL_COMPRESSED_RGBA_ASTC_8x8_KHR
37816	constant GL_COMPRESSED_RGBA_ASTC_10x5_KHR
37817	constant GL_COMPRESSED_RGBA_ASTC_10x6_KHR
37818	constant GL_COMPRESSED_RGBA_ASTC_10x8_KHR
37819	constant GL_COMPRESSED_RGBA_ASTC_10x10_KHR
37820	constant GL_COMPRESSED_RGBA_ASTC_12x10_KHR
37821	constant GL_COMPRESSED_RGBA_ASTC_12x12_KHR
37840	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR
37841	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR
37842	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR
37843	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR
37844	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR
37845	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR
37846	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR
37847	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR
37848	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR
37849	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR
37850	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x8_KHR
37851	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR
37852	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR
37853	constant GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR
1	constant GL_KHR_texture_compression_astc_ldr
1	constant GL_OES_byte_coordinates
1	constant GL_OES_compressed_paletted_texture
35728	constant GL_PALETTE4_RGB8_OES
35729	constant GL_PALETTE4_RGBA8_OES
35730	constant GL_PALETTE4_R5_G6_B5_OES
35731	constant GL_PALETTE4_RGBA4_OES
35732	constant GL_PALETTE4_RGB5_A1_OES
35733	constant GL_PALETTE8_RGB8_OES
35734	constant GL_PALETTE8_RGBA8_OES
35735	constant GL_PALETTE8_R5_G6_B5_OES
35736	constant GL_PALETTE8_RGBA4_OES
35737	constant GL_PALETTE8_RGB5_A1_OES
1	constant GL_OES_fixed_point
5132	constant GL_FIXED_OES
1	constant GL_OES_query_matrix
1	constant GL_OES_read_format
35738	constant GL_IMPLEMENTATION_COLOR_READ_TYPE_OES
35739	constant GL_IMPLEMENTATION_COLOR_READ_FORMAT_OES
1	constant GL_OES_single_precision
1	constant GL_3DFX_multisample
34482	constant GL_MULTISAMPLE_3DFX
34483	constant GL_SAMPLE_BUFFERS_3DFX
34484	constant GL_SAMPLES_3DFX
536870912	constant GL_MULTISAMPLE_BIT_3DFX
1	constant GL_3DFX_tbuffer
1	constant GL_3DFX_texture_compression_FXT1
34480	constant GL_COMPRESSED_RGB_FXT1_3DFX
34481	constant GL_COMPRESSED_RGBA_FXT1_3DFX
1	constant GL_AMD_blend_minmax_factor
36892	constant GL_FACTOR_MIN_AMD
36893	constant GL_FACTOR_MAX_AMD
1	constant GL_AMD_conservative_depth
1	constant GL_AMD_debug_output
37187	constant GL_MAX_DEBUG_MESSAGE_LENGTH_AMD
37188	constant GL_MAX_DEBUG_LOGGED_MESSAGES_AMD
37189	constant GL_DEBUG_LOGGED_MESSAGES_AMD
37190	constant GL_DEBUG_SEVERITY_HIGH_AMD
37191	constant GL_DEBUG_SEVERITY_MEDIUM_AMD
37192	constant GL_DEBUG_SEVERITY_LOW_AMD
37193	constant GL_DEBUG_CATEGORY_API_ERROR_AMD
37194	constant GL_DEBUG_CATEGORY_WINDOW_SYSTEM_AMD
37195	constant GL_DEBUG_CATEGORY_DEPRECATION_AMD
37196	constant GL_DEBUG_CATEGORY_UNDEFINED_BEHAVIOR_AMD
37197	constant GL_DEBUG_CATEGORY_PERFORMANCE_AMD
37198	constant GL_DEBUG_CATEGORY_SHADER_COMPILER_AMD
37199	constant GL_DEBUG_CATEGORY_APPLICATION_AMD
37200	constant GL_DEBUG_CATEGORY_OTHER_AMD
1	constant GL_AMD_depth_clamp_separate
36894	constant GL_DEPTH_CLAMP_NEAR_AMD
36895	constant GL_DEPTH_CLAMP_FAR_AMD
1	constant GL_AMD_draw_buffers_blend
1	constant GL_AMD_gcn_shader
1	constant GL_AMD_gpu_shader_int64
5134	constant GL_INT64_NV
5135	constant GL_UNSIGNED_INT64_NV
36832	constant GL_INT8_NV
36833	constant GL_INT8_VEC2_NV
36834	constant GL_INT8_VEC3_NV
36835	constant GL_INT8_VEC4_NV
36836	constant GL_INT16_NV
36837	constant GL_INT16_VEC2_NV
36838	constant GL_INT16_VEC3_NV
36839	constant GL_INT16_VEC4_NV
36841	constant GL_INT64_VEC2_NV
36842	constant GL_INT64_VEC3_NV
36843	constant GL_INT64_VEC4_NV
36844	constant GL_UNSIGNED_INT8_NV
36845	constant GL_UNSIGNED_INT8_VEC2_NV
36846	constant GL_UNSIGNED_INT8_VEC3_NV
36847	constant GL_UNSIGNED_INT8_VEC4_NV
36848	constant GL_UNSIGNED_INT16_NV
36849	constant GL_UNSIGNED_INT16_VEC2_NV
36850	constant GL_UNSIGNED_INT16_VEC3_NV
36851	constant GL_UNSIGNED_INT16_VEC4_NV
36853	constant GL_UNSIGNED_INT64_VEC2_NV
36854	constant GL_UNSIGNED_INT64_VEC3_NV
36855	constant GL_UNSIGNED_INT64_VEC4_NV
36856	constant GL_FLOAT16_NV
36857	constant GL_FLOAT16_VEC2_NV
36858	constant GL_FLOAT16_VEC3_NV
36859	constant GL_FLOAT16_VEC4_NV
1	constant GL_AMD_interleaved_elements
37284	constant GL_VERTEX_ELEMENT_SWIZZLE_AMD
37285	constant GL_VERTEX_ID_SWIZZLE_AMD
1	constant GL_AMD_multi_draw_indirect
1	constant GL_AMD_name_gen_delete
37201	constant GL_DATA_BUFFER_AMD
37202	constant GL_PERFORMANCE_MONITOR_AMD
37203	constant GL_QUERY_OBJECT_AMD
37204	constant GL_VERTEX_ARRAY_OBJECT_AMD
37205	constant GL_SAMPLER_OBJECT_AMD
1	constant GL_AMD_occlusion_query_event
34639	constant GL_OCCLUSION_QUERY_EVENT_MASK_AMD
1	constant GL_QUERY_DEPTH_PASS_EVENT_BIT_AMD
2	constant GL_QUERY_DEPTH_FAIL_EVENT_BIT_AMD
4	constant GL_QUERY_STENCIL_FAIL_EVENT_BIT_AMD
8	constant GL_QUERY_DEPTH_BOUNDS_FAIL_EVENT_BIT_AMD
4294967295	constant GL_QUERY_ALL_EVENT_BITS_AMD
1	constant GL_AMD_performance_monitor
35776	constant GL_COUNTER_TYPE_AMD
35777	constant GL_COUNTER_RANGE_AMD
35778	constant GL_UNSIGNED_INT64_AMD
35779	constant GL_PERCENTAGE_AMD
35780	constant GL_PERFMON_RESULT_AVAILABLE_AMD
35781	constant GL_PERFMON_RESULT_SIZE_AMD
35782	constant GL_PERFMON_RESULT_AMD
1	constant GL_AMD_pinned_memory
37216	constant GL_EXTERNAL_VIRTUAL_MEMORY_BUFFER_AMD
1	constant GL_AMD_query_buffer_object
37266	constant GL_QUERY_BUFFER_AMD
37267	constant GL_QUERY_BUFFER_BINDING_AMD
37268	constant GL_QUERY_RESULT_NO_WAIT_AMD
1	constant GL_AMD_sample_positions
34879	constant GL_SUBSAMPLE_DISTANCE_AMD
1	constant GL_AMD_seamless_cubemap_per_texture
1	constant GL_AMD_shader_atomic_counter_ops
1	constant GL_AMD_shader_stencil_export
1	constant GL_AMD_shader_trinary_minmax
1	constant GL_AMD_sparse_texture
37269	constant GL_VIRTUAL_PAGE_SIZE_X_AMD
37270	constant GL_VIRTUAL_PAGE_SIZE_Y_AMD
37271	constant GL_VIRTUAL_PAGE_SIZE_Z_AMD
37272	constant GL_MAX_SPARSE_TEXTURE_SIZE_AMD
37273	constant GL_MAX_SPARSE_3D_TEXTURE_SIZE_AMD
37274	constant GL_MAX_SPARSE_ARRAY_TEXTURE_LAYERS
37275	constant GL_MIN_SPARSE_LEVEL_AMD
37276	constant GL_MIN_LOD_WARNING_AMD
1	constant GL_TEXTURE_STORAGE_SPARSE_BIT_AMD
1	constant GL_AMD_stencil_operation_extended
34634	constant GL_SET_AMD
34635	constant GL_REPLACE_VALUE_AMD
34636	constant GL_STENCIL_OP_VALUE_AMD
34637	constant GL_STENCIL_BACK_OP_VALUE_AMD
1	constant GL_AMD_texture_texture4
1	constant GL_AMD_transform_feedback3_lines_triangles
1	constant GL_AMD_transform_feedback4
37280	constant GL_STREAM_RASTERIZATION_AMD
1	constant GL_AMD_vertex_shader_layer
1	constant GL_AMD_vertex_shader_tessellator
36865	constant GL_SAMPLER_BUFFER_AMD
36866	constant GL_INT_SAMPLER_BUFFER_AMD
36867	constant GL_UNSIGNED_INT_SAMPLER_BUFFER_AMD
36868	constant GL_TESSELLATION_MODE_AMD
36869	constant GL_TESSELLATION_FACTOR_AMD
36870	constant GL_DISCRETE_AMD
36871	constant GL_CONTINUOUS_AMD
1	constant GL_AMD_vertex_shader_viewport_index
1	constant GL_APPLE_aux_depth_stencil
35348	constant GL_AUX_DEPTH_STENCIL_APPLE
1	constant GL_APPLE_client_storage
34226	constant GL_UNPACK_CLIENT_STORAGE_APPLE
1	constant GL_APPLE_element_array
35340	constant GL_ELEMENT_ARRAY_APPLE
35341	constant GL_ELEMENT_ARRAY_TYPE_APPLE
35342	constant GL_ELEMENT_ARRAY_POINTER_APPLE
1	constant GL_APPLE_fence
35338	constant GL_DRAW_PIXELS_APPLE
35339	constant GL_FENCE_APPLE
1	constant GL_APPLE_float_pixels
5131	constant GL_HALF_APPLE
34836	constant GL_RGBA_FLOAT32_APPLE
34837	constant GL_RGB_FLOAT32_APPLE
34838	constant GL_ALPHA_FLOAT32_APPLE
34839	constant GL_INTENSITY_FLOAT32_APPLE
34840	constant GL_LUMINANCE_FLOAT32_APPLE
34841	constant GL_LUMINANCE_ALPHA_FLOAT32_APPLE
34842	constant GL_RGBA_FLOAT16_APPLE
34843	constant GL_RGB_FLOAT16_APPLE
34844	constant GL_ALPHA_FLOAT16_APPLE
34845	constant GL_INTENSITY_FLOAT16_APPLE
34846	constant GL_LUMINANCE_FLOAT16_APPLE
34847	constant GL_LUMINANCE_ALPHA_FLOAT16_APPLE
35343	constant GL_COLOR_FLOAT_APPLE
1	constant GL_APPLE_flush_buffer_range
35346	constant GL_BUFFER_SERIALIZED_MODIFY_APPLE
35347	constant GL_BUFFER_FLUSHING_UNMAP_APPLE
1	constant GL_APPLE_object_purgeable
34227	constant GL_BUFFER_OBJECT_APPLE
35353	constant GL_RELEASED_APPLE
35354	constant GL_VOLATILE_APPLE
35355	constant GL_RETAINED_APPLE
35356	constant GL_UNDEFINED_APPLE
35357	constant GL_PURGEABLE_APPLE
1	constant GL_APPLE_rgb_422
35359	constant GL_RGB_422_APPLE
34234	constant GL_UNSIGNED_SHORT_8_8_APPLE
34235	constant GL_UNSIGNED_SHORT_8_8_REV_APPLE
35409	constant GL_RGB_RAW_422_APPLE
1	constant GL_APPLE_row_bytes
35349	constant GL_PACK_ROW_BYTES_APPLE
35350	constant GL_UNPACK_ROW_BYTES_APPLE
1	constant GL_APPLE_specular_vector
34224	constant GL_LIGHT_MODEL_SPECULAR_VECTOR_APPLE
1	constant GL_APPLE_texture_range
34231	constant GL_TEXTURE_RANGE_LENGTH_APPLE
34232	constant GL_TEXTURE_RANGE_POINTER_APPLE
34236	constant GL_TEXTURE_STORAGE_HINT_APPLE
34237	constant GL_STORAGE_PRIVATE_APPLE
34238	constant GL_STORAGE_CACHED_APPLE
34239	constant GL_STORAGE_SHARED_APPLE
1	constant GL_APPLE_transform_hint
34225	constant GL_TRANSFORM_HINT_APPLE
1	constant GL_APPLE_vertex_array_object
34229	constant GL_VERTEX_ARRAY_BINDING_APPLE
1	constant GL_APPLE_vertex_array_range
34077	constant GL_VERTEX_ARRAY_RANGE_APPLE
34078	constant GL_VERTEX_ARRAY_RANGE_LENGTH_APPLE
34079	constant GL_VERTEX_ARRAY_STORAGE_HINT_APPLE
34081	constant GL_VERTEX_ARRAY_RANGE_POINTER_APPLE
34228	constant GL_STORAGE_CLIENT_APPLE
1	constant GL_APPLE_vertex_program_evaluators
35328	constant GL_VERTEX_ATTRIB_MAP1_APPLE
35329	constant GL_VERTEX_ATTRIB_MAP2_APPLE
35330	constant GL_VERTEX_ATTRIB_MAP1_SIZE_APPLE
35331	constant GL_VERTEX_ATTRIB_MAP1_COEFF_APPLE
35332	constant GL_VERTEX_ATTRIB_MAP1_ORDER_APPLE
35333	constant GL_VERTEX_ATTRIB_MAP1_DOMAIN_APPLE
35334	constant GL_VERTEX_ATTRIB_MAP2_SIZE_APPLE
35335	constant GL_VERTEX_ATTRIB_MAP2_COEFF_APPLE
35336	constant GL_VERTEX_ATTRIB_MAP2_ORDER_APPLE
35337	constant GL_VERTEX_ATTRIB_MAP2_DOMAIN_APPLE
1	constant GL_APPLE_ycbcr_422
34233	constant GL_YCBCR_422_APPLE
1	constant GL_ATI_draw_buffers
34852	constant GL_MAX_DRAW_BUFFERS_ATI
34853	constant GL_DRAW_BUFFER0_ATI
34854	constant GL_DRAW_BUFFER1_ATI
34855	constant GL_DRAW_BUFFER2_ATI
34856	constant GL_DRAW_BUFFER3_ATI
34857	constant GL_DRAW_BUFFER4_ATI
34858	constant GL_DRAW_BUFFER5_ATI
34859	constant GL_DRAW_BUFFER6_ATI
34860	constant GL_DRAW_BUFFER7_ATI
34861	constant GL_DRAW_BUFFER8_ATI
34862	constant GL_DRAW_BUFFER9_ATI
34863	constant GL_DRAW_BUFFER10_ATI
34864	constant GL_DRAW_BUFFER11_ATI
34865	constant GL_DRAW_BUFFER12_ATI
34866	constant GL_DRAW_BUFFER13_ATI
34867	constant GL_DRAW_BUFFER14_ATI
34868	constant GL_DRAW_BUFFER15_ATI
1	constant GL_ATI_element_array
34664	constant GL_ELEMENT_ARRAY_ATI
34665	constant GL_ELEMENT_ARRAY_TYPE_ATI
34666	constant GL_ELEMENT_ARRAY_POINTER_ATI
1	constant GL_ATI_envmap_bumpmap
34677	constant GL_BUMP_ROT_MATRIX_ATI
34678	constant GL_BUMP_ROT_MATRIX_SIZE_ATI
34679	constant GL_BUMP_NUM_TEX_UNITS_ATI
34680	constant GL_BUMP_TEX_UNITS_ATI
34681	constant GL_DUDV_ATI
34682	constant GL_DU8DV8_ATI
34683	constant GL_BUMP_ENVMAP_ATI
34684	constant GL_BUMP_TARGET_ATI
1	constant GL_ATI_fragment_shader
35104	constant GL_FRAGMENT_SHADER_ATI
35105	constant GL_REG_0_ATI
35106	constant GL_REG_1_ATI
35107	constant GL_REG_2_ATI
35108	constant GL_REG_3_ATI
35109	constant GL_REG_4_ATI
35110	constant GL_REG_5_ATI
35111	constant GL_REG_6_ATI
35112	constant GL_REG_7_ATI
35113	constant GL_REG_8_ATI
35114	constant GL_REG_9_ATI
35115	constant GL_REG_10_ATI
35116	constant GL_REG_11_ATI
35117	constant GL_REG_12_ATI
35118	constant GL_REG_13_ATI
35119	constant GL_REG_14_ATI
35120	constant GL_REG_15_ATI
35121	constant GL_REG_16_ATI
35122	constant GL_REG_17_ATI
35123	constant GL_REG_18_ATI
35124	constant GL_REG_19_ATI
35125	constant GL_REG_20_ATI
35126	constant GL_REG_21_ATI
35127	constant GL_REG_22_ATI
35128	constant GL_REG_23_ATI
35129	constant GL_REG_24_ATI
35130	constant GL_REG_25_ATI
35131	constant GL_REG_26_ATI
35132	constant GL_REG_27_ATI
35133	constant GL_REG_28_ATI
35134	constant GL_REG_29_ATI
35135	constant GL_REG_30_ATI
35136	constant GL_REG_31_ATI
35137	constant GL_CON_0_ATI
35138	constant GL_CON_1_ATI
35139	constant GL_CON_2_ATI
35140	constant GL_CON_3_ATI
35141	constant GL_CON_4_ATI
35142	constant GL_CON_5_ATI
35143	constant GL_CON_6_ATI
35144	constant GL_CON_7_ATI
35145	constant GL_CON_8_ATI
35146	constant GL_CON_9_ATI
35147	constant GL_CON_10_ATI
35148	constant GL_CON_11_ATI
35149	constant GL_CON_12_ATI
35150	constant GL_CON_13_ATI
35151	constant GL_CON_14_ATI
35152	constant GL_CON_15_ATI
35153	constant GL_CON_16_ATI
35154	constant GL_CON_17_ATI
35155	constant GL_CON_18_ATI
35156	constant GL_CON_19_ATI
35157	constant GL_CON_20_ATI
35158	constant GL_CON_21_ATI
35159	constant GL_CON_22_ATI
35160	constant GL_CON_23_ATI
35161	constant GL_CON_24_ATI
35162	constant GL_CON_25_ATI
35163	constant GL_CON_26_ATI
35164	constant GL_CON_27_ATI
35165	constant GL_CON_28_ATI
35166	constant GL_CON_29_ATI
35167	constant GL_CON_30_ATI
35168	constant GL_CON_31_ATI
35169	constant GL_MOV_ATI
35171	constant GL_ADD_ATI
35172	constant GL_MUL_ATI
35173	constant GL_SUB_ATI
35174	constant GL_DOT3_ATI
35175	constant GL_DOT4_ATI
35176	constant GL_MAD_ATI
35177	constant GL_LERP_ATI
35178	constant GL_CND_ATI
35179	constant GL_CND0_ATI
35180	constant GL_DOT2_ADD_ATI
35181	constant GL_SECONDARY_INTERPOLATOR_ATI
35182	constant GL_NUM_FRAGMENT_REGISTERS_ATI
35183	constant GL_NUM_FRAGMENT_CONSTANTS_ATI
35184	constant GL_NUM_PASSES_ATI
35185	constant GL_NUM_INSTRUCTIONS_PER_PASS_ATI
35186	constant GL_NUM_INSTRUCTIONS_TOTAL_ATI
35187	constant GL_NUM_INPUT_INTERPOLATOR_COMPONENTS_ATI
35188	constant GL_NUM_LOOPBACK_COMPONENTS_ATI
35189	constant GL_COLOR_ALPHA_PAIRING_ATI
35190	constant GL_SWIZZLE_STR_ATI
35191	constant GL_SWIZZLE_STQ_ATI
35192	constant GL_SWIZZLE_STR_DR_ATI
35193	constant GL_SWIZZLE_STQ_DQ_ATI
35194	constant GL_SWIZZLE_STRQ_ATI
35195	constant GL_SWIZZLE_STRQ_DQ_ATI
1	constant GL_RED_BIT_ATI
2	constant GL_GREEN_BIT_ATI
4	constant GL_BLUE_BIT_ATI
1	constant GL_2X_BIT_ATI
2	constant GL_4X_BIT_ATI
4	constant GL_8X_BIT_ATI
8	constant GL_HALF_BIT_ATI
16	constant GL_QUARTER_BIT_ATI
32	constant GL_EIGHTH_BIT_ATI
64	constant GL_SATURATE_BIT_ATI
2	constant GL_COMP_BIT_ATI
4	constant GL_NEGATE_BIT_ATI
8	constant GL_BIAS_BIT_ATI
1	constant GL_ATI_map_object_buffer
1	constant GL_ATI_meminfo
34811	constant GL_VBO_FREE_MEMORY_ATI
34812	constant GL_TEXTURE_FREE_MEMORY_ATI
34813	constant GL_RENDERBUFFER_FREE_MEMORY_ATI
1	constant GL_ATI_pixel_format_float
34848	constant GL_RGBA_FLOAT_MODE_ATI
34869	constant GL_COLOR_CLEAR_UNCLAMPED_VALUE_ATI
1	constant GL_ATI_pn_triangles
34800	constant GL_PN_TRIANGLES_ATI
34801	constant GL_MAX_PN_TRIANGLES_TESSELATION_LEVEL_ATI
34802	constant GL_PN_TRIANGLES_POINT_MODE_ATI
34803	constant GL_PN_TRIANGLES_NORMAL_MODE_ATI
34804	constant GL_PN_TRIANGLES_TESSELATION_LEVEL_ATI
34805	constant GL_PN_TRIANGLES_POINT_MODE_LINEAR_ATI
34806	constant GL_PN_TRIANGLES_POINT_MODE_CUBIC_ATI
34807	constant GL_PN_TRIANGLES_NORMAL_MODE_LINEAR_ATI
34808	constant GL_PN_TRIANGLES_NORMAL_MODE_QUADRATIC_ATI
1	constant GL_ATI_separate_stencil
34816	constant GL_STENCIL_BACK_FUNC_ATI
34817	constant GL_STENCIL_BACK_FAIL_ATI
34818	constant GL_STENCIL_BACK_PASS_DEPTH_FAIL_ATI
34819	constant GL_STENCIL_BACK_PASS_DEPTH_PASS_ATI
1	constant GL_ATI_text_fragment_shader
33280	constant GL_TEXT_FRAGMENT_SHADER_ATI
1	constant GL_ATI_texture_env_combine3
34628	constant GL_MODULATE_ADD_ATI
34629	constant GL_MODULATE_SIGNED_ADD_ATI
34630	constant GL_MODULATE_SUBTRACT_ATI
1	constant GL_ATI_texture_float
34836	constant GL_RGBA_FLOAT32_ATI
34837	constant GL_RGB_FLOAT32_ATI
34838	constant GL_ALPHA_FLOAT32_ATI
34839	constant GL_INTENSITY_FLOAT32_ATI
34840	constant GL_LUMINANCE_FLOAT32_ATI
34841	constant GL_LUMINANCE_ALPHA_FLOAT32_ATI
34842	constant GL_RGBA_FLOAT16_ATI
34843	constant GL_RGB_FLOAT16_ATI
34844	constant GL_ALPHA_FLOAT16_ATI
34845	constant GL_INTENSITY_FLOAT16_ATI
34846	constant GL_LUMINANCE_FLOAT16_ATI
34847	constant GL_LUMINANCE_ALPHA_FLOAT16_ATI
1	constant GL_ATI_texture_mirror_once
34626	constant GL_MIRROR_CLAMP_ATI
34627	constant GL_MIRROR_CLAMP_TO_EDGE_ATI
1	constant GL_ATI_vertex_array_object
34656	constant GL_STATIC_ATI
34657	constant GL_DYNAMIC_ATI
34658	constant GL_PRESERVE_ATI
34659	constant GL_DISCARD_ATI
34660	constant GL_OBJECT_BUFFER_SIZE_ATI
34661	constant GL_OBJECT_BUFFER_USAGE_ATI
34662	constant GL_ARRAY_OBJECT_BUFFER_ATI
34663	constant GL_ARRAY_OBJECT_OFFSET_ATI
1	constant GL_ATI_vertex_attrib_array_object
1	constant GL_ATI_vertex_streams
34667	constant GL_MAX_VERTEX_STREAMS_ATI
34668	constant GL_VERTEX_STREAM0_ATI
34669	constant GL_VERTEX_STREAM1_ATI
34670	constant GL_VERTEX_STREAM2_ATI
34671	constant GL_VERTEX_STREAM3_ATI
34672	constant GL_VERTEX_STREAM4_ATI
34673	constant GL_VERTEX_STREAM5_ATI
34674	constant GL_VERTEX_STREAM6_ATI
34675	constant GL_VERTEX_STREAM7_ATI
34676	constant GL_VERTEX_SOURCE_ATI
1	constant GL_EXT_422_pixels
32972	constant GL_422_EXT
32973	constant GL_422_REV_EXT
32974	constant GL_422_AVERAGE_EXT
32975	constant GL_422_REV_AVERAGE_EXT
1	constant GL_EXT_abgr
32768	constant GL_ABGR_EXT
1	constant GL_EXT_bgra
32992	constant GL_BGR_EXT
32993	constant GL_BGRA_EXT
1	constant GL_EXT_bindable_uniform
36322	constant GL_MAX_VERTEX_BINDABLE_UNIFORMS_EXT
36323	constant GL_MAX_FRAGMENT_BINDABLE_UNIFORMS_EXT
36324	constant GL_MAX_GEOMETRY_BINDABLE_UNIFORMS_EXT
36333	constant GL_MAX_BINDABLE_UNIFORM_SIZE_EXT
36334	constant GL_UNIFORM_BUFFER_EXT
36335	constant GL_UNIFORM_BUFFER_BINDING_EXT
1	constant GL_EXT_blend_color
32769	constant GL_CONSTANT_COLOR_EXT
32770	constant GL_ONE_MINUS_CONSTANT_COLOR_EXT
32771	constant GL_CONSTANT_ALPHA_EXT
32772	constant GL_ONE_MINUS_CONSTANT_ALPHA_EXT
32773	constant GL_BLEND_COLOR_EXT
1	constant GL_EXT_blend_equation_separate
32777	constant GL_BLEND_EQUATION_RGB_EXT
34877	constant GL_BLEND_EQUATION_ALPHA_EXT
1	constant GL_EXT_blend_func_separate
32968	constant GL_BLEND_DST_RGB_EXT
32969	constant GL_BLEND_SRC_RGB_EXT
32970	constant GL_BLEND_DST_ALPHA_EXT
32971	constant GL_BLEND_SRC_ALPHA_EXT
1	constant GL_EXT_blend_logic_op
1	constant GL_EXT_blend_minmax
32775	constant GL_MIN_EXT
32776	constant GL_MAX_EXT
32774	constant GL_FUNC_ADD_EXT
32777	constant GL_BLEND_EQUATION_EXT
1	constant GL_EXT_blend_subtract
32778	constant GL_FUNC_SUBTRACT_EXT
32779	constant GL_FUNC_REVERSE_SUBTRACT_EXT
1	constant GL_EXT_clip_volume_hint
33008	constant GL_CLIP_VOLUME_CLIPPING_HINT_EXT
1	constant GL_EXT_cmyka
32780	constant GL_CMYK_EXT
32781	constant GL_CMYKA_EXT
32782	constant GL_PACK_CMYK_HINT_EXT
32783	constant GL_UNPACK_CMYK_HINT_EXT
1	constant GL_EXT_color_subtable
1	constant GL_EXT_compiled_vertex_array
33192	constant GL_ARRAY_ELEMENT_LOCK_FIRST_EXT
33193	constant GL_ARRAY_ELEMENT_LOCK_COUNT_EXT
1	constant GL_EXT_convolution
32784	constant GL_CONVOLUTION_1D_EXT
32785	constant GL_CONVOLUTION_2D_EXT
32786	constant GL_SEPARABLE_2D_EXT
32787	constant GL_CONVOLUTION_BORDER_MODE_EXT
32788	constant GL_CONVOLUTION_FILTER_SCALE_EXT
32789	constant GL_CONVOLUTION_FILTER_BIAS_EXT
32790	constant GL_REDUCE_EXT
32791	constant GL_CONVOLUTION_FORMAT_EXT
32792	constant GL_CONVOLUTION_WIDTH_EXT
32793	constant GL_CONVOLUTION_HEIGHT_EXT
32794	constant GL_MAX_CONVOLUTION_WIDTH_EXT
32795	constant GL_MAX_CONVOLUTION_HEIGHT_EXT
32796	constant GL_POST_CONVOLUTION_RED_SCALE_EXT
32797	constant GL_POST_CONVOLUTION_GREEN_SCALE_EXT
32798	constant GL_POST_CONVOLUTION_BLUE_SCALE_EXT
32799	constant GL_POST_CONVOLUTION_ALPHA_SCALE_EXT
32800	constant GL_POST_CONVOLUTION_RED_BIAS_EXT
32801	constant GL_POST_CONVOLUTION_GREEN_BIAS_EXT
32802	constant GL_POST_CONVOLUTION_BLUE_BIAS_EXT
32803	constant GL_POST_CONVOLUTION_ALPHA_BIAS_EXT
1	constant GL_EXT_coordinate_frame
33849	constant GL_TANGENT_ARRAY_EXT
33850	constant GL_BINORMAL_ARRAY_EXT
33851	constant GL_CURRENT_TANGENT_EXT
33852	constant GL_CURRENT_BINORMAL_EXT
33854	constant GL_TANGENT_ARRAY_TYPE_EXT
33855	constant GL_TANGENT_ARRAY_STRIDE_EXT
33856	constant GL_BINORMAL_ARRAY_TYPE_EXT
33857	constant GL_BINORMAL_ARRAY_STRIDE_EXT
33858	constant GL_TANGENT_ARRAY_POINTER_EXT
33859	constant GL_BINORMAL_ARRAY_POINTER_EXT
33860	constant GL_MAP1_TANGENT_EXT
33861	constant GL_MAP2_TANGENT_EXT
33862	constant GL_MAP1_BINORMAL_EXT
33863	constant GL_MAP2_BINORMAL_EXT
1	constant GL_EXT_copy_texture
1	constant GL_EXT_cull_vertex
33194	constant GL_CULL_VERTEX_EXT
33195	constant GL_CULL_VERTEX_EYE_POSITION_EXT
33196	constant GL_CULL_VERTEX_OBJECT_POSITION_EXT
1	constant GL_EXT_debug_label
35407	constant GL_PROGRAM_PIPELINE_OBJECT_EXT
35648	constant GL_PROGRAM_OBJECT_EXT
35656	constant GL_SHADER_OBJECT_EXT
37201	constant GL_BUFFER_OBJECT_EXT
37203	constant GL_QUERY_OBJECT_EXT
37204	constant GL_VERTEX_ARRAY_OBJECT_EXT
1	constant GL_EXT_debug_marker
1	constant GL_EXT_depth_bounds_test
34960	constant GL_DEPTH_BOUNDS_TEST_EXT
34961	constant GL_DEPTH_BOUNDS_EXT
1	constant GL_EXT_direct_state_access
36397	constant GL_PROGRAM_MATRIX_EXT
36398	constant GL_TRANSPOSE_PROGRAM_MATRIX_EXT
36399	constant GL_PROGRAM_MATRIX_STACK_DEPTH_EXT
1	constant GL_EXT_draw_buffers2
1	constant GL_EXT_draw_instanced
1	constant GL_EXT_draw_range_elements
33000	constant GL_MAX_ELEMENTS_VERTICES_EXT
33001	constant GL_MAX_ELEMENTS_INDICES_EXT
1	constant GL_EXT_fog_coord
33872	constant GL_FOG_COORDINATE_SOURCE_EXT
33873	constant GL_FOG_COORDINATE_EXT
33874	constant GL_FRAGMENT_DEPTH_EXT
33875	constant GL_CURRENT_FOG_COORDINATE_EXT
33876	constant GL_FOG_COORDINATE_ARRAY_TYPE_EXT
33877	constant GL_FOG_COORDINATE_ARRAY_STRIDE_EXT
33878	constant GL_FOG_COORDINATE_ARRAY_POINTER_EXT
33879	constant GL_FOG_COORDINATE_ARRAY_EXT
1	constant GL_EXT_framebuffer_blit
36008	constant GL_READ_FRAMEBUFFER_EXT
36009	constant GL_DRAW_FRAMEBUFFER_EXT
36006	constant GL_DRAW_FRAMEBUFFER_BINDING_EXT
36010	constant GL_READ_FRAMEBUFFER_BINDING_EXT
1	constant GL_EXT_framebuffer_multisample
36011	constant GL_RENDERBUFFER_SAMPLES_EXT
36182	constant GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE_EXT
36183	constant GL_MAX_SAMPLES_EXT
1	constant GL_EXT_framebuffer_multisample_blit_scaled
37050	constant GL_SCALED_RESOLVE_FASTEST_EXT
37051	constant GL_SCALED_RESOLVE_NICEST_EXT
1	constant GL_EXT_framebuffer_object
1286	constant GL_INVALID_FRAMEBUFFER_OPERATION_EXT
34024	constant GL_MAX_RENDERBUFFER_SIZE_EXT
36006	constant GL_FRAMEBUFFER_BINDING_EXT
36007	constant GL_RENDERBUFFER_BINDING_EXT
36048	constant GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE_EXT
36049	constant GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME_EXT
36050	constant GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL_EXT
36051	constant GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE_EXT
36052	constant GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET_EXT
36053	constant GL_FRAMEBUFFER_COMPLETE_EXT
36054	constant GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT_EXT
36055	constant GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT_EXT
36057	constant GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS_EXT
36058	constant GL_FRAMEBUFFER_INCOMPLETE_FORMATS_EXT
36059	constant GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER_EXT
36060	constant GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER_EXT
36061	constant GL_FRAMEBUFFER_UNSUPPORTED_EXT
36063	constant GL_MAX_COLOR_ATTACHMENTS_EXT
36064	constant GL_COLOR_ATTACHMENT0_EXT
36065	constant GL_COLOR_ATTACHMENT1_EXT
36066	constant GL_COLOR_ATTACHMENT2_EXT
36067	constant GL_COLOR_ATTACHMENT3_EXT
36068	constant GL_COLOR_ATTACHMENT4_EXT
36069	constant GL_COLOR_ATTACHMENT5_EXT
36070	constant GL_COLOR_ATTACHMENT6_EXT
36071	constant GL_COLOR_ATTACHMENT7_EXT
36072	constant GL_COLOR_ATTACHMENT8_EXT
36073	constant GL_COLOR_ATTACHMENT9_EXT
36074	constant GL_COLOR_ATTACHMENT10_EXT
36075	constant GL_COLOR_ATTACHMENT11_EXT
36076	constant GL_COLOR_ATTACHMENT12_EXT
36077	constant GL_COLOR_ATTACHMENT13_EXT
36078	constant GL_COLOR_ATTACHMENT14_EXT
36079	constant GL_COLOR_ATTACHMENT15_EXT
36096	constant GL_DEPTH_ATTACHMENT_EXT
36128	constant GL_STENCIL_ATTACHMENT_EXT
36160	constant GL_FRAMEBUFFER_EXT
36161	constant GL_RENDERBUFFER_EXT
36162	constant GL_RENDERBUFFER_WIDTH_EXT
36163	constant GL_RENDERBUFFER_HEIGHT_EXT
36164	constant GL_RENDERBUFFER_INTERNAL_FORMAT_EXT
36166	constant GL_STENCIL_INDEX1_EXT
36167	constant GL_STENCIL_INDEX4_EXT
36168	constant GL_STENCIL_INDEX8_EXT
36169	constant GL_STENCIL_INDEX16_EXT
36176	constant GL_RENDERBUFFER_RED_SIZE_EXT
36177	constant GL_RENDERBUFFER_GREEN_SIZE_EXT
36178	constant GL_RENDERBUFFER_BLUE_SIZE_EXT
36179	constant GL_RENDERBUFFER_ALPHA_SIZE_EXT
36180	constant GL_RENDERBUFFER_DEPTH_SIZE_EXT
36181	constant GL_RENDERBUFFER_STENCIL_SIZE_EXT
1	constant GL_EXT_framebuffer_sRGB
36281	constant GL_FRAMEBUFFER_SRGB_EXT
36282	constant GL_FRAMEBUFFER_SRGB_CAPABLE_EXT
1	constant GL_EXT_geometry_shader4
36313	constant GL_GEOMETRY_SHADER_EXT
36314	constant GL_GEOMETRY_VERTICES_OUT_EXT
36315	constant GL_GEOMETRY_INPUT_TYPE_EXT
36316	constant GL_GEOMETRY_OUTPUT_TYPE_EXT
35881	constant GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS_EXT
36317	constant GL_MAX_GEOMETRY_VARYING_COMPONENTS_EXT
36318	constant GL_MAX_VERTEX_VARYING_COMPONENTS_EXT
35659	constant GL_MAX_VARYING_COMPONENTS_EXT
36319	constant GL_MAX_GEOMETRY_UNIFORM_COMPONENTS_EXT
36320	constant GL_MAX_GEOMETRY_OUTPUT_VERTICES_EXT
36321	constant GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS_EXT
10	constant GL_LINES_ADJACENCY_EXT
11	constant GL_LINE_STRIP_ADJACENCY_EXT
12	constant GL_TRIANGLES_ADJACENCY_EXT
13	constant GL_TRIANGLE_STRIP_ADJACENCY_EXT
36264	constant GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS_EXT
36265	constant GL_FRAMEBUFFER_INCOMPLETE_LAYER_COUNT_EXT
36263	constant GL_FRAMEBUFFER_ATTACHMENT_LAYERED_EXT
36052	constant GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER_EXT
34370	constant GL_PROGRAM_POINT_SIZE_EXT
1	constant GL_EXT_gpu_program_parameters
1	constant GL_EXT_gpu_shader4
35069	constant GL_VERTEX_ATTRIB_ARRAY_INTEGER_EXT
36288	constant GL_SAMPLER_1D_ARRAY_EXT
36289	constant GL_SAMPLER_2D_ARRAY_EXT
36290	constant GL_SAMPLER_BUFFER_EXT
36291	constant GL_SAMPLER_1D_ARRAY_SHADOW_EXT
36292	constant GL_SAMPLER_2D_ARRAY_SHADOW_EXT
36293	constant GL_SAMPLER_CUBE_SHADOW_EXT
36294	constant GL_UNSIGNED_INT_VEC2_EXT
36295	constant GL_UNSIGNED_INT_VEC3_EXT
36296	constant GL_UNSIGNED_INT_VEC4_EXT
36297	constant GL_INT_SAMPLER_1D_EXT
36298	constant GL_INT_SAMPLER_2D_EXT
36299	constant GL_INT_SAMPLER_3D_EXT
36300	constant GL_INT_SAMPLER_CUBE_EXT
36301	constant GL_INT_SAMPLER_2D_RECT_EXT
36302	constant GL_INT_SAMPLER_1D_ARRAY_EXT
36303	constant GL_INT_SAMPLER_2D_ARRAY_EXT
36304	constant GL_INT_SAMPLER_BUFFER_EXT
36305	constant GL_UNSIGNED_INT_SAMPLER_1D_EXT
36306	constant GL_UNSIGNED_INT_SAMPLER_2D_EXT
36307	constant GL_UNSIGNED_INT_SAMPLER_3D_EXT
36308	constant GL_UNSIGNED_INT_SAMPLER_CUBE_EXT
36309	constant GL_UNSIGNED_INT_SAMPLER_2D_RECT_EXT
36310	constant GL_UNSIGNED_INT_SAMPLER_1D_ARRAY_EXT
36311	constant GL_UNSIGNED_INT_SAMPLER_2D_ARRAY_EXT
36312	constant GL_UNSIGNED_INT_SAMPLER_BUFFER_EXT
35076	constant GL_MIN_PROGRAM_TEXEL_OFFSET_EXT
35077	constant GL_MAX_PROGRAM_TEXEL_OFFSET_EXT
1	constant GL_EXT_histogram
32804	constant GL_HISTOGRAM_EXT
32805	constant GL_PROXY_HISTOGRAM_EXT
32806	constant GL_HISTOGRAM_WIDTH_EXT
32807	constant GL_HISTOGRAM_FORMAT_EXT
32808	constant GL_HISTOGRAM_RED_SIZE_EXT
32809	constant GL_HISTOGRAM_GREEN_SIZE_EXT
32810	constant GL_HISTOGRAM_BLUE_SIZE_EXT
32811	constant GL_HISTOGRAM_ALPHA_SIZE_EXT
32812	constant GL_HISTOGRAM_LUMINANCE_SIZE_EXT
32813	constant GL_HISTOGRAM_SINK_EXT
32814	constant GL_MINMAX_EXT
32815	constant GL_MINMAX_FORMAT_EXT
32816	constant GL_MINMAX_SINK_EXT
32817	constant GL_TABLE_TOO_LARGE_EXT
1	constant GL_EXT_index_array_formats
33197	constant GL_IUI_V2F_EXT
33198	constant GL_IUI_V3F_EXT
33199	constant GL_IUI_N3F_V2F_EXT
33200	constant GL_IUI_N3F_V3F_EXT
33201	constant GL_T2F_IUI_V2F_EXT
33202	constant GL_T2F_IUI_V3F_EXT
33203	constant GL_T2F_IUI_N3F_V2F_EXT
33204	constant GL_T2F_IUI_N3F_V3F_EXT
1	constant GL_EXT_index_func
33205	constant GL_INDEX_TEST_EXT
33206	constant GL_INDEX_TEST_FUNC_EXT
33207	constant GL_INDEX_TEST_REF_EXT
1	constant GL_EXT_index_material
33208	constant GL_INDEX_MATERIAL_EXT
33209	constant GL_INDEX_MATERIAL_PARAMETER_EXT
33210	constant GL_INDEX_MATERIAL_FACE_EXT
1	constant GL_EXT_index_texture
1	constant GL_EXT_light_texture
33609	constant GL_FRAGMENT_MATERIAL_EXT
33610	constant GL_FRAGMENT_NORMAL_EXT
33612	constant GL_FRAGMENT_COLOR_EXT
33613	constant GL_ATTENUATION_EXT
33614	constant GL_SHADOW_ATTENUATION_EXT
33615	constant GL_TEXTURE_APPLICATION_MODE_EXT
33616	constant GL_TEXTURE_LIGHT_EXT
33617	constant GL_TEXTURE_MATERIAL_FACE_EXT
33618	constant GL_TEXTURE_MATERIAL_PARAMETER_EXT
1	constant GL_EXT_misc_attribute
1	constant GL_EXT_multi_draw_arrays
1	constant GL_EXT_multisample
32925	constant GL_MULTISAMPLE_EXT
32926	constant GL_SAMPLE_ALPHA_TO_MASK_EXT
32927	constant GL_SAMPLE_ALPHA_TO_ONE_EXT
32928	constant GL_SAMPLE_MASK_EXT
32929	constant GL_1PASS_EXT
32930	constant GL_2PASS_0_EXT
32931	constant GL_2PASS_1_EXT
32932	constant GL_4PASS_0_EXT
32933	constant GL_4PASS_1_EXT
32934	constant GL_4PASS_2_EXT
32935	constant GL_4PASS_3_EXT
32936	constant GL_SAMPLE_BUFFERS_EXT
32937	constant GL_SAMPLES_EXT
32938	constant GL_SAMPLE_MASK_VALUE_EXT
32939	constant GL_SAMPLE_MASK_INVERT_EXT
32940	constant GL_SAMPLE_PATTERN_EXT
536870912	constant GL_MULTISAMPLE_BIT_EXT
1	constant GL_EXT_packed_depth_stencil
34041	constant GL_DEPTH_STENCIL_EXT
34042	constant GL_UNSIGNED_INT_24_8_EXT
35056	constant GL_DEPTH24_STENCIL8_EXT
35057	constant GL_TEXTURE_STENCIL_SIZE_EXT
1	constant GL_EXT_packed_float
35898	constant GL_R11F_G11F_B10F_EXT
35899	constant GL_UNSIGNED_INT_10F_11F_11F_REV_EXT
35900	constant GL_RGBA_SIGNED_COMPONENTS_EXT
1	constant GL_EXT_packed_pixels
32818	constant GL_UNSIGNED_BYTE_3_3_2_EXT
32819	constant GL_UNSIGNED_SHORT_4_4_4_4_EXT
32820	constant GL_UNSIGNED_SHORT_5_5_5_1_EXT
32821	constant GL_UNSIGNED_INT_8_8_8_8_EXT
32822	constant GL_UNSIGNED_INT_10_10_10_2_EXT
1	constant GL_EXT_paletted_texture
32994	constant GL_COLOR_INDEX1_EXT
32995	constant GL_COLOR_INDEX2_EXT
32996	constant GL_COLOR_INDEX4_EXT
32997	constant GL_COLOR_INDEX8_EXT
32998	constant GL_COLOR_INDEX12_EXT
32999	constant GL_COLOR_INDEX16_EXT
33005	constant GL_TEXTURE_INDEX_SIZE_EXT
1	constant GL_EXT_pixel_buffer_object
35051	constant GL_PIXEL_PACK_BUFFER_EXT
35052	constant GL_PIXEL_UNPACK_BUFFER_EXT
35053	constant GL_PIXEL_PACK_BUFFER_BINDING_EXT
35055	constant GL_PIXEL_UNPACK_BUFFER_BINDING_EXT
1	constant GL_EXT_pixel_transform
33584	constant GL_PIXEL_TRANSFORM_2D_EXT
33585	constant GL_PIXEL_MAG_FILTER_EXT
33586	constant GL_PIXEL_MIN_FILTER_EXT
33587	constant GL_PIXEL_CUBIC_WEIGHT_EXT
33588	constant GL_CUBIC_EXT
33589	constant GL_AVERAGE_EXT
33590	constant GL_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT
33591	constant GL_MAX_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT
33592	constant GL_PIXEL_TRANSFORM_2D_MATRIX_EXT
1	constant GL_EXT_pixel_transform_color_table
1	constant GL_EXT_point_parameters
33062	constant GL_POINT_SIZE_MIN_EXT
33063	constant GL_POINT_SIZE_MAX_EXT
33064	constant GL_POINT_FADE_THRESHOLD_SIZE_EXT
33065	constant GL_DISTANCE_ATTENUATION_EXT
1	constant GL_EXT_polygon_offset
32823	constant GL_POLYGON_OFFSET_EXT
32824	constant GL_POLYGON_OFFSET_FACTOR_EXT
32825	constant GL_POLYGON_OFFSET_BIAS_EXT
1	constant GL_EXT_polygon_offset_clamp
36379	constant GL_POLYGON_OFFSET_CLAMP_EXT
1	constant GL_EXT_post_depth_coverage
1	constant GL_EXT_provoking_vertex
36428	constant GL_QUADS_FOLLOW_PROVOKING_VERTEX_CONVENTION_EXT
36429	constant GL_FIRST_VERTEX_CONVENTION_EXT
36430	constant GL_LAST_VERTEX_CONVENTION_EXT
36431	constant GL_PROVOKING_VERTEX_EXT
1	constant GL_EXT_raster_multisample
37671	constant GL_RASTER_MULTISAMPLE_EXT
37672	constant GL_RASTER_SAMPLES_EXT
37673	constant GL_MAX_RASTER_SAMPLES_EXT
37674	constant GL_RASTER_FIXED_SAMPLE_LOCATIONS_EXT
37675	constant GL_MULTISAMPLE_RASTERIZATION_ALLOWED_EXT
37676	constant GL_EFFECTIVE_RASTER_SAMPLES_EXT
1	constant GL_EXT_rescale_normal
32826	constant GL_RESCALE_NORMAL_EXT
1	constant GL_EXT_secondary_color
33880	constant GL_COLOR_SUM_EXT
33881	constant GL_CURRENT_SECONDARY_COLOR_EXT
33882	constant GL_SECONDARY_COLOR_ARRAY_SIZE_EXT
33883	constant GL_SECONDARY_COLOR_ARRAY_TYPE_EXT
33884	constant GL_SECONDARY_COLOR_ARRAY_STRIDE_EXT
33885	constant GL_SECONDARY_COLOR_ARRAY_POINTER_EXT
33886	constant GL_SECONDARY_COLOR_ARRAY_EXT
1	constant GL_EXT_separate_shader_objects
35725	constant GL_ACTIVE_PROGRAM_EXT
1	constant GL_EXT_separate_specular_color
33272	constant GL_LIGHT_MODEL_COLOR_CONTROL_EXT
33273	constant GL_SINGLE_COLOR_EXT
33274	constant GL_SEPARATE_SPECULAR_COLOR_EXT
1	constant GL_EXT_shader_image_load_formatted
1	constant GL_EXT_shader_image_load_store
36664	constant GL_MAX_IMAGE_UNITS_EXT
36665	constant GL_MAX_COMBINED_IMAGE_UNITS_AND_FRAGMENT_OUTPUTS_EXT
36666	constant GL_IMAGE_BINDING_NAME_EXT
36667	constant GL_IMAGE_BINDING_LEVEL_EXT
36668	constant GL_IMAGE_BINDING_LAYERED_EXT
36669	constant GL_IMAGE_BINDING_LAYER_EXT
36670	constant GL_IMAGE_BINDING_ACCESS_EXT
36940	constant GL_IMAGE_1D_EXT
36941	constant GL_IMAGE_2D_EXT
36942	constant GL_IMAGE_3D_EXT
36943	constant GL_IMAGE_2D_RECT_EXT
36944	constant GL_IMAGE_CUBE_EXT
36945	constant GL_IMAGE_BUFFER_EXT
36946	constant GL_IMAGE_1D_ARRAY_EXT
36947	constant GL_IMAGE_2D_ARRAY_EXT
36948	constant GL_IMAGE_CUBE_MAP_ARRAY_EXT
36949	constant GL_IMAGE_2D_MULTISAMPLE_EXT
36950	constant GL_IMAGE_2D_MULTISAMPLE_ARRAY_EXT
36951	constant GL_INT_IMAGE_1D_EXT
36952	constant GL_INT_IMAGE_2D_EXT
36953	constant GL_INT_IMAGE_3D_EXT
36954	constant GL_INT_IMAGE_2D_RECT_EXT
36955	constant GL_INT_IMAGE_CUBE_EXT
36956	constant GL_INT_IMAGE_BUFFER_EXT
36957	constant GL_INT_IMAGE_1D_ARRAY_EXT
36958	constant GL_INT_IMAGE_2D_ARRAY_EXT
36959	constant GL_INT_IMAGE_CUBE_MAP_ARRAY_EXT
36960	constant GL_INT_IMAGE_2D_MULTISAMPLE_EXT
36961	constant GL_INT_IMAGE_2D_MULTISAMPLE_ARRAY_EXT
36962	constant GL_UNSIGNED_INT_IMAGE_1D_EXT
36963	constant GL_UNSIGNED_INT_IMAGE_2D_EXT
36964	constant GL_UNSIGNED_INT_IMAGE_3D_EXT
36965	constant GL_UNSIGNED_INT_IMAGE_2D_RECT_EXT
36966	constant GL_UNSIGNED_INT_IMAGE_CUBE_EXT
36967	constant GL_UNSIGNED_INT_IMAGE_BUFFER_EXT
36968	constant GL_UNSIGNED_INT_IMAGE_1D_ARRAY_EXT
36969	constant GL_UNSIGNED_INT_IMAGE_2D_ARRAY_EXT
36970	constant GL_UNSIGNED_INT_IMAGE_CUBE_MAP_ARRAY_EXT
36971	constant GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE_EXT
36972	constant GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE_ARRAY_EXT
36973	constant GL_MAX_IMAGE_SAMPLES_EXT
36974	constant GL_IMAGE_BINDING_FORMAT_EXT
1	constant GL_VERTEX_ATTRIB_ARRAY_BARRIER_BIT_EXT
2	constant GL_ELEMENT_ARRAY_BARRIER_BIT_EXT
4	constant GL_UNIFORM_BARRIER_BIT_EXT
8	constant GL_TEXTURE_FETCH_BARRIER_BIT_EXT
32	constant GL_SHADER_IMAGE_ACCESS_BARRIER_BIT_EXT
64	constant GL_COMMAND_BARRIER_BIT_EXT
128	constant GL_PIXEL_BUFFER_BARRIER_BIT_EXT
256	constant GL_TEXTURE_UPDATE_BARRIER_BIT_EXT
512	constant GL_BUFFER_UPDATE_BARRIER_BIT_EXT
1024	constant GL_FRAMEBUFFER_BARRIER_BIT_EXT
2048	constant GL_TRANSFORM_FEEDBACK_BARRIER_BIT_EXT
4096	constant GL_ATOMIC_COUNTER_BARRIER_BIT_EXT
4294967295	constant GL_ALL_BARRIER_BITS_EXT
1	constant GL_EXT_shader_integer_mix
1	constant GL_EXT_shadow_funcs
1	constant GL_EXT_shared_texture_palette
33275	constant GL_SHARED_TEXTURE_PALETTE_EXT
1	constant GL_EXT_sparse_texture2
1	constant GL_EXT_stencil_clear_tag
35058	constant GL_STENCIL_TAG_BITS_EXT
35059	constant GL_STENCIL_CLEAR_TAG_VALUE_EXT
1	constant GL_EXT_stencil_two_side
35088	constant GL_STENCIL_TEST_TWO_SIDE_EXT
35089	constant GL_ACTIVE_STENCIL_FACE_EXT
1	constant GL_EXT_stencil_wrap
34055	constant GL_INCR_WRAP_EXT
34056	constant GL_DECR_WRAP_EXT
1	constant GL_EXT_subtexture
1	constant GL_EXT_texture
32827	constant GL_ALPHA4_EXT
32828	constant GL_ALPHA8_EXT
32829	constant GL_ALPHA12_EXT
32830	constant GL_ALPHA16_EXT
32831	constant GL_LUMINANCE4_EXT
32832	constant GL_LUMINANCE8_EXT
32833	constant GL_LUMINANCE12_EXT
32834	constant GL_LUMINANCE16_EXT
32835	constant GL_LUMINANCE4_ALPHA4_EXT
32836	constant GL_LUMINANCE6_ALPHA2_EXT
32837	constant GL_LUMINANCE8_ALPHA8_EXT
32838	constant GL_LUMINANCE12_ALPHA4_EXT
32839	constant GL_LUMINANCE12_ALPHA12_EXT
32840	constant GL_LUMINANCE16_ALPHA16_EXT
32841	constant GL_INTENSITY_EXT
32842	constant GL_INTENSITY4_EXT
32843	constant GL_INTENSITY8_EXT
32844	constant GL_INTENSITY12_EXT
32845	constant GL_INTENSITY16_EXT
32846	constant GL_RGB2_EXT
32847	constant GL_RGB4_EXT
32848	constant GL_RGB5_EXT
32849	constant GL_RGB8_EXT
32850	constant GL_RGB10_EXT
32851	constant GL_RGB12_EXT
32852	constant GL_RGB16_EXT
32853	constant GL_RGBA2_EXT
32854	constant GL_RGBA4_EXT
32855	constant GL_RGB5_A1_EXT
32856	constant GL_RGBA8_EXT
32857	constant GL_RGB10_A2_EXT
32858	constant GL_RGBA12_EXT
32859	constant GL_RGBA16_EXT
32860	constant GL_TEXTURE_RED_SIZE_EXT
32861	constant GL_TEXTURE_GREEN_SIZE_EXT
32862	constant GL_TEXTURE_BLUE_SIZE_EXT
32863	constant GL_TEXTURE_ALPHA_SIZE_EXT
32864	constant GL_TEXTURE_LUMINANCE_SIZE_EXT
32865	constant GL_TEXTURE_INTENSITY_SIZE_EXT
32866	constant GL_REPLACE_EXT
32867	constant GL_PROXY_TEXTURE_1D_EXT
32868	constant GL_PROXY_TEXTURE_2D_EXT
32869	constant GL_TEXTURE_TOO_LARGE_EXT
1	constant GL_EXT_texture3D
32875	constant GL_PACK_SKIP_IMAGES_EXT
32876	constant GL_PACK_IMAGE_HEIGHT_EXT
32877	constant GL_UNPACK_SKIP_IMAGES_EXT
32878	constant GL_UNPACK_IMAGE_HEIGHT_EXT
32879	constant GL_TEXTURE_3D_EXT
32880	constant GL_PROXY_TEXTURE_3D_EXT
32881	constant GL_TEXTURE_DEPTH_EXT
32882	constant GL_TEXTURE_WRAP_R_EXT
32883	constant GL_MAX_3D_TEXTURE_SIZE_EXT
1	constant GL_EXT_texture_array
35864	constant GL_TEXTURE_1D_ARRAY_EXT
35865	constant GL_PROXY_TEXTURE_1D_ARRAY_EXT
35866	constant GL_TEXTURE_2D_ARRAY_EXT
35867	constant GL_PROXY_TEXTURE_2D_ARRAY_EXT
35868	constant GL_TEXTURE_BINDING_1D_ARRAY_EXT
35869	constant GL_TEXTURE_BINDING_2D_ARRAY_EXT
35071	constant GL_MAX_ARRAY_TEXTURE_LAYERS_EXT
34894	constant GL_COMPARE_REF_DEPTH_TO_TEXTURE_EXT
1	constant GL_EXT_texture_buffer_object
35882	constant GL_TEXTURE_BUFFER_EXT
35883	constant GL_MAX_TEXTURE_BUFFER_SIZE_EXT
35884	constant GL_TEXTURE_BINDING_BUFFER_EXT
35885	constant GL_TEXTURE_BUFFER_DATA_STORE_BINDING_EXT
35886	constant GL_TEXTURE_BUFFER_FORMAT_EXT
1	constant GL_EXT_texture_compression_latc
35952	constant GL_COMPRESSED_LUMINANCE_LATC1_EXT
35953	constant GL_COMPRESSED_SIGNED_LUMINANCE_LATC1_EXT
35954	constant GL_COMPRESSED_LUMINANCE_ALPHA_LATC2_EXT
35955	constant GL_COMPRESSED_SIGNED_LUMINANCE_ALPHA_LATC2_EXT
1	constant GL_EXT_texture_compression_rgtc
36283	constant GL_COMPRESSED_RED_RGTC1_EXT
36284	constant GL_COMPRESSED_SIGNED_RED_RGTC1_EXT
36285	constant GL_COMPRESSED_RED_GREEN_RGTC2_EXT
36286	constant GL_COMPRESSED_SIGNED_RED_GREEN_RGTC2_EXT
1	constant GL_EXT_texture_compression_s3tc
33776	constant GL_COMPRESSED_RGB_S3TC_DXT1_EXT
33777	constant GL_COMPRESSED_RGBA_S3TC_DXT1_EXT
33778	constant GL_COMPRESSED_RGBA_S3TC_DXT3_EXT
33779	constant GL_COMPRESSED_RGBA_S3TC_DXT5_EXT
1	constant GL_EXT_texture_cube_map
34065	constant GL_NORMAL_MAP_EXT
34066	constant GL_REFLECTION_MAP_EXT
34067	constant GL_TEXTURE_CUBE_MAP_EXT
34068	constant GL_TEXTURE_BINDING_CUBE_MAP_EXT
34069	constant GL_TEXTURE_CUBE_MAP_POSITIVE_X_EXT
34070	constant GL_TEXTURE_CUBE_MAP_NEGATIVE_X_EXT
34071	constant GL_TEXTURE_CUBE_MAP_POSITIVE_Y_EXT
34072	constant GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_EXT
34073	constant GL_TEXTURE_CUBE_MAP_POSITIVE_Z_EXT
34074	constant GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_EXT
34075	constant GL_PROXY_TEXTURE_CUBE_MAP_EXT
34076	constant GL_MAX_CUBE_MAP_TEXTURE_SIZE_EXT
1	constant GL_EXT_texture_env_add
1	constant GL_EXT_texture_env_combine
34160	constant GL_COMBINE_EXT
34161	constant GL_COMBINE_RGB_EXT
34162	constant GL_COMBINE_ALPHA_EXT
34163	constant GL_RGB_SCALE_EXT
34164	constant GL_ADD_SIGNED_EXT
34165	constant GL_INTERPOLATE_EXT
34166	constant GL_CONSTANT_EXT
34167	constant GL_PRIMARY_COLOR_EXT
34168	constant GL_PREVIOUS_EXT
34176	constant GL_SOURCE0_RGB_EXT
34177	constant GL_SOURCE1_RGB_EXT
34178	constant GL_SOURCE2_RGB_EXT
34184	constant GL_SOURCE0_ALPHA_EXT
34185	constant GL_SOURCE1_ALPHA_EXT
34186	constant GL_SOURCE2_ALPHA_EXT
34192	constant GL_OPERAND0_RGB_EXT
34193	constant GL_OPERAND1_RGB_EXT
34194	constant GL_OPERAND2_RGB_EXT
34200	constant GL_OPERAND0_ALPHA_EXT
34201	constant GL_OPERAND1_ALPHA_EXT
34202	constant GL_OPERAND2_ALPHA_EXT
1	constant GL_EXT_texture_env_dot3
34624	constant GL_DOT3_RGB_EXT
34625	constant GL_DOT3_RGBA_EXT
1	constant GL_EXT_texture_filter_anisotropic
34046	constant GL_TEXTURE_MAX_ANISOTROPY_EXT
34047	constant GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT
1	constant GL_EXT_texture_filter_minmax
1	constant GL_EXT_texture_integer
36208	constant GL_RGBA32UI_EXT
36209	constant GL_RGB32UI_EXT
36210	constant GL_ALPHA32UI_EXT
36211	constant GL_INTENSITY32UI_EXT
36212	constant GL_LUMINANCE32UI_EXT
36213	constant GL_LUMINANCE_ALPHA32UI_EXT
36214	constant GL_RGBA16UI_EXT
36215	constant GL_RGB16UI_EXT
36216	constant GL_ALPHA16UI_EXT
36217	constant GL_INTENSITY16UI_EXT
36218	constant GL_LUMINANCE16UI_EXT
36219	constant GL_LUMINANCE_ALPHA16UI_EXT
36220	constant GL_RGBA8UI_EXT
36221	constant GL_RGB8UI_EXT
36222	constant GL_ALPHA8UI_EXT
36223	constant GL_INTENSITY8UI_EXT
36224	constant GL_LUMINANCE8UI_EXT
36225	constant GL_LUMINANCE_ALPHA8UI_EXT
36226	constant GL_RGBA32I_EXT
36227	constant GL_RGB32I_EXT
36228	constant GL_ALPHA32I_EXT
36229	constant GL_INTENSITY32I_EXT
36230	constant GL_LUMINANCE32I_EXT
36231	constant GL_LUMINANCE_ALPHA32I_EXT
36232	constant GL_RGBA16I_EXT
36233	constant GL_RGB16I_EXT
36234	constant GL_ALPHA16I_EXT
36235	constant GL_INTENSITY16I_EXT
36236	constant GL_LUMINANCE16I_EXT
36237	constant GL_LUMINANCE_ALPHA16I_EXT
36238	constant GL_RGBA8I_EXT
36239	constant GL_RGB8I_EXT
36240	constant GL_ALPHA8I_EXT
36241	constant GL_INTENSITY8I_EXT
36242	constant GL_LUMINANCE8I_EXT
36243	constant GL_LUMINANCE_ALPHA8I_EXT
36244	constant GL_RED_INTEGER_EXT
36245	constant GL_GREEN_INTEGER_EXT
36246	constant GL_BLUE_INTEGER_EXT
36247	constant GL_ALPHA_INTEGER_EXT
36248	constant GL_RGB_INTEGER_EXT
36249	constant GL_RGBA_INTEGER_EXT
36250	constant GL_BGR_INTEGER_EXT
36251	constant GL_BGRA_INTEGER_EXT
36252	constant GL_LUMINANCE_INTEGER_EXT
36253	constant GL_LUMINANCE_ALPHA_INTEGER_EXT
36254	constant GL_RGBA_INTEGER_MODE_EXT
1	constant GL_EXT_texture_lod_bias
34045	constant GL_MAX_TEXTURE_LOD_BIAS_EXT
34048	constant GL_TEXTURE_FILTER_CONTROL_EXT
34049	constant GL_TEXTURE_LOD_BIAS_EXT
1	constant GL_EXT_texture_mirror_clamp
34626	constant GL_MIRROR_CLAMP_EXT
34627	constant GL_MIRROR_CLAMP_TO_EDGE_EXT
35090	constant GL_MIRROR_CLAMP_TO_BORDER_EXT
1	constant GL_EXT_texture_object
32870	constant GL_TEXTURE_PRIORITY_EXT
32871	constant GL_TEXTURE_RESIDENT_EXT
32872	constant GL_TEXTURE_1D_BINDING_EXT
32873	constant GL_TEXTURE_2D_BINDING_EXT
32874	constant GL_TEXTURE_3D_BINDING_EXT
1	constant GL_EXT_texture_perturb_normal
34222	constant GL_PERTURB_EXT
34223	constant GL_TEXTURE_NORMAL_EXT
1	constant GL_EXT_texture_sRGB
35904	constant GL_SRGB_EXT
35905	constant GL_SRGB8_EXT
35906	constant GL_SRGB_ALPHA_EXT
35907	constant GL_SRGB8_ALPHA8_EXT
35908	constant GL_SLUMINANCE_ALPHA_EXT
35909	constant GL_SLUMINANCE8_ALPHA8_EXT
35910	constant GL_SLUMINANCE_EXT
35911	constant GL_SLUMINANCE8_EXT
35912	constant GL_COMPRESSED_SRGB_EXT
35913	constant GL_COMPRESSED_SRGB_ALPHA_EXT
35914	constant GL_COMPRESSED_SLUMINANCE_EXT
35915	constant GL_COMPRESSED_SLUMINANCE_ALPHA_EXT
35916	constant GL_COMPRESSED_SRGB_S3TC_DXT1_EXT
35917	constant GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_EXT
35918	constant GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_EXT
35919	constant GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_EXT
1	constant GL_EXT_texture_sRGB_decode
35400	constant GL_TEXTURE_SRGB_DECODE_EXT
35401	constant GL_DECODE_EXT
35402	constant GL_SKIP_DECODE_EXT
1	constant GL_EXT_texture_shared_exponent
35901	constant GL_RGB9_E5_EXT
35902	constant GL_UNSIGNED_INT_5_9_9_9_REV_EXT
35903	constant GL_TEXTURE_SHARED_SIZE_EXT
1	constant GL_EXT_texture_snorm
36880	constant GL_ALPHA_SNORM
36881	constant GL_LUMINANCE_SNORM
36882	constant GL_LUMINANCE_ALPHA_SNORM
36883	constant GL_INTENSITY_SNORM
36884	constant GL_ALPHA8_SNORM
36885	constant GL_LUMINANCE8_SNORM
36886	constant GL_LUMINANCE8_ALPHA8_SNORM
36887	constant GL_INTENSITY8_SNORM
36888	constant GL_ALPHA16_SNORM
36889	constant GL_LUMINANCE16_SNORM
36890	constant GL_LUMINANCE16_ALPHA16_SNORM
36891	constant GL_INTENSITY16_SNORM
36752	constant GL_RED_SNORM
36753	constant GL_RG_SNORM
36754	constant GL_RGB_SNORM
36755	constant GL_RGBA_SNORM
1	constant GL_EXT_texture_swizzle
36418	constant GL_TEXTURE_SWIZZLE_R_EXT
36419	constant GL_TEXTURE_SWIZZLE_G_EXT
36420	constant GL_TEXTURE_SWIZZLE_B_EXT
36421	constant GL_TEXTURE_SWIZZLE_A_EXT
36422	constant GL_TEXTURE_SWIZZLE_RGBA_EXT
1	constant GL_EXT_timer_query
35007	constant GL_TIME_ELAPSED_EXT
1	constant GL_EXT_transform_feedback
35982	constant GL_TRANSFORM_FEEDBACK_BUFFER_EXT
35972	constant GL_TRANSFORM_FEEDBACK_BUFFER_START_EXT
35973	constant GL_TRANSFORM_FEEDBACK_BUFFER_SIZE_EXT
35983	constant GL_TRANSFORM_FEEDBACK_BUFFER_BINDING_EXT
35980	constant GL_INTERLEAVED_ATTRIBS_EXT
35981	constant GL_SEPARATE_ATTRIBS_EXT
35975	constant GL_PRIMITIVES_GENERATED_EXT
35976	constant GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN_EXT
35977	constant GL_RASTERIZER_DISCARD_EXT
35978	constant GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS_EXT
35979	constant GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS_EXT
35968	constant GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS_EXT
35971	constant GL_TRANSFORM_FEEDBACK_VARYINGS_EXT
35967	constant GL_TRANSFORM_FEEDBACK_BUFFER_MODE_EXT
35958	constant GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH_EXT
1	constant GL_EXT_vertex_array
32884	constant GL_VERTEX_ARRAY_EXT
32885	constant GL_NORMAL_ARRAY_EXT
32886	constant GL_COLOR_ARRAY_EXT
32887	constant GL_INDEX_ARRAY_EXT
32888	constant GL_TEXTURE_COORD_ARRAY_EXT
32889	constant GL_EDGE_FLAG_ARRAY_EXT
32890	constant GL_VERTEX_ARRAY_SIZE_EXT
32891	constant GL_VERTEX_ARRAY_TYPE_EXT
32892	constant GL_VERTEX_ARRAY_STRIDE_EXT
32893	constant GL_VERTEX_ARRAY_COUNT_EXT
32894	constant GL_NORMAL_ARRAY_TYPE_EXT
32895	constant GL_NORMAL_ARRAY_STRIDE_EXT
32896	constant GL_NORMAL_ARRAY_COUNT_EXT
32897	constant GL_COLOR_ARRAY_SIZE_EXT
32898	constant GL_COLOR_ARRAY_TYPE_EXT
32899	constant GL_COLOR_ARRAY_STRIDE_EXT
32900	constant GL_COLOR_ARRAY_COUNT_EXT
32901	constant GL_INDEX_ARRAY_TYPE_EXT
32902	constant GL_INDEX_ARRAY_STRIDE_EXT
32903	constant GL_INDEX_ARRAY_COUNT_EXT
32904	constant GL_TEXTURE_COORD_ARRAY_SIZE_EXT
32905	constant GL_TEXTURE_COORD_ARRAY_TYPE_EXT
32906	constant GL_TEXTURE_COORD_ARRAY_STRIDE_EXT
32907	constant GL_TEXTURE_COORD_ARRAY_COUNT_EXT
32908	constant GL_EDGE_FLAG_ARRAY_STRIDE_EXT
32909	constant GL_EDGE_FLAG_ARRAY_COUNT_EXT
32910	constant GL_VERTEX_ARRAY_POINTER_EXT
32911	constant GL_NORMAL_ARRAY_POINTER_EXT
32912	constant GL_COLOR_ARRAY_POINTER_EXT
32913	constant GL_INDEX_ARRAY_POINTER_EXT
32914	constant GL_TEXTURE_COORD_ARRAY_POINTER_EXT
32915	constant GL_EDGE_FLAG_ARRAY_POINTER_EXT
1	constant GL_EXT_vertex_array_bgra
1	constant GL_EXT_vertex_attrib_64bit
36860	constant GL_DOUBLE_VEC2_EXT
36861	constant GL_DOUBLE_VEC3_EXT
36862	constant GL_DOUBLE_VEC4_EXT
36678	constant GL_DOUBLE_MAT2_EXT
36679	constant GL_DOUBLE_MAT3_EXT
36680	constant GL_DOUBLE_MAT4_EXT
36681	constant GL_DOUBLE_MAT2x3_EXT
36682	constant GL_DOUBLE_MAT2x4_EXT
36683	constant GL_DOUBLE_MAT3x2_EXT
36684	constant GL_DOUBLE_MAT3x4_EXT
36685	constant GL_DOUBLE_MAT4x2_EXT
36686	constant GL_DOUBLE_MAT4x3_EXT
1	constant GL_EXT_vertex_shader
34688	constant GL_VERTEX_SHADER_EXT
34689	constant GL_VERTEX_SHADER_BINDING_EXT
34690	constant GL_OP_INDEX_EXT
34691	constant GL_OP_NEGATE_EXT
34692	constant GL_OP_DOT3_EXT
34693	constant GL_OP_DOT4_EXT
34694	constant GL_OP_MUL_EXT
34695	constant GL_OP_ADD_EXT
34696	constant GL_OP_MADD_EXT
34697	constant GL_OP_FRAC_EXT
34698	constant GL_OP_MAX_EXT
34699	constant GL_OP_MIN_EXT
34700	constant GL_OP_SET_GE_EXT
34701	constant GL_OP_SET_LT_EXT
34702	constant GL_OP_CLAMP_EXT
34703	constant GL_OP_FLOOR_EXT
34704	constant GL_OP_ROUND_EXT
34705	constant GL_OP_EXP_BASE_2_EXT
34706	constant GL_OP_LOG_BASE_2_EXT
34707	constant GL_OP_POWER_EXT
34708	constant GL_OP_RECIP_EXT
34709	constant GL_OP_RECIP_SQRT_EXT
34710	constant GL_OP_SUB_EXT
34711	constant GL_OP_CROSS_PRODUCT_EXT
34712	constant GL_OP_MULTIPLY_MATRIX_EXT
34713	constant GL_OP_MOV_EXT
34714	constant GL_OUTPUT_VERTEX_EXT
34715	constant GL_OUTPUT_COLOR0_EXT
34716	constant GL_OUTPUT_COLOR1_EXT
34717	constant GL_OUTPUT_TEXTURE_COORD0_EXT
34718	constant GL_OUTPUT_TEXTURE_COORD1_EXT
34719	constant GL_OUTPUT_TEXTURE_COORD2_EXT
34720	constant GL_OUTPUT_TEXTURE_COORD3_EXT
34721	constant GL_OUTPUT_TEXTURE_COORD4_EXT
34722	constant GL_OUTPUT_TEXTURE_COORD5_EXT
34723	constant GL_OUTPUT_TEXTURE_COORD6_EXT
34724	constant GL_OUTPUT_TEXTURE_COORD7_EXT
34725	constant GL_OUTPUT_TEXTURE_COORD8_EXT
34726	constant GL_OUTPUT_TEXTURE_COORD9_EXT
34727	constant GL_OUTPUT_TEXTURE_COORD10_EXT
34728	constant GL_OUTPUT_TEXTURE_COORD11_EXT
34729	constant GL_OUTPUT_TEXTURE_COORD12_EXT
34730	constant GL_OUTPUT_TEXTURE_COORD13_EXT
34731	constant GL_OUTPUT_TEXTURE_COORD14_EXT
34732	constant GL_OUTPUT_TEXTURE_COORD15_EXT
34733	constant GL_OUTPUT_TEXTURE_COORD16_EXT
34734	constant GL_OUTPUT_TEXTURE_COORD17_EXT
34735	constant GL_OUTPUT_TEXTURE_COORD18_EXT
34736	constant GL_OUTPUT_TEXTURE_COORD19_EXT
34737	constant GL_OUTPUT_TEXTURE_COORD20_EXT
34738	constant GL_OUTPUT_TEXTURE_COORD21_EXT
34739	constant GL_OUTPUT_TEXTURE_COORD22_EXT
34740	constant GL_OUTPUT_TEXTURE_COORD23_EXT
34741	constant GL_OUTPUT_TEXTURE_COORD24_EXT
34742	constant GL_OUTPUT_TEXTURE_COORD25_EXT
34743	constant GL_OUTPUT_TEXTURE_COORD26_EXT
34744	constant GL_OUTPUT_TEXTURE_COORD27_EXT
34745	constant GL_OUTPUT_TEXTURE_COORD28_EXT
34746	constant GL_OUTPUT_TEXTURE_COORD29_EXT
34747	constant GL_OUTPUT_TEXTURE_COORD30_EXT
34748	constant GL_OUTPUT_TEXTURE_COORD31_EXT
34749	constant GL_OUTPUT_FOG_EXT
34750	constant GL_SCALAR_EXT
34751	constant GL_VECTOR_EXT
34752	constant GL_MATRIX_EXT
34753	constant GL_VARIANT_EXT
34754	constant GL_INVARIANT_EXT
34755	constant GL_LOCAL_CONSTANT_EXT
34756	constant GL_LOCAL_EXT
34757	constant GL_MAX_VERTEX_SHADER_INSTRUCTIONS_EXT
34758	constant GL_MAX_VERTEX_SHADER_VARIANTS_EXT
34759	constant GL_MAX_VERTEX_SHADER_INVARIANTS_EXT
34760	constant GL_MAX_VERTEX_SHADER_LOCAL_CONSTANTS_EXT
34761	constant GL_MAX_VERTEX_SHADER_LOCALS_EXT
34762	constant GL_MAX_OPTIMIZED_VERTEX_SHADER_INSTRUCTIONS_EXT
34763	constant GL_MAX_OPTIMIZED_VERTEX_SHADER_VARIANTS_EXT
34764	constant GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCAL_CONSTANTS_EXT
34765	constant GL_MAX_OPTIMIZED_VERTEX_SHADER_INVARIANTS_EXT
34766	constant GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCALS_EXT
34767	constant GL_VERTEX_SHADER_INSTRUCTIONS_EXT
34768	constant GL_VERTEX_SHADER_VARIANTS_EXT
34769	constant GL_VERTEX_SHADER_INVARIANTS_EXT
34770	constant GL_VERTEX_SHADER_LOCAL_CONSTANTS_EXT
34771	constant GL_VERTEX_SHADER_LOCALS_EXT
34772	constant GL_VERTEX_SHADER_OPTIMIZED_EXT
34773	constant GL_X_EXT
34774	constant GL_Y_EXT
34775	constant GL_Z_EXT
34776	constant GL_W_EXT
34777	constant GL_NEGATIVE_X_EXT
34778	constant GL_NEGATIVE_Y_EXT
34779	constant GL_NEGATIVE_Z_EXT
34780	constant GL_NEGATIVE_W_EXT
34781	constant GL_ZERO_EXT
34782	constant GL_ONE_EXT
34783	constant GL_NEGATIVE_ONE_EXT
34784	constant GL_NORMALIZED_RANGE_EXT
34785	constant GL_FULL_RANGE_EXT
34786	constant GL_CURRENT_VERTEX_EXT
34787	constant GL_MVP_MATRIX_EXT
34788	constant GL_VARIANT_VALUE_EXT
34789	constant GL_VARIANT_DATATYPE_EXT
34790	constant GL_VARIANT_ARRAY_STRIDE_EXT
34791	constant GL_VARIANT_ARRAY_TYPE_EXT
34792	constant GL_VARIANT_ARRAY_EXT
34793	constant GL_VARIANT_ARRAY_POINTER_EXT
34794	constant GL_INVARIANT_VALUE_EXT
34795	constant GL_INVARIANT_DATATYPE_EXT
34796	constant GL_LOCAL_CONSTANT_VALUE_EXT
34797	constant GL_LOCAL_CONSTANT_DATATYPE_EXT
1	constant GL_EXT_vertex_weighting
2979	constant GL_MODELVIEW0_STACK_DEPTH_EXT
34050	constant GL_MODELVIEW1_STACK_DEPTH_EXT
2982	constant GL_MODELVIEW0_MATRIX_EXT
34054	constant GL_MODELVIEW1_MATRIX_EXT
34057	constant GL_VERTEX_WEIGHTING_EXT
5888	constant GL_MODELVIEW0_EXT
34058	constant GL_MODELVIEW1_EXT
34059	constant GL_CURRENT_VERTEX_WEIGHT_EXT
34060	constant GL_VERTEX_WEIGHT_ARRAY_EXT
34061	constant GL_VERTEX_WEIGHT_ARRAY_SIZE_EXT
34062	constant GL_VERTEX_WEIGHT_ARRAY_TYPE_EXT
34063	constant GL_VERTEX_WEIGHT_ARRAY_STRIDE_EXT
34064	constant GL_VERTEX_WEIGHT_ARRAY_POINTER_EXT
1	constant GL_EXT_x11_sync_object
37089	constant GL_SYNC_X11_FENCE_EXT
1	constant GL_GREMEDY_frame_terminator
1	constant GL_GREMEDY_string_marker
1	constant GL_HP_convolution_border_modes
33104	constant GL_IGNORE_BORDER_HP
33105	constant GL_CONSTANT_BORDER_HP
33107	constant GL_REPLICATE_BORDER_HP
33108	constant GL_CONVOLUTION_BORDER_COLOR_HP
1	constant GL_HP_image_transform
33109	constant GL_IMAGE_SCALE_X_HP
33110	constant GL_IMAGE_SCALE_Y_HP
33111	constant GL_IMAGE_TRANSLATE_X_HP
33112	constant GL_IMAGE_TRANSLATE_Y_HP
33113	constant GL_IMAGE_ROTATE_ANGLE_HP
33114	constant GL_IMAGE_ROTATE_ORIGIN_X_HP
33115	constant GL_IMAGE_ROTATE_ORIGIN_Y_HP
33116	constant GL_IMAGE_MAG_FILTER_HP
33117	constant GL_IMAGE_MIN_FILTER_HP
33118	constant GL_IMAGE_CUBIC_WEIGHT_HP
33119	constant GL_CUBIC_HP
33120	constant GL_AVERAGE_HP
33121	constant GL_IMAGE_TRANSFORM_2D_HP
33122	constant GL_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP
33123	constant GL_PROXY_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP
1	constant GL_HP_occlusion_test
33125	constant GL_OCCLUSION_TEST_HP
33126	constant GL_OCCLUSION_TEST_RESULT_HP
1	constant GL_HP_texture_lighting
33127	constant GL_TEXTURE_LIGHTING_MODE_HP
33128	constant GL_TEXTURE_POST_SPECULAR_HP
33129	constant GL_TEXTURE_PRE_SPECULAR_HP
1	constant GL_IBM_cull_vertex
103050	constant GL_CULL_VERTEX_IBM
1	constant GL_IBM_multimode_draw_arrays
1	constant GL_IBM_rasterpos_clip
103010	constant GL_RASTER_POSITION_UNCLIPPED_IBM
1	constant GL_IBM_static_data
103060	constant GL_ALL_STATIC_DATA_IBM
103061	constant GL_STATIC_VERTEX_ARRAY_IBM
1	constant GL_IBM_texture_mirrored_repeat
33648	constant GL_MIRRORED_REPEAT_IBM
1	constant GL_IBM_vertex_array_lists
103070	constant GL_VERTEX_ARRAY_LIST_IBM
103071	constant GL_NORMAL_ARRAY_LIST_IBM
103072	constant GL_COLOR_ARRAY_LIST_IBM
103073	constant GL_INDEX_ARRAY_LIST_IBM
103074	constant GL_TEXTURE_COORD_ARRAY_LIST_IBM
103075	constant GL_EDGE_FLAG_ARRAY_LIST_IBM
103076	constant GL_FOG_COORDINATE_ARRAY_LIST_IBM
103077	constant GL_SECONDARY_COLOR_ARRAY_LIST_IBM
103080	constant GL_VERTEX_ARRAY_LIST_STRIDE_IBM
103081	constant GL_NORMAL_ARRAY_LIST_STRIDE_IBM
103082	constant GL_COLOR_ARRAY_LIST_STRIDE_IBM
103083	constant GL_INDEX_ARRAY_LIST_STRIDE_IBM
103084	constant GL_TEXTURE_COORD_ARRAY_LIST_STRIDE_IBM
103085	constant GL_EDGE_FLAG_ARRAY_LIST_STRIDE_IBM
103086	constant GL_FOG_COORDINATE_ARRAY_LIST_STRIDE_IBM
103087	constant GL_SECONDARY_COLOR_ARRAY_LIST_STRIDE_IBM
1	constant GL_INGR_blend_func_separate
1	constant GL_INGR_color_clamp
34144	constant GL_RED_MIN_CLAMP_INGR
34145	constant GL_GREEN_MIN_CLAMP_INGR
34146	constant GL_BLUE_MIN_CLAMP_INGR
34147	constant GL_ALPHA_MIN_CLAMP_INGR
34148	constant GL_RED_MAX_CLAMP_INGR
34149	constant GL_GREEN_MAX_CLAMP_INGR
34150	constant GL_BLUE_MAX_CLAMP_INGR
34151	constant GL_ALPHA_MAX_CLAMP_INGR
1	constant GL_INGR_interlace_read
34152	constant GL_INTERLACE_READ_INGR
1	constant GL_INTEL_fragment_shader_ordering
1	constant GL_INTEL_map_texture
33791	constant GL_TEXTURE_MEMORY_LAYOUT_INTEL
0	constant GL_LAYOUT_DEFAULT_INTEL
1	constant GL_LAYOUT_LINEAR_INTEL
2	constant GL_LAYOUT_LINEAR_CPU_CACHED_INTEL
1	constant GL_INTEL_parallel_arrays
33780	constant GL_PARALLEL_ARRAYS_INTEL
33781	constant GL_VERTEX_ARRAY_PARALLEL_POINTERS_INTEL
33782	constant GL_NORMAL_ARRAY_PARALLEL_POINTERS_INTEL
33783	constant GL_COLOR_ARRAY_PARALLEL_POINTERS_INTEL
33784	constant GL_TEXTURE_COORD_ARRAY_PARALLEL_POINTERS_INTEL
1	constant GL_INTEL_performance_query
0	constant GL_PERFQUERY_SINGLE_CONTEXT_INTEL
1	constant GL_PERFQUERY_GLOBAL_CONTEXT_INTEL
33787	constant GL_PERFQUERY_WAIT_INTEL
33786	constant GL_PERFQUERY_FLUSH_INTEL
33785	constant GL_PERFQUERY_DONOT_FLUSH_INTEL
38128	constant GL_PERFQUERY_COUNTER_EVENT_INTEL
38129	constant GL_PERFQUERY_COUNTER_DURATION_NORM_INTEL
38130	constant GL_PERFQUERY_COUNTER_DURATION_RAW_INTEL
38131	constant GL_PERFQUERY_COUNTER_THROUGHPUT_INTEL
38132	constant GL_PERFQUERY_COUNTER_RAW_INTEL
38133	constant GL_PERFQUERY_COUNTER_TIMESTAMP_INTEL
38136	constant GL_PERFQUERY_COUNTER_DATA_UINT32_INTEL
38137	constant GL_PERFQUERY_COUNTER_DATA_UINT64_INTEL
38138	constant GL_PERFQUERY_COUNTER_DATA_FLOAT_INTEL
38139	constant GL_PERFQUERY_COUNTER_DATA_DOUBLE_INTEL
38140	constant GL_PERFQUERY_COUNTER_DATA_BOOL32_INTEL
38141	constant GL_PERFQUERY_QUERY_NAME_LENGTH_MAX_INTEL
38142	constant GL_PERFQUERY_COUNTER_NAME_LENGTH_MAX_INTEL
38143	constant GL_PERFQUERY_COUNTER_DESC_LENGTH_MAX_INTEL
38144	constant GL_PERFQUERY_GPA_EXTENDED_COUNTERS_INTEL
1	constant GL_MESAX_texture_stack
34649	constant GL_TEXTURE_1D_STACK_MESAX
34650	constant GL_TEXTURE_2D_STACK_MESAX
34651	constant GL_PROXY_TEXTURE_1D_STACK_MESAX
34652	constant GL_PROXY_TEXTURE_2D_STACK_MESAX
34653	constant GL_TEXTURE_1D_STACK_BINDING_MESAX
34654	constant GL_TEXTURE_2D_STACK_BINDING_MESAX
1	constant GL_MESA_pack_invert
34648	constant GL_PACK_INVERT_MESA
1	constant GL_MESA_resize_buffers
1	constant GL_MESA_window_pos
1	constant GL_MESA_ycbcr_texture
34234	constant GL_UNSIGNED_SHORT_8_8_MESA
34235	constant GL_UNSIGNED_SHORT_8_8_REV_MESA
34647	constant GL_YCBCR_MESA
1	constant GL_NVX_conditional_render
1	constant GL_NVX_gpu_memory_info
36935	constant GL_GPU_MEMORY_INFO_DEDICATED_VIDMEM_NVX
36936	constant GL_GPU_MEMORY_INFO_TOTAL_AVAILABLE_MEMORY_NVX
36937	constant GL_GPU_MEMORY_INFO_CURRENT_AVAILABLE_VIDMEM_NVX
36938	constant GL_GPU_MEMORY_INFO_EVICTION_COUNT_NVX
36939	constant GL_GPU_MEMORY_INFO_EVICTED_MEMORY_NVX
1	constant GL_NV_bindless_multi_draw_indirect
1	constant GL_NV_bindless_multi_draw_indirect_count
1	constant GL_NV_bindless_texture
1	constant GL_NV_blend_equation_advanced
37505	constant GL_BLEND_OVERLAP_NV
37504	constant GL_BLEND_PREMULTIPLIED_SRC_NV
6405	constant GL_BLUE_NV
37530	constant GL_COLORBURN_NV
37529	constant GL_COLORDODGE_NV
37508	constant GL_CONJOINT_NV
37537	constant GL_CONTRAST_NV
37527	constant GL_DARKEN_NV
37534	constant GL_DIFFERENCE_NV
37507	constant GL_DISJOINT_NV
37519	constant GL_DST_ATOP_NV
37515	constant GL_DST_IN_NV
37511	constant GL_DST_NV
37517	constant GL_DST_OUT_NV
37513	constant GL_DST_OVER_NV
37536	constant GL_EXCLUSION_NV
6404	constant GL_GREEN_NV
37531	constant GL_HARDLIGHT_NV
37545	constant GL_HARDMIX_NV
37551	constant GL_HSL_COLOR_NV
37549	constant GL_HSL_HUE_NV
37552	constant GL_HSL_LUMINOSITY_NV
37550	constant GL_HSL_SATURATION_NV
37556	constant GL_INVERT_OVG_NV
37539	constant GL_INVERT_RGB_NV
37528	constant GL_LIGHTEN_NV
37541	constant GL_LINEARBURN_NV
37540	constant GL_LINEARDODGE_NV
37543	constant GL_LINEARLIGHT_NV
37555	constant GL_MINUS_CLAMPED_NV
37535	constant GL_MINUS_NV
37524	constant GL_MULTIPLY_NV
37526	constant GL_OVERLAY_NV
37544	constant GL_PINLIGHT_NV
37554	constant GL_PLUS_CLAMPED_ALPHA_NV
37553	constant GL_PLUS_CLAMPED_NV
37522	constant GL_PLUS_DARKER_NV
37521	constant GL_PLUS_NV
6403	constant GL_RED_NV
37525	constant GL_SCREEN_NV
37532	constant GL_SOFTLIGHT_NV
37518	constant GL_SRC_ATOP_NV
37514	constant GL_SRC_IN_NV
37510	constant GL_SRC_NV
37516	constant GL_SRC_OUT_NV
37512	constant GL_SRC_OVER_NV
37506	constant GL_UNCORRELATED_NV
37542	constant GL_VIVIDLIGHT_NV
5382	constant GL_XOR_NV
1	constant GL_NV_blend_equation_advanced_coherent
37509	constant GL_BLEND_ADVANCED_COHERENT_NV
1	constant GL_NV_blend_square
1	constant GL_NV_compute_program5
37115	constant GL_COMPUTE_PROGRAM_NV
37116	constant GL_COMPUTE_PROGRAM_PARAMETER_BUFFER_NV
1	constant GL_NV_conditional_render
36371	constant GL_QUERY_WAIT_NV
36372	constant GL_QUERY_NO_WAIT_NV
36373	constant GL_QUERY_BY_REGION_WAIT_NV
36374	constant GL_QUERY_BY_REGION_NO_WAIT_NV
1	constant GL_NV_conservative_raster
37702	constant GL_CONSERVATIVE_RASTERIZATION_NV
37703	constant GL_SUBPIXEL_PRECISION_BIAS_X_BITS_NV
37704	constant GL_SUBPIXEL_PRECISION_BIAS_Y_BITS_NV
37705	constant GL_MAX_SUBPIXEL_PRECISION_BIAS_BITS_NV
1	constant GL_NV_copy_depth_to_color
34926	constant GL_DEPTH_STENCIL_TO_RGBA_NV
34927	constant GL_DEPTH_STENCIL_TO_BGRA_NV
1	constant GL_NV_copy_image
1	constant GL_NV_deep_texture3D
37072	constant GL_MAX_DEEP_3D_TEXTURE_WIDTH_HEIGHT_NV
37073	constant GL_MAX_DEEP_3D_TEXTURE_DEPTH_NV
1	constant GL_NV_depth_buffer_float
36267	constant GL_DEPTH_COMPONENT32F_NV
36268	constant GL_DEPTH32F_STENCIL8_NV
36269	constant GL_FLOAT_32_UNSIGNED_INT_24_8_REV_NV
36271	constant GL_DEPTH_BUFFER_FLOAT_MODE_NV
1	constant GL_NV_depth_clamp
34383	constant GL_DEPTH_CLAMP_NV
1	constant GL_NV_draw_texture
1	constant GL_NV_evaluators
34496	constant GL_EVAL_2D_NV
34497	constant GL_EVAL_TRIANGULAR_2D_NV
34498	constant GL_MAP_TESSELLATION_NV
34499	constant GL_MAP_ATTRIB_U_ORDER_NV
34500	constant GL_MAP_ATTRIB_V_ORDER_NV
34501	constant GL_EVAL_FRACTIONAL_TESSELLATION_NV
34502	constant GL_EVAL_VERTEX_ATTRIB0_NV
34503	constant GL_EVAL_VERTEX_ATTRIB1_NV
34504	constant GL_EVAL_VERTEX_ATTRIB2_NV
34505	constant GL_EVAL_VERTEX_ATTRIB3_NV
34506	constant GL_EVAL_VERTEX_ATTRIB4_NV
34507	constant GL_EVAL_VERTEX_ATTRIB5_NV
34508	constant GL_EVAL_VERTEX_ATTRIB6_NV
34509	constant GL_EVAL_VERTEX_ATTRIB7_NV
34510	constant GL_EVAL_VERTEX_ATTRIB8_NV
34511	constant GL_EVAL_VERTEX_ATTRIB9_NV
34512	constant GL_EVAL_VERTEX_ATTRIB10_NV
34513	constant GL_EVAL_VERTEX_ATTRIB11_NV
34514	constant GL_EVAL_VERTEX_ATTRIB12_NV
34515	constant GL_EVAL_VERTEX_ATTRIB13_NV
34516	constant GL_EVAL_VERTEX_ATTRIB14_NV
34517	constant GL_EVAL_VERTEX_ATTRIB15_NV
34518	constant GL_MAX_MAP_TESSELLATION_NV
34519	constant GL_MAX_RATIONAL_EVAL_ORDER_NV
1	constant GL_NV_explicit_multisample
36432	constant GL_SAMPLE_POSITION_NV
36433	constant GL_SAMPLE_MASK_NV
36434	constant GL_SAMPLE_MASK_VALUE_NV
36435	constant GL_TEXTURE_BINDING_RENDERBUFFER_NV
36436	constant GL_TEXTURE_RENDERBUFFER_DATA_STORE_BINDING_NV
36437	constant GL_TEXTURE_RENDERBUFFER_NV
36438	constant GL_SAMPLER_RENDERBUFFER_NV
36439	constant GL_INT_SAMPLER_RENDERBUFFER_NV
36440	constant GL_UNSIGNED_INT_SAMPLER_RENDERBUFFER_NV
36441	constant GL_MAX_SAMPLE_MASK_WORDS_NV
1	constant GL_NV_fence
34034	constant GL_ALL_COMPLETED_NV
34035	constant GL_FENCE_STATUS_NV
34036	constant GL_FENCE_CONDITION_NV
1	constant GL_NV_fill_rectangle
37692	constant GL_FILL_RECTANGLE_NV
1	constant GL_NV_float_buffer
34944	constant GL_FLOAT_R_NV
34945	constant GL_FLOAT_RG_NV
34946	constant GL_FLOAT_RGB_NV
34947	constant GL_FLOAT_RGBA_NV
34948	constant GL_FLOAT_R16_NV
34949	constant GL_FLOAT_R32_NV
34950	constant GL_FLOAT_RG16_NV
34951	constant GL_FLOAT_RG32_NV
34952	constant GL_FLOAT_RGB16_NV
34953	constant GL_FLOAT_RGB32_NV
34954	constant GL_FLOAT_RGBA16_NV
34955	constant GL_FLOAT_RGBA32_NV
34956	constant GL_TEXTURE_FLOAT_COMPONENTS_NV
34957	constant GL_FLOAT_CLEAR_COLOR_VALUE_NV
34958	constant GL_FLOAT_RGBA_MODE_NV
1	constant GL_NV_fog_distance
34138	constant GL_FOG_DISTANCE_MODE_NV
34139	constant GL_EYE_RADIAL_NV
34140	constant GL_EYE_PLANE_ABSOLUTE_NV
1	constant GL_NV_fragment_coverage_to_color
37597	constant GL_FRAGMENT_COVERAGE_TO_COLOR_NV
37598	constant GL_FRAGMENT_COVERAGE_COLOR_NV
1	constant GL_NV_fragment_program
34920	constant GL_MAX_FRAGMENT_PROGRAM_LOCAL_PARAMETERS_NV
34928	constant GL_FRAGMENT_PROGRAM_NV
34929	constant GL_MAX_TEXTURE_COORDS_NV
34930	constant GL_MAX_TEXTURE_IMAGE_UNITS_NV
34931	constant GL_FRAGMENT_PROGRAM_BINDING_NV
34932	constant GL_PROGRAM_ERROR_STRING_NV
1	constant GL_NV_fragment_program2
35060	constant GL_MAX_PROGRAM_EXEC_INSTRUCTIONS_NV
35061	constant GL_MAX_PROGRAM_CALL_DEPTH_NV
35062	constant GL_MAX_PROGRAM_IF_DEPTH_NV
35063	constant GL_MAX_PROGRAM_LOOP_DEPTH_NV
35064	constant GL_MAX_PROGRAM_LOOP_COUNT_NV
1	constant GL_NV_fragment_program4
1	constant GL_NV_fragment_program_option
1	constant GL_NV_fragment_shader_interlock
1	constant GL_NV_framebuffer_mixed_samples
37681	constant GL_COVERAGE_MODULATION_TABLE_NV
36384	constant GL_COLOR_SAMPLES_NV
37677	constant GL_DEPTH_SAMPLES_NV
37678	constant GL_STENCIL_SAMPLES_NV
37679	constant GL_MIXED_DEPTH_SAMPLES_SUPPORTED_NV
37680	constant GL_MIXED_STENCIL_SAMPLES_SUPPORTED_NV
37682	constant GL_COVERAGE_MODULATION_NV
37683	constant GL_COVERAGE_MODULATION_TABLE_SIZE_NV
1	constant GL_NV_framebuffer_multisample_coverage
36011	constant GL_RENDERBUFFER_COVERAGE_SAMPLES_NV
36368	constant GL_RENDERBUFFER_COLOR_SAMPLES_NV
36369	constant GL_MAX_MULTISAMPLE_COVERAGE_MODES_NV
36370	constant GL_MULTISAMPLE_COVERAGE_MODES_NV
1	constant GL_NV_geometry_program4
35878	constant GL_GEOMETRY_PROGRAM_NV
35879	constant GL_MAX_PROGRAM_OUTPUT_VERTICES_NV
35880	constant GL_MAX_PROGRAM_TOTAL_OUTPUT_COMPONENTS_NV
1	constant GL_NV_geometry_shader4
1	constant GL_NV_geometry_shader_passthrough
1	constant GL_NV_gpu_program4
35076	constant GL_MIN_PROGRAM_TEXEL_OFFSET_NV
35077	constant GL_MAX_PROGRAM_TEXEL_OFFSET_NV
35078	constant GL_PROGRAM_ATTRIB_COMPONENTS_NV
35079	constant GL_PROGRAM_RESULT_COMPONENTS_NV
35080	constant GL_MAX_PROGRAM_ATTRIB_COMPONENTS_NV
35081	constant GL_MAX_PROGRAM_RESULT_COMPONENTS_NV
36261	constant GL_MAX_PROGRAM_GENERIC_ATTRIBS_NV
36262	constant GL_MAX_PROGRAM_GENERIC_RESULTS_NV
1	constant GL_NV_gpu_program5
36442	constant GL_MAX_GEOMETRY_PROGRAM_INVOCATIONS_NV
36443	constant GL_MIN_FRAGMENT_INTERPOLATION_OFFSET_NV
36444	constant GL_MAX_FRAGMENT_INTERPOLATION_OFFSET_NV
36445	constant GL_FRAGMENT_PROGRAM_INTERPOLATION_OFFSET_BITS_NV
36446	constant GL_MIN_PROGRAM_TEXTURE_GATHER_OFFSET_NV
36447	constant GL_MAX_PROGRAM_TEXTURE_GATHER_OFFSET_NV
36676	constant GL_MAX_PROGRAM_SUBROUTINE_PARAMETERS_NV
36677	constant GL_MAX_PROGRAM_SUBROUTINE_NUM_NV
1	constant GL_NV_gpu_program5_mem_extended
1	constant GL_NV_gpu_shader5
1	constant GL_NV_half_float
5131	constant GL_HALF_FLOAT_NV
1	constant GL_NV_internalformat_sample_query
37745	constant GL_MULTISAMPLES_NV
37746	constant GL_SUPERSAMPLE_SCALE_X_NV
37747	constant GL_SUPERSAMPLE_SCALE_Y_NV
37748	constant GL_CONFORMANT_NV
1	constant GL_NV_light_max_exponent
34052	constant GL_MAX_SHININESS_NV
34053	constant GL_MAX_SPOT_EXPONENT_NV
1	constant GL_NV_multisample_coverage
1	constant GL_NV_multisample_filter_hint
34100	constant GL_MULTISAMPLE_FILTER_HINT_NV
1	constant GL_NV_occlusion_query
34916	constant GL_PIXEL_COUNTER_BITS_NV
34917	constant GL_CURRENT_OCCLUSION_QUERY_ID_NV
34918	constant GL_PIXEL_COUNT_NV
34919	constant GL_PIXEL_COUNT_AVAILABLE_NV
1	constant GL_NV_packed_depth_stencil
34041	constant GL_DEPTH_STENCIL_NV
34042	constant GL_UNSIGNED_INT_24_8_NV
1	constant GL_NV_parameter_buffer_object
36256	constant GL_MAX_PROGRAM_PARAMETER_BUFFER_BINDINGS_NV
36257	constant GL_MAX_PROGRAM_PARAMETER_BUFFER_SIZE_NV
36258	constant GL_VERTEX_PROGRAM_PARAMETER_BUFFER_NV
36259	constant GL_GEOMETRY_PROGRAM_PARAMETER_BUFFER_NV
36260	constant GL_FRAGMENT_PROGRAM_PARAMETER_BUFFER_NV
1	constant GL_NV_parameter_buffer_object2
1	constant GL_NV_path_rendering
36976	constant GL_PATH_FORMAT_SVG_NV
36977	constant GL_PATH_FORMAT_PS_NV
36978	constant GL_STANDARD_FONT_NAME_NV
36979	constant GL_SYSTEM_FONT_NAME_NV
36980	constant GL_FILE_NAME_NV
36981	constant GL_PATH_STROKE_WIDTH_NV
36982	constant GL_PATH_END_CAPS_NV
36983	constant GL_PATH_INITIAL_END_CAP_NV
36984	constant GL_PATH_TERMINAL_END_CAP_NV
36985	constant GL_PATH_JOIN_STYLE_NV
36986	constant GL_PATH_MITER_LIMIT_NV
36987	constant GL_PATH_DASH_CAPS_NV
36988	constant GL_PATH_INITIAL_DASH_CAP_NV
36989	constant GL_PATH_TERMINAL_DASH_CAP_NV
36990	constant GL_PATH_DASH_OFFSET_NV
36991	constant GL_PATH_CLIENT_LENGTH_NV
36992	constant GL_PATH_FILL_MODE_NV
36993	constant GL_PATH_FILL_MASK_NV
36994	constant GL_PATH_FILL_COVER_MODE_NV
36995	constant GL_PATH_STROKE_COVER_MODE_NV
36996	constant GL_PATH_STROKE_MASK_NV
37000	constant GL_COUNT_UP_NV
37001	constant GL_COUNT_DOWN_NV
37002	constant GL_PATH_OBJECT_BOUNDING_BOX_NV
37003	constant GL_CONVEX_HULL_NV
37005	constant GL_BOUNDING_BOX_NV
37006	constant GL_TRANSLATE_X_NV
37007	constant GL_TRANSLATE_Y_NV
37008	constant GL_TRANSLATE_2D_NV
37009	constant GL_TRANSLATE_3D_NV
37010	constant GL_AFFINE_2D_NV
37012	constant GL_AFFINE_3D_NV
37014	constant GL_TRANSPOSE_AFFINE_2D_NV
37016	constant GL_TRANSPOSE_AFFINE_3D_NV
37018	constant GL_UTF8_NV
37019	constant GL_UTF16_NV
37020	constant GL_BOUNDING_BOX_OF_BOUNDING_BOXES_NV
37021	constant GL_PATH_COMMAND_COUNT_NV
37022	constant GL_PATH_COORD_COUNT_NV
37023	constant GL_PATH_DASH_ARRAY_COUNT_NV
37024	constant GL_PATH_COMPUTED_LENGTH_NV
37025	constant GL_PATH_FILL_BOUNDING_BOX_NV
37026	constant GL_PATH_STROKE_BOUNDING_BOX_NV
37027	constant GL_SQUARE_NV
37028	constant GL_ROUND_NV
37029	constant GL_TRIANGULAR_NV
37030	constant GL_BEVEL_NV
37031	constant GL_MITER_REVERT_NV
37032	constant GL_MITER_TRUNCATE_NV
37033	constant GL_SKIP_MISSING_GLYPH_NV
37034	constant GL_USE_MISSING_GLYPH_NV
37035	constant GL_PATH_ERROR_POSITION_NV
37037	constant GL_ACCUM_ADJACENT_PAIRS_NV
37038	constant GL_ADJACENT_PAIRS_NV
37039	constant GL_FIRST_TO_REST_NV
37040	constant GL_PATH_GEN_MODE_NV
37041	constant GL_PATH_GEN_COEFF_NV
37043	constant GL_PATH_GEN_COMPONENTS_NV
37047	constant GL_PATH_STENCIL_FUNC_NV
37048	constant GL_PATH_STENCIL_REF_NV
37049	constant GL_PATH_STENCIL_VALUE_MASK_NV
37053	constant GL_PATH_STENCIL_DEPTH_OFFSET_FACTOR_NV
37054	constant GL_PATH_STENCIL_DEPTH_OFFSET_UNITS_NV
37055	constant GL_PATH_COVER_DEPTH_FUNC_NV
37044	constant GL_PATH_DASH_OFFSET_RESET_NV
37045	constant GL_MOVE_TO_RESETS_NV
37046	constant GL_MOVE_TO_CONTINUES_NV
0	constant GL_CLOSE_PATH_NV
2	constant GL_MOVE_TO_NV
3	constant GL_RELATIVE_MOVE_TO_NV
4	constant GL_LINE_TO_NV
5	constant GL_RELATIVE_LINE_TO_NV
6	constant GL_HORIZONTAL_LINE_TO_NV
7	constant GL_RELATIVE_HORIZONTAL_LINE_TO_NV
8	constant GL_VERTICAL_LINE_TO_NV
9	constant GL_RELATIVE_VERTICAL_LINE_TO_NV
10	constant GL_QUADRATIC_CURVE_TO_NV
11	constant GL_RELATIVE_QUADRATIC_CURVE_TO_NV
12	constant GL_CUBIC_CURVE_TO_NV
13	constant GL_RELATIVE_CUBIC_CURVE_TO_NV
14	constant GL_SMOOTH_QUADRATIC_CURVE_TO_NV
15	constant GL_RELATIVE_SMOOTH_QUADRATIC_CURVE_TO_NV
16	constant GL_SMOOTH_CUBIC_CURVE_TO_NV
17	constant GL_RELATIVE_SMOOTH_CUBIC_CURVE_TO_NV
18	constant GL_SMALL_CCW_ARC_TO_NV
19	constant GL_RELATIVE_SMALL_CCW_ARC_TO_NV
20	constant GL_SMALL_CW_ARC_TO_NV
21	constant GL_RELATIVE_SMALL_CW_ARC_TO_NV
22	constant GL_LARGE_CCW_ARC_TO_NV
23	constant GL_RELATIVE_LARGE_CCW_ARC_TO_NV
24	constant GL_LARGE_CW_ARC_TO_NV
25	constant GL_RELATIVE_LARGE_CW_ARC_TO_NV
240	constant GL_RESTART_PATH_NV
242	constant GL_DUP_FIRST_CUBIC_CURVE_TO_NV
244	constant GL_DUP_LAST_CUBIC_CURVE_TO_NV
246	constant GL_RECT_NV
248	constant GL_CIRCULAR_CCW_ARC_TO_NV
250	constant GL_CIRCULAR_CW_ARC_TO_NV
252	constant GL_CIRCULAR_TANGENT_ARC_TO_NV
254	constant GL_ARC_TO_NV
255	constant GL_RELATIVE_ARC_TO_NV
1	constant GL_BOLD_BIT_NV
2	constant GL_ITALIC_BIT_NV
1	constant GL_GLYPH_WIDTH_BIT_NV
2	constant GL_GLYPH_HEIGHT_BIT_NV
4	constant GL_GLYPH_HORIZONTAL_BEARING_X_BIT_NV
8	constant GL_GLYPH_HORIZONTAL_BEARING_Y_BIT_NV
16	constant GL_GLYPH_HORIZONTAL_BEARING_ADVANCE_BIT_NV
32	constant GL_GLYPH_VERTICAL_BEARING_X_BIT_NV
64	constant GL_GLYPH_VERTICAL_BEARING_Y_BIT_NV
128	constant GL_GLYPH_VERTICAL_BEARING_ADVANCE_BIT_NV
256	constant GL_GLYPH_HAS_KERNING_BIT_NV
65536	constant GL_FONT_X_MIN_BOUNDS_BIT_NV
131072	constant GL_FONT_Y_MIN_BOUNDS_BIT_NV
262144	constant GL_FONT_X_MAX_BOUNDS_BIT_NV
524288	constant GL_FONT_Y_MAX_BOUNDS_BIT_NV
1048576	constant GL_FONT_UNITS_PER_EM_BIT_NV
2097152	constant GL_FONT_ASCENDER_BIT_NV
4194304	constant GL_FONT_DESCENDER_BIT_NV
8388608	constant GL_FONT_HEIGHT_BIT_NV
16777216	constant GL_FONT_MAX_ADVANCE_WIDTH_BIT_NV
33554432	constant GL_FONT_MAX_ADVANCE_HEIGHT_BIT_NV
67108864	constant GL_FONT_UNDERLINE_POSITION_BIT_NV
134217728	constant GL_FONT_UNDERLINE_THICKNESS_BIT_NV
268435456	constant GL_FONT_HAS_KERNING_BIT_NV
232	constant GL_ROUNDED_RECT_NV
233	constant GL_RELATIVE_ROUNDED_RECT_NV
234	constant GL_ROUNDED_RECT2_NV
235	constant GL_RELATIVE_ROUNDED_RECT2_NV
236	constant GL_ROUNDED_RECT4_NV
237	constant GL_RELATIVE_ROUNDED_RECT4_NV
238	constant GL_ROUNDED_RECT8_NV
239	constant GL_RELATIVE_ROUNDED_RECT8_NV
247	constant GL_RELATIVE_RECT_NV
37736	constant GL_FONT_GLYPHS_AVAILABLE_NV
37737	constant GL_FONT_TARGET_UNAVAILABLE_NV
37738	constant GL_FONT_UNAVAILABLE_NV
37739	constant GL_FONT_UNINTELLIGIBLE_NV
26	constant GL_CONIC_CURVE_TO_NV
27	constant GL_RELATIVE_CONIC_CURVE_TO_NV
536870912	constant GL_FONT_NUM_GLYPH_INDICES_BIT_NV
37740	constant GL_STANDARD_FONT_FORMAT_NV
5127	constant GL_2_BYTES_NV
5128	constant GL_3_BYTES_NV
5129	constant GL_4_BYTES_NV
9216	constant GL_EYE_LINEAR_NV
9217	constant GL_OBJECT_LINEAR_NV
34166	constant GL_CONSTANT_NV
37036	constant GL_PATH_FOG_GEN_MODE_NV
34092	constant GL_PRIMARY_COLOR_NV
34093	constant GL_SECONDARY_COLOR_NV
37042	constant GL_PATH_GEN_COLOR_FORMAT_NV
5889	constant GL_PATH_PROJECTION_NV
5888	constant GL_PATH_MODELVIEW_NV
2979	constant GL_PATH_MODELVIEW_STACK_DEPTH_NV
2982	constant GL_PATH_MODELVIEW_MATRIX_NV
3382	constant GL_PATH_MAX_MODELVIEW_STACK_DEPTH_NV
34019	constant GL_PATH_TRANSPOSE_MODELVIEW_MATRIX_NV
2980	constant GL_PATH_PROJECTION_STACK_DEPTH_NV
2983	constant GL_PATH_PROJECTION_MATRIX_NV
3384	constant GL_PATH_MAX_PROJECTION_STACK_DEPTH_NV
34020	constant GL_PATH_TRANSPOSE_PROJECTION_MATRIX_NV
37741	constant GL_FRAGMENT_INPUT_NV
1	constant GL_NV_path_rendering_shared_edge
192	constant GL_SHARED_EDGE_NV
1	constant GL_NV_pixel_data_range
34936	constant GL_WRITE_PIXEL_DATA_RANGE_NV
34937	constant GL_READ_PIXEL_DATA_RANGE_NV
34938	constant GL_WRITE_PIXEL_DATA_RANGE_LENGTH_NV
34939	constant GL_READ_PIXEL_DATA_RANGE_LENGTH_NV
34940	constant GL_WRITE_PIXEL_DATA_RANGE_POINTER_NV
34941	constant GL_READ_PIXEL_DATA_RANGE_POINTER_NV
1	constant GL_NV_point_sprite
34913	constant GL_POINT_SPRITE_NV
34914	constant GL_COORD_REPLACE_NV
34915	constant GL_POINT_SPRITE_R_MODE_NV
1	constant GL_NV_present_video
36390	constant GL_FRAME_NV
36391	constant GL_FIELDS_NV
36392	constant GL_CURRENT_TIME_NV
36393	constant GL_NUM_FILL_STREAMS_NV
36394	constant GL_PRESENT_TIME_NV
36395	constant GL_PRESENT_DURATION_NV
1	constant GL_NV_primitive_restart
34136	constant GL_PRIMITIVE_RESTART_NV
34137	constant GL_PRIMITIVE_RESTART_INDEX_NV
1	constant GL_NV_register_combiners
34082	constant GL_REGISTER_COMBINERS_NV
34083	constant GL_VARIABLE_A_NV
34084	constant GL_VARIABLE_B_NV
34085	constant GL_VARIABLE_C_NV
34086	constant GL_VARIABLE_D_NV
34087	constant GL_VARIABLE_E_NV
34088	constant GL_VARIABLE_F_NV
34089	constant GL_VARIABLE_G_NV
34090	constant GL_CONSTANT_COLOR0_NV
34091	constant GL_CONSTANT_COLOR1_NV
34094	constant GL_SPARE0_NV
34095	constant GL_SPARE1_NV
34096	constant GL_DISCARD_NV
34097	constant GL_E_TIMES_F_NV
34098	constant GL_SPARE0_PLUS_SECONDARY_COLOR_NV
34102	constant GL_UNSIGNED_IDENTITY_NV
34103	constant GL_UNSIGNED_INVERT_NV
34104	constant GL_EXPAND_NORMAL_NV
34105	constant GL_EXPAND_NEGATE_NV
34106	constant GL_HALF_BIAS_NORMAL_NV
34107	constant GL_HALF_BIAS_NEGATE_NV
34108	constant GL_SIGNED_IDENTITY_NV
34109	constant GL_SIGNED_NEGATE_NV
34110	constant GL_SCALE_BY_TWO_NV
34111	constant GL_SCALE_BY_FOUR_NV
34112	constant GL_SCALE_BY_ONE_HALF_NV
34113	constant GL_BIAS_BY_NEGATIVE_ONE_HALF_NV
34114	constant GL_COMBINER_INPUT_NV
34115	constant GL_COMBINER_MAPPING_NV
34116	constant GL_COMBINER_COMPONENT_USAGE_NV
34117	constant GL_COMBINER_AB_DOT_PRODUCT_NV
34118	constant GL_COMBINER_CD_DOT_PRODUCT_NV
34119	constant GL_COMBINER_MUX_SUM_NV
34120	constant GL_COMBINER_SCALE_NV
34121	constant GL_COMBINER_BIAS_NV
34122	constant GL_COMBINER_AB_OUTPUT_NV
34123	constant GL_COMBINER_CD_OUTPUT_NV
34124	constant GL_COMBINER_SUM_OUTPUT_NV
34125	constant GL_MAX_GENERAL_COMBINERS_NV
34126	constant GL_NUM_GENERAL_COMBINERS_NV
34127	constant GL_COLOR_SUM_CLAMP_NV
34128	constant GL_COMBINER0_NV
34129	constant GL_COMBINER1_NV
34130	constant GL_COMBINER2_NV
34131	constant GL_COMBINER3_NV
34132	constant GL_COMBINER4_NV
34133	constant GL_COMBINER5_NV
34134	constant GL_COMBINER6_NV
34135	constant GL_COMBINER7_NV
1	constant GL_NV_register_combiners2
34101	constant GL_PER_STAGE_CONSTANTS_NV
1	constant GL_NV_sample_locations
37693	constant GL_SAMPLE_LOCATION_SUBPIXEL_BITS_NV
37694	constant GL_SAMPLE_LOCATION_PIXEL_GRID_WIDTH_NV
37695	constant GL_SAMPLE_LOCATION_PIXEL_GRID_HEIGHT_NV
37696	constant GL_PROGRAMMABLE_SAMPLE_LOCATION_TABLE_SIZE_NV
36432	constant GL_SAMPLE_LOCATION_NV
37697	constant GL_PROGRAMMABLE_SAMPLE_LOCATION_NV
37698	constant GL_FRAMEBUFFER_PROGRAMMABLE_SAMPLE_LOCATIONS_NV
37699	constant GL_FRAMEBUFFER_SAMPLE_LOCATION_PIXEL_GRID_NV
1	constant GL_NV_sample_mask_override_coverage
1	constant GL_NV_shader_atomic_counters
1	constant GL_NV_shader_atomic_float
1	constant GL_NV_shader_atomic_fp16_vector
1	constant GL_NV_shader_atomic_int64
1	constant GL_NV_shader_buffer_load
36637	constant GL_BUFFER_GPU_ADDRESS_NV
36660	constant GL_GPU_ADDRESS_NV
36661	constant GL_MAX_SHADER_BUFFER_ADDRESS_NV
1	constant GL_NV_shader_buffer_store
16	constant GL_SHADER_GLOBAL_ACCESS_BARRIER_BIT_NV
1	constant GL_NV_shader_storage_buffer_object
1	constant GL_NV_shader_thread_group
37689	constant GL_WARP_SIZE_NV
37690	constant GL_WARPS_PER_SM_NV
37691	constant GL_SM_COUNT_NV
1	constant GL_NV_shader_thread_shuffle
1	constant GL_NV_tessellation_program5
34520	constant GL_MAX_PROGRAM_PATCH_ATTRIBS_NV
35102	constant GL_TESS_CONTROL_PROGRAM_NV
35103	constant GL_TESS_EVALUATION_PROGRAM_NV
35956	constant GL_TESS_CONTROL_PROGRAM_PARAMETER_BUFFER_NV
35957	constant GL_TESS_EVALUATION_PROGRAM_PARAMETER_BUFFER_NV
1	constant GL_NV_texgen_emboss
34141	constant GL_EMBOSS_LIGHT_NV
34142	constant GL_EMBOSS_CONSTANT_NV
34143	constant GL_EMBOSS_MAP_NV
1	constant GL_NV_texgen_reflection
34065	constant GL_NORMAL_MAP_NV
34066	constant GL_REFLECTION_MAP_NV
1	constant GL_NV_texture_barrier
1	constant GL_NV_texture_compression_vtc
1	constant GL_NV_texture_env_combine4
34051	constant GL_COMBINE4_NV
34179	constant GL_SOURCE3_RGB_NV
34187	constant GL_SOURCE3_ALPHA_NV
34195	constant GL_OPERAND3_RGB_NV
34203	constant GL_OPERAND3_ALPHA_NV
1	constant GL_NV_texture_expand_normal
34959	constant GL_TEXTURE_UNSIGNED_REMAP_MODE_NV
1	constant GL_NV_texture_multisample
36933	constant GL_TEXTURE_COVERAGE_SAMPLES_NV
36934	constant GL_TEXTURE_COLOR_SAMPLES_NV
1	constant GL_NV_texture_rectangle
34037	constant GL_TEXTURE_RECTANGLE_NV
34038	constant GL_TEXTURE_BINDING_RECTANGLE_NV
34039	constant GL_PROXY_TEXTURE_RECTANGLE_NV
34040	constant GL_MAX_RECTANGLE_TEXTURE_SIZE_NV
1	constant GL_NV_texture_shader
34380	constant GL_OFFSET_TEXTURE_RECTANGLE_NV
34381	constant GL_OFFSET_TEXTURE_RECTANGLE_SCALE_NV
34382	constant GL_DOT_PRODUCT_TEXTURE_RECTANGLE_NV
34521	constant GL_RGBA_UNSIGNED_DOT_PRODUCT_MAPPING_NV
34522	constant GL_UNSIGNED_INT_S8_S8_8_8_NV
34523	constant GL_UNSIGNED_INT_8_8_S8_S8_REV_NV
34524	constant GL_DSDT_MAG_INTENSITY_NV
34525	constant GL_SHADER_CONSISTENT_NV
34526	constant GL_TEXTURE_SHADER_NV
34527	constant GL_SHADER_OPERATION_NV
34528	constant GL_CULL_MODES_NV
34529	constant GL_OFFSET_TEXTURE_MATRIX_NV
34530	constant GL_OFFSET_TEXTURE_SCALE_NV
34531	constant GL_OFFSET_TEXTURE_BIAS_NV
34529	constant GL_OFFSET_TEXTURE_2D_MATRIX_NV
34530	constant GL_OFFSET_TEXTURE_2D_SCALE_NV
34531	constant GL_OFFSET_TEXTURE_2D_BIAS_NV
34532	constant GL_PREVIOUS_TEXTURE_INPUT_NV
34533	constant GL_CONST_EYE_NV
34534	constant GL_PASS_THROUGH_NV
34535	constant GL_CULL_FRAGMENT_NV
34536	constant GL_OFFSET_TEXTURE_2D_NV
34537	constant GL_DEPENDENT_AR_TEXTURE_2D_NV
34538	constant GL_DEPENDENT_GB_TEXTURE_2D_NV
34540	constant GL_DOT_PRODUCT_NV
34541	constant GL_DOT_PRODUCT_DEPTH_REPLACE_NV
34542	constant GL_DOT_PRODUCT_TEXTURE_2D_NV
34544	constant GL_DOT_PRODUCT_TEXTURE_CUBE_MAP_NV
34545	constant GL_DOT_PRODUCT_DIFFUSE_CUBE_MAP_NV
34546	constant GL_DOT_PRODUCT_REFLECT_CUBE_MAP_NV
34547	constant GL_DOT_PRODUCT_CONST_EYE_REFLECT_CUBE_MAP_NV
34548	constant GL_HILO_NV
34549	constant GL_DSDT_NV
34550	constant GL_DSDT_MAG_NV
34551	constant GL_DSDT_MAG_VIB_NV
34552	constant GL_HILO16_NV
34553	constant GL_SIGNED_HILO_NV
34554	constant GL_SIGNED_HILO16_NV
34555	constant GL_SIGNED_RGBA_NV
34556	constant GL_SIGNED_RGBA8_NV
34558	constant GL_SIGNED_RGB_NV
34559	constant GL_SIGNED_RGB8_NV
34561	constant GL_SIGNED_LUMINANCE_NV
34562	constant GL_SIGNED_LUMINANCE8_NV
34563	constant GL_SIGNED_LUMINANCE_ALPHA_NV
34564	constant GL_SIGNED_LUMINANCE8_ALPHA8_NV
34565	constant GL_SIGNED_ALPHA_NV
34566	constant GL_SIGNED_ALPHA8_NV
34567	constant GL_SIGNED_INTENSITY_NV
34568	constant GL_SIGNED_INTENSITY8_NV
34569	constant GL_DSDT8_NV
34570	constant GL_DSDT8_MAG8_NV
34571	constant GL_DSDT8_MAG8_INTENSITY8_NV
34572	constant GL_SIGNED_RGB_UNSIGNED_ALPHA_NV
34573	constant GL_SIGNED_RGB8_UNSIGNED_ALPHA8_NV
34574	constant GL_HI_SCALE_NV
34575	constant GL_LO_SCALE_NV
34576	constant GL_DS_SCALE_NV
34577	constant GL_DT_SCALE_NV
34578	constant GL_MAGNITUDE_SCALE_NV
34579	constant GL_VIBRANCE_SCALE_NV
34580	constant GL_HI_BIAS_NV
34581	constant GL_LO_BIAS_NV
34582	constant GL_DS_BIAS_NV
34583	constant GL_DT_BIAS_NV
34584	constant GL_MAGNITUDE_BIAS_NV
34585	constant GL_VIBRANCE_BIAS_NV
34586	constant GL_TEXTURE_BORDER_VALUES_NV
34587	constant GL_TEXTURE_HI_SIZE_NV
34588	constant GL_TEXTURE_LO_SIZE_NV
34589	constant GL_TEXTURE_DS_SIZE_NV
34590	constant GL_TEXTURE_DT_SIZE_NV
34591	constant GL_TEXTURE_MAG_SIZE_NV
1	constant GL_NV_texture_shader2
34543	constant GL_DOT_PRODUCT_TEXTURE_3D_NV
1	constant GL_NV_texture_shader3
34896	constant GL_OFFSET_PROJECTIVE_TEXTURE_2D_NV
34897	constant GL_OFFSET_PROJECTIVE_TEXTURE_2D_SCALE_NV
34898	constant GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_NV
34899	constant GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_SCALE_NV
34900	constant GL_OFFSET_HILO_TEXTURE_2D_NV
34901	constant GL_OFFSET_HILO_TEXTURE_RECTANGLE_NV
34902	constant GL_OFFSET_HILO_PROJECTIVE_TEXTURE_2D_NV
34903	constant GL_OFFSET_HILO_PROJECTIVE_TEXTURE_RECTANGLE_NV
34904	constant GL_DEPENDENT_HILO_TEXTURE_2D_NV
34905	constant GL_DEPENDENT_RGB_TEXTURE_3D_NV
34906	constant GL_DEPENDENT_RGB_TEXTURE_CUBE_MAP_NV
34907	constant GL_DOT_PRODUCT_PASS_THROUGH_NV
34908	constant GL_DOT_PRODUCT_TEXTURE_1D_NV
34909	constant GL_DOT_PRODUCT_AFFINE_DEPTH_REPLACE_NV
34910	constant GL_HILO8_NV
34911	constant GL_SIGNED_HILO8_NV
34912	constant GL_FORCE_BLUE_TO_ONE_NV
1	constant GL_NV_transform_feedback
35959	constant GL_BACK_PRIMARY_COLOR_NV
35960	constant GL_BACK_SECONDARY_COLOR_NV
35961	constant GL_TEXTURE_COORD_NV
35962	constant GL_CLIP_DISTANCE_NV
35963	constant GL_VERTEX_ID_NV
35964	constant GL_PRIMITIVE_ID_NV
35965	constant GL_GENERIC_ATTRIB_NV
35966	constant GL_TRANSFORM_FEEDBACK_ATTRIBS_NV
35967	constant GL_TRANSFORM_FEEDBACK_BUFFER_MODE_NV
35968	constant GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS_NV
35969	constant GL_ACTIVE_VARYINGS_NV
35970	constant GL_ACTIVE_VARYING_MAX_LENGTH_NV
35971	constant GL_TRANSFORM_FEEDBACK_VARYINGS_NV
35972	constant GL_TRANSFORM_FEEDBACK_BUFFER_START_NV
35973	constant GL_TRANSFORM_FEEDBACK_BUFFER_SIZE_NV
35974	constant GL_TRANSFORM_FEEDBACK_RECORD_NV
35975	constant GL_PRIMITIVES_GENERATED_NV
35976	constant GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN_NV
35977	constant GL_RASTERIZER_DISCARD_NV
35978	constant GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS_NV
35979	constant GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS_NV
35980	constant GL_INTERLEAVED_ATTRIBS_NV
35981	constant GL_SEPARATE_ATTRIBS_NV
35982	constant GL_TRANSFORM_FEEDBACK_BUFFER_NV
35983	constant GL_TRANSFORM_FEEDBACK_BUFFER_BINDING_NV
36266	constant GL_LAYER_NV
-2	constant GL_NEXT_BUFFER_NV
-3	constant GL_SKIP_COMPONENTS4_NV
-4	constant GL_SKIP_COMPONENTS3_NV
-5	constant GL_SKIP_COMPONENTS2_NV
-6	constant GL_SKIP_COMPONENTS1_NV
1	constant GL_NV_transform_feedback2
36386	constant GL_TRANSFORM_FEEDBACK_NV
36387	constant GL_TRANSFORM_FEEDBACK_BUFFER_PAUSED_NV
36388	constant GL_TRANSFORM_FEEDBACK_BUFFER_ACTIVE_NV
36389	constant GL_TRANSFORM_FEEDBACK_BINDING_NV
1	constant GL_NV_uniform_buffer_unified_memory
37742	constant GL_UNIFORM_BUFFER_UNIFIED_NV
37743	constant GL_UNIFORM_BUFFER_ADDRESS_NV
37744	constant GL_UNIFORM_BUFFER_LENGTH_NV
1	constant GL_NV_vdpau_interop
34539	constant GL_SURFACE_STATE_NV
34557	constant GL_SURFACE_REGISTERED_NV
34560	constant GL_SURFACE_MAPPED_NV
35006	constant GL_WRITE_DISCARD_NV
1	constant GL_NV_vertex_array_range
34077	constant GL_VERTEX_ARRAY_RANGE_NV
34078	constant GL_VERTEX_ARRAY_RANGE_LENGTH_NV
34079	constant GL_VERTEX_ARRAY_RANGE_VALID_NV
34080	constant GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_NV
34081	constant GL_VERTEX_ARRAY_RANGE_POINTER_NV
1	constant GL_NV_vertex_array_range2
34099	constant GL_VERTEX_ARRAY_RANGE_WITHOUT_FLUSH_NV
1	constant GL_NV_vertex_attrib_integer_64bit
1	constant GL_NV_vertex_buffer_unified_memory
36638	constant GL_VERTEX_ATTRIB_ARRAY_UNIFIED_NV
36639	constant GL_ELEMENT_ARRAY_UNIFIED_NV
36640	constant GL_VERTEX_ATTRIB_ARRAY_ADDRESS_NV
36641	constant GL_VERTEX_ARRAY_ADDRESS_NV
36642	constant GL_NORMAL_ARRAY_ADDRESS_NV
36643	constant GL_COLOR_ARRAY_ADDRESS_NV
36644	constant GL_INDEX_ARRAY_ADDRESS_NV
36645	constant GL_TEXTURE_COORD_ARRAY_ADDRESS_NV
36646	constant GL_EDGE_FLAG_ARRAY_ADDRESS_NV
36647	constant GL_SECONDARY_COLOR_ARRAY_ADDRESS_NV
36648	constant GL_FOG_COORD_ARRAY_ADDRESS_NV
36649	constant GL_ELEMENT_ARRAY_ADDRESS_NV
36650	constant GL_VERTEX_ATTRIB_ARRAY_LENGTH_NV
36651	constant GL_VERTEX_ARRAY_LENGTH_NV
36652	constant GL_NORMAL_ARRAY_LENGTH_NV
36653	constant GL_COLOR_ARRAY_LENGTH_NV
36654	constant GL_INDEX_ARRAY_LENGTH_NV
36655	constant GL_TEXTURE_COORD_ARRAY_LENGTH_NV
36656	constant GL_EDGE_FLAG_ARRAY_LENGTH_NV
36657	constant GL_SECONDARY_COLOR_ARRAY_LENGTH_NV
36658	constant GL_FOG_COORD_ARRAY_LENGTH_NV
36659	constant GL_ELEMENT_ARRAY_LENGTH_NV
36672	constant GL_DRAW_INDIRECT_UNIFIED_NV
36673	constant GL_DRAW_INDIRECT_ADDRESS_NV
36674	constant GL_DRAW_INDIRECT_LENGTH_NV
1	constant GL_NV_vertex_program
34336	constant GL_VERTEX_PROGRAM_NV
34337	constant GL_VERTEX_STATE_PROGRAM_NV
34339	constant GL_ATTRIB_ARRAY_SIZE_NV
34340	constant GL_ATTRIB_ARRAY_STRIDE_NV
34341	constant GL_ATTRIB_ARRAY_TYPE_NV
34342	constant GL_CURRENT_ATTRIB_NV
34343	constant GL_PROGRAM_LENGTH_NV
34344	constant GL_PROGRAM_STRING_NV
34345	constant GL_MODELVIEW_PROJECTION_NV
34346	constant GL_IDENTITY_NV
34347	constant GL_INVERSE_NV
34348	constant GL_TRANSPOSE_NV
34349	constant GL_INVERSE_TRANSPOSE_NV
34350	constant GL_MAX_TRACK_MATRIX_STACK_DEPTH_NV
34351	constant GL_MAX_TRACK_MATRICES_NV
34352	constant GL_MATRIX0_NV
34353	constant GL_MATRIX1_NV
34354	constant GL_MATRIX2_NV
34355	constant GL_MATRIX3_NV
34356	constant GL_MATRIX4_NV
34357	constant GL_MATRIX5_NV
34358	constant GL_MATRIX6_NV
34359	constant GL_MATRIX7_NV
34368	constant GL_CURRENT_MATRIX_STACK_DEPTH_NV
34369	constant GL_CURRENT_MATRIX_NV
34370	constant GL_VERTEX_PROGRAM_POINT_SIZE_NV
34371	constant GL_VERTEX_PROGRAM_TWO_SIDE_NV
34372	constant GL_PROGRAM_PARAMETER_NV
34373	constant GL_ATTRIB_ARRAY_POINTER_NV
34374	constant GL_PROGRAM_TARGET_NV
34375	constant GL_PROGRAM_RESIDENT_NV
34376	constant GL_TRACK_MATRIX_NV
34377	constant GL_TRACK_MATRIX_TRANSFORM_NV
34378	constant GL_VERTEX_PROGRAM_BINDING_NV
34379	constant GL_PROGRAM_ERROR_POSITION_NV
34384	constant GL_VERTEX_ATTRIB_ARRAY0_NV
34385	constant GL_VERTEX_ATTRIB_ARRAY1_NV
34386	constant GL_VERTEX_ATTRIB_ARRAY2_NV
34387	constant GL_VERTEX_ATTRIB_ARRAY3_NV
34388	constant GL_VERTEX_ATTRIB_ARRAY4_NV
34389	constant GL_VERTEX_ATTRIB_ARRAY5_NV
34390	constant GL_VERTEX_ATTRIB_ARRAY6_NV
34391	constant GL_VERTEX_ATTRIB_ARRAY7_NV
34392	constant GL_VERTEX_ATTRIB_ARRAY8_NV
34393	constant GL_VERTEX_ATTRIB_ARRAY9_NV
34394	constant GL_VERTEX_ATTRIB_ARRAY10_NV
34395	constant GL_VERTEX_ATTRIB_ARRAY11_NV
34396	constant GL_VERTEX_ATTRIB_ARRAY12_NV
34397	constant GL_VERTEX_ATTRIB_ARRAY13_NV
34398	constant GL_VERTEX_ATTRIB_ARRAY14_NV
34399	constant GL_VERTEX_ATTRIB_ARRAY15_NV
34400	constant GL_MAP1_VERTEX_ATTRIB0_4_NV
34401	constant GL_MAP1_VERTEX_ATTRIB1_4_NV
34402	constant GL_MAP1_VERTEX_ATTRIB2_4_NV
34403	constant GL_MAP1_VERTEX_ATTRIB3_4_NV
34404	constant GL_MAP1_VERTEX_ATTRIB4_4_NV
34405	constant GL_MAP1_VERTEX_ATTRIB5_4_NV
34406	constant GL_MAP1_VERTEX_ATTRIB6_4_NV
34407	constant GL_MAP1_VERTEX_ATTRIB7_4_NV
34408	constant GL_MAP1_VERTEX_ATTRIB8_4_NV
34409	constant GL_MAP1_VERTEX_ATTRIB9_4_NV
34410	constant GL_MAP1_VERTEX_ATTRIB10_4_NV
34411	constant GL_MAP1_VERTEX_ATTRIB11_4_NV
34412	constant GL_MAP1_VERTEX_ATTRIB12_4_NV
34413	constant GL_MAP1_VERTEX_ATTRIB13_4_NV
34414	constant GL_MAP1_VERTEX_ATTRIB14_4_NV
34415	constant GL_MAP1_VERTEX_ATTRIB15_4_NV
34416	constant GL_MAP2_VERTEX_ATTRIB0_4_NV
34417	constant GL_MAP2_VERTEX_ATTRIB1_4_NV
34418	constant GL_MAP2_VERTEX_ATTRIB2_4_NV
34419	constant GL_MAP2_VERTEX_ATTRIB3_4_NV
34420	constant GL_MAP2_VERTEX_ATTRIB4_4_NV
34421	constant GL_MAP2_VERTEX_ATTRIB5_4_NV
34422	constant GL_MAP2_VERTEX_ATTRIB6_4_NV
34423	constant GL_MAP2_VERTEX_ATTRIB7_4_NV
34424	constant GL_MAP2_VERTEX_ATTRIB8_4_NV
34425	constant GL_MAP2_VERTEX_ATTRIB9_4_NV
34426	constant GL_MAP2_VERTEX_ATTRIB10_4_NV
34427	constant GL_MAP2_VERTEX_ATTRIB11_4_NV
34428	constant GL_MAP2_VERTEX_ATTRIB12_4_NV
34429	constant GL_MAP2_VERTEX_ATTRIB13_4_NV
34430	constant GL_MAP2_VERTEX_ATTRIB14_4_NV
34431	constant GL_MAP2_VERTEX_ATTRIB15_4_NV
1	constant GL_NV_vertex_program1_1
1	constant GL_NV_vertex_program2
1	constant GL_NV_vertex_program2_option
1	constant GL_NV_vertex_program3
1	constant GL_NV_vertex_program4
35069	constant GL_VERTEX_ATTRIB_ARRAY_INTEGER_NV
1	constant GL_NV_video_capture
36896	constant GL_VIDEO_BUFFER_NV
36897	constant GL_VIDEO_BUFFER_BINDING_NV
36898	constant GL_FIELD_UPPER_NV
36899	constant GL_FIELD_LOWER_NV
36900	constant GL_NUM_VIDEO_CAPTURE_STREAMS_NV
36901	constant GL_NEXT_VIDEO_CAPTURE_BUFFER_STATUS_NV
36902	constant GL_VIDEO_CAPTURE_TO_422_SUPPORTED_NV
36903	constant GL_LAST_VIDEO_CAPTURE_STATUS_NV
36904	constant GL_VIDEO_BUFFER_PITCH_NV
36905	constant GL_VIDEO_COLOR_CONVERSION_MATRIX_NV
36906	constant GL_VIDEO_COLOR_CONVERSION_MAX_NV
36907	constant GL_VIDEO_COLOR_CONVERSION_MIN_NV
36908	constant GL_VIDEO_COLOR_CONVERSION_OFFSET_NV
36909	constant GL_VIDEO_BUFFER_INTERNAL_FORMAT_NV
36910	constant GL_PARTIAL_SUCCESS_NV
36911	constant GL_SUCCESS_NV
36912	constant GL_FAILURE_NV
36913	constant GL_YCBYCR8_422_NV
36914	constant GL_YCBAYCR8A_4224_NV
36915	constant GL_Z6Y10Z6CB10Z6Y10Z6CR10_422_NV
36916	constant GL_Z6Y10Z6CB10Z6A10Z6Y10Z6CR10Z6A10_4224_NV
36917	constant GL_Z4Y12Z4CB12Z4Y12Z4CR12_422_NV
36918	constant GL_Z4Y12Z4CB12Z4A12Z4Y12Z4CR12Z4A12_4224_NV
36919	constant GL_Z4Y12Z4CB12Z4CR12_444_NV
36920	constant GL_VIDEO_CAPTURE_FRAME_WIDTH_NV
36921	constant GL_VIDEO_CAPTURE_FRAME_HEIGHT_NV
36922	constant GL_VIDEO_CAPTURE_FIELD_UPPER_HEIGHT_NV
36923	constant GL_VIDEO_CAPTURE_FIELD_LOWER_HEIGHT_NV
36924	constant GL_VIDEO_CAPTURE_SURFACE_ORIGIN_NV
1	constant GL_NV_viewport_array2
1	constant GL_OML_interlace
35200	constant GL_INTERLACE_OML
35201	constant GL_INTERLACE_READ_OML
1	constant GL_OML_resample
35204	constant GL_PACK_RESAMPLE_OML
35205	constant GL_UNPACK_RESAMPLE_OML
35206	constant GL_RESAMPLE_REPLICATE_OML
35207	constant GL_RESAMPLE_ZERO_FILL_OML
35208	constant GL_RESAMPLE_AVERAGE_OML
35209	constant GL_RESAMPLE_DECIMATE_OML
1	constant GL_OML_subsample
35202	constant GL_FORMAT_SUBSAMPLE_24_24_OML
35203	constant GL_FORMAT_SUBSAMPLE_244_244_OML
1	constant GL_PGI_misc_hints
107000	constant GL_PREFER_DOUBLEBUFFER_HINT_PGI
107005	constant GL_CONSERVE_MEMORY_HINT_PGI
107006	constant GL_RECLAIM_MEMORY_HINT_PGI
107010	constant GL_NATIVE_GRAPHICS_HANDLE_PGI
107011	constant GL_NATIVE_GRAPHICS_BEGIN_HINT_PGI
107012	constant GL_NATIVE_GRAPHICS_END_HINT_PGI
107020	constant GL_ALWAYS_FAST_HINT_PGI
107021	constant GL_ALWAYS_SOFT_HINT_PGI
107022	constant GL_ALLOW_DRAW_OBJ_HINT_PGI
107023	constant GL_ALLOW_DRAW_WIN_HINT_PGI
107024	constant GL_ALLOW_DRAW_FRG_HINT_PGI
107025	constant GL_ALLOW_DRAW_MEM_HINT_PGI
107030	constant GL_STRICT_DEPTHFUNC_HINT_PGI
107031	constant GL_STRICT_LIGHTING_HINT_PGI
107032	constant GL_STRICT_SCISSOR_HINT_PGI
107033	constant GL_FULL_STIPPLE_HINT_PGI
107040	constant GL_CLIP_NEAR_HINT_PGI
107041	constant GL_CLIP_FAR_HINT_PGI
107042	constant GL_WIDE_LINE_HINT_PGI
107043	constant GL_BACK_NORMALS_HINT_PGI
1	constant GL_PGI_vertex_hints
107050	constant GL_VERTEX_DATA_HINT_PGI
107051	constant GL_VERTEX_CONSISTENT_HINT_PGI
107052	constant GL_MATERIAL_SIDE_HINT_PGI
107053	constant GL_MAX_VERTEX_HINT_PGI
65536	constant GL_COLOR3_BIT_PGI
131072	constant GL_COLOR4_BIT_PGI
262144	constant GL_EDGEFLAG_BIT_PGI
524288	constant GL_INDEX_BIT_PGI
1048576	constant GL_MAT_AMBIENT_BIT_PGI
2097152	constant GL_MAT_AMBIENT_AND_DIFFUSE_BIT_PGI
4194304	constant GL_MAT_DIFFUSE_BIT_PGI
8388608	constant GL_MAT_EMISSION_BIT_PGI
16777216	constant GL_MAT_COLOR_INDEXES_BIT_PGI
33554432	constant GL_MAT_SHININESS_BIT_PGI
67108864	constant GL_MAT_SPECULAR_BIT_PGI
134217728	constant GL_NORMAL_BIT_PGI
268435456	constant GL_TEXCOORD1_BIT_PGI
536870912	constant GL_TEXCOORD2_BIT_PGI
1073741824	constant GL_TEXCOORD3_BIT_PGI
2147483648	constant GL_TEXCOORD4_BIT_PGI
4	constant GL_VERTEX23_BIT_PGI
8	constant GL_VERTEX4_BIT_PGI
1	constant GL_REND_screen_coordinates
33936	constant GL_SCREEN_COORDINATES_REND
33937	constant GL_INVERTED_SCREEN_W_REND
1	constant GL_S3_s3tc
33696	constant GL_RGB_S3TC
33697	constant GL_RGB4_S3TC
33698	constant GL_RGBA_S3TC
33699	constant GL_RGBA4_S3TC
33700	constant GL_RGBA_DXT5_S3TC
33701	constant GL_RGBA4_DXT5_S3TC
1	constant GL_SGIS_detail_texture
32917	constant GL_DETAIL_TEXTURE_2D_SGIS
32918	constant GL_DETAIL_TEXTURE_2D_BINDING_SGIS
32919	constant GL_LINEAR_DETAIL_SGIS
32920	constant GL_LINEAR_DETAIL_ALPHA_SGIS
32921	constant GL_LINEAR_DETAIL_COLOR_SGIS
32922	constant GL_DETAIL_TEXTURE_LEVEL_SGIS
32923	constant GL_DETAIL_TEXTURE_MODE_SGIS
32924	constant GL_DETAIL_TEXTURE_FUNC_POINTS_SGIS
1	constant GL_SGIS_fog_function
33066	constant GL_FOG_FUNC_SGIS
33067	constant GL_FOG_FUNC_POINTS_SGIS
33068	constant GL_MAX_FOG_FUNC_POINTS_SGIS
1	constant GL_SGIS_generate_mipmap
33169	constant GL_GENERATE_MIPMAP_SGIS
33170	constant GL_GENERATE_MIPMAP_HINT_SGIS
1	constant GL_SGIS_multisample
32925	constant GL_MULTISAMPLE_SGIS
32926	constant GL_SAMPLE_ALPHA_TO_MASK_SGIS
32927	constant GL_SAMPLE_ALPHA_TO_ONE_SGIS
32928	constant GL_SAMPLE_MASK_SGIS
32929	constant GL_1PASS_SGIS
32930	constant GL_2PASS_0_SGIS
32931	constant GL_2PASS_1_SGIS
32932	constant GL_4PASS_0_SGIS
32933	constant GL_4PASS_1_SGIS
32934	constant GL_4PASS_2_SGIS
32935	constant GL_4PASS_3_SGIS
32936	constant GL_SAMPLE_BUFFERS_SGIS
32937	constant GL_SAMPLES_SGIS
32938	constant GL_SAMPLE_MASK_VALUE_SGIS
32939	constant GL_SAMPLE_MASK_INVERT_SGIS
32940	constant GL_SAMPLE_PATTERN_SGIS
1	constant GL_SGIS_pixel_texture
33619	constant GL_PIXEL_TEXTURE_SGIS
33620	constant GL_PIXEL_FRAGMENT_RGB_SOURCE_SGIS
33621	constant GL_PIXEL_FRAGMENT_ALPHA_SOURCE_SGIS
33622	constant GL_PIXEL_GROUP_COLOR_SGIS
1	constant GL_SGIS_point_line_texgen
33264	constant GL_EYE_DISTANCE_TO_POINT_SGIS
33265	constant GL_OBJECT_DISTANCE_TO_POINT_SGIS
33266	constant GL_EYE_DISTANCE_TO_LINE_SGIS
33267	constant GL_OBJECT_DISTANCE_TO_LINE_SGIS
33268	constant GL_EYE_POINT_SGIS
33269	constant GL_OBJECT_POINT_SGIS
33270	constant GL_EYE_LINE_SGIS
33271	constant GL_OBJECT_LINE_SGIS
1	constant GL_SGIS_point_parameters
33062	constant GL_POINT_SIZE_MIN_SGIS
33063	constant GL_POINT_SIZE_MAX_SGIS
33064	constant GL_POINT_FADE_THRESHOLD_SIZE_SGIS
33065	constant GL_DISTANCE_ATTENUATION_SGIS
1	constant GL_SGIS_sharpen_texture
32941	constant GL_LINEAR_SHARPEN_SGIS
32942	constant GL_LINEAR_SHARPEN_ALPHA_SGIS
32943	constant GL_LINEAR_SHARPEN_COLOR_SGIS
32944	constant GL_SHARPEN_TEXTURE_FUNC_POINTS_SGIS
1	constant GL_SGIS_texture4D
33072	constant GL_PACK_SKIP_VOLUMES_SGIS
33073	constant GL_PACK_IMAGE_DEPTH_SGIS
33074	constant GL_UNPACK_SKIP_VOLUMES_SGIS
33075	constant GL_UNPACK_IMAGE_DEPTH_SGIS
33076	constant GL_TEXTURE_4D_SGIS
33077	constant GL_PROXY_TEXTURE_4D_SGIS
33078	constant GL_TEXTURE_4DSIZE_SGIS
33079	constant GL_TEXTURE_WRAP_Q_SGIS
33080	constant GL_MAX_4D_TEXTURE_SIZE_SGIS
33103	constant GL_TEXTURE_4D_BINDING_SGIS
1	constant GL_SGIS_texture_border_clamp
33069	constant GL_CLAMP_TO_BORDER_SGIS
1	constant GL_SGIS_texture_color_mask
33263	constant GL_TEXTURE_COLOR_WRITEMASK_SGIS
1	constant GL_SGIS_texture_edge_clamp
33071	constant GL_CLAMP_TO_EDGE_SGIS
1	constant GL_SGIS_texture_filter4
33094	constant GL_FILTER4_SGIS
33095	constant GL_TEXTURE_FILTER4_SIZE_SGIS
1	constant GL_SGIS_texture_lod
33082	constant GL_TEXTURE_MIN_LOD_SGIS
33083	constant GL_TEXTURE_MAX_LOD_SGIS
33084	constant GL_TEXTURE_BASE_LEVEL_SGIS
33085	constant GL_TEXTURE_MAX_LEVEL_SGIS
1	constant GL_SGIS_texture_select
33040	constant GL_DUAL_ALPHA4_SGIS
33041	constant GL_DUAL_ALPHA8_SGIS
33042	constant GL_DUAL_ALPHA12_SGIS
33043	constant GL_DUAL_ALPHA16_SGIS
33044	constant GL_DUAL_LUMINANCE4_SGIS
33045	constant GL_DUAL_LUMINANCE8_SGIS
33046	constant GL_DUAL_LUMINANCE12_SGIS
33047	constant GL_DUAL_LUMINANCE16_SGIS
33048	constant GL_DUAL_INTENSITY4_SGIS
33049	constant GL_DUAL_INTENSITY8_SGIS
33050	constant GL_DUAL_INTENSITY12_SGIS
33051	constant GL_DUAL_INTENSITY16_SGIS
33052	constant GL_DUAL_LUMINANCE_ALPHA4_SGIS
33053	constant GL_DUAL_LUMINANCE_ALPHA8_SGIS
33054	constant GL_QUAD_ALPHA4_SGIS
33055	constant GL_QUAD_ALPHA8_SGIS
33056	constant GL_QUAD_LUMINANCE4_SGIS
33057	constant GL_QUAD_LUMINANCE8_SGIS
33058	constant GL_QUAD_INTENSITY4_SGIS
33059	constant GL_QUAD_INTENSITY8_SGIS
33060	constant GL_DUAL_TEXTURE_SELECT_SGIS
33061	constant GL_QUAD_TEXTURE_SELECT_SGIS
1	constant GL_SGIX_async
33577	constant GL_ASYNC_MARKER_SGIX
1	constant GL_SGIX_async_histogram
33580	constant GL_ASYNC_HISTOGRAM_SGIX
33581	constant GL_MAX_ASYNC_HISTOGRAM_SGIX
1	constant GL_SGIX_async_pixel
33628	constant GL_ASYNC_TEX_IMAGE_SGIX
33629	constant GL_ASYNC_DRAW_PIXELS_SGIX
33630	constant GL_ASYNC_READ_PIXELS_SGIX
33631	constant GL_MAX_ASYNC_TEX_IMAGE_SGIX
33632	constant GL_MAX_ASYNC_DRAW_PIXELS_SGIX
33633	constant GL_MAX_ASYNC_READ_PIXELS_SGIX
1	constant GL_SGIX_blend_alpha_minmax
33568	constant GL_ALPHA_MIN_SGIX
33569	constant GL_ALPHA_MAX_SGIX
1	constant GL_SGIX_calligraphic_fragment
33155	constant GL_CALLIGRAPHIC_FRAGMENT_SGIX
1	constant GL_SGIX_clipmap
33136	constant GL_LINEAR_CLIPMAP_LINEAR_SGIX
33137	constant GL_TEXTURE_CLIPMAP_CENTER_SGIX
33138	constant GL_TEXTURE_CLIPMAP_FRAME_SGIX
33139	constant GL_TEXTURE_CLIPMAP_OFFSET_SGIX
33140	constant GL_TEXTURE_CLIPMAP_VIRTUAL_DEPTH_SGIX
33141	constant GL_TEXTURE_CLIPMAP_LOD_OFFSET_SGIX
33142	constant GL_TEXTURE_CLIPMAP_DEPTH_SGIX
33143	constant GL_MAX_CLIPMAP_DEPTH_SGIX
33144	constant GL_MAX_CLIPMAP_VIRTUAL_DEPTH_SGIX
33869	constant GL_NEAREST_CLIPMAP_NEAREST_SGIX
33870	constant GL_NEAREST_CLIPMAP_LINEAR_SGIX
33871	constant GL_LINEAR_CLIPMAP_NEAREST_SGIX
1	constant GL_SGIX_convolution_accuracy
33558	constant GL_CONVOLUTION_HINT_SGIX
1	constant GL_SGIX_depth_pass_instrument
1	constant GL_SGIX_depth_texture
33189	constant GL_DEPTH_COMPONENT16_SGIX
33190	constant GL_DEPTH_COMPONENT24_SGIX
33191	constant GL_DEPTH_COMPONENT32_SGIX
1	constant GL_SGIX_flush_raster
1	constant GL_SGIX_fog_offset
33176	constant GL_FOG_OFFSET_SGIX
33177	constant GL_FOG_OFFSET_VALUE_SGIX
1	constant GL_SGIX_fragment_lighting
33792	constant GL_FRAGMENT_LIGHTING_SGIX
33793	constant GL_FRAGMENT_COLOR_MATERIAL_SGIX
33794	constant GL_FRAGMENT_COLOR_MATERIAL_FACE_SGIX
33795	constant GL_FRAGMENT_COLOR_MATERIAL_PARAMETER_SGIX
33796	constant GL_MAX_FRAGMENT_LIGHTS_SGIX
33797	constant GL_MAX_ACTIVE_LIGHTS_SGIX
33798	constant GL_CURRENT_RASTER_NORMAL_SGIX
33799	constant GL_LIGHT_ENV_MODE_SGIX
33800	constant GL_FRAGMENT_LIGHT_MODEL_LOCAL_VIEWER_SGIX
33801	constant GL_FRAGMENT_LIGHT_MODEL_TWO_SIDE_SGIX
33802	constant GL_FRAGMENT_LIGHT_MODEL_AMBIENT_SGIX
33803	constant GL_FRAGMENT_LIGHT_MODEL_NORMAL_INTERPOLATION_SGIX
33804	constant GL_FRAGMENT_LIGHT0_SGIX
33805	constant GL_FRAGMENT_LIGHT1_SGIX
33806	constant GL_FRAGMENT_LIGHT2_SGIX
33807	constant GL_FRAGMENT_LIGHT3_SGIX
33808	constant GL_FRAGMENT_LIGHT4_SGIX
33809	constant GL_FRAGMENT_LIGHT5_SGIX
33810	constant GL_FRAGMENT_LIGHT6_SGIX
33811	constant GL_FRAGMENT_LIGHT7_SGIX
1	constant GL_SGIX_framezoom
33163	constant GL_FRAMEZOOM_SGIX
33164	constant GL_FRAMEZOOM_FACTOR_SGIX
33165	constant GL_MAX_FRAMEZOOM_FACTOR_SGIX
1	constant GL_SGIX_igloo_interface
1	constant GL_SGIX_instruments
33152	constant GL_INSTRUMENT_BUFFER_POINTER_SGIX
33153	constant GL_INSTRUMENT_MEASUREMENTS_SGIX
1	constant GL_SGIX_interlace
32916	constant GL_INTERLACE_SGIX
1	constant GL_SGIX_ir_instrument1
33151	constant GL_IR_INSTRUMENT1_SGIX
1	constant GL_SGIX_list_priority
33154	constant GL_LIST_PRIORITY_SGIX
1	constant GL_SGIX_pixel_texture
33081	constant GL_PIXEL_TEX_GEN_SGIX
33579	constant GL_PIXEL_TEX_GEN_MODE_SGIX
1	constant GL_SGIX_pixel_tiles
33086	constant GL_PIXEL_TILE_BEST_ALIGNMENT_SGIX
33087	constant GL_PIXEL_TILE_CACHE_INCREMENT_SGIX
33088	constant GL_PIXEL_TILE_WIDTH_SGIX
33089	constant GL_PIXEL_TILE_HEIGHT_SGIX
33090	constant GL_PIXEL_TILE_GRID_WIDTH_SGIX
33091	constant GL_PIXEL_TILE_GRID_HEIGHT_SGIX
33092	constant GL_PIXEL_TILE_GRID_DEPTH_SGIX
33093	constant GL_PIXEL_TILE_CACHE_SIZE_SGIX
1	constant GL_SGIX_polynomial_ffd
1	constant GL_TEXTURE_DEFORMATION_BIT_SGIX
2	constant GL_GEOMETRY_DEFORMATION_BIT_SGIX
33172	constant GL_GEOMETRY_DEFORMATION_SGIX
33173	constant GL_TEXTURE_DEFORMATION_SGIX
33174	constant GL_DEFORMATIONS_MASK_SGIX
33175	constant GL_MAX_DEFORMATION_ORDER_SGIX
1	constant GL_SGIX_reference_plane
33149	constant GL_REFERENCE_PLANE_SGIX
33150	constant GL_REFERENCE_PLANE_EQUATION_SGIX
1	constant GL_SGIX_resample
33838	constant GL_PACK_RESAMPLE_SGIX
33839	constant GL_UNPACK_RESAMPLE_SGIX
33843	constant GL_RESAMPLE_REPLICATE_SGIX
33844	constant GL_RESAMPLE_ZERO_FILL_SGIX
33840	constant GL_RESAMPLE_DECIMATE_SGIX
1	constant GL_SGIX_scalebias_hint
33570	constant GL_SCALEBIAS_HINT_SGIX
1	constant GL_SGIX_shadow
33178	constant GL_TEXTURE_COMPARE_SGIX
33179	constant GL_TEXTURE_COMPARE_OPERATOR_SGIX
33180	constant GL_TEXTURE_LEQUAL_R_SGIX
33181	constant GL_TEXTURE_GEQUAL_R_SGIX
1	constant GL_SGIX_shadow_ambient
32959	constant GL_SHADOW_AMBIENT_SGIX
1	constant GL_SGIX_sprite
33096	constant GL_SPRITE_SGIX
33097	constant GL_SPRITE_MODE_SGIX
33098	constant GL_SPRITE_AXIS_SGIX
33099	constant GL_SPRITE_TRANSLATION_SGIX
33100	constant GL_SPRITE_AXIAL_SGIX
33101	constant GL_SPRITE_OBJECT_ALIGNED_SGIX
33102	constant GL_SPRITE_EYE_ALIGNED_SGIX
1	constant GL_SGIX_subsample
34208	constant GL_PACK_SUBSAMPLE_RATE_SGIX
34209	constant GL_UNPACK_SUBSAMPLE_RATE_SGIX
34210	constant GL_PIXEL_SUBSAMPLE_4444_SGIX
34211	constant GL_PIXEL_SUBSAMPLE_2424_SGIX
34212	constant GL_PIXEL_SUBSAMPLE_4242_SGIX
1	constant GL_SGIX_tag_sample_buffer
1	constant GL_SGIX_texture_add_env
32958	constant GL_TEXTURE_ENV_BIAS_SGIX
1	constant GL_SGIX_texture_coordinate_clamp
33641	constant GL_TEXTURE_MAX_CLAMP_S_SGIX
33642	constant GL_TEXTURE_MAX_CLAMP_T_SGIX
33643	constant GL_TEXTURE_MAX_CLAMP_R_SGIX
1	constant GL_SGIX_texture_lod_bias
33166	constant GL_TEXTURE_LOD_BIAS_S_SGIX
33167	constant GL_TEXTURE_LOD_BIAS_T_SGIX
33168	constant GL_TEXTURE_LOD_BIAS_R_SGIX
1	constant GL_SGIX_texture_multi_buffer
33070	constant GL_TEXTURE_MULTI_BUFFER_HINT_SGIX
1	constant GL_SGIX_texture_scale_bias
33145	constant GL_POST_TEXTURE_FILTER_BIAS_SGIX
33146	constant GL_POST_TEXTURE_FILTER_SCALE_SGIX
33147	constant GL_POST_TEXTURE_FILTER_BIAS_RANGE_SGIX
33148	constant GL_POST_TEXTURE_FILTER_SCALE_RANGE_SGIX
1	constant GL_SGIX_vertex_preclip
33774	constant GL_VERTEX_PRECLIP_SGIX
33775	constant GL_VERTEX_PRECLIP_HINT_SGIX
1	constant GL_SGIX_ycrcb
33211	constant GL_YCRCB_422_SGIX
33212	constant GL_YCRCB_444_SGIX
1	constant GL_SGIX_ycrcb_subsample
1	constant GL_SGIX_ycrcba
33560	constant GL_YCRCB_SGIX
33561	constant GL_YCRCBA_SGIX
1	constant GL_SGI_color_matrix
32945	constant GL_COLOR_MATRIX_SGI
32946	constant GL_COLOR_MATRIX_STACK_DEPTH_SGI
32947	constant GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI
32948	constant GL_POST_COLOR_MATRIX_RED_SCALE_SGI
32949	constant GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI
32950	constant GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI
32951	constant GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI
32952	constant GL_POST_COLOR_MATRIX_RED_BIAS_SGI
32953	constant GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI
32954	constant GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI
32955	constant GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI
1	constant GL_SGI_color_table
32976	constant GL_COLOR_TABLE_SGI
32977	constant GL_POST_CONVOLUTION_COLOR_TABLE_SGI
32978	constant GL_POST_COLOR_MATRIX_COLOR_TABLE_SGI
32979	constant GL_PROXY_COLOR_TABLE_SGI
32980	constant GL_PROXY_POST_CONVOLUTION_COLOR_TABLE_SGI
32981	constant GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE_SGI
32982	constant GL_COLOR_TABLE_SCALE_SGI
32983	constant GL_COLOR_TABLE_BIAS_SGI
32984	constant GL_COLOR_TABLE_FORMAT_SGI
32985	constant GL_COLOR_TABLE_WIDTH_SGI
32986	constant GL_COLOR_TABLE_RED_SIZE_SGI
32987	constant GL_COLOR_TABLE_GREEN_SIZE_SGI
32988	constant GL_COLOR_TABLE_BLUE_SIZE_SGI
32989	constant GL_COLOR_TABLE_ALPHA_SIZE_SGI
32990	constant GL_COLOR_TABLE_LUMINANCE_SIZE_SGI
32991	constant GL_COLOR_TABLE_INTENSITY_SIZE_SGI
1	constant GL_SGI_texture_color_table
32956	constant GL_TEXTURE_COLOR_TABLE_SGI
32957	constant GL_PROXY_TEXTURE_COLOR_TABLE_SGI
1	constant GL_SUNX_constant_data
33237	constant GL_UNPACK_CONSTANT_DATA_SUNX
33238	constant GL_TEXTURE_CONSTANT_DATA_SUNX
1	constant GL_SUN_convolution_border_modes
33236	constant GL_WRAP_BORDER_SUN
1	constant GL_SUN_global_alpha
33241	constant GL_GLOBAL_ALPHA_SUN
33242	constant GL_GLOBAL_ALPHA_FACTOR_SUN
1	constant GL_SUN_mesh_array
34324	constant GL_QUAD_MESH_SUN
34325	constant GL_TRIANGLE_MESH_SUN
1	constant GL_SUN_slice_accum
34252	constant GL_SLICE_ACCUM_SUN
1	constant GL_SUN_triangle_list
1	constant GL_RESTART_SUN
2	constant GL_REPLACE_MIDDLE_SUN
3	constant GL_REPLACE_OLDEST_SUN
33239	constant GL_TRIANGLE_LIST_SUN
33240	constant GL_REPLACEMENT_CODE_SUN
34240	constant GL_REPLACEMENT_CODE_ARRAY_SUN
34241	constant GL_REPLACEMENT_CODE_ARRAY_TYPE_SUN
34242	constant GL_REPLACEMENT_CODE_ARRAY_STRIDE_SUN
34243	constant GL_REPLACEMENT_CODE_ARRAY_POINTER_SUN
34244	constant GL_R1UI_V3F_SUN
34245	constant GL_R1UI_C4UB_V3F_SUN
34246	constant GL_R1UI_C3F_V3F_SUN
34247	constant GL_R1UI_N3F_V3F_SUN
34248	constant GL_R1UI_C4F_N3F_V3F_SUN
34249	constant GL_R1UI_T2F_V3F_SUN
34250	constant GL_R1UI_T2F_N3F_V3F_SUN
34251	constant GL_R1UI_T2F_C4F_N3F_V3F_SUN
1	constant GL_SUN_vertex
1	constant GL_WIN_phong_shading
33002	constant GL_PHONG_WIN
33003	constant GL_PHONG_HINT_WIN
1	constant GL_WIN_specular_fog
33004	constant GL_FOG_SPECULAR_TEXTURE_WIN

\ ----===< long constants ===>-----
18446744073709551615.	2constant GL_TIMEOUT_IGNORED

\ ------===< functions >===-------
c-function glClearIndex glClearIndex r -- void
c-function glClearColor glClearColor r r r r -- void
c-function glClear glClear u -- void
c-function glIndexMask glIndexMask u -- void
c-function glColorMask glColorMask n n n n -- void
c-function glAlphaFunc glAlphaFunc u r -- void
c-function glBlendFunc glBlendFunc u u -- void
c-function glLogicOp glLogicOp u -- void
c-function glCullFace glCullFace u -- void
c-function glFrontFace glFrontFace u -- void
c-function glPointSize glPointSize r -- void
c-function glLineWidth glLineWidth r -- void
c-function glLineStipple glLineStipple n n -- void
c-function glPolygonMode glPolygonMode u u -- void
c-function glPolygonOffset glPolygonOffset r r -- void
c-function glPolygonStipple glPolygonStipple a -- void
c-function glGetPolygonStipple glGetPolygonStipple a -- void
c-function glEdgeFlag glEdgeFlag n -- void
c-function glEdgeFlagv glEdgeFlagv a -- void
c-function glScissor glScissor n n n n -- void
c-function glClipPlane glClipPlane u a -- void
c-function glGetClipPlane glGetClipPlane u a -- void
c-function glDrawBuffer glDrawBuffer u -- void
c-function glReadBuffer glReadBuffer u -- void
c-function glEnable glEnable u -- void
c-function glDisable glDisable u -- void
c-function glIsEnabled glIsEnabled u -- n
c-function glEnableClientState glEnableClientState u -- void
c-function glDisableClientState glDisableClientState u -- void
c-function glGetBooleanv glGetBooleanv u a -- void
c-function glGetDoublev glGetDoublev u a -- void
c-function glGetFloatv glGetFloatv u a -- void
c-function glGetIntegerv glGetIntegerv u a -- void
c-function glPushAttrib glPushAttrib u -- void
c-function glPopAttrib glPopAttrib  -- void
c-function glPushClientAttrib glPushClientAttrib u -- void
c-function glPopClientAttrib glPopClientAttrib  -- void
c-function glRenderMode glRenderMode u -- n
c-function glGetError glGetError  -- u
c-function glGetString glGetString u -- a
c-function glFinish glFinish  -- void
c-function glFlush glFlush  -- void
c-function glHint glHint u u -- void
c-function glClearDepth glClearDepth r -- void
c-function glDepthFunc glDepthFunc u -- void
c-function glDepthMask glDepthMask n -- void
c-function glDepthRange glDepthRange r r -- void
c-function glClearAccum glClearAccum r r r r -- void
c-function glAccum glAccum u r -- void
c-function glMatrixMode glMatrixMode u -- void
c-function glOrtho glOrtho r r r r r r -- void
c-function glFrustum glFrustum r r r r r r -- void
c-function glViewport glViewport n n n n -- void
c-function glPushMatrix glPushMatrix  -- void
c-function glPopMatrix glPopMatrix  -- void
c-function glLoadIdentity glLoadIdentity  -- void
c-function glLoadMatrixd glLoadMatrixd a -- void
c-function glLoadMatrixf glLoadMatrixf a -- void
c-function glMultMatrixd glMultMatrixd a -- void
c-function glMultMatrixf glMultMatrixf a -- void
c-function glRotated glRotated r r r r -- void
c-function glRotatef glRotatef r r r r -- void
c-function glScaled glScaled r r r -- void
c-function glScalef glScalef r r r -- void
c-function glTranslated glTranslated r r r -- void
c-function glTranslatef glTranslatef r r r -- void
c-function glIsList glIsList u -- n
c-function glDeleteLists glDeleteLists u n -- void
c-function glGenLists glGenLists n -- u
c-function glNewList glNewList u u -- void
c-function glEndList glEndList  -- void
c-function glCallList glCallList u -- void
c-function glCallLists glCallLists n u a -- void
c-function glListBase glListBase u -- void
c-function glBegin glBegin u -- void
c-function glEnd glEnd  -- void
c-function glVertex2d glVertex2d r r -- void
c-function glVertex2f glVertex2f r r -- void
c-function glVertex2i glVertex2i n n -- void
c-function glVertex2s glVertex2s n n -- void
c-function glVertex3d glVertex3d r r r -- void
c-function glVertex3f glVertex3f r r r -- void
c-function glVertex3i glVertex3i n n n -- void
c-function glVertex3s glVertex3s n n n -- void
c-function glVertex4d glVertex4d r r r r -- void
c-function glVertex4f glVertex4f r r r r -- void
c-function glVertex4i glVertex4i n n n n -- void
c-function glVertex4s glVertex4s n n n n -- void
c-function glVertex2dv glVertex2dv a -- void
c-function glVertex2fv glVertex2fv a -- void
c-function glVertex2iv glVertex2iv a -- void
c-function glVertex2sv glVertex2sv a -- void
c-function glVertex3dv glVertex3dv a -- void
c-function glVertex3fv glVertex3fv a -- void
c-function glVertex3iv glVertex3iv a -- void
c-function glVertex3sv glVertex3sv a -- void
c-function glVertex4dv glVertex4dv a -- void
c-function glVertex4fv glVertex4fv a -- void
c-function glVertex4iv glVertex4iv a -- void
c-function glVertex4sv glVertex4sv a -- void
c-function glNormal3b glNormal3b n n n -- void
c-function glNormal3d glNormal3d r r r -- void
c-function glNormal3f glNormal3f r r r -- void
c-function glNormal3i glNormal3i n n n -- void
c-function glNormal3s glNormal3s n n n -- void
c-function glNormal3bv glNormal3bv a -- void
c-function glNormal3dv glNormal3dv a -- void
c-function glNormal3fv glNormal3fv a -- void
c-function glNormal3iv glNormal3iv a -- void
c-function glNormal3sv glNormal3sv a -- void
c-function glIndexd glIndexd r -- void
c-function glIndexf glIndexf r -- void
c-function glIndexi glIndexi n -- void
c-function glIndexs glIndexs n -- void
c-function glIndexub glIndexub n -- void
c-function glIndexdv glIndexdv a -- void
c-function glIndexfv glIndexfv a -- void
c-function glIndexiv glIndexiv a -- void
c-function glIndexsv glIndexsv a -- void
c-function glIndexubv glIndexubv a -- void
c-function glColor3b glColor3b n n n -- void
c-function glColor3d glColor3d r r r -- void
c-function glColor3f glColor3f r r r -- void
c-function glColor3i glColor3i n n n -- void
c-function glColor3s glColor3s n n n -- void
c-function glColor3ub glColor3ub n n n -- void
c-function glColor3ui glColor3ui u u u -- void
c-function glColor3us glColor3us n n n -- void
c-function glColor4b glColor4b n n n n -- void
c-function glColor4d glColor4d r r r r -- void
c-function glColor4f glColor4f r r r r -- void
c-function glColor4i glColor4i n n n n -- void
c-function glColor4s glColor4s n n n n -- void
c-function glColor4ub glColor4ub n n n n -- void
c-function glColor4ui glColor4ui u u u u -- void
c-function glColor4us glColor4us n n n n -- void
c-function glColor3bv glColor3bv a -- void
c-function glColor3dv glColor3dv a -- void
c-function glColor3fv glColor3fv a -- void
c-function glColor3iv glColor3iv a -- void
c-function glColor3sv glColor3sv a -- void
c-function glColor3ubv glColor3ubv a -- void
c-function glColor3uiv glColor3uiv a -- void
c-function glColor3usv glColor3usv a -- void
c-function glColor4bv glColor4bv a -- void
c-function glColor4dv glColor4dv a -- void
c-function glColor4fv glColor4fv a -- void
c-function glColor4iv glColor4iv a -- void
c-function glColor4sv glColor4sv a -- void
c-function glColor4ubv glColor4ubv a -- void
c-function glColor4uiv glColor4uiv a -- void
c-function glColor4usv glColor4usv a -- void
c-function glTexCoord1d glTexCoord1d r -- void
c-function glTexCoord1f glTexCoord1f r -- void
c-function glTexCoord1i glTexCoord1i n -- void
c-function glTexCoord1s glTexCoord1s n -- void
c-function glTexCoord2d glTexCoord2d r r -- void
c-function glTexCoord2f glTexCoord2f r r -- void
c-function glTexCoord2i glTexCoord2i n n -- void
c-function glTexCoord2s glTexCoord2s n n -- void
c-function glTexCoord3d glTexCoord3d r r r -- void
c-function glTexCoord3f glTexCoord3f r r r -- void
c-function glTexCoord3i glTexCoord3i n n n -- void
c-function glTexCoord3s glTexCoord3s n n n -- void
c-function glTexCoord4d glTexCoord4d r r r r -- void
c-function glTexCoord4f glTexCoord4f r r r r -- void
c-function glTexCoord4i glTexCoord4i n n n n -- void
c-function glTexCoord4s glTexCoord4s n n n n -- void
c-function glTexCoord1dv glTexCoord1dv a -- void
c-function glTexCoord1fv glTexCoord1fv a -- void
c-function glTexCoord1iv glTexCoord1iv a -- void
c-function glTexCoord1sv glTexCoord1sv a -- void
c-function glTexCoord2dv glTexCoord2dv a -- void
c-function glTexCoord2fv glTexCoord2fv a -- void
c-function glTexCoord2iv glTexCoord2iv a -- void
c-function glTexCoord2sv glTexCoord2sv a -- void
c-function glTexCoord3dv glTexCoord3dv a -- void
c-function glTexCoord3fv glTexCoord3fv a -- void
c-function glTexCoord3iv glTexCoord3iv a -- void
c-function glTexCoord3sv glTexCoord3sv a -- void
c-function glTexCoord4dv glTexCoord4dv a -- void
c-function glTexCoord4fv glTexCoord4fv a -- void
c-function glTexCoord4iv glTexCoord4iv a -- void
c-function glTexCoord4sv glTexCoord4sv a -- void
c-function glRasterPos2d glRasterPos2d r r -- void
c-function glRasterPos2f glRasterPos2f r r -- void
c-function glRasterPos2i glRasterPos2i n n -- void
c-function glRasterPos2s glRasterPos2s n n -- void
c-function glRasterPos3d glRasterPos3d r r r -- void
c-function glRasterPos3f glRasterPos3f r r r -- void
c-function glRasterPos3i glRasterPos3i n n n -- void
c-function glRasterPos3s glRasterPos3s n n n -- void
c-function glRasterPos4d glRasterPos4d r r r r -- void
c-function glRasterPos4f glRasterPos4f r r r r -- void
c-function glRasterPos4i glRasterPos4i n n n n -- void
c-function glRasterPos4s glRasterPos4s n n n n -- void
c-function glRasterPos2dv glRasterPos2dv a -- void
c-function glRasterPos2fv glRasterPos2fv a -- void
c-function glRasterPos2iv glRasterPos2iv a -- void
c-function glRasterPos2sv glRasterPos2sv a -- void
c-function glRasterPos3dv glRasterPos3dv a -- void
c-function glRasterPos3fv glRasterPos3fv a -- void
c-function glRasterPos3iv glRasterPos3iv a -- void
c-function glRasterPos3sv glRasterPos3sv a -- void
c-function glRasterPos4dv glRasterPos4dv a -- void
c-function glRasterPos4fv glRasterPos4fv a -- void
c-function glRasterPos4iv glRasterPos4iv a -- void
c-function glRasterPos4sv glRasterPos4sv a -- void
c-function glRectd glRectd r r r r -- void
c-function glRectf glRectf r r r r -- void
c-function glRecti glRecti n n n n -- void
c-function glRects glRects n n n n -- void
c-function glRectdv glRectdv a a -- void
c-function glRectfv glRectfv a a -- void
c-function glRectiv glRectiv a a -- void
c-function glRectsv glRectsv a a -- void
c-function glVertexPointer glVertexPointer n u n a -- void
c-function glNormalPointer glNormalPointer u n a -- void
c-function glColorPointer glColorPointer n u n a -- void
c-function glIndexPointer glIndexPointer u n a -- void
c-function glTexCoordPointer glTexCoordPointer n u n a -- void
c-function glEdgeFlagPointer glEdgeFlagPointer n a -- void
c-function glGetPointerv glGetPointerv u a -- void
c-function glArrayElement glArrayElement n -- void
c-function glDrawArrays glDrawArrays u n n -- void
c-function glDrawElements glDrawElements u n u a -- void
c-function glInterleavedArrays glInterleavedArrays u n a -- void
c-function glShadeModel glShadeModel u -- void
c-function glLightf glLightf u u r -- void
c-function glLighti glLighti u u n -- void
c-function glLightfv glLightfv u u a -- void
c-function glLightiv glLightiv u u a -- void
c-function glGetLightfv glGetLightfv u u a -- void
c-function glGetLightiv glGetLightiv u u a -- void
c-function glLightModelf glLightModelf u r -- void
c-function glLightModeli glLightModeli u n -- void
c-function glLightModelfv glLightModelfv u a -- void
c-function glLightModeliv glLightModeliv u a -- void
c-function glMaterialf glMaterialf u u r -- void
c-function glMateriali glMateriali u u n -- void
c-function glMaterialfv glMaterialfv u u a -- void
c-function glMaterialiv glMaterialiv u u a -- void
c-function glGetMaterialfv glGetMaterialfv u u a -- void
c-function glGetMaterialiv glGetMaterialiv u u a -- void
c-function glColorMaterial glColorMaterial u u -- void
c-function glPixelZoom glPixelZoom r r -- void
c-function glPixelStoref glPixelStoref u r -- void
c-function glPixelStorei glPixelStorei u n -- void
c-function glPixelTransferf glPixelTransferf u r -- void
c-function glPixelTransferi glPixelTransferi u n -- void
c-function glPixelMapfv glPixelMapfv u n a -- void
c-function glPixelMapuiv glPixelMapuiv u n a -- void
c-function glPixelMapusv glPixelMapusv u n a -- void
c-function glGetPixelMapfv glGetPixelMapfv u a -- void
c-function glGetPixelMapuiv glGetPixelMapuiv u a -- void
c-function glGetPixelMapusv glGetPixelMapusv u a -- void
c-function glBitmap glBitmap n n r r r r a -- void
c-function glReadPixels glReadPixels n n n n u u a -- void
c-function glDrawPixels glDrawPixels n n u u a -- void
c-function glCopyPixels glCopyPixels n n n n u -- void
c-function glStencilFunc glStencilFunc u n u -- void
c-function glStencilMask glStencilMask u -- void
c-function glStencilOp glStencilOp u u u -- void
c-function glClearStencil glClearStencil n -- void
c-function glTexGend glTexGend u u r -- void
c-function glTexGenf glTexGenf u u r -- void
c-function glTexGeni glTexGeni u u n -- void
c-function glTexGendv glTexGendv u u a -- void
c-function glTexGenfv glTexGenfv u u a -- void
c-function glTexGeniv glTexGeniv u u a -- void
c-function glGetTexGendv glGetTexGendv u u a -- void
c-function glGetTexGenfv glGetTexGenfv u u a -- void
c-function glGetTexGeniv glGetTexGeniv u u a -- void
c-function glTexEnvf glTexEnvf u u r -- void
c-function glTexEnvi glTexEnvi u u n -- void
c-function glTexEnvfv glTexEnvfv u u a -- void
c-function glTexEnviv glTexEnviv u u a -- void
c-function glGetTexEnvfv glGetTexEnvfv u u a -- void
c-function glGetTexEnviv glGetTexEnviv u u a -- void
c-function glTexParameterf glTexParameterf u u r -- void
c-function glTexParameteri glTexParameteri u u n -- void
c-function glTexParameterfv glTexParameterfv u u a -- void
c-function glTexParameteriv glTexParameteriv u u a -- void
c-function glGetTexParameterfv glGetTexParameterfv u u a -- void
c-function glGetTexParameteriv glGetTexParameteriv u u a -- void
c-function glGetTexLevelParameterfv glGetTexLevelParameterfv u n u a -- void
c-function glGetTexLevelParameteriv glGetTexLevelParameteriv u n u a -- void
c-function glTexImage1D glTexImage1D u n n n n u u a -- void
c-function glTexImage2D glTexImage2D u n n n n n u u a -- void
c-function glGetTexImage glGetTexImage u n u u a -- void
c-function glGenTextures glGenTextures n a -- void
c-function glDeleteTextures glDeleteTextures n a -- void
c-function glBindTexture glBindTexture u u -- void
c-function glPrioritizeTextures glPrioritizeTextures n a a -- void
c-function glAreTexturesResident glAreTexturesResident n a a -- n
c-function glIsTexture glIsTexture u -- n
c-function glTexSubImage1D glTexSubImage1D u n n n u u a -- void
c-function glTexSubImage2D glTexSubImage2D u n n n n n u u a -- void
c-function glCopyTexImage1D glCopyTexImage1D u n u n n n n -- void
c-function glCopyTexImage2D glCopyTexImage2D u n u n n n n n -- void
c-function glCopyTexSubImage1D glCopyTexSubImage1D u n n n n n -- void
c-function glCopyTexSubImage2D glCopyTexSubImage2D u n n n n n n n -- void
c-function glMap1d glMap1d u r r n n a -- void
c-function glMap1f glMap1f u r r n n a -- void
c-function glMap2d glMap2d u r r n n r r n n a -- void
c-function glMap2f glMap2f u r r n n r r n n a -- void
c-function glGetMapdv glGetMapdv u u a -- void
c-function glGetMapfv glGetMapfv u u a -- void
c-function glGetMapiv glGetMapiv u u a -- void
c-function glEvalCoord1d glEvalCoord1d r -- void
c-function glEvalCoord1f glEvalCoord1f r -- void
c-function glEvalCoord1dv glEvalCoord1dv a -- void
c-function glEvalCoord1fv glEvalCoord1fv a -- void
c-function glEvalCoord2d glEvalCoord2d r r -- void
c-function glEvalCoord2f glEvalCoord2f r r -- void
c-function glEvalCoord2dv glEvalCoord2dv a -- void
c-function glEvalCoord2fv glEvalCoord2fv a -- void
c-function glMapGrid1d glMapGrid1d n r r -- void
c-function glMapGrid1f glMapGrid1f n r r -- void
c-function glMapGrid2d glMapGrid2d n r r n r r -- void
c-function glMapGrid2f glMapGrid2f n r r n r r -- void
c-function glEvalPoint1 glEvalPoint1 n -- void
c-function glEvalPoint2 glEvalPoint2 n n -- void
c-function glEvalMesh1 glEvalMesh1 u n n -- void
c-function glEvalMesh2 glEvalMesh2 u n n n n -- void
c-function glFogf glFogf u r -- void
c-function glFogi glFogi u n -- void
c-function glFogfv glFogfv u a -- void
c-function glFogiv glFogiv u a -- void
c-function glFeedbackBuffer glFeedbackBuffer n u a -- void
c-function glPassThrough glPassThrough r -- void
c-function glSelectBuffer glSelectBuffer n a -- void
c-function glInitNames glInitNames  -- void
c-function glLoadName glLoadName u -- void
c-function glPushName glPushName u -- void
c-function glPopName glPopName  -- void
c-function glDrawRangeElements glDrawRangeElements u u u n u a -- void
c-function glTexImage3D glTexImage3D u n n n n n n u u a -- void
c-function glTexSubImage3D glTexSubImage3D u n n n n n n n u u a -- void
c-function glCopyTexSubImage3D glCopyTexSubImage3D u n n n n n n n n -- void
c-function glColorTable glColorTable u u n u u a -- void
c-function glColorSubTable glColorSubTable u n n u u a -- void
c-function glColorTableParameteriv glColorTableParameteriv u u a -- void
c-function glColorTableParameterfv glColorTableParameterfv u u a -- void
c-function glCopyColorSubTable glCopyColorSubTable u n n n n -- void
c-function glCopyColorTable glCopyColorTable u u n n n -- void
c-function glGetColorTable glGetColorTable u u u a -- void
c-function glGetColorTableParameterfv glGetColorTableParameterfv u u a -- void
c-function glGetColorTableParameteriv glGetColorTableParameteriv u u a -- void
c-function glBlendEquation glBlendEquation u -- void
c-function glBlendColor glBlendColor r r r r -- void
c-function glHistogram glHistogram u n u n -- void
c-function glResetHistogram glResetHistogram u -- void
c-function glGetHistogram glGetHistogram u n u u a -- void
c-function glGetHistogramParameterfv glGetHistogramParameterfv u u a -- void
c-function glGetHistogramParameteriv glGetHistogramParameteriv u u a -- void
c-function glMinmax glMinmax u u n -- void
c-function glResetMinmax glResetMinmax u -- void
c-function glGetMinmax glGetMinmax u n u u a -- void
c-function glGetMinmaxParameterfv glGetMinmaxParameterfv u u a -- void
c-function glGetMinmaxParameteriv glGetMinmaxParameteriv u u a -- void
c-function glConvolutionFilter1D glConvolutionFilter1D u u n u u a -- void
c-function glConvolutionFilter2D glConvolutionFilter2D u u n n u u a -- void
c-function glConvolutionParameterf glConvolutionParameterf u u r -- void
c-function glConvolutionParameterfv glConvolutionParameterfv u u a -- void
c-function glConvolutionParameteri glConvolutionParameteri u u n -- void
c-function glConvolutionParameteriv glConvolutionParameteriv u u a -- void
c-function glCopyConvolutionFilter1D glCopyConvolutionFilter1D u u n n n -- void
c-function glCopyConvolutionFilter2D glCopyConvolutionFilter2D u u n n n n -- void
c-function glGetConvolutionFilter glGetConvolutionFilter u u u a -- void
c-function glGetConvolutionParameterfv glGetConvolutionParameterfv u u a -- void
c-function glGetConvolutionParameteriv glGetConvolutionParameteriv u u a -- void
c-function glSeparableFilter2D glSeparableFilter2D u u n n u u a a -- void
c-function glGetSeparableFilter glGetSeparableFilter u u u a a a -- void
c-function glActiveTexture glActiveTexture u -- void
c-function glClientActiveTexture glClientActiveTexture u -- void
c-function glCompressedTexImage1D glCompressedTexImage1D u n u n n n a -- void
c-function glCompressedTexImage2D glCompressedTexImage2D u n u n n n n a -- void
c-function glCompressedTexImage3D glCompressedTexImage3D u n u n n n n n a -- void
c-function glCompressedTexSubImage1D glCompressedTexSubImage1D u n n n u n a -- void
c-function glCompressedTexSubImage2D glCompressedTexSubImage2D u n n n n n u n a -- void
c-function glCompressedTexSubImage3D glCompressedTexSubImage3D u n n n n n n n u n a -- void
c-function glGetCompressedTexImage glGetCompressedTexImage u n a -- void
c-function glMultiTexCoord1d glMultiTexCoord1d u r -- void
c-function glMultiTexCoord1dv glMultiTexCoord1dv u a -- void
c-function glMultiTexCoord1f glMultiTexCoord1f u r -- void
c-function glMultiTexCoord1fv glMultiTexCoord1fv u a -- void
c-function glMultiTexCoord1i glMultiTexCoord1i u n -- void
c-function glMultiTexCoord1iv glMultiTexCoord1iv u a -- void
c-function glMultiTexCoord1s glMultiTexCoord1s u n -- void
c-function glMultiTexCoord1sv glMultiTexCoord1sv u a -- void
c-function glMultiTexCoord2d glMultiTexCoord2d u r r -- void
c-function glMultiTexCoord2dv glMultiTexCoord2dv u a -- void
c-function glMultiTexCoord2f glMultiTexCoord2f u r r -- void
c-function glMultiTexCoord2fv glMultiTexCoord2fv u a -- void
c-function glMultiTexCoord2i glMultiTexCoord2i u n n -- void
c-function glMultiTexCoord2iv glMultiTexCoord2iv u a -- void
c-function glMultiTexCoord2s glMultiTexCoord2s u n n -- void
c-function glMultiTexCoord2sv glMultiTexCoord2sv u a -- void
c-function glMultiTexCoord3d glMultiTexCoord3d u r r r -- void
c-function glMultiTexCoord3dv glMultiTexCoord3dv u a -- void
c-function glMultiTexCoord3f glMultiTexCoord3f u r r r -- void
c-function glMultiTexCoord3fv glMultiTexCoord3fv u a -- void
c-function glMultiTexCoord3i glMultiTexCoord3i u n n n -- void
c-function glMultiTexCoord3iv glMultiTexCoord3iv u a -- void
c-function glMultiTexCoord3s glMultiTexCoord3s u n n n -- void
c-function glMultiTexCoord3sv glMultiTexCoord3sv u a -- void
c-function glMultiTexCoord4d glMultiTexCoord4d u r r r r -- void
c-function glMultiTexCoord4dv glMultiTexCoord4dv u a -- void
c-function glMultiTexCoord4f glMultiTexCoord4f u r r r r -- void
c-function glMultiTexCoord4fv glMultiTexCoord4fv u a -- void
c-function glMultiTexCoord4i glMultiTexCoord4i u n n n n -- void
c-function glMultiTexCoord4iv glMultiTexCoord4iv u a -- void
c-function glMultiTexCoord4s glMultiTexCoord4s u n n n n -- void
c-function glMultiTexCoord4sv glMultiTexCoord4sv u a -- void
c-function glLoadTransposeMatrixd glLoadTransposeMatrixd a -- void
c-function glLoadTransposeMatrixf glLoadTransposeMatrixf a -- void
c-function glMultTransposeMatrixd glMultTransposeMatrixd a -- void
c-function glMultTransposeMatrixf glMultTransposeMatrixf a -- void
c-function glSampleCoverage glSampleCoverage r n -- void
c-function glActiveTextureARB glActiveTextureARB u -- void
c-function glClientActiveTextureARB glClientActiveTextureARB u -- void
c-function glMultiTexCoord1dARB glMultiTexCoord1dARB u r -- void
c-function glMultiTexCoord1dvARB glMultiTexCoord1dvARB u a -- void
c-function glMultiTexCoord1fARB glMultiTexCoord1fARB u r -- void
c-function glMultiTexCoord1fvARB glMultiTexCoord1fvARB u a -- void
c-function glMultiTexCoord1iARB glMultiTexCoord1iARB u n -- void
c-function glMultiTexCoord1ivARB glMultiTexCoord1ivARB u a -- void
c-function glMultiTexCoord1sARB glMultiTexCoord1sARB u n -- void
c-function glMultiTexCoord1svARB glMultiTexCoord1svARB u a -- void
c-function glMultiTexCoord2dARB glMultiTexCoord2dARB u r r -- void
c-function glMultiTexCoord2dvARB glMultiTexCoord2dvARB u a -- void
c-function glMultiTexCoord2fARB glMultiTexCoord2fARB u r r -- void
c-function glMultiTexCoord2fvARB glMultiTexCoord2fvARB u a -- void
c-function glMultiTexCoord2iARB glMultiTexCoord2iARB u n n -- void
c-function glMultiTexCoord2ivARB glMultiTexCoord2ivARB u a -- void
c-function glMultiTexCoord2sARB glMultiTexCoord2sARB u n n -- void
c-function glMultiTexCoord2svARB glMultiTexCoord2svARB u a -- void
c-function glMultiTexCoord3dARB glMultiTexCoord3dARB u r r r -- void
c-function glMultiTexCoord3dvARB glMultiTexCoord3dvARB u a -- void
c-function glMultiTexCoord3fARB glMultiTexCoord3fARB u r r r -- void
c-function glMultiTexCoord3fvARB glMultiTexCoord3fvARB u a -- void
c-function glMultiTexCoord3iARB glMultiTexCoord3iARB u n n n -- void
c-function glMultiTexCoord3ivARB glMultiTexCoord3ivARB u a -- void
c-function glMultiTexCoord3sARB glMultiTexCoord3sARB u n n n -- void
c-function glMultiTexCoord3svARB glMultiTexCoord3svARB u a -- void
c-function glMultiTexCoord4dARB glMultiTexCoord4dARB u r r r r -- void
c-function glMultiTexCoord4dvARB glMultiTexCoord4dvARB u a -- void
c-function glMultiTexCoord4fARB glMultiTexCoord4fARB u r r r r -- void
c-function glMultiTexCoord4fvARB glMultiTexCoord4fvARB u a -- void
c-function glMultiTexCoord4iARB glMultiTexCoord4iARB u n n n n -- void
c-function glMultiTexCoord4ivARB glMultiTexCoord4ivARB u a -- void
c-function glMultiTexCoord4sARB glMultiTexCoord4sARB u n n n n -- void
c-function glMultiTexCoord4svARB glMultiTexCoord4svARB u a -- void
c-function glBlendEquationSeparateATI glBlendEquationSeparateATI u u -- void
c-function glEGLImageTargetTexture2DOES glEGLImageTargetTexture2DOES u a -- void
c-function glEGLImageTargetRenderbufferStorageOES glEGLImageTargetRenderbufferStorageOES u a -- void
c-function glBlendFuncSeparate glBlendFuncSeparate u u u u -- void
c-function glMultiDrawArrays glMultiDrawArrays u a a n -- void
c-function glMultiDrawElements glMultiDrawElements u a u a n -- void
c-function glPointParameterf glPointParameterf u r -- void
c-function glPointParameterfv glPointParameterfv u a -- void
c-function glPointParameteri glPointParameteri u n -- void
c-function glPointParameteriv glPointParameteriv u a -- void
c-function glFogCoordf glFogCoordf r -- void
c-function glFogCoordfv glFogCoordfv a -- void
c-function glFogCoordd glFogCoordd r -- void
c-function glFogCoorddv glFogCoorddv a -- void
c-function glFogCoordPointer glFogCoordPointer u n a -- void
c-function glSecondaryColor3b glSecondaryColor3b n n n -- void
c-function glSecondaryColor3bv glSecondaryColor3bv a -- void
c-function glSecondaryColor3d glSecondaryColor3d r r r -- void
c-function glSecondaryColor3dv glSecondaryColor3dv a -- void
c-function glSecondaryColor3f glSecondaryColor3f r r r -- void
c-function glSecondaryColor3fv glSecondaryColor3fv a -- void
c-function glSecondaryColor3i glSecondaryColor3i n n n -- void
c-function glSecondaryColor3iv glSecondaryColor3iv a -- void
c-function glSecondaryColor3s glSecondaryColor3s n n n -- void
c-function glSecondaryColor3sv glSecondaryColor3sv a -- void
c-function glSecondaryColor3ub glSecondaryColor3ub n n n -- void
c-function glSecondaryColor3ubv glSecondaryColor3ubv a -- void
c-function glSecondaryColor3ui glSecondaryColor3ui u u u -- void
c-function glSecondaryColor3uiv glSecondaryColor3uiv a -- void
c-function glSecondaryColor3us glSecondaryColor3us n n n -- void
c-function glSecondaryColor3usv glSecondaryColor3usv a -- void
c-function glSecondaryColorPointer glSecondaryColorPointer n u n a -- void
c-function glWindowPos2d glWindowPos2d r r -- void
c-function glWindowPos2dv glWindowPos2dv a -- void
c-function glWindowPos2f glWindowPos2f r r -- void
c-function glWindowPos2fv glWindowPos2fv a -- void
c-function glWindowPos2i glWindowPos2i n n -- void
c-function glWindowPos2iv glWindowPos2iv a -- void
c-function glWindowPos2s glWindowPos2s n n -- void
c-function glWindowPos2sv glWindowPos2sv a -- void
c-function glWindowPos3d glWindowPos3d r r r -- void
c-function glWindowPos3dv glWindowPos3dv a -- void
c-function glWindowPos3f glWindowPos3f r r r -- void
c-function glWindowPos3fv glWindowPos3fv a -- void
c-function glWindowPos3i glWindowPos3i n n n -- void
c-function glWindowPos3iv glWindowPos3iv a -- void
c-function glWindowPos3s glWindowPos3s n n n -- void
c-function glWindowPos3sv glWindowPos3sv a -- void
c-function glGenQueries glGenQueries n a -- void
c-function glDeleteQueries glDeleteQueries n a -- void
c-function glIsQuery glIsQuery u -- n
c-function glBeginQuery glBeginQuery u u -- void
c-function glEndQuery glEndQuery u -- void
c-function glGetQueryiv glGetQueryiv u u a -- void
c-function glGetQueryObjectiv glGetQueryObjectiv u u a -- void
c-function glGetQueryObjectuiv glGetQueryObjectuiv u u a -- void
c-function glBindBuffer glBindBuffer u u -- void
c-function glDeleteBuffers glDeleteBuffers n a -- void
c-function glGenBuffers glGenBuffers n a -- void
c-function glIsBuffer glIsBuffer u -- n
c-function glBufferData glBufferData u n a u -- void
c-function glBufferSubData glBufferSubData u n n a -- void
c-function glGetBufferSubData glGetBufferSubData u n n a -- void
c-function glMapBuffer glMapBuffer u u -- a
c-function glUnmapBuffer glUnmapBuffer u -- n
c-function glGetBufferParameteriv glGetBufferParameteriv u u a -- void
c-function glGetBufferPointerv glGetBufferPointerv u u a -- void
c-function glBlendEquationSeparate glBlendEquationSeparate u u -- void
c-function glDrawBuffers glDrawBuffers n a -- void
c-function glStencilOpSeparate glStencilOpSeparate u u u u -- void
c-function glStencilFuncSeparate glStencilFuncSeparate u u n u -- void
c-function glStencilMaskSeparate glStencilMaskSeparate u u -- void
c-function glAttachShader glAttachShader u u -- void
c-function glBindAttribLocation glBindAttribLocation u u a -- void
c-function glCompileShader glCompileShader u -- void
c-function glCreateProgram glCreateProgram  -- u
c-function glCreateShader glCreateShader u -- u
c-function glDeleteProgram glDeleteProgram u -- void
c-function glDeleteShader glDeleteShader u -- void
c-function glDetachShader glDetachShader u u -- void
c-function glDisableVertexAttribArray glDisableVertexAttribArray u -- void
c-function glEnableVertexAttribArray glEnableVertexAttribArray u -- void
c-function glGetActiveAttrib glGetActiveAttrib u u n a a a a -- void
c-function glGetActiveUniform glGetActiveUniform u u n a a a a -- void
c-function glGetAttachedShaders glGetAttachedShaders u n a a -- void
c-function glGetAttribLocation glGetAttribLocation u a -- n
c-function glGetProgramiv glGetProgramiv u u a -- void
c-function glGetProgramInfoLog glGetProgramInfoLog u n a a -- void
c-function glGetShaderiv glGetShaderiv u u a -- void
c-function glGetShaderInfoLog glGetShaderInfoLog u n a a -- void
c-function glGetShaderSource glGetShaderSource u n a a -- void
c-function glGetUniformLocation glGetUniformLocation u a -- n
c-function glGetUniformfv glGetUniformfv u n a -- void
c-function glGetUniformiv glGetUniformiv u n a -- void
c-function glGetVertexAttribdv glGetVertexAttribdv u u a -- void
c-function glGetVertexAttribfv glGetVertexAttribfv u u a -- void
c-function glGetVertexAttribiv glGetVertexAttribiv u u a -- void
c-function glGetVertexAttribPointerv glGetVertexAttribPointerv u u a -- void
c-function glIsProgram glIsProgram u -- n
c-function glIsShader glIsShader u -- n
c-function glLinkProgram glLinkProgram u -- void
c-function glShaderSource glShaderSource u n a a -- void
c-function glUseProgram glUseProgram u -- void
c-function glUniform1f glUniform1f n r -- void
c-function glUniform2f glUniform2f n r r -- void
c-function glUniform3f glUniform3f n r r r -- void
c-function glUniform4f glUniform4f n r r r r -- void
c-function glUniform1i glUniform1i n n -- void
c-function glUniform2i glUniform2i n n n -- void
c-function glUniform3i glUniform3i n n n n -- void
c-function glUniform4i glUniform4i n n n n n -- void
c-function glUniform1fv glUniform1fv n n a -- void
c-function glUniform2fv glUniform2fv n n a -- void
c-function glUniform3fv glUniform3fv n n a -- void
c-function glUniform4fv glUniform4fv n n a -- void
c-function glUniform1iv glUniform1iv n n a -- void
c-function glUniform2iv glUniform2iv n n a -- void
c-function glUniform3iv glUniform3iv n n a -- void
c-function glUniform4iv glUniform4iv n n a -- void
c-function glUniformMatrix2fv glUniformMatrix2fv n n n a -- void
c-function glUniformMatrix3fv glUniformMatrix3fv n n n a -- void
c-function glUniformMatrix4fv glUniformMatrix4fv n n n a -- void
c-function glValidateProgram glValidateProgram u -- void
c-function glVertexAttrib1d glVertexAttrib1d u r -- void
c-function glVertexAttrib1dv glVertexAttrib1dv u a -- void
c-function glVertexAttrib1f glVertexAttrib1f u r -- void
c-function glVertexAttrib1fv glVertexAttrib1fv u a -- void
c-function glVertexAttrib1s glVertexAttrib1s u n -- void
c-function glVertexAttrib1sv glVertexAttrib1sv u a -- void
c-function glVertexAttrib2d glVertexAttrib2d u r r -- void
c-function glVertexAttrib2dv glVertexAttrib2dv u a -- void
c-function glVertexAttrib2f glVertexAttrib2f u r r -- void
c-function glVertexAttrib2fv glVertexAttrib2fv u a -- void
c-function glVertexAttrib2s glVertexAttrib2s u n n -- void
c-function glVertexAttrib2sv glVertexAttrib2sv u a -- void
c-function glVertexAttrib3d glVertexAttrib3d u r r r -- void
c-function glVertexAttrib3dv glVertexAttrib3dv u a -- void
c-function glVertexAttrib3f glVertexAttrib3f u r r r -- void
c-function glVertexAttrib3fv glVertexAttrib3fv u a -- void
c-function glVertexAttrib3s glVertexAttrib3s u n n n -- void
c-function glVertexAttrib3sv glVertexAttrib3sv u a -- void
c-function glVertexAttrib4Nbv glVertexAttrib4Nbv u a -- void
c-function glVertexAttrib4Niv glVertexAttrib4Niv u a -- void
c-function glVertexAttrib4Nsv glVertexAttrib4Nsv u a -- void
c-function glVertexAttrib4Nub glVertexAttrib4Nub u n n n n -- void
c-function glVertexAttrib4Nubv glVertexAttrib4Nubv u a -- void
c-function glVertexAttrib4Nuiv glVertexAttrib4Nuiv u a -- void
c-function glVertexAttrib4Nusv glVertexAttrib4Nusv u a -- void
c-function glVertexAttrib4bv glVertexAttrib4bv u a -- void
c-function glVertexAttrib4d glVertexAttrib4d u r r r r -- void
c-function glVertexAttrib4dv glVertexAttrib4dv u a -- void
c-function glVertexAttrib4f glVertexAttrib4f u r r r r -- void
c-function glVertexAttrib4fv glVertexAttrib4fv u a -- void
c-function glVertexAttrib4iv glVertexAttrib4iv u a -- void
c-function glVertexAttrib4s glVertexAttrib4s u n n n n -- void
c-function glVertexAttrib4sv glVertexAttrib4sv u a -- void
c-function glVertexAttrib4ubv glVertexAttrib4ubv u a -- void
c-function glVertexAttrib4uiv glVertexAttrib4uiv u a -- void
c-function glVertexAttrib4usv glVertexAttrib4usv u a -- void
c-function glVertexAttribPointer glVertexAttribPointer u n u n n a -- void
c-function glUniformMatrix2x3fv glUniformMatrix2x3fv n n n a -- void
c-function glUniformMatrix3x2fv glUniformMatrix3x2fv n n n a -- void
c-function glUniformMatrix2x4fv glUniformMatrix2x4fv n n n a -- void
c-function glUniformMatrix4x2fv glUniformMatrix4x2fv n n n a -- void
c-function glUniformMatrix3x4fv glUniformMatrix3x4fv n n n a -- void
c-function glUniformMatrix4x3fv glUniformMatrix4x3fv n n n a -- void
c-function glColorMaski glColorMaski u n n n n -- void
c-function glGetBooleani_v glGetBooleani_v u u a -- void
c-function glGetIntegeri_v glGetIntegeri_v u u a -- void
c-function glEnablei glEnablei u u -- void
c-function glDisablei glDisablei u u -- void
c-function glIsEnabledi glIsEnabledi u u -- n
c-function glBeginTransformFeedback glBeginTransformFeedback u -- void
c-function glEndTransformFeedback glEndTransformFeedback  -- void
c-function glBindBufferRange glBindBufferRange u u u n n -- void
c-function glBindBufferBase glBindBufferBase u u u -- void
c-function glTransformFeedbackVaryings glTransformFeedbackVaryings u n a u -- void
c-function glGetTransformFeedbackVarying glGetTransformFeedbackVarying u u n a a a a -- void
c-function glClampColor glClampColor u u -- void
c-function glBeginConditionalRender glBeginConditionalRender u u -- void
c-function glEndConditionalRender glEndConditionalRender  -- void
c-function glVertexAttribIPointer glVertexAttribIPointer u n u n a -- void
c-function glGetVertexAttribIiv glGetVertexAttribIiv u u a -- void
c-function glGetVertexAttribIuiv glGetVertexAttribIuiv u u a -- void
c-function glVertexAttribI1i glVertexAttribI1i u n -- void
c-function glVertexAttribI2i glVertexAttribI2i u n n -- void
c-function glVertexAttribI3i glVertexAttribI3i u n n n -- void
c-function glVertexAttribI4i glVertexAttribI4i u n n n n -- void
c-function glVertexAttribI1ui glVertexAttribI1ui u u -- void
c-function glVertexAttribI2ui glVertexAttribI2ui u u u -- void
c-function glVertexAttribI3ui glVertexAttribI3ui u u u u -- void
c-function glVertexAttribI4ui glVertexAttribI4ui u u u u u -- void
c-function glVertexAttribI1iv glVertexAttribI1iv u a -- void
c-function glVertexAttribI2iv glVertexAttribI2iv u a -- void
c-function glVertexAttribI3iv glVertexAttribI3iv u a -- void
c-function glVertexAttribI4iv glVertexAttribI4iv u a -- void
c-function glVertexAttribI1uiv glVertexAttribI1uiv u a -- void
c-function glVertexAttribI2uiv glVertexAttribI2uiv u a -- void
c-function glVertexAttribI3uiv glVertexAttribI3uiv u a -- void
c-function glVertexAttribI4uiv glVertexAttribI4uiv u a -- void
c-function glVertexAttribI4bv glVertexAttribI4bv u a -- void
c-function glVertexAttribI4sv glVertexAttribI4sv u a -- void
c-function glVertexAttribI4ubv glVertexAttribI4ubv u a -- void
c-function glVertexAttribI4usv glVertexAttribI4usv u a -- void
c-function glGetUniformuiv glGetUniformuiv u n a -- void
c-function glBindFragDataLocation glBindFragDataLocation u u a -- void
c-function glGetFragDataLocation glGetFragDataLocation u a -- n
c-function glUniform1ui glUniform1ui n u -- void
c-function glUniform2ui glUniform2ui n u u -- void
c-function glUniform3ui glUniform3ui n u u u -- void
c-function glUniform4ui glUniform4ui n u u u u -- void
c-function glUniform1uiv glUniform1uiv n n a -- void
c-function glUniform2uiv glUniform2uiv n n a -- void
c-function glUniform3uiv glUniform3uiv n n a -- void
c-function glUniform4uiv glUniform4uiv n n a -- void
c-function glTexParameterIiv glTexParameterIiv u u a -- void
c-function glTexParameterIuiv glTexParameterIuiv u u a -- void
c-function glGetTexParameterIiv glGetTexParameterIiv u u a -- void
c-function glGetTexParameterIuiv glGetTexParameterIuiv u u a -- void
c-function glClearBufferiv glClearBufferiv u n a -- void
c-function glClearBufferuiv glClearBufferuiv u n a -- void
c-function glClearBufferfv glClearBufferfv u n a -- void
c-function glClearBufferfi glClearBufferfi u n r n -- void
c-function glGetStringi glGetStringi u u -- a
c-function glIsRenderbuffer glIsRenderbuffer u -- n
c-function glBindRenderbuffer glBindRenderbuffer u u -- void
c-function glDeleteRenderbuffers glDeleteRenderbuffers n a -- void
c-function glGenRenderbuffers glGenRenderbuffers n a -- void
c-function glRenderbufferStorage glRenderbufferStorage u u n n -- void
c-function glGetRenderbufferParameteriv glGetRenderbufferParameteriv u u a -- void
c-function glIsFramebuffer glIsFramebuffer u -- n
c-function glBindFramebuffer glBindFramebuffer u u -- void
c-function glDeleteFramebuffers glDeleteFramebuffers n a -- void
c-function glGenFramebuffers glGenFramebuffers n a -- void
c-function glCheckFramebufferStatus glCheckFramebufferStatus u -- u
c-function glFramebufferTexture1D glFramebufferTexture1D u u u u n -- void
c-function glFramebufferTexture2D glFramebufferTexture2D u u u u n -- void
c-function glFramebufferTexture3D glFramebufferTexture3D u u u u n n -- void
c-function glFramebufferRenderbuffer glFramebufferRenderbuffer u u u u -- void
c-function glGetFramebufferAttachmentParameteriv glGetFramebufferAttachmentParameteriv u u u a -- void
c-function glGenerateMipmap glGenerateMipmap u -- void
c-function glBlitFramebuffer glBlitFramebuffer n n n n n n n n u u -- void
c-function glRenderbufferStorageMultisample glRenderbufferStorageMultisample u n u n n -- void
c-function glFramebufferTextureLayer glFramebufferTextureLayer u u u n n -- void
c-function glMapBufferRange glMapBufferRange u n n u -- a
c-function glFlushMappedBufferRange glFlushMappedBufferRange u n n -- void
c-function glBindVertexArray glBindVertexArray u -- void
c-function glDeleteVertexArrays glDeleteVertexArrays n a -- void
c-function glGenVertexArrays glGenVertexArrays n a -- void
c-function glIsVertexArray glIsVertexArray u -- n
c-function glDrawArraysInstanced glDrawArraysInstanced u n n n -- void
c-function glDrawElementsInstanced glDrawElementsInstanced u n u a n -- void
c-function glTexBuffer glTexBuffer u u u -- void
c-function glPrimitiveRestartIndex glPrimitiveRestartIndex u -- void
c-function glCopyBufferSubData glCopyBufferSubData u u n n n -- void
c-function glGetUniformIndices glGetUniformIndices u n a a -- void
c-function glGetActiveUniformsiv glGetActiveUniformsiv u n a u a -- void
c-function glGetActiveUniformName glGetActiveUniformName u u n a a -- void
c-function glGetUniformBlockIndex glGetUniformBlockIndex u a -- u
c-function glGetActiveUniformBlockiv glGetActiveUniformBlockiv u u u a -- void
c-function glGetActiveUniformBlockName glGetActiveUniformBlockName u u n a a -- void
c-function glUniformBlockBinding glUniformBlockBinding u u u -- void
c-function glDrawElementsBaseVertex glDrawElementsBaseVertex u n u a n -- void
c-function glDrawRangeElementsBaseVertex glDrawRangeElementsBaseVertex u u u n u a n -- void
c-function glDrawElementsInstancedBaseVertex glDrawElementsInstancedBaseVertex u n u a n n -- void
c-function glMultiDrawElementsBaseVertex glMultiDrawElementsBaseVertex u a u a n a -- void
c-function glProvokingVertex glProvokingVertex u -- void
c-function glFenceSync glFenceSync u u -- a
c-function glIsSync glIsSync a -- n
c-function glDeleteSync glDeleteSync a -- void
c-function glClientWaitSync glClientWaitSync a u d -- u
c-function glWaitSync glWaitSync a u d -- void
c-function glGetInteger64v glGetInteger64v u a -- void
c-function glGetSynciv glGetSynciv a u n a a -- void
c-function glGetInteger64i_v glGetInteger64i_v u u a -- void
c-function glGetBufferParameteri64v glGetBufferParameteri64v u u a -- void
c-function glFramebufferTexture glFramebufferTexture u u u n -- void
c-function glTexImage2DMultisample glTexImage2DMultisample u n u n n n -- void
c-function glTexImage3DMultisample glTexImage3DMultisample u n u n n n n -- void
c-function glGetMultisamplefv glGetMultisamplefv u u a -- void
c-function glSampleMaski glSampleMaski u u -- void
c-function glBindFragDataLocationIndexed glBindFragDataLocationIndexed u u u a -- void
c-function glGetFragDataIndex glGetFragDataIndex u a -- n
c-function glGenSamplers glGenSamplers n a -- void
c-function glDeleteSamplers glDeleteSamplers n a -- void
c-function glIsSampler glIsSampler u -- n
c-function glBindSampler glBindSampler u u -- void
c-function glSamplerParameteri glSamplerParameteri u u n -- void
c-function glSamplerParameteriv glSamplerParameteriv u u a -- void
c-function glSamplerParameterf glSamplerParameterf u u r -- void
c-function glSamplerParameterfv glSamplerParameterfv u u a -- void
c-function glSamplerParameterIiv glSamplerParameterIiv u u a -- void
c-function glSamplerParameterIuiv glSamplerParameterIuiv u u a -- void
c-function glGetSamplerParameteriv glGetSamplerParameteriv u u a -- void
c-function glGetSamplerParameterIiv glGetSamplerParameterIiv u u a -- void
c-function glGetSamplerParameterfv glGetSamplerParameterfv u u a -- void
c-function glGetSamplerParameterIuiv glGetSamplerParameterIuiv u u a -- void
c-function glQueryCounter glQueryCounter u u -- void
c-function glGetQueryObjecti64v glGetQueryObjecti64v u u a -- void
c-function glGetQueryObjectui64v glGetQueryObjectui64v u u a -- void
c-function glVertexAttribDivisor glVertexAttribDivisor u u -- void
c-function glVertexAttribP1ui glVertexAttribP1ui u u n u -- void
c-function glVertexAttribP1uiv glVertexAttribP1uiv u u n a -- void
c-function glVertexAttribP2ui glVertexAttribP2ui u u n u -- void
c-function glVertexAttribP2uiv glVertexAttribP2uiv u u n a -- void
c-function glVertexAttribP3ui glVertexAttribP3ui u u n u -- void
c-function glVertexAttribP3uiv glVertexAttribP3uiv u u n a -- void
c-function glVertexAttribP4ui glVertexAttribP4ui u u n u -- void
c-function glVertexAttribP4uiv glVertexAttribP4uiv u u n a -- void
c-function glVertexP2ui glVertexP2ui u u -- void
c-function glVertexP2uiv glVertexP2uiv u a -- void
c-function glVertexP3ui glVertexP3ui u u -- void
c-function glVertexP3uiv glVertexP3uiv u a -- void
c-function glVertexP4ui glVertexP4ui u u -- void
c-function glVertexP4uiv glVertexP4uiv u a -- void
c-function glTexCoordP1ui glTexCoordP1ui u u -- void
c-function glTexCoordP1uiv glTexCoordP1uiv u a -- void
c-function glTexCoordP2ui glTexCoordP2ui u u -- void
c-function glTexCoordP2uiv glTexCoordP2uiv u a -- void
c-function glTexCoordP3ui glTexCoordP3ui u u -- void
c-function glTexCoordP3uiv glTexCoordP3uiv u a -- void
c-function glTexCoordP4ui glTexCoordP4ui u u -- void
c-function glTexCoordP4uiv glTexCoordP4uiv u a -- void
c-function glMultiTexCoordP1ui glMultiTexCoordP1ui u u u -- void
c-function glMultiTexCoordP1uiv glMultiTexCoordP1uiv u u a -- void
c-function glMultiTexCoordP2ui glMultiTexCoordP2ui u u u -- void
c-function glMultiTexCoordP2uiv glMultiTexCoordP2uiv u u a -- void
c-function glMultiTexCoordP3ui glMultiTexCoordP3ui u u u -- void
c-function glMultiTexCoordP3uiv glMultiTexCoordP3uiv u u a -- void
c-function glMultiTexCoordP4ui glMultiTexCoordP4ui u u u -- void
c-function glMultiTexCoordP4uiv glMultiTexCoordP4uiv u u a -- void
c-function glNormalP3ui glNormalP3ui u u -- void
c-function glNormalP3uiv glNormalP3uiv u a -- void
c-function glColorP3ui glColorP3ui u u -- void
c-function glColorP3uiv glColorP3uiv u a -- void
c-function glColorP4ui glColorP4ui u u -- void
c-function glColorP4uiv glColorP4uiv u a -- void
c-function glSecondaryColorP3ui glSecondaryColorP3ui u u -- void
c-function glSecondaryColorP3uiv glSecondaryColorP3uiv u a -- void
c-function glMinSampleShading glMinSampleShading r -- void
c-function glBlendEquationi glBlendEquationi u u -- void
c-function glBlendEquationSeparatei glBlendEquationSeparatei u u u -- void
c-function glBlendFunci glBlendFunci u u u -- void
c-function glBlendFuncSeparatei glBlendFuncSeparatei u u u u u -- void
c-function glDrawArraysIndirect glDrawArraysIndirect u a -- void
c-function glDrawElementsIndirect glDrawElementsIndirect u u a -- void
c-function glUniform1d glUniform1d n r -- void
c-function glUniform2d glUniform2d n r r -- void
c-function glUniform3d glUniform3d n r r r -- void
c-function glUniform4d glUniform4d n r r r r -- void
c-function glUniform1dv glUniform1dv n n a -- void
c-function glUniform2dv glUniform2dv n n a -- void
c-function glUniform3dv glUniform3dv n n a -- void
c-function glUniform4dv glUniform4dv n n a -- void
c-function glUniformMatrix2dv glUniformMatrix2dv n n n a -- void
c-function glUniformMatrix3dv glUniformMatrix3dv n n n a -- void
c-function glUniformMatrix4dv glUniformMatrix4dv n n n a -- void
c-function glUniformMatrix2x3dv glUniformMatrix2x3dv n n n a -- void
c-function glUniformMatrix2x4dv glUniformMatrix2x4dv n n n a -- void
c-function glUniformMatrix3x2dv glUniformMatrix3x2dv n n n a -- void
c-function glUniformMatrix3x4dv glUniformMatrix3x4dv n n n a -- void
c-function glUniformMatrix4x2dv glUniformMatrix4x2dv n n n a -- void
c-function glUniformMatrix4x3dv glUniformMatrix4x3dv n n n a -- void
c-function glGetUniformdv glGetUniformdv u n a -- void
c-function glGetSubroutineUniformLocation glGetSubroutineUniformLocation u u a -- n
c-function glGetSubroutineIndex glGetSubroutineIndex u u a -- u
c-function glGetActiveSubroutineUniformiv glGetActiveSubroutineUniformiv u u u u a -- void
c-function glGetActiveSubroutineUniformName glGetActiveSubroutineUniformName u u u n a a -- void
c-function glGetActiveSubroutineName glGetActiveSubroutineName u u u n a a -- void
c-function glUniformSubroutinesuiv glUniformSubroutinesuiv u n a -- void
c-function glGetUniformSubroutineuiv glGetUniformSubroutineuiv u n a -- void
c-function glGetProgramStageiv glGetProgramStageiv u u u a -- void
c-function glPatchParameteri glPatchParameteri u n -- void
c-function glPatchParameterfv glPatchParameterfv u a -- void
c-function glBindTransformFeedback glBindTransformFeedback u u -- void
c-function glDeleteTransformFeedbacks glDeleteTransformFeedbacks n a -- void
c-function glGenTransformFeedbacks glGenTransformFeedbacks n a -- void
c-function glIsTransformFeedback glIsTransformFeedback u -- n
c-function glPauseTransformFeedback glPauseTransformFeedback  -- void
c-function glResumeTransformFeedback glResumeTransformFeedback  -- void
c-function glDrawTransformFeedback glDrawTransformFeedback u u -- void
c-function glDrawTransformFeedbackStream glDrawTransformFeedbackStream u u u -- void
c-function glBeginQueryIndexed glBeginQueryIndexed u u u -- void
c-function glEndQueryIndexed glEndQueryIndexed u u -- void
c-function glGetQueryIndexediv glGetQueryIndexediv u u u a -- void
c-function glReleaseShaderCompiler glReleaseShaderCompiler  -- void
c-function glShaderBinary glShaderBinary n a u a n -- void
c-function glGetShaderPrecisionFormat glGetShaderPrecisionFormat u u a a -- void
c-function glDepthRangef glDepthRangef r r -- void
c-function glClearDepthf glClearDepthf r -- void
c-function glGetProgramBinary glGetProgramBinary u n a a a -- void
c-function glProgramBinary glProgramBinary u u a n -- void
c-function glProgramParameteri glProgramParameteri u u n -- void
c-function glUseProgramStages glUseProgramStages u u u -- void
c-function glActiveShaderProgram glActiveShaderProgram u u -- void
c-function glCreateShaderProgramv glCreateShaderProgramv u n a -- u
c-function glBindProgramPipeline glBindProgramPipeline u -- void
c-function glDeleteProgramPipelines glDeleteProgramPipelines n a -- void
c-function glGenProgramPipelines glGenProgramPipelines n a -- void
c-function glIsProgramPipeline glIsProgramPipeline u -- n
c-function glGetProgramPipelineiv glGetProgramPipelineiv u u a -- void
c-function glProgramUniform1i glProgramUniform1i u n n -- void
c-function glProgramUniform1iv glProgramUniform1iv u n n a -- void
c-function glProgramUniform1f glProgramUniform1f u n r -- void
c-function glProgramUniform1fv glProgramUniform1fv u n n a -- void
c-function glProgramUniform1d glProgramUniform1d u n r -- void
c-function glProgramUniform1dv glProgramUniform1dv u n n a -- void
c-function glProgramUniform1ui glProgramUniform1ui u n u -- void
c-function glProgramUniform1uiv glProgramUniform1uiv u n n a -- void
c-function glProgramUniform2i glProgramUniform2i u n n n -- void
c-function glProgramUniform2iv glProgramUniform2iv u n n a -- void
c-function glProgramUniform2f glProgramUniform2f u n r r -- void
c-function glProgramUniform2fv glProgramUniform2fv u n n a -- void
c-function glProgramUniform2d glProgramUniform2d u n r r -- void
c-function glProgramUniform2dv glProgramUniform2dv u n n a -- void
c-function glProgramUniform2ui glProgramUniform2ui u n u u -- void
c-function glProgramUniform2uiv glProgramUniform2uiv u n n a -- void
c-function glProgramUniform3i glProgramUniform3i u n n n n -- void
c-function glProgramUniform3iv glProgramUniform3iv u n n a -- void
c-function glProgramUniform3f glProgramUniform3f u n r r r -- void
c-function glProgramUniform3fv glProgramUniform3fv u n n a -- void
c-function glProgramUniform3d glProgramUniform3d u n r r r -- void
c-function glProgramUniform3dv glProgramUniform3dv u n n a -- void
c-function glProgramUniform3ui glProgramUniform3ui u n u u u -- void
c-function glProgramUniform3uiv glProgramUniform3uiv u n n a -- void
c-function glProgramUniform4i glProgramUniform4i u n n n n n -- void
c-function glProgramUniform4iv glProgramUniform4iv u n n a -- void
c-function glProgramUniform4f glProgramUniform4f u n r r r r -- void
c-function glProgramUniform4fv glProgramUniform4fv u n n a -- void
c-function glProgramUniform4d glProgramUniform4d u n r r r r -- void
c-function glProgramUniform4dv glProgramUniform4dv u n n a -- void
c-function glProgramUniform4ui glProgramUniform4ui u n u u u u -- void
c-function glProgramUniform4uiv glProgramUniform4uiv u n n a -- void
c-function glProgramUniformMatrix2fv glProgramUniformMatrix2fv u n n n a -- void
c-function glProgramUniformMatrix3fv glProgramUniformMatrix3fv u n n n a -- void
c-function glProgramUniformMatrix4fv glProgramUniformMatrix4fv u n n n a -- void
c-function glProgramUniformMatrix2dv glProgramUniformMatrix2dv u n n n a -- void
c-function glProgramUniformMatrix3dv glProgramUniformMatrix3dv u n n n a -- void
c-function glProgramUniformMatrix4dv glProgramUniformMatrix4dv u n n n a -- void
c-function glProgramUniformMatrix2x3fv glProgramUniformMatrix2x3fv u n n n a -- void
c-function glProgramUniformMatrix3x2fv glProgramUniformMatrix3x2fv u n n n a -- void
c-function glProgramUniformMatrix2x4fv glProgramUniformMatrix2x4fv u n n n a -- void
c-function glProgramUniformMatrix4x2fv glProgramUniformMatrix4x2fv u n n n a -- void
c-function glProgramUniformMatrix3x4fv glProgramUniformMatrix3x4fv u n n n a -- void
c-function glProgramUniformMatrix4x3fv glProgramUniformMatrix4x3fv u n n n a -- void
c-function glProgramUniformMatrix2x3dv glProgramUniformMatrix2x3dv u n n n a -- void
c-function glProgramUniformMatrix3x2dv glProgramUniformMatrix3x2dv u n n n a -- void
c-function glProgramUniformMatrix2x4dv glProgramUniformMatrix2x4dv u n n n a -- void
c-function glProgramUniformMatrix4x2dv glProgramUniformMatrix4x2dv u n n n a -- void
c-function glProgramUniformMatrix3x4dv glProgramUniformMatrix3x4dv u n n n a -- void
c-function glProgramUniformMatrix4x3dv glProgramUniformMatrix4x3dv u n n n a -- void
c-function glValidateProgramPipeline glValidateProgramPipeline u -- void
c-function glGetProgramPipelineInfoLog glGetProgramPipelineInfoLog u n a a -- void
c-function glVertexAttribL1d glVertexAttribL1d u r -- void
c-function glVertexAttribL2d glVertexAttribL2d u r r -- void
c-function glVertexAttribL3d glVertexAttribL3d u r r r -- void
c-function glVertexAttribL4d glVertexAttribL4d u r r r r -- void
c-function glVertexAttribL1dv glVertexAttribL1dv u a -- void
c-function glVertexAttribL2dv glVertexAttribL2dv u a -- void
c-function glVertexAttribL3dv glVertexAttribL3dv u a -- void
c-function glVertexAttribL4dv glVertexAttribL4dv u a -- void
c-function glVertexAttribLPointer glVertexAttribLPointer u n u n a -- void
c-function glGetVertexAttribLdv glGetVertexAttribLdv u u a -- void
c-function glViewportArrayv glViewportArrayv u n a -- void
c-function glViewportIndexedf glViewportIndexedf u r r r r -- void
c-function glViewportIndexedfv glViewportIndexedfv u a -- void
c-function glScissorArrayv glScissorArrayv u n a -- void
c-function glScissorIndexed glScissorIndexed u n n n n -- void
c-function glScissorIndexedv glScissorIndexedv u a -- void
c-function glDepthRangeArrayv glDepthRangeArrayv u n a -- void
c-function glDepthRangeIndexed glDepthRangeIndexed u r r -- void
c-function glGetFloati_v glGetFloati_v u u a -- void
c-function glGetDoublei_v glGetDoublei_v u u a -- void
c-function glDrawArraysInstancedBaseInstance glDrawArraysInstancedBaseInstance u n n n u -- void
c-function glDrawElementsInstancedBaseInstance glDrawElementsInstancedBaseInstance u n u a n u -- void
c-function glDrawElementsInstancedBaseVertexBaseInstance glDrawElementsInstancedBaseVertexBaseInstance u n u a n n u -- void
c-function glGetInternalformativ glGetInternalformativ u u u n a -- void
c-function glGetActiveAtomicCounterBufferiv glGetActiveAtomicCounterBufferiv u u u a -- void
c-function glBindImageTexture glBindImageTexture u u n n n u u -- void
c-function glMemoryBarrier glMemoryBarrier u -- void
c-function glTexStorage1D glTexStorage1D u n u n -- void
c-function glTexStorage2D glTexStorage2D u n u n n -- void
c-function glTexStorage3D glTexStorage3D u n u n n n -- void
c-function glDrawTransformFeedbackInstanced glDrawTransformFeedbackInstanced u u n -- void
c-function glDrawTransformFeedbackStreamInstanced glDrawTransformFeedbackStreamInstanced u u u n -- void
c-function glClearBufferData glClearBufferData u u u u a -- void
c-function glClearBufferSubData glClearBufferSubData u u n n u u a -- void
c-function glDispatchCompute glDispatchCompute u u u -- void
c-function glDispatchComputeIndirect glDispatchComputeIndirect n -- void
c-function glCopyImageSubData glCopyImageSubData u u n n n n u u n n n n n n n -- void
c-function glFramebufferParameteri glFramebufferParameteri u u n -- void
c-function glGetFramebufferParameteriv glGetFramebufferParameteriv u u a -- void
c-function glGetInternalformati64v glGetInternalformati64v u u u n a -- void
c-function glInvalidateTexSubImage glInvalidateTexSubImage u n n n n n n n -- void
c-function glInvalidateTexImage glInvalidateTexImage u n -- void
c-function glInvalidateBufferSubData glInvalidateBufferSubData u n n -- void
c-function glInvalidateBufferData glInvalidateBufferData u -- void
c-function glInvalidateFramebuffer glInvalidateFramebuffer u n a -- void
c-function glInvalidateSubFramebuffer glInvalidateSubFramebuffer u n a n n n n -- void
c-function glMultiDrawArraysIndirect glMultiDrawArraysIndirect u a n n -- void
c-function glMultiDrawElementsIndirect glMultiDrawElementsIndirect u u a n n -- void
c-function glGetProgramInterfaceiv glGetProgramInterfaceiv u u u a -- void
c-function glGetProgramResourceIndex glGetProgramResourceIndex u u a -- u
c-function glGetProgramResourceName glGetProgramResourceName u u u n a a -- void
c-function glGetProgramResourceiv glGetProgramResourceiv u u u n a n a a -- void
c-function glGetProgramResourceLocation glGetProgramResourceLocation u u a -- n
c-function glGetProgramResourceLocationIndex glGetProgramResourceLocationIndex u u a -- n
c-function glShaderStorageBlockBinding glShaderStorageBlockBinding u u u -- void
c-function glTexBufferRange glTexBufferRange u u u n n -- void
c-function glTexStorage2DMultisample glTexStorage2DMultisample u n u n n n -- void
c-function glTexStorage3DMultisample glTexStorage3DMultisample u n u n n n n -- void
c-function glTextureView glTextureView u u u u u u u u -- void
c-function glBindVertexBuffer glBindVertexBuffer u u n n -- void
c-function glVertexAttribFormat glVertexAttribFormat u n u n u -- void
c-function glVertexAttribIFormat glVertexAttribIFormat u n u u -- void
c-function glVertexAttribLFormat glVertexAttribLFormat u n u u -- void
c-function glVertexAttribBinding glVertexAttribBinding u u -- void
c-function glVertexBindingDivisor glVertexBindingDivisor u u -- void
c-function glDebugMessageControl glDebugMessageControl u u u n a n -- void
c-function glDebugMessageInsert glDebugMessageInsert u u u u n a -- void
c-function glDebugMessageCallback glDebugMessageCallback a a -- void
c-function glGetDebugMessageLog glGetDebugMessageLog u n a a a a a a -- u
c-function glPushDebugGroup glPushDebugGroup u u n a -- void
c-function glPopDebugGroup glPopDebugGroup  -- void
c-function glObjectLabel glObjectLabel u u n a -- void
c-function glGetObjectLabel glGetObjectLabel u u n a a -- void
c-function glObjectPtrLabel glObjectPtrLabel a n a -- void
c-function glGetObjectPtrLabel glGetObjectPtrLabel a n a a -- void
c-function glBufferStorage glBufferStorage u n a u -- void
c-function glClearTexImage glClearTexImage u n u u a -- void
c-function glClearTexSubImage glClearTexSubImage u n n n n n n n u u a -- void
c-function glBindBuffersBase glBindBuffersBase u u n a -- void
c-function glBindBuffersRange glBindBuffersRange u u n a a a -- void
c-function glBindTextures glBindTextures u n a -- void
c-function glBindSamplers glBindSamplers u n a -- void
c-function glBindImageTextures glBindImageTextures u n a -- void
c-function glBindVertexBuffers glBindVertexBuffers u n a a a -- void
c-function glClipControl glClipControl u u -- void
c-function glCreateTransformFeedbacks glCreateTransformFeedbacks n a -- void
c-function glTransformFeedbackBufferBase glTransformFeedbackBufferBase u u u -- void
c-function glTransformFeedbackBufferRange glTransformFeedbackBufferRange u u u n n -- void
c-function glGetTransformFeedbackiv glGetTransformFeedbackiv u u a -- void
c-function glGetTransformFeedbacki_v glGetTransformFeedbacki_v u u u a -- void
c-function glGetTransformFeedbacki64_v glGetTransformFeedbacki64_v u u u a -- void
c-function glCreateBuffers glCreateBuffers n a -- void
c-function glNamedBufferStorage glNamedBufferStorage u n a u -- void
c-function glNamedBufferData glNamedBufferData u n a u -- void
c-function glNamedBufferSubData glNamedBufferSubData u n n a -- void
c-function glCopyNamedBufferSubData glCopyNamedBufferSubData u u n n n -- void
c-function glClearNamedBufferData glClearNamedBufferData u u u u a -- void
c-function glClearNamedBufferSubData glClearNamedBufferSubData u u n n u u a -- void
c-function glMapNamedBuffer glMapNamedBuffer u u -- a
c-function glMapNamedBufferRange glMapNamedBufferRange u n n u -- a
c-function glUnmapNamedBuffer glUnmapNamedBuffer u -- n
c-function glFlushMappedNamedBufferRange glFlushMappedNamedBufferRange u n n -- void
c-function glGetNamedBufferParameteriv glGetNamedBufferParameteriv u u a -- void
c-function glGetNamedBufferParameteri64v glGetNamedBufferParameteri64v u u a -- void
c-function glGetNamedBufferPointerv glGetNamedBufferPointerv u u a -- void
c-function glGetNamedBufferSubData glGetNamedBufferSubData u n n a -- void
c-function glCreateFramebuffers glCreateFramebuffers n a -- void
c-function glNamedFramebufferRenderbuffer glNamedFramebufferRenderbuffer u u u u -- void
c-function glNamedFramebufferParameteri glNamedFramebufferParameteri u u n -- void
c-function glNamedFramebufferTexture glNamedFramebufferTexture u u u n -- void
c-function glNamedFramebufferTextureLayer glNamedFramebufferTextureLayer u u u n n -- void
c-function glNamedFramebufferDrawBuffer glNamedFramebufferDrawBuffer u u -- void
c-function glNamedFramebufferDrawBuffers glNamedFramebufferDrawBuffers u n a -- void
c-function glNamedFramebufferReadBuffer glNamedFramebufferReadBuffer u u -- void
c-function glInvalidateNamedFramebufferData glInvalidateNamedFramebufferData u n a -- void
c-function glInvalidateNamedFramebufferSubData glInvalidateNamedFramebufferSubData u n a n n n n -- void
c-function glClearNamedFramebufferiv glClearNamedFramebufferiv u u n a -- void
c-function glClearNamedFramebufferuiv glClearNamedFramebufferuiv u u n a -- void
c-function glClearNamedFramebufferfv glClearNamedFramebufferfv u u n a -- void
c-function glClearNamedFramebufferfi glClearNamedFramebufferfi u u r n -- void
c-function glBlitNamedFramebuffer glBlitNamedFramebuffer u u n n n n n n n n u u -- void
c-function glCheckNamedFramebufferStatus glCheckNamedFramebufferStatus u u -- u
c-function glGetNamedFramebufferParameteriv glGetNamedFramebufferParameteriv u u a -- void
c-function glGetNamedFramebufferAttachmentParameteriv glGetNamedFramebufferAttachmentParameteriv u u u a -- void
c-function glCreateRenderbuffers glCreateRenderbuffers n a -- void
c-function glNamedRenderbufferStorage glNamedRenderbufferStorage u u n n -- void
c-function glNamedRenderbufferStorageMultisample glNamedRenderbufferStorageMultisample u n u n n -- void
c-function glGetNamedRenderbufferParameteriv glGetNamedRenderbufferParameteriv u u a -- void
c-function glCreateTextures glCreateTextures u n a -- void
c-function glTextureBuffer glTextureBuffer u u u -- void
c-function glTextureBufferRange glTextureBufferRange u u u n n -- void
c-function glTextureStorage1D glTextureStorage1D u n u n -- void
c-function glTextureStorage2D glTextureStorage2D u n u n n -- void
c-function glTextureStorage3D glTextureStorage3D u n u n n n -- void
c-function glTextureStorage2DMultisample glTextureStorage2DMultisample u n u n n n -- void
c-function glTextureStorage3DMultisample glTextureStorage3DMultisample u n u n n n n -- void
c-function glTextureSubImage1D glTextureSubImage1D u n n n u u a -- void
c-function glTextureSubImage2D glTextureSubImage2D u n n n n n u u a -- void
c-function glTextureSubImage3D glTextureSubImage3D u n n n n n n n u u a -- void
c-function glCompressedTextureSubImage1D glCompressedTextureSubImage1D u n n n u n a -- void
c-function glCompressedTextureSubImage2D glCompressedTextureSubImage2D u n n n n n u n a -- void
c-function glCompressedTextureSubImage3D glCompressedTextureSubImage3D u n n n n n n n u n a -- void
c-function glCopyTextureSubImage1D glCopyTextureSubImage1D u n n n n n -- void
c-function glCopyTextureSubImage2D glCopyTextureSubImage2D u n n n n n n n -- void
c-function glCopyTextureSubImage3D glCopyTextureSubImage3D u n n n n n n n n -- void
c-function glTextureParameterf glTextureParameterf u u r -- void
c-function glTextureParameterfv glTextureParameterfv u u a -- void
c-function glTextureParameteri glTextureParameteri u u n -- void
c-function glTextureParameterIiv glTextureParameterIiv u u a -- void
c-function glTextureParameterIuiv glTextureParameterIuiv u u a -- void
c-function glTextureParameteriv glTextureParameteriv u u a -- void
c-function glGenerateTextureMipmap glGenerateTextureMipmap u -- void
c-function glBindTextureUnit glBindTextureUnit u u -- void
c-function glGetTextureImage glGetTextureImage u n u u n a -- void
c-function glGetCompressedTextureImage glGetCompressedTextureImage u n n a -- void
c-function glGetTextureLevelParameterfv glGetTextureLevelParameterfv u n u a -- void
c-function glGetTextureLevelParameteriv glGetTextureLevelParameteriv u n u a -- void
c-function glGetTextureParameterfv glGetTextureParameterfv u u a -- void
c-function glGetTextureParameterIiv glGetTextureParameterIiv u u a -- void
c-function glGetTextureParameterIuiv glGetTextureParameterIuiv u u a -- void
c-function glGetTextureParameteriv glGetTextureParameteriv u u a -- void
c-function glCreateVertexArrays glCreateVertexArrays n a -- void
c-function glDisableVertexArrayAttrib glDisableVertexArrayAttrib u u -- void
c-function glEnableVertexArrayAttrib glEnableVertexArrayAttrib u u -- void
c-function glVertexArrayElementBuffer glVertexArrayElementBuffer u u -- void
c-function glVertexArrayVertexBuffer glVertexArrayVertexBuffer u u u n n -- void
c-function glVertexArrayVertexBuffers glVertexArrayVertexBuffers u u n a a a -- void
c-function glVertexArrayAttribBinding glVertexArrayAttribBinding u u u -- void
c-function glVertexArrayAttribFormat glVertexArrayAttribFormat u u n u n u -- void
c-function glVertexArrayAttribIFormat glVertexArrayAttribIFormat u u n u u -- void
c-function glVertexArrayAttribLFormat glVertexArrayAttribLFormat u u n u u -- void
c-function glVertexArrayBindingDivisor glVertexArrayBindingDivisor u u u -- void
c-function glGetVertexArrayiv glGetVertexArrayiv u u a -- void
c-function glGetVertexArrayIndexediv glGetVertexArrayIndexediv u u u a -- void
c-function glGetVertexArrayIndexed64iv glGetVertexArrayIndexed64iv u u u a -- void
c-function glCreateSamplers glCreateSamplers n a -- void
c-function glCreateProgramPipelines glCreateProgramPipelines n a -- void
c-function glCreateQueries glCreateQueries u n a -- void
c-function glGetQueryBufferObjecti64v glGetQueryBufferObjecti64v u u u n -- void
c-function glGetQueryBufferObjectiv glGetQueryBufferObjectiv u u u n -- void
c-function glGetQueryBufferObjectui64v glGetQueryBufferObjectui64v u u u n -- void
c-function glGetQueryBufferObjectuiv glGetQueryBufferObjectuiv u u u n -- void
c-function glMemoryBarrierByRegion glMemoryBarrierByRegion u -- void
c-function glGetTextureSubImage glGetTextureSubImage u n n n n n n n u u n a -- void
c-function glGetCompressedTextureSubImage glGetCompressedTextureSubImage u n n n n n n n n a -- void
c-function glGetGraphicsResetStatus glGetGraphicsResetStatus  -- u
c-function glGetnCompressedTexImage glGetnCompressedTexImage u n n a -- void
c-function glGetnTexImage glGetnTexImage u n u u n a -- void
c-function glGetnUniformdv glGetnUniformdv u n n a -- void
c-function glGetnUniformfv glGetnUniformfv u n n a -- void
c-function glGetnUniformiv glGetnUniformiv u n n a -- void
c-function glGetnUniformuiv glGetnUniformuiv u n n a -- void
c-function glReadnPixels glReadnPixels n n n n u u n a -- void
c-function glGetnMapdv glGetnMapdv u u n a -- void
c-function glGetnMapfv glGetnMapfv u u n a -- void
c-function glGetnMapiv glGetnMapiv u u n a -- void
c-function glGetnPixelMapfv glGetnPixelMapfv u n a -- void
c-function glGetnPixelMapuiv glGetnPixelMapuiv u n a -- void
c-function glGetnPixelMapusv glGetnPixelMapusv u n a -- void
c-function glGetnPolygonStipple glGetnPolygonStipple n a -- void
c-function glGetnColorTable glGetnColorTable u u u n a -- void
c-function glGetnConvolutionFilter glGetnConvolutionFilter u u u n a -- void
c-function glGetnSeparableFilter glGetnSeparableFilter u u u n a n a a -- void
c-function glGetnHistogram glGetnHistogram u n u u n a -- void
c-function glGetnMinmax glGetnMinmax u n u u n a -- void
c-function glTextureBarrier glTextureBarrier  -- void
c-function glGetTextureHandleARB glGetTextureHandleARB u -- d
c-function glGetTextureSamplerHandleARB glGetTextureSamplerHandleARB u u -- d
c-function glMakeTextureHandleResidentARB glMakeTextureHandleResidentARB d -- void
c-function glMakeTextureHandleNonResidentARB glMakeTextureHandleNonResidentARB d -- void
c-function glGetImageHandleARB glGetImageHandleARB u n n n u -- d
c-function glMakeImageHandleResidentARB glMakeImageHandleResidentARB d u -- void
c-function glMakeImageHandleNonResidentARB glMakeImageHandleNonResidentARB d -- void
c-function glUniformHandleui64ARB glUniformHandleui64ARB n d -- void
c-function glUniformHandleui64vARB glUniformHandleui64vARB n n a -- void
c-function glProgramUniformHandleui64ARB glProgramUniformHandleui64ARB u n d -- void
c-function glProgramUniformHandleui64vARB glProgramUniformHandleui64vARB u n n a -- void
c-function glIsTextureHandleResidentARB glIsTextureHandleResidentARB d -- n
c-function glIsImageHandleResidentARB glIsImageHandleResidentARB d -- n
c-function glVertexAttribL1ui64ARB glVertexAttribL1ui64ARB u d -- void
c-function glVertexAttribL1ui64vARB glVertexAttribL1ui64vARB u a -- void
c-function glGetVertexAttribLui64vARB glGetVertexAttribLui64vARB u u a -- void
c-function glCreateSyncFromCLeventARB glCreateSyncFromCLeventARB a a u -- a
c-function glClampColorARB glClampColorARB u u -- void
c-function glDispatchComputeGroupSizeARB glDispatchComputeGroupSizeARB u u u u u u -- void
c-function glDebugMessageControlARB glDebugMessageControlARB u u u n a n -- void
c-function glDebugMessageInsertARB glDebugMessageInsertARB u u u u n a -- void
c-function glDebugMessageCallbackARB glDebugMessageCallbackARB a a -- void
c-function glGetDebugMessageLogARB glGetDebugMessageLogARB u n a a a a a a -- u
c-function glDrawBuffersARB glDrawBuffersARB n a -- void
c-function glBlendEquationiARB glBlendEquationiARB u u -- void
c-function glBlendEquationSeparateiARB glBlendEquationSeparateiARB u u u -- void
c-function glBlendFunciARB glBlendFunciARB u u u -- void
c-function glBlendFuncSeparateiARB glBlendFuncSeparateiARB u u u u u -- void
c-function glDrawArraysInstancedARB glDrawArraysInstancedARB u n n n -- void
c-function glDrawElementsInstancedARB glDrawElementsInstancedARB u n u a n -- void
c-function glProgramStringARB glProgramStringARB u u n a -- void
c-function glBindProgramARB glBindProgramARB u u -- void
c-function glDeleteProgramsARB glDeleteProgramsARB n a -- void
c-function glGenProgramsARB glGenProgramsARB n a -- void
c-function glProgramEnvParameter4dARB glProgramEnvParameter4dARB u u r r r r -- void
c-function glProgramEnvParameter4dvARB glProgramEnvParameter4dvARB u u a -- void
c-function glProgramEnvParameter4fARB glProgramEnvParameter4fARB u u r r r r -- void
c-function glProgramEnvParameter4fvARB glProgramEnvParameter4fvARB u u a -- void
c-function glProgramLocalParameter4dARB glProgramLocalParameter4dARB u u r r r r -- void
c-function glProgramLocalParameter4dvARB glProgramLocalParameter4dvARB u u a -- void
c-function glProgramLocalParameter4fARB glProgramLocalParameter4fARB u u r r r r -- void
c-function glProgramLocalParameter4fvARB glProgramLocalParameter4fvARB u u a -- void
c-function glGetProgramEnvParameterdvARB glGetProgramEnvParameterdvARB u u a -- void
c-function glGetProgramEnvParameterfvARB glGetProgramEnvParameterfvARB u u a -- void
c-function glGetProgramLocalParameterdvARB glGetProgramLocalParameterdvARB u u a -- void
c-function glGetProgramLocalParameterfvARB glGetProgramLocalParameterfvARB u u a -- void
c-function glGetProgramivARB glGetProgramivARB u u a -- void
c-function glGetProgramStringARB glGetProgramStringARB u u a -- void
c-function glIsProgramARB glIsProgramARB u -- n
c-function glProgramParameteriARB glProgramParameteriARB u u n -- void
c-function glFramebufferTextureARB glFramebufferTextureARB u u u n -- void
c-function glFramebufferTextureLayerARB glFramebufferTextureLayerARB u u u n n -- void
c-function glFramebufferTextureFaceARB glFramebufferTextureFaceARB u u u n u -- void
c-function glMultiDrawArraysIndirectCountARB glMultiDrawArraysIndirectCountARB u n n n n -- void
c-function glMultiDrawElementsIndirectCountARB glMultiDrawElementsIndirectCountARB u u n n n n -- void
c-function glVertexAttribDivisorARB glVertexAttribDivisorARB u u -- void
c-function glCurrentPaletteMatrixARB glCurrentPaletteMatrixARB n -- void
c-function glMatrixIndexubvARB glMatrixIndexubvARB n a -- void
c-function glMatrixIndexusvARB glMatrixIndexusvARB n a -- void
c-function glMatrixIndexuivARB glMatrixIndexuivARB n a -- void
c-function glMatrixIndexPointerARB glMatrixIndexPointerARB n u n a -- void
c-function glSampleCoverageARB glSampleCoverageARB r n -- void
c-function glGenQueriesARB glGenQueriesARB n a -- void
c-function glDeleteQueriesARB glDeleteQueriesARB n a -- void
c-function glIsQueryARB glIsQueryARB u -- n
c-function glBeginQueryARB glBeginQueryARB u u -- void
c-function glEndQueryARB glEndQueryARB u -- void
c-function glGetQueryivARB glGetQueryivARB u u a -- void
c-function glGetQueryObjectivARB glGetQueryObjectivARB u u a -- void
c-function glGetQueryObjectuivARB glGetQueryObjectuivARB u u a -- void
c-function glPointParameterfARB glPointParameterfARB u r -- void
c-function glPointParameterfvARB glPointParameterfvARB u a -- void
c-function glGetGraphicsResetStatusARB glGetGraphicsResetStatusARB  -- u
c-function glGetnTexImageARB glGetnTexImageARB u n u u n a -- void
c-function glReadnPixelsARB glReadnPixelsARB n n n n u u n a -- void
c-function glGetnCompressedTexImageARB glGetnCompressedTexImageARB u n n a -- void
c-function glGetnUniformfvARB glGetnUniformfvARB u n n a -- void
c-function glGetnUniformivARB glGetnUniformivARB u n n a -- void
c-function glGetnUniformuivARB glGetnUniformuivARB u n n a -- void
c-function glGetnUniformdvARB glGetnUniformdvARB u n n a -- void
c-function glGetnMapdvARB glGetnMapdvARB u u n a -- void
c-function glGetnMapfvARB glGetnMapfvARB u u n a -- void
c-function glGetnMapivARB glGetnMapivARB u u n a -- void
c-function glGetnPixelMapfvARB glGetnPixelMapfvARB u n a -- void
c-function glGetnPixelMapuivARB glGetnPixelMapuivARB u n a -- void
c-function glGetnPixelMapusvARB glGetnPixelMapusvARB u n a -- void
c-function glGetnPolygonStippleARB glGetnPolygonStippleARB n a -- void
c-function glGetnColorTableARB glGetnColorTableARB u u u n a -- void
c-function glGetnConvolutionFilterARB glGetnConvolutionFilterARB u u u n a -- void
c-function glGetnSeparableFilterARB glGetnSeparableFilterARB u u u n a n a a -- void
c-function glGetnHistogramARB glGetnHistogramARB u n u u n a -- void
c-function glGetnMinmaxARB glGetnMinmaxARB u n u u n a -- void
c-function glMinSampleShadingARB glMinSampleShadingARB r -- void
c-function glDeleteObjectARB glDeleteObjectARB u -- void
c-function glGetHandleARB glGetHandleARB u -- u
c-function glDetachObjectARB glDetachObjectARB u u -- void
c-function glCreateShaderObjectARB glCreateShaderObjectARB u -- u
c-function glShaderSourceARB glShaderSourceARB u n a a -- void
c-function glCompileShaderARB glCompileShaderARB u -- void
c-function glCreateProgramObjectARB glCreateProgramObjectARB  -- u
c-function glAttachObjectARB glAttachObjectARB u u -- void
c-function glLinkProgramARB glLinkProgramARB u -- void
c-function glUseProgramObjectARB glUseProgramObjectARB u -- void
c-function glValidateProgramARB glValidateProgramARB u -- void
c-function glUniform1fARB glUniform1fARB n r -- void
c-function glUniform2fARB glUniform2fARB n r r -- void
c-function glUniform3fARB glUniform3fARB n r r r -- void
c-function glUniform4fARB glUniform4fARB n r r r r -- void
c-function glUniform1iARB glUniform1iARB n n -- void
c-function glUniform2iARB glUniform2iARB n n n -- void
c-function glUniform3iARB glUniform3iARB n n n n -- void
c-function glUniform4iARB glUniform4iARB n n n n n -- void
c-function glUniform1fvARB glUniform1fvARB n n a -- void
c-function glUniform2fvARB glUniform2fvARB n n a -- void
c-function glUniform3fvARB glUniform3fvARB n n a -- void
c-function glUniform4fvARB glUniform4fvARB n n a -- void
c-function glUniform1ivARB glUniform1ivARB n n a -- void
c-function glUniform2ivARB glUniform2ivARB n n a -- void
c-function glUniform3ivARB glUniform3ivARB n n a -- void
c-function glUniform4ivARB glUniform4ivARB n n a -- void
c-function glUniformMatrix2fvARB glUniformMatrix2fvARB n n n a -- void
c-function glUniformMatrix3fvARB glUniformMatrix3fvARB n n n a -- void
c-function glUniformMatrix4fvARB glUniformMatrix4fvARB n n n a -- void
c-function glGetObjectParameterfvARB glGetObjectParameterfvARB u u a -- void
c-function glGetObjectParameterivARB glGetObjectParameterivARB u u a -- void
c-function glGetInfoLogARB glGetInfoLogARB u n a a -- void
c-function glGetAttachedObjectsARB glGetAttachedObjectsARB u n a a -- void
c-function glGetUniformLocationARB glGetUniformLocationARB u a -- n
c-function glGetActiveUniformARB glGetActiveUniformARB u u n a a a a -- void
c-function glGetUniformfvARB glGetUniformfvARB u n a -- void
c-function glGetUniformivARB glGetUniformivARB u n a -- void
c-function glGetShaderSourceARB glGetShaderSourceARB u n a a -- void
c-function glNamedStringARB glNamedStringARB u n a n a -- void
c-function glDeleteNamedStringARB glDeleteNamedStringARB n a -- void
c-function glCompileShaderIncludeARB glCompileShaderIncludeARB u n a a -- void
c-function glIsNamedStringARB glIsNamedStringARB n a -- n
c-function glGetNamedStringARB glGetNamedStringARB n a n a a -- void
c-function glGetNamedStringivARB glGetNamedStringivARB n a u a -- void
c-function glBufferPageCommitmentARB glBufferPageCommitmentARB u n n n -- void
c-function glNamedBufferPageCommitmentEXT glNamedBufferPageCommitmentEXT u n n n -- void
c-function glNamedBufferPageCommitmentARB glNamedBufferPageCommitmentARB u n n n -- void
c-function glTexPageCommitmentARB glTexPageCommitmentARB u n n n n n n n n -- void
c-function glTexBufferARB glTexBufferARB u u u -- void
c-function glCompressedTexImage3DARB glCompressedTexImage3DARB u n u n n n n n a -- void
c-function glCompressedTexImage2DARB glCompressedTexImage2DARB u n u n n n n a -- void
c-function glCompressedTexImage1DARB glCompressedTexImage1DARB u n u n n n a -- void
c-function glCompressedTexSubImage3DARB glCompressedTexSubImage3DARB u n n n n n n n u n a -- void
c-function glCompressedTexSubImage2DARB glCompressedTexSubImage2DARB u n n n n n u n a -- void
c-function glCompressedTexSubImage1DARB glCompressedTexSubImage1DARB u n n n u n a -- void
c-function glGetCompressedTexImageARB glGetCompressedTexImageARB u n a -- void
c-function glLoadTransposeMatrixfARB glLoadTransposeMatrixfARB a -- void
c-function glLoadTransposeMatrixdARB glLoadTransposeMatrixdARB a -- void
c-function glMultTransposeMatrixfARB glMultTransposeMatrixfARB a -- void
c-function glMultTransposeMatrixdARB glMultTransposeMatrixdARB a -- void
c-function glWeightbvARB glWeightbvARB n a -- void
c-function glWeightsvARB glWeightsvARB n a -- void
c-function glWeightivARB glWeightivARB n a -- void
c-function glWeightfvARB glWeightfvARB n a -- void
c-function glWeightdvARB glWeightdvARB n a -- void
c-function glWeightubvARB glWeightubvARB n a -- void
c-function glWeightusvARB glWeightusvARB n a -- void
c-function glWeightuivARB glWeightuivARB n a -- void
c-function glWeightPointerARB glWeightPointerARB n u n a -- void
c-function glVertexBlendARB glVertexBlendARB n -- void
c-function glBindBufferARB glBindBufferARB u u -- void
c-function glDeleteBuffersARB glDeleteBuffersARB n a -- void
c-function glGenBuffersARB glGenBuffersARB n a -- void
c-function glIsBufferARB glIsBufferARB u -- n
c-function glBufferDataARB glBufferDataARB u n a u -- void
c-function glBufferSubDataARB glBufferSubDataARB u n n a -- void
c-function glGetBufferSubDataARB glGetBufferSubDataARB u n n a -- void
c-function glMapBufferARB glMapBufferARB u u -- a
c-function glUnmapBufferARB glUnmapBufferARB u -- n
c-function glGetBufferParameterivARB glGetBufferParameterivARB u u a -- void
c-function glGetBufferPointervARB glGetBufferPointervARB u u a -- void
c-function glVertexAttrib1dARB glVertexAttrib1dARB u r -- void
c-function glVertexAttrib1dvARB glVertexAttrib1dvARB u a -- void
c-function glVertexAttrib1fARB glVertexAttrib1fARB u r -- void
c-function glVertexAttrib1fvARB glVertexAttrib1fvARB u a -- void
c-function glVertexAttrib1sARB glVertexAttrib1sARB u n -- void
c-function glVertexAttrib1svARB glVertexAttrib1svARB u a -- void
c-function glVertexAttrib2dARB glVertexAttrib2dARB u r r -- void
c-function glVertexAttrib2dvARB glVertexAttrib2dvARB u a -- void
c-function glVertexAttrib2fARB glVertexAttrib2fARB u r r -- void
c-function glVertexAttrib2fvARB glVertexAttrib2fvARB u a -- void
c-function glVertexAttrib2sARB glVertexAttrib2sARB u n n -- void
c-function glVertexAttrib2svARB glVertexAttrib2svARB u a -- void
c-function glVertexAttrib3dARB glVertexAttrib3dARB u r r r -- void
c-function glVertexAttrib3dvARB glVertexAttrib3dvARB u a -- void
c-function glVertexAttrib3fARB glVertexAttrib3fARB u r r r -- void
c-function glVertexAttrib3fvARB glVertexAttrib3fvARB u a -- void
c-function glVertexAttrib3sARB glVertexAttrib3sARB u n n n -- void
c-function glVertexAttrib3svARB glVertexAttrib3svARB u a -- void
c-function glVertexAttrib4NbvARB glVertexAttrib4NbvARB u a -- void
c-function glVertexAttrib4NivARB glVertexAttrib4NivARB u a -- void
c-function glVertexAttrib4NsvARB glVertexAttrib4NsvARB u a -- void
c-function glVertexAttrib4NubARB glVertexAttrib4NubARB u n n n n -- void
c-function glVertexAttrib4NubvARB glVertexAttrib4NubvARB u a -- void
c-function glVertexAttrib4NuivARB glVertexAttrib4NuivARB u a -- void
c-function glVertexAttrib4NusvARB glVertexAttrib4NusvARB u a -- void
c-function glVertexAttrib4bvARB glVertexAttrib4bvARB u a -- void
c-function glVertexAttrib4dARB glVertexAttrib4dARB u r r r r -- void
c-function glVertexAttrib4dvARB glVertexAttrib4dvARB u a -- void
c-function glVertexAttrib4fARB glVertexAttrib4fARB u r r r r -- void
c-function glVertexAttrib4fvARB glVertexAttrib4fvARB u a -- void
c-function glVertexAttrib4ivARB glVertexAttrib4ivARB u a -- void
c-function glVertexAttrib4sARB glVertexAttrib4sARB u n n n n -- void
c-function glVertexAttrib4svARB glVertexAttrib4svARB u a -- void
c-function glVertexAttrib4ubvARB glVertexAttrib4ubvARB u a -- void
c-function glVertexAttrib4uivARB glVertexAttrib4uivARB u a -- void
c-function glVertexAttrib4usvARB glVertexAttrib4usvARB u a -- void
c-function glVertexAttribPointerARB glVertexAttribPointerARB u n u n n a -- void
c-function glEnableVertexAttribArrayARB glEnableVertexAttribArrayARB u -- void
c-function glDisableVertexAttribArrayARB glDisableVertexAttribArrayARB u -- void
c-function glGetVertexAttribdvARB glGetVertexAttribdvARB u u a -- void
c-function glGetVertexAttribfvARB glGetVertexAttribfvARB u u a -- void
c-function glGetVertexAttribivARB glGetVertexAttribivARB u u a -- void
c-function glGetVertexAttribPointervARB glGetVertexAttribPointervARB u u a -- void
c-function glBindAttribLocationARB glBindAttribLocationARB u u a -- void
c-function glGetActiveAttribARB glGetActiveAttribARB u u n a a a a -- void
c-function glGetAttribLocationARB glGetAttribLocationARB u a -- n
c-function glWindowPos2dARB glWindowPos2dARB r r -- void
c-function glWindowPos2dvARB glWindowPos2dvARB a -- void
c-function glWindowPos2fARB glWindowPos2fARB r r -- void
c-function glWindowPos2fvARB glWindowPos2fvARB a -- void
c-function glWindowPos2iARB glWindowPos2iARB n n -- void
c-function glWindowPos2ivARB glWindowPos2ivARB a -- void
c-function glWindowPos2sARB glWindowPos2sARB n n -- void
c-function glWindowPos2svARB glWindowPos2svARB a -- void
c-function glWindowPos3dARB glWindowPos3dARB r r r -- void
c-function glWindowPos3dvARB glWindowPos3dvARB a -- void
c-function glWindowPos3fARB glWindowPos3fARB r r r -- void
c-function glWindowPos3fvARB glWindowPos3fvARB a -- void
c-function glWindowPos3iARB glWindowPos3iARB n n n -- void
c-function glWindowPos3ivARB glWindowPos3ivARB a -- void
c-function glWindowPos3sARB glWindowPos3sARB n n n -- void
c-function glWindowPos3svARB glWindowPos3svARB a -- void
c-function glBlendBarrierKHR glBlendBarrierKHR  -- void
c-function glMultiTexCoord1bOES glMultiTexCoord1bOES u n -- void
c-function glMultiTexCoord1bvOES glMultiTexCoord1bvOES u a -- void
c-function glMultiTexCoord2bOES glMultiTexCoord2bOES u n n -- void
c-function glMultiTexCoord2bvOES glMultiTexCoord2bvOES u a -- void
c-function glMultiTexCoord3bOES glMultiTexCoord3bOES u n n n -- void
c-function glMultiTexCoord3bvOES glMultiTexCoord3bvOES u a -- void
c-function glMultiTexCoord4bOES glMultiTexCoord4bOES u n n n n -- void
c-function glMultiTexCoord4bvOES glMultiTexCoord4bvOES u a -- void
c-function glTexCoord1bOES glTexCoord1bOES n -- void
c-function glTexCoord1bvOES glTexCoord1bvOES a -- void
c-function glTexCoord2bOES glTexCoord2bOES n n -- void
c-function glTexCoord2bvOES glTexCoord2bvOES a -- void
c-function glTexCoord3bOES glTexCoord3bOES n n n -- void
c-function glTexCoord3bvOES glTexCoord3bvOES a -- void
c-function glTexCoord4bOES glTexCoord4bOES n n n n -- void
c-function glTexCoord4bvOES glTexCoord4bvOES a -- void
c-function glVertex2bOES glVertex2bOES n n -- void
c-function glVertex2bvOES glVertex2bvOES a -- void
c-function glVertex3bOES glVertex3bOES n n n -- void
c-function glVertex3bvOES glVertex3bvOES a -- void
c-function glVertex4bOES glVertex4bOES n n n n -- void
c-function glVertex4bvOES glVertex4bvOES a -- void
c-function glAlphaFuncxOES glAlphaFuncxOES u n -- void
c-function glClearColorxOES glClearColorxOES n n n n -- void
c-function glClearDepthxOES glClearDepthxOES n -- void
c-function glClipPlanexOES glClipPlanexOES u a -- void
c-function glColor4xOES glColor4xOES n n n n -- void
c-function glDepthRangexOES glDepthRangexOES n n -- void
c-function glFogxOES glFogxOES u n -- void
c-function glFogxvOES glFogxvOES u a -- void
c-function glFrustumxOES glFrustumxOES n n n n n n -- void
c-function glGetClipPlanexOES glGetClipPlanexOES u a -- void
c-function glGetFixedvOES glGetFixedvOES u a -- void
c-function glGetTexEnvxvOES glGetTexEnvxvOES u u a -- void
c-function glGetTexParameterxvOES glGetTexParameterxvOES u u a -- void
c-function glLightModelxOES glLightModelxOES u n -- void
c-function glLightModelxvOES glLightModelxvOES u a -- void
c-function glLightxOES glLightxOES u u n -- void
c-function glLightxvOES glLightxvOES u u a -- void
c-function glLineWidthxOES glLineWidthxOES n -- void
c-function glLoadMatrixxOES glLoadMatrixxOES a -- void
c-function glMaterialxOES glMaterialxOES u u n -- void
c-function glMaterialxvOES glMaterialxvOES u u a -- void
c-function glMultMatrixxOES glMultMatrixxOES a -- void
c-function glMultiTexCoord4xOES glMultiTexCoord4xOES u n n n n -- void
c-function glNormal3xOES glNormal3xOES n n n -- void
c-function glOrthoxOES glOrthoxOES n n n n n n -- void
c-function glPointParameterxvOES glPointParameterxvOES u a -- void
c-function glPointSizexOES glPointSizexOES n -- void
c-function glPolygonOffsetxOES glPolygonOffsetxOES n n -- void
c-function glRotatexOES glRotatexOES n n n n -- void
c-function glSampleCoverageOES glSampleCoverageOES n n -- void
c-function glScalexOES glScalexOES n n n -- void
c-function glTexEnvxOES glTexEnvxOES u u n -- void
c-function glTexEnvxvOES glTexEnvxvOES u u a -- void
c-function glTexParameterxOES glTexParameterxOES u u n -- void
c-function glTexParameterxvOES glTexParameterxvOES u u a -- void
c-function glTranslatexOES glTranslatexOES n n n -- void
c-function glAccumxOES glAccumxOES u n -- void
c-function glBitmapxOES glBitmapxOES n n n n n n a -- void
c-function glBlendColorxOES glBlendColorxOES n n n n -- void
c-function glClearAccumxOES glClearAccumxOES n n n n -- void
c-function glColor3xOES glColor3xOES n n n -- void
c-function glColor3xvOES glColor3xvOES a -- void
c-function glColor4xvOES glColor4xvOES a -- void
c-function glConvolutionParameterxOES glConvolutionParameterxOES u u n -- void
c-function glConvolutionParameterxvOES glConvolutionParameterxvOES u u a -- void
c-function glEvalCoord1xOES glEvalCoord1xOES n -- void
c-function glEvalCoord1xvOES glEvalCoord1xvOES a -- void
c-function glEvalCoord2xOES glEvalCoord2xOES n n -- void
c-function glEvalCoord2xvOES glEvalCoord2xvOES a -- void
c-function glFeedbackBufferxOES glFeedbackBufferxOES n u a -- void
c-function glGetConvolutionParameterxvOES glGetConvolutionParameterxvOES u u a -- void
c-function glGetHistogramParameterxvOES glGetHistogramParameterxvOES u u a -- void
c-function glGetLightxOES glGetLightxOES u u a -- void
c-function glGetMapxvOES glGetMapxvOES u u a -- void
c-function glGetMaterialxOES glGetMaterialxOES u u n -- void
c-function glGetPixelMapxv glGetPixelMapxv u n a -- void
c-function glGetTexGenxvOES glGetTexGenxvOES u u a -- void
c-function glGetTexLevelParameterxvOES glGetTexLevelParameterxvOES u n u a -- void
c-function glIndexxOES glIndexxOES n -- void
c-function glIndexxvOES glIndexxvOES a -- void
c-function glLoadTransposeMatrixxOES glLoadTransposeMatrixxOES a -- void
c-function glMap1xOES glMap1xOES u n n n n n -- void
c-function glMap2xOES glMap2xOES u n n n n n n n n n -- void
c-function glMapGrid1xOES glMapGrid1xOES n n n -- void
c-function glMapGrid2xOES glMapGrid2xOES n n n n n -- void
c-function glMultTransposeMatrixxOES glMultTransposeMatrixxOES a -- void
c-function glMultiTexCoord1xOES glMultiTexCoord1xOES u n -- void
c-function glMultiTexCoord1xvOES glMultiTexCoord1xvOES u a -- void
c-function glMultiTexCoord2xOES glMultiTexCoord2xOES u n n -- void
c-function glMultiTexCoord2xvOES glMultiTexCoord2xvOES u a -- void
c-function glMultiTexCoord3xOES glMultiTexCoord3xOES u n n n -- void
c-function glMultiTexCoord3xvOES glMultiTexCoord3xvOES u a -- void
c-function glMultiTexCoord4xvOES glMultiTexCoord4xvOES u a -- void
c-function glNormal3xvOES glNormal3xvOES a -- void
c-function glPassThroughxOES glPassThroughxOES n -- void
c-function glPixelMapx glPixelMapx u n a -- void
c-function glPixelStorex glPixelStorex u n -- void
c-function glPixelTransferxOES glPixelTransferxOES u n -- void
c-function glPixelZoomxOES glPixelZoomxOES n n -- void
c-function glPrioritizeTexturesxOES glPrioritizeTexturesxOES n a a -- void
c-function glRasterPos2xOES glRasterPos2xOES n n -- void
c-function glRasterPos2xvOES glRasterPos2xvOES a -- void
c-function glRasterPos3xOES glRasterPos3xOES n n n -- void
c-function glRasterPos3xvOES glRasterPos3xvOES a -- void
c-function glRasterPos4xOES glRasterPos4xOES n n n n -- void
c-function glRasterPos4xvOES glRasterPos4xvOES a -- void
c-function glRectxOES glRectxOES n n n n -- void
c-function glRectxvOES glRectxvOES a a -- void
c-function glTexCoord1xOES glTexCoord1xOES n -- void
c-function glTexCoord1xvOES glTexCoord1xvOES a -- void
c-function glTexCoord2xOES glTexCoord2xOES n n -- void
c-function glTexCoord2xvOES glTexCoord2xvOES a -- void
c-function glTexCoord3xOES glTexCoord3xOES n n n -- void
c-function glTexCoord3xvOES glTexCoord3xvOES a -- void
c-function glTexCoord4xOES glTexCoord4xOES n n n n -- void
c-function glTexCoord4xvOES glTexCoord4xvOES a -- void
c-function glTexGenxOES glTexGenxOES u u n -- void
c-function glTexGenxvOES glTexGenxvOES u u a -- void
c-function glVertex2xOES glVertex2xOES n -- void
c-function glVertex2xvOES glVertex2xvOES a -- void
c-function glVertex3xOES glVertex3xOES n n -- void
c-function glVertex3xvOES glVertex3xvOES a -- void
c-function glVertex4xOES glVertex4xOES n n n -- void
c-function glVertex4xvOES glVertex4xvOES a -- void
c-function glQueryMatrixxOES glQueryMatrixxOES a a -- u
c-function glClearDepthfOES glClearDepthfOES r -- void
c-function glClipPlanefOES glClipPlanefOES u a -- void
c-function glDepthRangefOES glDepthRangefOES r r -- void
c-function glFrustumfOES glFrustumfOES r r r r r r -- void
c-function glGetClipPlanefOES glGetClipPlanefOES u a -- void
c-function glOrthofOES glOrthofOES r r r r r r -- void
c-function glTbufferMask3DFX glTbufferMask3DFX u -- void
c-function glDebugMessageEnableAMD glDebugMessageEnableAMD u u n a n -- void
c-function glDebugMessageInsertAMD glDebugMessageInsertAMD u u u n a -- void
c-function glDebugMessageCallbackAMD glDebugMessageCallbackAMD a a -- void
c-function glGetDebugMessageLogAMD glGetDebugMessageLogAMD u n a a a a a -- u
c-function glBlendFuncIndexedAMD glBlendFuncIndexedAMD u u u -- void
c-function glBlendFuncSeparateIndexedAMD glBlendFuncSeparateIndexedAMD u u u u u -- void
c-function glBlendEquationIndexedAMD glBlendEquationIndexedAMD u u -- void
c-function glBlendEquationSeparateIndexedAMD glBlendEquationSeparateIndexedAMD u u u -- void
c-function glUniform1i64NV glUniform1i64NV n d -- void
c-function glUniform2i64NV glUniform2i64NV n d d -- void
c-function glUniform3i64NV glUniform3i64NV n d d d -- void
c-function glUniform4i64NV glUniform4i64NV n d d d d -- void
c-function glUniform1i64vNV glUniform1i64vNV n n a -- void
c-function glUniform2i64vNV glUniform2i64vNV n n a -- void
c-function glUniform3i64vNV glUniform3i64vNV n n a -- void
c-function glUniform4i64vNV glUniform4i64vNV n n a -- void
c-function glUniform1ui64NV glUniform1ui64NV n d -- void
c-function glUniform2ui64NV glUniform2ui64NV n d d -- void
c-function glUniform3ui64NV glUniform3ui64NV n d d d -- void
c-function glUniform4ui64NV glUniform4ui64NV n d d d d -- void
c-function glUniform1ui64vNV glUniform1ui64vNV n n a -- void
c-function glUniform2ui64vNV glUniform2ui64vNV n n a -- void
c-function glUniform3ui64vNV glUniform3ui64vNV n n a -- void
c-function glUniform4ui64vNV glUniform4ui64vNV n n a -- void
c-function glGetUniformi64vNV glGetUniformi64vNV u n a -- void
c-function glGetUniformui64vNV glGetUniformui64vNV u n a -- void
c-function glProgramUniform1i64NV glProgramUniform1i64NV u n d -- void
c-function glProgramUniform2i64NV glProgramUniform2i64NV u n d d -- void
c-function glProgramUniform3i64NV glProgramUniform3i64NV u n d d d -- void
c-function glProgramUniform4i64NV glProgramUniform4i64NV u n d d d d -- void
c-function glProgramUniform1i64vNV glProgramUniform1i64vNV u n n a -- void
c-function glProgramUniform2i64vNV glProgramUniform2i64vNV u n n a -- void
c-function glProgramUniform3i64vNV glProgramUniform3i64vNV u n n a -- void
c-function glProgramUniform4i64vNV glProgramUniform4i64vNV u n n a -- void
c-function glProgramUniform1ui64NV glProgramUniform1ui64NV u n d -- void
c-function glProgramUniform2ui64NV glProgramUniform2ui64NV u n d d -- void
c-function glProgramUniform3ui64NV glProgramUniform3ui64NV u n d d d -- void
c-function glProgramUniform4ui64NV glProgramUniform4ui64NV u n d d d d -- void
c-function glProgramUniform1ui64vNV glProgramUniform1ui64vNV u n n a -- void
c-function glProgramUniform2ui64vNV glProgramUniform2ui64vNV u n n a -- void
c-function glProgramUniform3ui64vNV glProgramUniform3ui64vNV u n n a -- void
c-function glProgramUniform4ui64vNV glProgramUniform4ui64vNV u n n a -- void
c-function glVertexAttribParameteriAMD glVertexAttribParameteriAMD u u n -- void
c-function glMultiDrawArraysIndirectAMD glMultiDrawArraysIndirectAMD u a n n -- void
c-function glMultiDrawElementsIndirectAMD glMultiDrawElementsIndirectAMD u u a n n -- void
c-function glGenNamesAMD glGenNamesAMD u u a -- void
c-function glDeleteNamesAMD glDeleteNamesAMD u u a -- void
c-function glIsNameAMD glIsNameAMD u u -- n
c-function glQueryObjectParameteruiAMD glQueryObjectParameteruiAMD u u u u -- void
c-function glGetPerfMonitorGroupsAMD glGetPerfMonitorGroupsAMD a n a -- void
c-function glGetPerfMonitorCountersAMD glGetPerfMonitorCountersAMD u a a n a -- void
c-function glGetPerfMonitorGroupStringAMD glGetPerfMonitorGroupStringAMD u n a a -- void
c-function glGetPerfMonitorCounterStringAMD glGetPerfMonitorCounterStringAMD u u n a a -- void
c-function glGetPerfMonitorCounterInfoAMD glGetPerfMonitorCounterInfoAMD u u u a -- void
c-function glGenPerfMonitorsAMD glGenPerfMonitorsAMD n a -- void
c-function glDeletePerfMonitorsAMD glDeletePerfMonitorsAMD n a -- void
c-function glSelectPerfMonitorCountersAMD glSelectPerfMonitorCountersAMD u n u n a -- void
c-function glBeginPerfMonitorAMD glBeginPerfMonitorAMD u -- void
c-function glEndPerfMonitorAMD glEndPerfMonitorAMD u -- void
c-function glGetPerfMonitorCounterDataAMD glGetPerfMonitorCounterDataAMD u u n a a -- void
c-function glSetMultisamplefvAMD glSetMultisamplefvAMD u u a -- void
c-function glTexStorageSparseAMD glTexStorageSparseAMD u u n n n n u -- void
c-function glTextureStorageSparseAMD glTextureStorageSparseAMD u u u n n n n u -- void
c-function glStencilOpValueAMD glStencilOpValueAMD u u -- void
c-function glTessellationFactorAMD glTessellationFactorAMD r -- void
c-function glTessellationModeAMD glTessellationModeAMD u -- void
c-function glElementPointerAPPLE glElementPointerAPPLE u a -- void
c-function glDrawElementArrayAPPLE glDrawElementArrayAPPLE u n n -- void
c-function glDrawRangeElementArrayAPPLE glDrawRangeElementArrayAPPLE u u u n n -- void
c-function glMultiDrawElementArrayAPPLE glMultiDrawElementArrayAPPLE u a a n -- void
c-function glMultiDrawRangeElementArrayAPPLE glMultiDrawRangeElementArrayAPPLE u u u a a n -- void
c-function glGenFencesAPPLE glGenFencesAPPLE n a -- void
c-function glDeleteFencesAPPLE glDeleteFencesAPPLE n a -- void
c-function glSetFenceAPPLE glSetFenceAPPLE u -- void
c-function glIsFenceAPPLE glIsFenceAPPLE u -- n
c-function glTestFenceAPPLE glTestFenceAPPLE u -- n
c-function glFinishFenceAPPLE glFinishFenceAPPLE u -- void
c-function glTestObjectAPPLE glTestObjectAPPLE u u -- n
c-function glFinishObjectAPPLE glFinishObjectAPPLE u n -- void
c-function glBufferParameteriAPPLE glBufferParameteriAPPLE u u n -- void
c-function glFlushMappedBufferRangeAPPLE glFlushMappedBufferRangeAPPLE u n n -- void
c-function glObjectPurgeableAPPLE glObjectPurgeableAPPLE u u u -- u
c-function glObjectUnpurgeableAPPLE glObjectUnpurgeableAPPLE u u u -- u
c-function glGetObjectParameterivAPPLE glGetObjectParameterivAPPLE u u u a -- void
c-function glTextureRangeAPPLE glTextureRangeAPPLE u n a -- void
c-function glGetTexParameterPointervAPPLE glGetTexParameterPointervAPPLE u u a -- void
c-function glBindVertexArrayAPPLE glBindVertexArrayAPPLE u -- void
c-function glDeleteVertexArraysAPPLE glDeleteVertexArraysAPPLE n a -- void
c-function glGenVertexArraysAPPLE glGenVertexArraysAPPLE n a -- void
c-function glIsVertexArrayAPPLE glIsVertexArrayAPPLE u -- n
c-function glVertexArrayRangeAPPLE glVertexArrayRangeAPPLE n a -- void
c-function glFlushVertexArrayRangeAPPLE glFlushVertexArrayRangeAPPLE n a -- void
c-function glVertexArrayParameteriAPPLE glVertexArrayParameteriAPPLE u n -- void
c-function glEnableVertexAttribAPPLE glEnableVertexAttribAPPLE u u -- void
c-function glDisableVertexAttribAPPLE glDisableVertexAttribAPPLE u u -- void
c-function glIsVertexAttribEnabledAPPLE glIsVertexAttribEnabledAPPLE u u -- n
c-function glMapVertexAttrib1dAPPLE glMapVertexAttrib1dAPPLE u u r r n n a -- void
c-function glMapVertexAttrib1fAPPLE glMapVertexAttrib1fAPPLE u u r r n n a -- void
c-function glMapVertexAttrib2dAPPLE glMapVertexAttrib2dAPPLE u u r r n n r r n n a -- void
c-function glMapVertexAttrib2fAPPLE glMapVertexAttrib2fAPPLE u u r r n n r r n n a -- void
c-function glDrawBuffersATI glDrawBuffersATI n a -- void
c-function glElementPointerATI glElementPointerATI u a -- void
c-function glDrawElementArrayATI glDrawElementArrayATI u n -- void
c-function glDrawRangeElementArrayATI glDrawRangeElementArrayATI u u u n -- void
c-function glTexBumpParameterivATI glTexBumpParameterivATI u a -- void
c-function glTexBumpParameterfvATI glTexBumpParameterfvATI u a -- void
c-function glGetTexBumpParameterivATI glGetTexBumpParameterivATI u a -- void
c-function glGetTexBumpParameterfvATI glGetTexBumpParameterfvATI u a -- void
c-function glGenFragmentShadersATI glGenFragmentShadersATI u -- u
c-function glBindFragmentShaderATI glBindFragmentShaderATI u -- void
c-function glDeleteFragmentShaderATI glDeleteFragmentShaderATI u -- void
c-function glBeginFragmentShaderATI glBeginFragmentShaderATI  -- void
c-function glEndFragmentShaderATI glEndFragmentShaderATI  -- void
c-function glPassTexCoordATI glPassTexCoordATI u u u -- void
c-function glSampleMapATI glSampleMapATI u u u -- void
c-function glColorFragmentOp1ATI glColorFragmentOp1ATI u u u u u u u -- void
c-function glColorFragmentOp2ATI glColorFragmentOp2ATI u u u u u u u u u u -- void
c-function glColorFragmentOp3ATI glColorFragmentOp3ATI u u u u u u u u u u u u u -- void
c-function glAlphaFragmentOp1ATI glAlphaFragmentOp1ATI u u u u u u -- void
c-function glAlphaFragmentOp2ATI glAlphaFragmentOp2ATI u u u u u u u u u -- void
c-function glAlphaFragmentOp3ATI glAlphaFragmentOp3ATI u u u u u u u u u u u u -- void
c-function glSetFragmentShaderConstantATI glSetFragmentShaderConstantATI u a -- void
c-function glMapObjectBufferATI glMapObjectBufferATI u -- a
c-function glUnmapObjectBufferATI glUnmapObjectBufferATI u -- void
c-function glPNTrianglesiATI glPNTrianglesiATI u n -- void
c-function glPNTrianglesfATI glPNTrianglesfATI u r -- void
c-function glStencilOpSeparateATI glStencilOpSeparateATI u u u u -- void
c-function glStencilFuncSeparateATI glStencilFuncSeparateATI u u n u -- void
c-function glNewObjectBufferATI glNewObjectBufferATI n a u -- u
c-function glIsObjectBufferATI glIsObjectBufferATI u -- n
c-function glUpdateObjectBufferATI glUpdateObjectBufferATI u u n a u -- void
c-function glGetObjectBufferfvATI glGetObjectBufferfvATI u u a -- void
c-function glGetObjectBufferivATI glGetObjectBufferivATI u u a -- void
c-function glFreeObjectBufferATI glFreeObjectBufferATI u -- void
c-function glArrayObjectATI glArrayObjectATI u n u n u u -- void
c-function glGetArrayObjectfvATI glGetArrayObjectfvATI u u a -- void
c-function glGetArrayObjectivATI glGetArrayObjectivATI u u a -- void
c-function glVariantArrayObjectATI glVariantArrayObjectATI u u n u u -- void
c-function glGetVariantArrayObjectfvATI glGetVariantArrayObjectfvATI u u a -- void
c-function glGetVariantArrayObjectivATI glGetVariantArrayObjectivATI u u a -- void
c-function glVertexAttribArrayObjectATI glVertexAttribArrayObjectATI u n u n n u u -- void
c-function glGetVertexAttribArrayObjectfvATI glGetVertexAttribArrayObjectfvATI u u a -- void
c-function glGetVertexAttribArrayObjectivATI glGetVertexAttribArrayObjectivATI u u a -- void
c-function glVertexStream1sATI glVertexStream1sATI u n -- void
c-function glVertexStream1svATI glVertexStream1svATI u a -- void
c-function glVertexStream1iATI glVertexStream1iATI u n -- void
c-function glVertexStream1ivATI glVertexStream1ivATI u a -- void
c-function glVertexStream1fATI glVertexStream1fATI u r -- void
c-function glVertexStream1fvATI glVertexStream1fvATI u a -- void
c-function glVertexStream1dATI glVertexStream1dATI u r -- void
c-function glVertexStream1dvATI glVertexStream1dvATI u a -- void
c-function glVertexStream2sATI glVertexStream2sATI u n n -- void
c-function glVertexStream2svATI glVertexStream2svATI u a -- void
c-function glVertexStream2iATI glVertexStream2iATI u n n -- void
c-function glVertexStream2ivATI glVertexStream2ivATI u a -- void
c-function glVertexStream2fATI glVertexStream2fATI u r r -- void
c-function glVertexStream2fvATI glVertexStream2fvATI u a -- void
c-function glVertexStream2dATI glVertexStream2dATI u r r -- void
c-function glVertexStream2dvATI glVertexStream2dvATI u a -- void
c-function glVertexStream3sATI glVertexStream3sATI u n n n -- void
c-function glVertexStream3svATI glVertexStream3svATI u a -- void
c-function glVertexStream3iATI glVertexStream3iATI u n n n -- void
c-function glVertexStream3ivATI glVertexStream3ivATI u a -- void
c-function glVertexStream3fATI glVertexStream3fATI u r r r -- void
c-function glVertexStream3fvATI glVertexStream3fvATI u a -- void
c-function glVertexStream3dATI glVertexStream3dATI u r r r -- void
c-function glVertexStream3dvATI glVertexStream3dvATI u a -- void
c-function glVertexStream4sATI glVertexStream4sATI u n n n n -- void
c-function glVertexStream4svATI glVertexStream4svATI u a -- void
c-function glVertexStream4iATI glVertexStream4iATI u n n n n -- void
c-function glVertexStream4ivATI glVertexStream4ivATI u a -- void
c-function glVertexStream4fATI glVertexStream4fATI u r r r r -- void
c-function glVertexStream4fvATI glVertexStream4fvATI u a -- void
c-function glVertexStream4dATI glVertexStream4dATI u r r r r -- void
c-function glVertexStream4dvATI glVertexStream4dvATI u a -- void
c-function glNormalStream3bATI glNormalStream3bATI u n n n -- void
c-function glNormalStream3bvATI glNormalStream3bvATI u a -- void
c-function glNormalStream3sATI glNormalStream3sATI u n n n -- void
c-function glNormalStream3svATI glNormalStream3svATI u a -- void
c-function glNormalStream3iATI glNormalStream3iATI u n n n -- void
c-function glNormalStream3ivATI glNormalStream3ivATI u a -- void
c-function glNormalStream3fATI glNormalStream3fATI u r r r -- void
c-function glNormalStream3fvATI glNormalStream3fvATI u a -- void
c-function glNormalStream3dATI glNormalStream3dATI u r r r -- void
c-function glNormalStream3dvATI glNormalStream3dvATI u a -- void
c-function glClientActiveVertexStreamATI glClientActiveVertexStreamATI u -- void
c-function glVertexBlendEnviATI glVertexBlendEnviATI u n -- void
c-function glVertexBlendEnvfATI glVertexBlendEnvfATI u r -- void
c-function glUniformBufferEXT glUniformBufferEXT u n u -- void
c-function glGetUniformBufferSizeEXT glGetUniformBufferSizeEXT u n -- n
c-function glGetUniformOffsetEXT glGetUniformOffsetEXT u n -- n
c-function glBlendColorEXT glBlendColorEXT r r r r -- void
c-function glBlendEquationSeparateEXT glBlendEquationSeparateEXT u u -- void
c-function glBlendFuncSeparateEXT glBlendFuncSeparateEXT u u u u -- void
c-function glBlendEquationEXT glBlendEquationEXT u -- void
c-function glColorSubTableEXT glColorSubTableEXT u n n u u a -- void
c-function glCopyColorSubTableEXT glCopyColorSubTableEXT u n n n n -- void
c-function glLockArraysEXT glLockArraysEXT n n -- void
c-function glUnlockArraysEXT glUnlockArraysEXT  -- void
c-function glConvolutionFilter1DEXT glConvolutionFilter1DEXT u u n u u a -- void
c-function glConvolutionFilter2DEXT glConvolutionFilter2DEXT u u n n u u a -- void
c-function glConvolutionParameterfEXT glConvolutionParameterfEXT u u r -- void
c-function glConvolutionParameterfvEXT glConvolutionParameterfvEXT u u a -- void
c-function glConvolutionParameteriEXT glConvolutionParameteriEXT u u n -- void
c-function glConvolutionParameterivEXT glConvolutionParameterivEXT u u a -- void
c-function glCopyConvolutionFilter1DEXT glCopyConvolutionFilter1DEXT u u n n n -- void
c-function glCopyConvolutionFilter2DEXT glCopyConvolutionFilter2DEXT u u n n n n -- void
c-function glGetConvolutionFilterEXT glGetConvolutionFilterEXT u u u a -- void
c-function glGetConvolutionParameterfvEXT glGetConvolutionParameterfvEXT u u a -- void
c-function glGetConvolutionParameterivEXT glGetConvolutionParameterivEXT u u a -- void
c-function glGetSeparableFilterEXT glGetSeparableFilterEXT u u u a a a -- void
c-function glSeparableFilter2DEXT glSeparableFilter2DEXT u u n n u u a a -- void
c-function glTangent3bEXT glTangent3bEXT n n n -- void
c-function glTangent3bvEXT glTangent3bvEXT a -- void
c-function glTangent3dEXT glTangent3dEXT r r r -- void
c-function glTangent3dvEXT glTangent3dvEXT a -- void
c-function glTangent3fEXT glTangent3fEXT r r r -- void
c-function glTangent3fvEXT glTangent3fvEXT a -- void
c-function glTangent3iEXT glTangent3iEXT n n n -- void
c-function glTangent3ivEXT glTangent3ivEXT a -- void
c-function glTangent3sEXT glTangent3sEXT n n n -- void
c-function glTangent3svEXT glTangent3svEXT a -- void
c-function glBinormal3bEXT glBinormal3bEXT n n n -- void
c-function glBinormal3bvEXT glBinormal3bvEXT a -- void
c-function glBinormal3dEXT glBinormal3dEXT r r r -- void
c-function glBinormal3dvEXT glBinormal3dvEXT a -- void
c-function glBinormal3fEXT glBinormal3fEXT r r r -- void
c-function glBinormal3fvEXT glBinormal3fvEXT a -- void
c-function glBinormal3iEXT glBinormal3iEXT n n n -- void
c-function glBinormal3ivEXT glBinormal3ivEXT a -- void
c-function glBinormal3sEXT glBinormal3sEXT n n n -- void
c-function glBinormal3svEXT glBinormal3svEXT a -- void
c-function glTangentPointerEXT glTangentPointerEXT u n a -- void
c-function glBinormalPointerEXT glBinormalPointerEXT u n a -- void
c-function glCopyTexImage1DEXT glCopyTexImage1DEXT u n u n n n n -- void
c-function glCopyTexImage2DEXT glCopyTexImage2DEXT u n u n n n n n -- void
c-function glCopyTexSubImage1DEXT glCopyTexSubImage1DEXT u n n n n n -- void
c-function glCopyTexSubImage2DEXT glCopyTexSubImage2DEXT u n n n n n n n -- void
c-function glCopyTexSubImage3DEXT glCopyTexSubImage3DEXT u n n n n n n n n -- void
c-function glCullParameterdvEXT glCullParameterdvEXT u a -- void
c-function glCullParameterfvEXT glCullParameterfvEXT u a -- void
c-function glLabelObjectEXT glLabelObjectEXT u u n a -- void
c-function glGetObjectLabelEXT glGetObjectLabelEXT u u n a a -- void
c-function glInsertEventMarkerEXT glInsertEventMarkerEXT n a -- void
c-function glPushGroupMarkerEXT glPushGroupMarkerEXT n a -- void
c-function glPopGroupMarkerEXT glPopGroupMarkerEXT  -- void
c-function glDepthBoundsEXT glDepthBoundsEXT r r -- void
c-function glMatrixLoadfEXT glMatrixLoadfEXT u a -- void
c-function glMatrixLoaddEXT glMatrixLoaddEXT u a -- void
c-function glMatrixMultfEXT glMatrixMultfEXT u a -- void
c-function glMatrixMultdEXT glMatrixMultdEXT u a -- void
c-function glMatrixLoadIdentityEXT glMatrixLoadIdentityEXT u -- void
c-function glMatrixRotatefEXT glMatrixRotatefEXT u r r r r -- void
c-function glMatrixRotatedEXT glMatrixRotatedEXT u r r r r -- void
c-function glMatrixScalefEXT glMatrixScalefEXT u r r r -- void
c-function glMatrixScaledEXT glMatrixScaledEXT u r r r -- void
c-function glMatrixTranslatefEXT glMatrixTranslatefEXT u r r r -- void
c-function glMatrixTranslatedEXT glMatrixTranslatedEXT u r r r -- void
c-function glMatrixFrustumEXT glMatrixFrustumEXT u r r r r r r -- void
c-function glMatrixOrthoEXT glMatrixOrthoEXT u r r r r r r -- void
c-function glMatrixPopEXT glMatrixPopEXT u -- void
c-function glMatrixPushEXT glMatrixPushEXT u -- void
c-function glClientAttribDefaultEXT glClientAttribDefaultEXT u -- void
c-function glPushClientAttribDefaultEXT glPushClientAttribDefaultEXT u -- void
c-function glTextureParameterfEXT glTextureParameterfEXT u u u r -- void
c-function glTextureParameterfvEXT glTextureParameterfvEXT u u u a -- void
c-function glTextureParameteriEXT glTextureParameteriEXT u u u n -- void
c-function glTextureParameterivEXT glTextureParameterivEXT u u u a -- void
c-function glTextureImage1DEXT glTextureImage1DEXT u u n n n n u u a -- void
c-function glTextureImage2DEXT glTextureImage2DEXT u u n n n n n u u a -- void
c-function glTextureSubImage1DEXT glTextureSubImage1DEXT u u n n n u u a -- void
c-function glTextureSubImage2DEXT glTextureSubImage2DEXT u u n n n n n u u a -- void
c-function glCopyTextureImage1DEXT glCopyTextureImage1DEXT u u n u n n n n -- void
c-function glCopyTextureImage2DEXT glCopyTextureImage2DEXT u u n u n n n n n -- void
c-function glCopyTextureSubImage1DEXT glCopyTextureSubImage1DEXT u u n n n n n -- void
c-function glCopyTextureSubImage2DEXT glCopyTextureSubImage2DEXT u u n n n n n n n -- void
c-function glGetTextureImageEXT glGetTextureImageEXT u u n u u a -- void
c-function glGetTextureParameterfvEXT glGetTextureParameterfvEXT u u u a -- void
c-function glGetTextureParameterivEXT glGetTextureParameterivEXT u u u a -- void
c-function glGetTextureLevelParameterfvEXT glGetTextureLevelParameterfvEXT u u n u a -- void
c-function glGetTextureLevelParameterivEXT glGetTextureLevelParameterivEXT u u n u a -- void
c-function glTextureImage3DEXT glTextureImage3DEXT u u n n n n n n u u a -- void
c-function glTextureSubImage3DEXT glTextureSubImage3DEXT u u n n n n n n n u u a -- void
c-function glCopyTextureSubImage3DEXT glCopyTextureSubImage3DEXT u u n n n n n n n n -- void
c-function glBindMultiTextureEXT glBindMultiTextureEXT u u u -- void
c-function glMultiTexCoordPointerEXT glMultiTexCoordPointerEXT u n u n a -- void
c-function glMultiTexEnvfEXT glMultiTexEnvfEXT u u u r -- void
c-function glMultiTexEnvfvEXT glMultiTexEnvfvEXT u u u a -- void
c-function glMultiTexEnviEXT glMultiTexEnviEXT u u u n -- void
c-function glMultiTexEnvivEXT glMultiTexEnvivEXT u u u a -- void
c-function glMultiTexGendEXT glMultiTexGendEXT u u u r -- void
c-function glMultiTexGendvEXT glMultiTexGendvEXT u u u a -- void
c-function glMultiTexGenfEXT glMultiTexGenfEXT u u u r -- void
c-function glMultiTexGenfvEXT glMultiTexGenfvEXT u u u a -- void
c-function glMultiTexGeniEXT glMultiTexGeniEXT u u u n -- void
c-function glMultiTexGenivEXT glMultiTexGenivEXT u u u a -- void
c-function glGetMultiTexEnvfvEXT glGetMultiTexEnvfvEXT u u u a -- void
c-function glGetMultiTexEnvivEXT glGetMultiTexEnvivEXT u u u a -- void
c-function glGetMultiTexGendvEXT glGetMultiTexGendvEXT u u u a -- void
c-function glGetMultiTexGenfvEXT glGetMultiTexGenfvEXT u u u a -- void
c-function glGetMultiTexGenivEXT glGetMultiTexGenivEXT u u u a -- void
c-function glMultiTexParameteriEXT glMultiTexParameteriEXT u u u n -- void
c-function glMultiTexParameterivEXT glMultiTexParameterivEXT u u u a -- void
c-function glMultiTexParameterfEXT glMultiTexParameterfEXT u u u r -- void
c-function glMultiTexParameterfvEXT glMultiTexParameterfvEXT u u u a -- void
c-function glMultiTexImage1DEXT glMultiTexImage1DEXT u u n n n n u u a -- void
c-function glMultiTexImage2DEXT glMultiTexImage2DEXT u u n n n n n u u a -- void
c-function glMultiTexSubImage1DEXT glMultiTexSubImage1DEXT u u n n n u u a -- void
c-function glMultiTexSubImage2DEXT glMultiTexSubImage2DEXT u u n n n n n u u a -- void
c-function glCopyMultiTexImage1DEXT glCopyMultiTexImage1DEXT u u n u n n n n -- void
c-function glCopyMultiTexImage2DEXT glCopyMultiTexImage2DEXT u u n u n n n n n -- void
c-function glCopyMultiTexSubImage1DEXT glCopyMultiTexSubImage1DEXT u u n n n n n -- void
c-function glCopyMultiTexSubImage2DEXT glCopyMultiTexSubImage2DEXT u u n n n n n n n -- void
c-function glGetMultiTexImageEXT glGetMultiTexImageEXT u u n u u a -- void
c-function glGetMultiTexParameterfvEXT glGetMultiTexParameterfvEXT u u u a -- void
c-function glGetMultiTexParameterivEXT glGetMultiTexParameterivEXT u u u a -- void
c-function glGetMultiTexLevelParameterfvEXT glGetMultiTexLevelParameterfvEXT u u n u a -- void
c-function glGetMultiTexLevelParameterivEXT glGetMultiTexLevelParameterivEXT u u n u a -- void
c-function glMultiTexImage3DEXT glMultiTexImage3DEXT u u n n n n n n u u a -- void
c-function glMultiTexSubImage3DEXT glMultiTexSubImage3DEXT u u n n n n n n n u u a -- void
c-function glCopyMultiTexSubImage3DEXT glCopyMultiTexSubImage3DEXT u u n n n n n n n n -- void
c-function glEnableClientStateIndexedEXT glEnableClientStateIndexedEXT u u -- void
c-function glDisableClientStateIndexedEXT glDisableClientStateIndexedEXT u u -- void
c-function glGetFloatIndexedvEXT glGetFloatIndexedvEXT u u a -- void
c-function glGetDoubleIndexedvEXT glGetDoubleIndexedvEXT u u a -- void
c-function glGetPointerIndexedvEXT glGetPointerIndexedvEXT u u a -- void
c-function glEnableIndexedEXT glEnableIndexedEXT u u -- void
c-function glDisableIndexedEXT glDisableIndexedEXT u u -- void
c-function glIsEnabledIndexedEXT glIsEnabledIndexedEXT u u -- n
c-function glGetIntegerIndexedvEXT glGetIntegerIndexedvEXT u u a -- void
c-function glGetBooleanIndexedvEXT glGetBooleanIndexedvEXT u u a -- void
c-function glCompressedTextureImage3DEXT glCompressedTextureImage3DEXT u u n u n n n n n a -- void
c-function glCompressedTextureImage2DEXT glCompressedTextureImage2DEXT u u n u n n n n a -- void
c-function glCompressedTextureImage1DEXT glCompressedTextureImage1DEXT u u n u n n n a -- void
c-function glCompressedTextureSubImage3DEXT glCompressedTextureSubImage3DEXT u u n n n n n n n u n a -- void
c-function glCompressedTextureSubImage2DEXT glCompressedTextureSubImage2DEXT u u n n n n n u n a -- void
c-function glCompressedTextureSubImage1DEXT glCompressedTextureSubImage1DEXT u u n n n u n a -- void
c-function glGetCompressedTextureImageEXT glGetCompressedTextureImageEXT u u n a -- void
c-function glCompressedMultiTexImage3DEXT glCompressedMultiTexImage3DEXT u u n u n n n n n a -- void
c-function glCompressedMultiTexImage2DEXT glCompressedMultiTexImage2DEXT u u n u n n n n a -- void
c-function glCompressedMultiTexImage1DEXT glCompressedMultiTexImage1DEXT u u n u n n n a -- void
c-function glCompressedMultiTexSubImage3DEXT glCompressedMultiTexSubImage3DEXT u u n n n n n n n u n a -- void
c-function glCompressedMultiTexSubImage2DEXT glCompressedMultiTexSubImage2DEXT u u n n n n n u n a -- void
c-function glCompressedMultiTexSubImage1DEXT glCompressedMultiTexSubImage1DEXT u u n n n u n a -- void
c-function glGetCompressedMultiTexImageEXT glGetCompressedMultiTexImageEXT u u n a -- void
c-function glMatrixLoadTransposefEXT glMatrixLoadTransposefEXT u a -- void
c-function glMatrixLoadTransposedEXT glMatrixLoadTransposedEXT u a -- void
c-function glMatrixMultTransposefEXT glMatrixMultTransposefEXT u a -- void
c-function glMatrixMultTransposedEXT glMatrixMultTransposedEXT u a -- void
c-function glNamedBufferDataEXT glNamedBufferDataEXT u n a u -- void
c-function glNamedBufferSubDataEXT glNamedBufferSubDataEXT u n n a -- void
c-function glMapNamedBufferEXT glMapNamedBufferEXT u u -- a
c-function glUnmapNamedBufferEXT glUnmapNamedBufferEXT u -- n
c-function glGetNamedBufferParameterivEXT glGetNamedBufferParameterivEXT u u a -- void
c-function glGetNamedBufferPointervEXT glGetNamedBufferPointervEXT u u a -- void
c-function glGetNamedBufferSubDataEXT glGetNamedBufferSubDataEXT u n n a -- void
c-function glProgramUniform1fEXT glProgramUniform1fEXT u n r -- void
c-function glProgramUniform2fEXT glProgramUniform2fEXT u n r r -- void
c-function glProgramUniform3fEXT glProgramUniform3fEXT u n r r r -- void
c-function glProgramUniform4fEXT glProgramUniform4fEXT u n r r r r -- void
c-function glProgramUniform1iEXT glProgramUniform1iEXT u n n -- void
c-function glProgramUniform2iEXT glProgramUniform2iEXT u n n n -- void
c-function glProgramUniform3iEXT glProgramUniform3iEXT u n n n n -- void
c-function glProgramUniform4iEXT glProgramUniform4iEXT u n n n n n -- void
c-function glProgramUniform1fvEXT glProgramUniform1fvEXT u n n a -- void
c-function glProgramUniform2fvEXT glProgramUniform2fvEXT u n n a -- void
c-function glProgramUniform3fvEXT glProgramUniform3fvEXT u n n a -- void
c-function glProgramUniform4fvEXT glProgramUniform4fvEXT u n n a -- void
c-function glProgramUniform1ivEXT glProgramUniform1ivEXT u n n a -- void
c-function glProgramUniform2ivEXT glProgramUniform2ivEXT u n n a -- void
c-function glProgramUniform3ivEXT glProgramUniform3ivEXT u n n a -- void
c-function glProgramUniform4ivEXT glProgramUniform4ivEXT u n n a -- void
c-function glProgramUniformMatrix2fvEXT glProgramUniformMatrix2fvEXT u n n n a -- void
c-function glProgramUniformMatrix3fvEXT glProgramUniformMatrix3fvEXT u n n n a -- void
c-function glProgramUniformMatrix4fvEXT glProgramUniformMatrix4fvEXT u n n n a -- void
c-function glProgramUniformMatrix2x3fvEXT glProgramUniformMatrix2x3fvEXT u n n n a -- void
c-function glProgramUniformMatrix3x2fvEXT glProgramUniformMatrix3x2fvEXT u n n n a -- void
c-function glProgramUniformMatrix2x4fvEXT glProgramUniformMatrix2x4fvEXT u n n n a -- void
c-function glProgramUniformMatrix4x2fvEXT glProgramUniformMatrix4x2fvEXT u n n n a -- void
c-function glProgramUniformMatrix3x4fvEXT glProgramUniformMatrix3x4fvEXT u n n n a -- void
c-function glProgramUniformMatrix4x3fvEXT glProgramUniformMatrix4x3fvEXT u n n n a -- void
c-function glTextureBufferEXT glTextureBufferEXT u u u u -- void
c-function glMultiTexBufferEXT glMultiTexBufferEXT u u u u -- void
c-function glTextureParameterIivEXT glTextureParameterIivEXT u u u a -- void
c-function glTextureParameterIuivEXT glTextureParameterIuivEXT u u u a -- void
c-function glGetTextureParameterIivEXT glGetTextureParameterIivEXT u u u a -- void
c-function glGetTextureParameterIuivEXT glGetTextureParameterIuivEXT u u u a -- void
c-function glMultiTexParameterIivEXT glMultiTexParameterIivEXT u u u a -- void
c-function glMultiTexParameterIuivEXT glMultiTexParameterIuivEXT u u u a -- void
c-function glGetMultiTexParameterIivEXT glGetMultiTexParameterIivEXT u u u a -- void
c-function glGetMultiTexParameterIuivEXT glGetMultiTexParameterIuivEXT u u u a -- void
c-function glProgramUniform1uiEXT glProgramUniform1uiEXT u n u -- void
c-function glProgramUniform2uiEXT glProgramUniform2uiEXT u n u u -- void
c-function glProgramUniform3uiEXT glProgramUniform3uiEXT u n u u u -- void
c-function glProgramUniform4uiEXT glProgramUniform4uiEXT u n u u u u -- void
c-function glProgramUniform1uivEXT glProgramUniform1uivEXT u n n a -- void
c-function glProgramUniform2uivEXT glProgramUniform2uivEXT u n n a -- void
c-function glProgramUniform3uivEXT glProgramUniform3uivEXT u n n a -- void
c-function glProgramUniform4uivEXT glProgramUniform4uivEXT u n n a -- void
c-function glNamedProgramLocalParameters4fvEXT glNamedProgramLocalParameters4fvEXT u u u n a -- void
c-function glNamedProgramLocalParameterI4iEXT glNamedProgramLocalParameterI4iEXT u u u n n n n -- void
c-function glNamedProgramLocalParameterI4ivEXT glNamedProgramLocalParameterI4ivEXT u u u a -- void
c-function glNamedProgramLocalParametersI4ivEXT glNamedProgramLocalParametersI4ivEXT u u u n a -- void
c-function glNamedProgramLocalParameterI4uiEXT glNamedProgramLocalParameterI4uiEXT u u u u u u u -- void
c-function glNamedProgramLocalParameterI4uivEXT glNamedProgramLocalParameterI4uivEXT u u u a -- void
c-function glNamedProgramLocalParametersI4uivEXT glNamedProgramLocalParametersI4uivEXT u u u n a -- void
c-function glGetNamedProgramLocalParameterIivEXT glGetNamedProgramLocalParameterIivEXT u u u a -- void
c-function glGetNamedProgramLocalParameterIuivEXT glGetNamedProgramLocalParameterIuivEXT u u u a -- void
c-function glEnableClientStateiEXT glEnableClientStateiEXT u u -- void
c-function glDisableClientStateiEXT glDisableClientStateiEXT u u -- void
c-function glGetFloati_vEXT glGetFloati_vEXT u u a -- void
c-function glGetDoublei_vEXT glGetDoublei_vEXT u u a -- void
c-function glGetPointeri_vEXT glGetPointeri_vEXT u u a -- void
c-function glNamedProgramStringEXT glNamedProgramStringEXT u u u n a -- void
c-function glNamedProgramLocalParameter4dEXT glNamedProgramLocalParameter4dEXT u u u r r r r -- void
c-function glNamedProgramLocalParameter4dvEXT glNamedProgramLocalParameter4dvEXT u u u a -- void
c-function glNamedProgramLocalParameter4fEXT glNamedProgramLocalParameter4fEXT u u u r r r r -- void
c-function glNamedProgramLocalParameter4fvEXT glNamedProgramLocalParameter4fvEXT u u u a -- void
c-function glGetNamedProgramLocalParameterdvEXT glGetNamedProgramLocalParameterdvEXT u u u a -- void
c-function glGetNamedProgramLocalParameterfvEXT glGetNamedProgramLocalParameterfvEXT u u u a -- void
c-function glGetNamedProgramivEXT glGetNamedProgramivEXT u u u a -- void
c-function glGetNamedProgramStringEXT glGetNamedProgramStringEXT u u u a -- void
c-function glNamedRenderbufferStorageEXT glNamedRenderbufferStorageEXT u u n n -- void
c-function glGetNamedRenderbufferParameterivEXT glGetNamedRenderbufferParameterivEXT u u a -- void
c-function glNamedRenderbufferStorageMultisampleEXT glNamedRenderbufferStorageMultisampleEXT u n u n n -- void
c-function glNamedRenderbufferStorageMultisampleCoverageEXT glNamedRenderbufferStorageMultisampleCoverageEXT u n n u n n -- void
c-function glCheckNamedFramebufferStatusEXT glCheckNamedFramebufferStatusEXT u u -- u
c-function glNamedFramebufferTexture1DEXT glNamedFramebufferTexture1DEXT u u u u n -- void
c-function glNamedFramebufferTexture2DEXT glNamedFramebufferTexture2DEXT u u u u n -- void
c-function glNamedFramebufferTexture3DEXT glNamedFramebufferTexture3DEXT u u u u n n -- void
c-function glNamedFramebufferRenderbufferEXT glNamedFramebufferRenderbufferEXT u u u u -- void
c-function glGetNamedFramebufferAttachmentParameterivEXT glGetNamedFramebufferAttachmentParameterivEXT u u u a -- void
c-function glGenerateTextureMipmapEXT glGenerateTextureMipmapEXT u u -- void
c-function glGenerateMultiTexMipmapEXT glGenerateMultiTexMipmapEXT u u -- void
c-function glFramebufferDrawBufferEXT glFramebufferDrawBufferEXT u u -- void
c-function glFramebufferDrawBuffersEXT glFramebufferDrawBuffersEXT u n a -- void
c-function glFramebufferReadBufferEXT glFramebufferReadBufferEXT u u -- void
c-function glGetFramebufferParameterivEXT glGetFramebufferParameterivEXT u u a -- void
c-function glNamedCopyBufferSubDataEXT glNamedCopyBufferSubDataEXT u u n n n -- void
c-function glNamedFramebufferTextureEXT glNamedFramebufferTextureEXT u u u n -- void
c-function glNamedFramebufferTextureLayerEXT glNamedFramebufferTextureLayerEXT u u u n n -- void
c-function glNamedFramebufferTextureFaceEXT glNamedFramebufferTextureFaceEXT u u u n u -- void
c-function glTextureRenderbufferEXT glTextureRenderbufferEXT u u u -- void
c-function glMultiTexRenderbufferEXT glMultiTexRenderbufferEXT u u u -- void
c-function glVertexArrayVertexOffsetEXT glVertexArrayVertexOffsetEXT u u n u n n -- void
c-function glVertexArrayColorOffsetEXT glVertexArrayColorOffsetEXT u u n u n n -- void
c-function glVertexArrayEdgeFlagOffsetEXT glVertexArrayEdgeFlagOffsetEXT u u n n -- void
c-function glVertexArrayIndexOffsetEXT glVertexArrayIndexOffsetEXT u u u n n -- void
c-function glVertexArrayNormalOffsetEXT glVertexArrayNormalOffsetEXT u u u n n -- void
c-function glVertexArrayTexCoordOffsetEXT glVertexArrayTexCoordOffsetEXT u u n u n n -- void
c-function glVertexArrayMultiTexCoordOffsetEXT glVertexArrayMultiTexCoordOffsetEXT u u u n u n n -- void
c-function glVertexArrayFogCoordOffsetEXT glVertexArrayFogCoordOffsetEXT u u u n n -- void
c-function glVertexArraySecondaryColorOffsetEXT glVertexArraySecondaryColorOffsetEXT u u n u n n -- void
c-function glVertexArrayVertexAttribOffsetEXT glVertexArrayVertexAttribOffsetEXT u u u n u n n n -- void
c-function glVertexArrayVertexAttribIOffsetEXT glVertexArrayVertexAttribIOffsetEXT u u u n u n n -- void
c-function glEnableVertexArrayEXT glEnableVertexArrayEXT u u -- void
c-function glDisableVertexArrayEXT glDisableVertexArrayEXT u u -- void
c-function glEnableVertexArrayAttribEXT glEnableVertexArrayAttribEXT u u -- void
c-function glDisableVertexArrayAttribEXT glDisableVertexArrayAttribEXT u u -- void
c-function glGetVertexArrayIntegervEXT glGetVertexArrayIntegervEXT u u a -- void
c-function glGetVertexArrayPointervEXT glGetVertexArrayPointervEXT u u a -- void
c-function glGetVertexArrayIntegeri_vEXT glGetVertexArrayIntegeri_vEXT u u u a -- void
c-function glGetVertexArrayPointeri_vEXT glGetVertexArrayPointeri_vEXT u u u a -- void
c-function glMapNamedBufferRangeEXT glMapNamedBufferRangeEXT u n n u -- a
c-function glFlushMappedNamedBufferRangeEXT glFlushMappedNamedBufferRangeEXT u n n -- void
c-function glNamedBufferStorageEXT glNamedBufferStorageEXT u n a u -- void
c-function glClearNamedBufferDataEXT glClearNamedBufferDataEXT u u u u a -- void
c-function glClearNamedBufferSubDataEXT glClearNamedBufferSubDataEXT u u n n u u a -- void
c-function glNamedFramebufferParameteriEXT glNamedFramebufferParameteriEXT u u n -- void
c-function glGetNamedFramebufferParameterivEXT glGetNamedFramebufferParameterivEXT u u a -- void
c-function glProgramUniform1dEXT glProgramUniform1dEXT u n r -- void
c-function glProgramUniform2dEXT glProgramUniform2dEXT u n r r -- void
c-function glProgramUniform3dEXT glProgramUniform3dEXT u n r r r -- void
c-function glProgramUniform4dEXT glProgramUniform4dEXT u n r r r r -- void
c-function glProgramUniform1dvEXT glProgramUniform1dvEXT u n n a -- void
c-function glProgramUniform2dvEXT glProgramUniform2dvEXT u n n a -- void
c-function glProgramUniform3dvEXT glProgramUniform3dvEXT u n n a -- void
c-function glProgramUniform4dvEXT glProgramUniform4dvEXT u n n a -- void
c-function glProgramUniformMatrix2dvEXT glProgramUniformMatrix2dvEXT u n n n a -- void
c-function glProgramUniformMatrix3dvEXT glProgramUniformMatrix3dvEXT u n n n a -- void
c-function glProgramUniformMatrix4dvEXT glProgramUniformMatrix4dvEXT u n n n a -- void
c-function glProgramUniformMatrix2x3dvEXT glProgramUniformMatrix2x3dvEXT u n n n a -- void
c-function glProgramUniformMatrix2x4dvEXT glProgramUniformMatrix2x4dvEXT u n n n a -- void
c-function glProgramUniformMatrix3x2dvEXT glProgramUniformMatrix3x2dvEXT u n n n a -- void
c-function glProgramUniformMatrix3x4dvEXT glProgramUniformMatrix3x4dvEXT u n n n a -- void
c-function glProgramUniformMatrix4x2dvEXT glProgramUniformMatrix4x2dvEXT u n n n a -- void
c-function glProgramUniformMatrix4x3dvEXT glProgramUniformMatrix4x3dvEXT u n n n a -- void
c-function glTextureBufferRangeEXT glTextureBufferRangeEXT u u u u n n -- void
c-function glTextureStorage1DEXT glTextureStorage1DEXT u u n u n -- void
c-function glTextureStorage2DEXT glTextureStorage2DEXT u u n u n n -- void
c-function glTextureStorage3DEXT glTextureStorage3DEXT u u n u n n n -- void
c-function glTextureStorage2DMultisampleEXT glTextureStorage2DMultisampleEXT u u n u n n n -- void
c-function glTextureStorage3DMultisampleEXT glTextureStorage3DMultisampleEXT u u n u n n n n -- void
c-function glVertexArrayBindVertexBufferEXT glVertexArrayBindVertexBufferEXT u u u n n -- void
c-function glVertexArrayVertexAttribFormatEXT glVertexArrayVertexAttribFormatEXT u u n u n u -- void
c-function glVertexArrayVertexAttribIFormatEXT glVertexArrayVertexAttribIFormatEXT u u n u u -- void
c-function glVertexArrayVertexAttribLFormatEXT glVertexArrayVertexAttribLFormatEXT u u n u u -- void
c-function glVertexArrayVertexAttribBindingEXT glVertexArrayVertexAttribBindingEXT u u u -- void
c-function glVertexArrayVertexBindingDivisorEXT glVertexArrayVertexBindingDivisorEXT u u u -- void
c-function glVertexArrayVertexAttribLOffsetEXT glVertexArrayVertexAttribLOffsetEXT u u u n u n n -- void
c-function glTexturePageCommitmentEXT glTexturePageCommitmentEXT u n n n n n n n n -- void
c-function glVertexArrayVertexAttribDivisorEXT glVertexArrayVertexAttribDivisorEXT u u u -- void
c-function glColorMaskIndexedEXT glColorMaskIndexedEXT u n n n n -- void
c-function glDrawArraysInstancedEXT glDrawArraysInstancedEXT u n n n -- void
c-function glDrawElementsInstancedEXT glDrawElementsInstancedEXT u n u a n -- void
c-function glDrawRangeElementsEXT glDrawRangeElementsEXT u u u n u a -- void
c-function glFogCoordfEXT glFogCoordfEXT r -- void
c-function glFogCoordfvEXT glFogCoordfvEXT a -- void
c-function glFogCoorddEXT glFogCoorddEXT r -- void
c-function glFogCoorddvEXT glFogCoorddvEXT a -- void
c-function glFogCoordPointerEXT glFogCoordPointerEXT u n a -- void
c-function glBlitFramebufferEXT glBlitFramebufferEXT n n n n n n n n u u -- void
c-function glRenderbufferStorageMultisampleEXT glRenderbufferStorageMultisampleEXT u n u n n -- void
c-function glIsRenderbufferEXT glIsRenderbufferEXT u -- n
c-function glBindRenderbufferEXT glBindRenderbufferEXT u u -- void
c-function glDeleteRenderbuffersEXT glDeleteRenderbuffersEXT n a -- void
c-function glGenRenderbuffersEXT glGenRenderbuffersEXT n a -- void
c-function glRenderbufferStorageEXT glRenderbufferStorageEXT u u n n -- void
c-function glGetRenderbufferParameterivEXT glGetRenderbufferParameterivEXT u u a -- void
c-function glIsFramebufferEXT glIsFramebufferEXT u -- n
c-function glBindFramebufferEXT glBindFramebufferEXT u u -- void
c-function glDeleteFramebuffersEXT glDeleteFramebuffersEXT n a -- void
c-function glGenFramebuffersEXT glGenFramebuffersEXT n a -- void
c-function glCheckFramebufferStatusEXT glCheckFramebufferStatusEXT u -- u
c-function glFramebufferTexture1DEXT glFramebufferTexture1DEXT u u u u n -- void
c-function glFramebufferTexture2DEXT glFramebufferTexture2DEXT u u u u n -- void
c-function glFramebufferTexture3DEXT glFramebufferTexture3DEXT u u u u n n -- void
c-function glFramebufferRenderbufferEXT glFramebufferRenderbufferEXT u u u u -- void
c-function glGetFramebufferAttachmentParameterivEXT glGetFramebufferAttachmentParameterivEXT u u u a -- void
c-function glGenerateMipmapEXT glGenerateMipmapEXT u -- void
c-function glProgramParameteriEXT glProgramParameteriEXT u u n -- void
c-function glProgramEnvParameters4fvEXT glProgramEnvParameters4fvEXT u u n a -- void
c-function glProgramLocalParameters4fvEXT glProgramLocalParameters4fvEXT u u n a -- void
c-function glGetUniformuivEXT glGetUniformuivEXT u n a -- void
c-function glBindFragDataLocationEXT glBindFragDataLocationEXT u u a -- void
c-function glGetFragDataLocationEXT glGetFragDataLocationEXT u a -- n
c-function glUniform1uiEXT glUniform1uiEXT n u -- void
c-function glUniform2uiEXT glUniform2uiEXT n u u -- void
c-function glUniform3uiEXT glUniform3uiEXT n u u u -- void
c-function glUniform4uiEXT glUniform4uiEXT n u u u u -- void
c-function glUniform1uivEXT glUniform1uivEXT n n a -- void
c-function glUniform2uivEXT glUniform2uivEXT n n a -- void
c-function glUniform3uivEXT glUniform3uivEXT n n a -- void
c-function glUniform4uivEXT glUniform4uivEXT n n a -- void
c-function glGetHistogramEXT glGetHistogramEXT u n u u a -- void
c-function glGetHistogramParameterfvEXT glGetHistogramParameterfvEXT u u a -- void
c-function glGetHistogramParameterivEXT glGetHistogramParameterivEXT u u a -- void
c-function glGetMinmaxEXT glGetMinmaxEXT u n u u a -- void
c-function glGetMinmaxParameterfvEXT glGetMinmaxParameterfvEXT u u a -- void
c-function glGetMinmaxParameterivEXT glGetMinmaxParameterivEXT u u a -- void
c-function glHistogramEXT glHistogramEXT u n u n -- void
c-function glMinmaxEXT glMinmaxEXT u u n -- void
c-function glResetHistogramEXT glResetHistogramEXT u -- void
c-function glResetMinmaxEXT glResetMinmaxEXT u -- void
c-function glIndexFuncEXT glIndexFuncEXT u r -- void
c-function glIndexMaterialEXT glIndexMaterialEXT u u -- void
c-function glApplyTextureEXT glApplyTextureEXT u -- void
c-function glTextureLightEXT glTextureLightEXT u -- void
c-function glTextureMaterialEXT glTextureMaterialEXT u u -- void
c-function glMultiDrawArraysEXT glMultiDrawArraysEXT u a a n -- void
c-function glMultiDrawElementsEXT glMultiDrawElementsEXT u a u a n -- void
c-function glSampleMaskEXT glSampleMaskEXT r n -- void
c-function glSamplePatternEXT glSamplePatternEXT u -- void
c-function glColorTableEXT glColorTableEXT u u n u u a -- void
c-function glGetColorTableEXT glGetColorTableEXT u u u a -- void
c-function glGetColorTableParameterivEXT glGetColorTableParameterivEXT u u a -- void
c-function glGetColorTableParameterfvEXT glGetColorTableParameterfvEXT u u a -- void
c-function glPixelTransformParameteriEXT glPixelTransformParameteriEXT u u n -- void
c-function glPixelTransformParameterfEXT glPixelTransformParameterfEXT u u r -- void
c-function glPixelTransformParameterivEXT glPixelTransformParameterivEXT u u a -- void
c-function glPixelTransformParameterfvEXT glPixelTransformParameterfvEXT u u a -- void
c-function glGetPixelTransformParameterivEXT glGetPixelTransformParameterivEXT u u a -- void
c-function glGetPixelTransformParameterfvEXT glGetPixelTransformParameterfvEXT u u a -- void
c-function glPointParameterfEXT glPointParameterfEXT u r -- void
c-function glPointParameterfvEXT glPointParameterfvEXT u a -- void
c-function glPolygonOffsetEXT glPolygonOffsetEXT r r -- void
c-function glPolygonOffsetClampEXT glPolygonOffsetClampEXT r r r -- void
c-function glProvokingVertexEXT glProvokingVertexEXT u -- void
c-function glRasterSamplesEXT glRasterSamplesEXT u n -- void
c-function glSecondaryColor3bEXT glSecondaryColor3bEXT n n n -- void
c-function glSecondaryColor3bvEXT glSecondaryColor3bvEXT a -- void
c-function glSecondaryColor3dEXT glSecondaryColor3dEXT r r r -- void
c-function glSecondaryColor3dvEXT glSecondaryColor3dvEXT a -- void
c-function glSecondaryColor3fEXT glSecondaryColor3fEXT r r r -- void
c-function glSecondaryColor3fvEXT glSecondaryColor3fvEXT a -- void
c-function glSecondaryColor3iEXT glSecondaryColor3iEXT n n n -- void
c-function glSecondaryColor3ivEXT glSecondaryColor3ivEXT a -- void
c-function glSecondaryColor3sEXT glSecondaryColor3sEXT n n n -- void
c-function glSecondaryColor3svEXT glSecondaryColor3svEXT a -- void
c-function glSecondaryColor3ubEXT glSecondaryColor3ubEXT n n n -- void
c-function glSecondaryColor3ubvEXT glSecondaryColor3ubvEXT a -- void
c-function glSecondaryColor3uiEXT glSecondaryColor3uiEXT u u u -- void
c-function glSecondaryColor3uivEXT glSecondaryColor3uivEXT a -- void
c-function glSecondaryColor3usEXT glSecondaryColor3usEXT n n n -- void
c-function glSecondaryColor3usvEXT glSecondaryColor3usvEXT a -- void
c-function glSecondaryColorPointerEXT glSecondaryColorPointerEXT n u n a -- void
c-function glUseShaderProgramEXT glUseShaderProgramEXT u u -- void
c-function glActiveProgramEXT glActiveProgramEXT u -- void
c-function glCreateShaderProgramEXT glCreateShaderProgramEXT u a -- u
c-function glBindImageTextureEXT glBindImageTextureEXT u u n n n u n -- void
c-function glMemoryBarrierEXT glMemoryBarrierEXT u -- void
c-function glStencilClearTagEXT glStencilClearTagEXT n u -- void
c-function glActiveStencilFaceEXT glActiveStencilFaceEXT u -- void
c-function glTexSubImage1DEXT glTexSubImage1DEXT u n n n u u a -- void
c-function glTexSubImage2DEXT glTexSubImage2DEXT u n n n n n u u a -- void
c-function glTexImage3DEXT glTexImage3DEXT u n u n n n n u u a -- void
c-function glTexSubImage3DEXT glTexSubImage3DEXT u n n n n n n n u u a -- void
c-function glFramebufferTextureLayerEXT glFramebufferTextureLayerEXT u u u n n -- void
c-function glTexBufferEXT glTexBufferEXT u u u -- void
c-function glTexParameterIivEXT glTexParameterIivEXT u u a -- void
c-function glTexParameterIuivEXT glTexParameterIuivEXT u u a -- void
c-function glGetTexParameterIivEXT glGetTexParameterIivEXT u u a -- void
c-function glGetTexParameterIuivEXT glGetTexParameterIuivEXT u u a -- void
c-function glClearColorIiEXT glClearColorIiEXT n n n n -- void
c-function glClearColorIuiEXT glClearColorIuiEXT u u u u -- void
c-function glAreTexturesResidentEXT glAreTexturesResidentEXT n a a -- n
c-function glBindTextureEXT glBindTextureEXT u u -- void
c-function glDeleteTexturesEXT glDeleteTexturesEXT n a -- void
c-function glGenTexturesEXT glGenTexturesEXT n a -- void
c-function glIsTextureEXT glIsTextureEXT u -- n
c-function glPrioritizeTexturesEXT glPrioritizeTexturesEXT n a a -- void
c-function glTextureNormalEXT glTextureNormalEXT u -- void
c-function glGetQueryObjecti64vEXT glGetQueryObjecti64vEXT u u a -- void
c-function glGetQueryObjectui64vEXT glGetQueryObjectui64vEXT u u a -- void
c-function glBeginTransformFeedbackEXT glBeginTransformFeedbackEXT u -- void
c-function glEndTransformFeedbackEXT glEndTransformFeedbackEXT  -- void
c-function glBindBufferRangeEXT glBindBufferRangeEXT u u u n n -- void
c-function glBindBufferOffsetEXT glBindBufferOffsetEXT u u u n -- void
c-function glBindBufferBaseEXT glBindBufferBaseEXT u u u -- void
c-function glTransformFeedbackVaryingsEXT glTransformFeedbackVaryingsEXT u n a u -- void
c-function glGetTransformFeedbackVaryingEXT glGetTransformFeedbackVaryingEXT u u n a a a a -- void
c-function glArrayElementEXT glArrayElementEXT n -- void
c-function glColorPointerEXT glColorPointerEXT n u n n a -- void
c-function glDrawArraysEXT glDrawArraysEXT u n n -- void
c-function glEdgeFlagPointerEXT glEdgeFlagPointerEXT n n a -- void
c-function glGetPointervEXT glGetPointervEXT u a -- void
c-function glIndexPointerEXT glIndexPointerEXT u n n a -- void
c-function glNormalPointerEXT glNormalPointerEXT u n n a -- void
c-function glTexCoordPointerEXT glTexCoordPointerEXT n u n n a -- void
c-function glVertexPointerEXT glVertexPointerEXT n u n n a -- void
c-function glVertexAttribL1dEXT glVertexAttribL1dEXT u r -- void
c-function glVertexAttribL2dEXT glVertexAttribL2dEXT u r r -- void
c-function glVertexAttribL3dEXT glVertexAttribL3dEXT u r r r -- void
c-function glVertexAttribL4dEXT glVertexAttribL4dEXT u r r r r -- void
c-function glVertexAttribL1dvEXT glVertexAttribL1dvEXT u a -- void
c-function glVertexAttribL2dvEXT glVertexAttribL2dvEXT u a -- void
c-function glVertexAttribL3dvEXT glVertexAttribL3dvEXT u a -- void
c-function glVertexAttribL4dvEXT glVertexAttribL4dvEXT u a -- void
c-function glVertexAttribLPointerEXT glVertexAttribLPointerEXT u n u n a -- void
c-function glGetVertexAttribLdvEXT glGetVertexAttribLdvEXT u u a -- void
c-function glBeginVertexShaderEXT glBeginVertexShaderEXT  -- void
c-function glEndVertexShaderEXT glEndVertexShaderEXT  -- void
c-function glBindVertexShaderEXT glBindVertexShaderEXT u -- void
c-function glGenVertexShadersEXT glGenVertexShadersEXT u -- u
c-function glDeleteVertexShaderEXT glDeleteVertexShaderEXT u -- void
c-function glShaderOp1EXT glShaderOp1EXT u u u -- void
c-function glShaderOp2EXT glShaderOp2EXT u u u u -- void
c-function glShaderOp3EXT glShaderOp3EXT u u u u u -- void
c-function glSwizzleEXT glSwizzleEXT u u u u u u -- void
c-function glWriteMaskEXT glWriteMaskEXT u u u u u u -- void
c-function glInsertComponentEXT glInsertComponentEXT u u u -- void
c-function glExtractComponentEXT glExtractComponentEXT u u u -- void
c-function glGenSymbolsEXT glGenSymbolsEXT u u u u -- u
c-function glSetInvariantEXT glSetInvariantEXT u u a -- void
c-function glSetLocalConstantEXT glSetLocalConstantEXT u u a -- void
c-function glVariantbvEXT glVariantbvEXT u a -- void
c-function glVariantsvEXT glVariantsvEXT u a -- void
c-function glVariantivEXT glVariantivEXT u a -- void
c-function glVariantfvEXT glVariantfvEXT u a -- void
c-function glVariantdvEXT glVariantdvEXT u a -- void
c-function glVariantubvEXT glVariantubvEXT u a -- void
c-function glVariantusvEXT glVariantusvEXT u a -- void
c-function glVariantuivEXT glVariantuivEXT u a -- void
c-function glVariantPointerEXT glVariantPointerEXT u u u a -- void
c-function glEnableVariantClientStateEXT glEnableVariantClientStateEXT u -- void
c-function glDisableVariantClientStateEXT glDisableVariantClientStateEXT u -- void
c-function glBindLightParameterEXT glBindLightParameterEXT u u -- u
c-function glBindMaterialParameterEXT glBindMaterialParameterEXT u u -- u
c-function glBindTexGenParameterEXT glBindTexGenParameterEXT u u u -- u
c-function glBindTextureUnitParameterEXT glBindTextureUnitParameterEXT u u -- u
c-function glBindParameterEXT glBindParameterEXT u -- u
c-function glIsVariantEnabledEXT glIsVariantEnabledEXT u u -- n
c-function glGetVariantBooleanvEXT glGetVariantBooleanvEXT u u a -- void
c-function glGetVariantIntegervEXT glGetVariantIntegervEXT u u a -- void
c-function glGetVariantFloatvEXT glGetVariantFloatvEXT u u a -- void
c-function glGetVariantPointervEXT glGetVariantPointervEXT u u a -- void
c-function glGetInvariantBooleanvEXT glGetInvariantBooleanvEXT u u a -- void
c-function glGetInvariantIntegervEXT glGetInvariantIntegervEXT u u a -- void
c-function glGetInvariantFloatvEXT glGetInvariantFloatvEXT u u a -- void
c-function glGetLocalConstantBooleanvEXT glGetLocalConstantBooleanvEXT u u a -- void
c-function glGetLocalConstantIntegervEXT glGetLocalConstantIntegervEXT u u a -- void
c-function glGetLocalConstantFloatvEXT glGetLocalConstantFloatvEXT u u a -- void
c-function glVertexWeightfEXT glVertexWeightfEXT r -- void
c-function glVertexWeightfvEXT glVertexWeightfvEXT a -- void
c-function glVertexWeightPointerEXT glVertexWeightPointerEXT n u n a -- void
c-function glImportSyncEXT glImportSyncEXT u n u -- a
c-function glFrameTerminatorGREMEDY glFrameTerminatorGREMEDY  -- void
c-function glStringMarkerGREMEDY glStringMarkerGREMEDY n a -- void
c-function glImageTransformParameteriHP glImageTransformParameteriHP u u n -- void
c-function glImageTransformParameterfHP glImageTransformParameterfHP u u r -- void
c-function glImageTransformParameterivHP glImageTransformParameterivHP u u a -- void
c-function glImageTransformParameterfvHP glImageTransformParameterfvHP u u a -- void
c-function glGetImageTransformParameterivHP glGetImageTransformParameterivHP u u a -- void
c-function glGetImageTransformParameterfvHP glGetImageTransformParameterfvHP u u a -- void
c-function glMultiModeDrawArraysIBM glMultiModeDrawArraysIBM a a a n n -- void
c-function glMultiModeDrawElementsIBM glMultiModeDrawElementsIBM a a u a n n -- void
c-function glFlushStaticDataIBM glFlushStaticDataIBM u -- void
c-function glColorPointerListIBM glColorPointerListIBM n u n a n -- void
c-function glSecondaryColorPointerListIBM glSecondaryColorPointerListIBM n u n a n -- void
c-function glEdgeFlagPointerListIBM glEdgeFlagPointerListIBM n a n -- void
c-function glFogCoordPointerListIBM glFogCoordPointerListIBM u n a n -- void
c-function glIndexPointerListIBM glIndexPointerListIBM u n a n -- void
c-function glNormalPointerListIBM glNormalPointerListIBM u n a n -- void
c-function glTexCoordPointerListIBM glTexCoordPointerListIBM n u n a n -- void
c-function glVertexPointerListIBM glVertexPointerListIBM n u n a n -- void
c-function glBlendFuncSeparateINGR glBlendFuncSeparateINGR u u u u -- void
c-function glSyncTextureINTEL glSyncTextureINTEL u -- void
c-function glUnmapTexture2DINTEL glUnmapTexture2DINTEL u n -- void
c-function glMapTexture2DINTEL glMapTexture2DINTEL u n u a a -- a
c-function glVertexPointervINTEL glVertexPointervINTEL n u a -- void
c-function glNormalPointervINTEL glNormalPointervINTEL u a -- void
c-function glColorPointervINTEL glColorPointervINTEL n u a -- void
c-function glTexCoordPointervINTEL glTexCoordPointervINTEL n u a -- void
c-function glBeginPerfQueryINTEL glBeginPerfQueryINTEL u -- void
c-function glCreatePerfQueryINTEL glCreatePerfQueryINTEL u a -- void
c-function glDeletePerfQueryINTEL glDeletePerfQueryINTEL u -- void
c-function glEndPerfQueryINTEL glEndPerfQueryINTEL u -- void
c-function glGetFirstPerfQueryIdINTEL glGetFirstPerfQueryIdINTEL a -- void
c-function glGetNextPerfQueryIdINTEL glGetNextPerfQueryIdINTEL u a -- void
c-function glGetPerfCounterInfoINTEL glGetPerfCounterInfoINTEL u u u a u a a a a a a -- void
c-function glGetPerfQueryDataINTEL glGetPerfQueryDataINTEL u u n a a -- void
c-function glGetPerfQueryIdByNameINTEL glGetPerfQueryIdByNameINTEL a a -- void
c-function glGetPerfQueryInfoINTEL glGetPerfQueryInfoINTEL u u a a a a a -- void
c-function glResizeBuffersMESA glResizeBuffersMESA  -- void
c-function glWindowPos2dMESA glWindowPos2dMESA r r -- void
c-function glWindowPos2dvMESA glWindowPos2dvMESA a -- void
c-function glWindowPos2fMESA glWindowPos2fMESA r r -- void
c-function glWindowPos2fvMESA glWindowPos2fvMESA a -- void
c-function glWindowPos2iMESA glWindowPos2iMESA n n -- void
c-function glWindowPos2ivMESA glWindowPos2ivMESA a -- void
c-function glWindowPos2sMESA glWindowPos2sMESA n n -- void
c-function glWindowPos2svMESA glWindowPos2svMESA a -- void
c-function glWindowPos3dMESA glWindowPos3dMESA r r r -- void
c-function glWindowPos3dvMESA glWindowPos3dvMESA a -- void
c-function glWindowPos3fMESA glWindowPos3fMESA r r r -- void
c-function glWindowPos3fvMESA glWindowPos3fvMESA a -- void
c-function glWindowPos3iMESA glWindowPos3iMESA n n n -- void
c-function glWindowPos3ivMESA glWindowPos3ivMESA a -- void
c-function glWindowPos3sMESA glWindowPos3sMESA n n n -- void
c-function glWindowPos3svMESA glWindowPos3svMESA a -- void
c-function glWindowPos4dMESA glWindowPos4dMESA r r r r -- void
c-function glWindowPos4dvMESA glWindowPos4dvMESA a -- void
c-function glWindowPos4fMESA glWindowPos4fMESA r r r r -- void
c-function glWindowPos4fvMESA glWindowPos4fvMESA a -- void
c-function glWindowPos4iMESA glWindowPos4iMESA n n n n -- void
c-function glWindowPos4ivMESA glWindowPos4ivMESA a -- void
c-function glWindowPos4sMESA glWindowPos4sMESA n n n n -- void
c-function glWindowPos4svMESA glWindowPos4svMESA a -- void
c-function glBeginConditionalRenderNVX glBeginConditionalRenderNVX u -- void
c-function glEndConditionalRenderNVX glEndConditionalRenderNVX  -- void
c-function glMultiDrawArraysIndirectBindlessNV glMultiDrawArraysIndirectBindlessNV u a n n n -- void
c-function glMultiDrawElementsIndirectBindlessNV glMultiDrawElementsIndirectBindlessNV u u a n n n -- void
c-function glMultiDrawArraysIndirectBindlessCountNV glMultiDrawArraysIndirectBindlessCountNV u a n n n n -- void
c-function glMultiDrawElementsIndirectBindlessCountNV glMultiDrawElementsIndirectBindlessCountNV u u a n n n n -- void
c-function glGetTextureHandleNV glGetTextureHandleNV u -- d
c-function glGetTextureSamplerHandleNV glGetTextureSamplerHandleNV u u -- d
c-function glMakeTextureHandleResidentNV glMakeTextureHandleResidentNV d -- void
c-function glMakeTextureHandleNonResidentNV glMakeTextureHandleNonResidentNV d -- void
c-function glGetImageHandleNV glGetImageHandleNV u n n n u -- d
c-function glMakeImageHandleResidentNV glMakeImageHandleResidentNV d u -- void
c-function glMakeImageHandleNonResidentNV glMakeImageHandleNonResidentNV d -- void
c-function glUniformHandleui64NV glUniformHandleui64NV n d -- void
c-function glUniformHandleui64vNV glUniformHandleui64vNV n n a -- void
c-function glProgramUniformHandleui64NV glProgramUniformHandleui64NV u n d -- void
c-function glProgramUniformHandleui64vNV glProgramUniformHandleui64vNV u n n a -- void
c-function glIsTextureHandleResidentNV glIsTextureHandleResidentNV d -- n
c-function glIsImageHandleResidentNV glIsImageHandleResidentNV d -- n
c-function glBlendParameteriNV glBlendParameteriNV u n -- void
c-function glBlendBarrierNV glBlendBarrierNV  -- void
c-function glBeginConditionalRenderNV glBeginConditionalRenderNV u u -- void
c-function glEndConditionalRenderNV glEndConditionalRenderNV  -- void
c-function glSubpixelPrecisionBiasNV glSubpixelPrecisionBiasNV u u -- void
c-function glCopyImageSubDataNV glCopyImageSubDataNV u u n n n n u u n n n n n n n -- void
c-function glDepthRangedNV glDepthRangedNV r r -- void
c-function glClearDepthdNV glClearDepthdNV r -- void
c-function glDepthBoundsdNV glDepthBoundsdNV r r -- void
c-function glDrawTextureNV glDrawTextureNV u u r r r r r r r r r -- void
c-function glMapControlPointsNV glMapControlPointsNV u u u n n n n n a -- void
c-function glMapParameterivNV glMapParameterivNV u u a -- void
c-function glMapParameterfvNV glMapParameterfvNV u u a -- void
c-function glGetMapControlPointsNV glGetMapControlPointsNV u u u n n n a -- void
c-function glGetMapParameterivNV glGetMapParameterivNV u u a -- void
c-function glGetMapParameterfvNV glGetMapParameterfvNV u u a -- void
c-function glGetMapAttribParameterivNV glGetMapAttribParameterivNV u u u a -- void
c-function glGetMapAttribParameterfvNV glGetMapAttribParameterfvNV u u u a -- void
c-function glEvalMapsNV glEvalMapsNV u u -- void
c-function glGetMultisamplefvNV glGetMultisamplefvNV u u a -- void
c-function glSampleMaskIndexedNV glSampleMaskIndexedNV u u -- void
c-function glTexRenderbufferNV glTexRenderbufferNV u u -- void
c-function glDeleteFencesNV glDeleteFencesNV n a -- void
c-function glGenFencesNV glGenFencesNV n a -- void
c-function glIsFenceNV glIsFenceNV u -- n
c-function glTestFenceNV glTestFenceNV u -- n
c-function glGetFenceivNV glGetFenceivNV u u a -- void
c-function glFinishFenceNV glFinishFenceNV u -- void
c-function glSetFenceNV glSetFenceNV u u -- void
c-function glFragmentCoverageColorNV glFragmentCoverageColorNV u -- void
c-function glProgramNamedParameter4fNV glProgramNamedParameter4fNV u n a r r r r -- void
c-function glProgramNamedParameter4fvNV glProgramNamedParameter4fvNV u n a a -- void
c-function glProgramNamedParameter4dNV glProgramNamedParameter4dNV u n a r r r r -- void
c-function glProgramNamedParameter4dvNV glProgramNamedParameter4dvNV u n a a -- void
c-function glGetProgramNamedParameterfvNV glGetProgramNamedParameterfvNV u n a a -- void
c-function glGetProgramNamedParameterdvNV glGetProgramNamedParameterdvNV u n a a -- void
c-function glCoverageModulationTableNV glCoverageModulationTableNV n a -- void
c-function glGetCoverageModulationTableNV glGetCoverageModulationTableNV n a -- void
c-function glCoverageModulationNV glCoverageModulationNV u -- void
c-function glRenderbufferStorageMultisampleCoverageNV glRenderbufferStorageMultisampleCoverageNV u n n u n n -- void
c-function glProgramVertexLimitNV glProgramVertexLimitNV u n -- void
c-function glFramebufferTextureEXT glFramebufferTextureEXT u u u n -- void
c-function glFramebufferTextureFaceEXT glFramebufferTextureFaceEXT u u u n u -- void
c-function glProgramLocalParameterI4iNV glProgramLocalParameterI4iNV u u n n n n -- void
c-function glProgramLocalParameterI4ivNV glProgramLocalParameterI4ivNV u u a -- void
c-function glProgramLocalParametersI4ivNV glProgramLocalParametersI4ivNV u u n a -- void
c-function glProgramLocalParameterI4uiNV glProgramLocalParameterI4uiNV u u u u u u -- void
c-function glProgramLocalParameterI4uivNV glProgramLocalParameterI4uivNV u u a -- void
c-function glProgramLocalParametersI4uivNV glProgramLocalParametersI4uivNV u u n a -- void
c-function glProgramEnvParameterI4iNV glProgramEnvParameterI4iNV u u n n n n -- void
c-function glProgramEnvParameterI4ivNV glProgramEnvParameterI4ivNV u u a -- void
c-function glProgramEnvParametersI4ivNV glProgramEnvParametersI4ivNV u u n a -- void
c-function glProgramEnvParameterI4uiNV glProgramEnvParameterI4uiNV u u u u u u -- void
c-function glProgramEnvParameterI4uivNV glProgramEnvParameterI4uivNV u u a -- void
c-function glProgramEnvParametersI4uivNV glProgramEnvParametersI4uivNV u u n a -- void
c-function glGetProgramLocalParameterIivNV glGetProgramLocalParameterIivNV u u a -- void
c-function glGetProgramLocalParameterIuivNV glGetProgramLocalParameterIuivNV u u a -- void
c-function glGetProgramEnvParameterIivNV glGetProgramEnvParameterIivNV u u a -- void
c-function glGetProgramEnvParameterIuivNV glGetProgramEnvParameterIuivNV u u a -- void
c-function glProgramSubroutineParametersuivNV glProgramSubroutineParametersuivNV u n a -- void
c-function glGetProgramSubroutineParameteruivNV glGetProgramSubroutineParameteruivNV u u a -- void
c-function glVertex2hNV glVertex2hNV n n -- void
c-function glVertex2hvNV glVertex2hvNV a -- void
c-function glVertex3hNV glVertex3hNV n n n -- void
c-function glVertex3hvNV glVertex3hvNV a -- void
c-function glVertex4hNV glVertex4hNV n n n n -- void
c-function glVertex4hvNV glVertex4hvNV a -- void
c-function glNormal3hNV glNormal3hNV n n n -- void
c-function glNormal3hvNV glNormal3hvNV a -- void
c-function glColor3hNV glColor3hNV n n n -- void
c-function glColor3hvNV glColor3hvNV a -- void
c-function glColor4hNV glColor4hNV n n n n -- void
c-function glColor4hvNV glColor4hvNV a -- void
c-function glTexCoord1hNV glTexCoord1hNV n -- void
c-function glTexCoord1hvNV glTexCoord1hvNV a -- void
c-function glTexCoord2hNV glTexCoord2hNV n n -- void
c-function glTexCoord2hvNV glTexCoord2hvNV a -- void
c-function glTexCoord3hNV glTexCoord3hNV n n n -- void
c-function glTexCoord3hvNV glTexCoord3hvNV a -- void
c-function glTexCoord4hNV glTexCoord4hNV n n n n -- void
c-function glTexCoord4hvNV glTexCoord4hvNV a -- void
c-function glMultiTexCoord1hNV glMultiTexCoord1hNV u n -- void
c-function glMultiTexCoord1hvNV glMultiTexCoord1hvNV u a -- void
c-function glMultiTexCoord2hNV glMultiTexCoord2hNV u n n -- void
c-function glMultiTexCoord2hvNV glMultiTexCoord2hvNV u a -- void
c-function glMultiTexCoord3hNV glMultiTexCoord3hNV u n n n -- void
c-function glMultiTexCoord3hvNV glMultiTexCoord3hvNV u a -- void
c-function glMultiTexCoord4hNV glMultiTexCoord4hNV u n n n n -- void
c-function glMultiTexCoord4hvNV glMultiTexCoord4hvNV u a -- void
c-function glFogCoordhNV glFogCoordhNV n -- void
c-function glFogCoordhvNV glFogCoordhvNV a -- void
c-function glSecondaryColor3hNV glSecondaryColor3hNV n n n -- void
c-function glSecondaryColor3hvNV glSecondaryColor3hvNV a -- void
c-function glVertexWeighthNV glVertexWeighthNV n -- void
c-function glVertexWeighthvNV glVertexWeighthvNV a -- void
c-function glVertexAttrib1hNV glVertexAttrib1hNV u n -- void
c-function glVertexAttrib1hvNV glVertexAttrib1hvNV u a -- void
c-function glVertexAttrib2hNV glVertexAttrib2hNV u n n -- void
c-function glVertexAttrib2hvNV glVertexAttrib2hvNV u a -- void
c-function glVertexAttrib3hNV glVertexAttrib3hNV u n n n -- void
c-function glVertexAttrib3hvNV glVertexAttrib3hvNV u a -- void
c-function glVertexAttrib4hNV glVertexAttrib4hNV u n n n n -- void
c-function glVertexAttrib4hvNV glVertexAttrib4hvNV u a -- void
c-function glVertexAttribs1hvNV glVertexAttribs1hvNV u n a -- void
c-function glVertexAttribs2hvNV glVertexAttribs2hvNV u n a -- void
c-function glVertexAttribs3hvNV glVertexAttribs3hvNV u n a -- void
c-function glVertexAttribs4hvNV glVertexAttribs4hvNV u n a -- void
c-function glGetInternalformatSampleivNV glGetInternalformatSampleivNV u u n u n a -- void
c-function glGenOcclusionQueriesNV glGenOcclusionQueriesNV n a -- void
c-function glDeleteOcclusionQueriesNV glDeleteOcclusionQueriesNV n a -- void
c-function glIsOcclusionQueryNV glIsOcclusionQueryNV u -- n
c-function glBeginOcclusionQueryNV glBeginOcclusionQueryNV u -- void
c-function glEndOcclusionQueryNV glEndOcclusionQueryNV  -- void
c-function glGetOcclusionQueryivNV glGetOcclusionQueryivNV u u a -- void
c-function glGetOcclusionQueryuivNV glGetOcclusionQueryuivNV u u a -- void
c-function glProgramBufferParametersfvNV glProgramBufferParametersfvNV u u u n a -- void
c-function glProgramBufferParametersIivNV glProgramBufferParametersIivNV u u u n a -- void
c-function glProgramBufferParametersIuivNV glProgramBufferParametersIuivNV u u u n a -- void
c-function glGenPathsNV glGenPathsNV n -- u
c-function glDeletePathsNV glDeletePathsNV u n -- void
c-function glIsPathNV glIsPathNV u -- n
c-function glPathCommandsNV glPathCommandsNV u n a n u a -- void
c-function glPathCoordsNV glPathCoordsNV u n u a -- void
c-function glPathSubCommandsNV glPathSubCommandsNV u n n n a n u a -- void
c-function glPathSubCoordsNV glPathSubCoordsNV u n n u a -- void
c-function glPathStringNV glPathStringNV u u n a -- void
c-function glPathGlyphsNV glPathGlyphsNV u u a u n u a u u r -- void
c-function glPathGlyphRangeNV glPathGlyphRangeNV u u a u u n u u r -- void
c-function glWeightPathsNV glWeightPathsNV u n a a -- void
c-function glCopyPathNV glCopyPathNV u u -- void
c-function glInterpolatePathsNV glInterpolatePathsNV u u u r -- void
c-function glTransformPathNV glTransformPathNV u u u a -- void
c-function glPathParameterivNV glPathParameterivNV u u a -- void
c-function glPathParameteriNV glPathParameteriNV u u n -- void
c-function glPathParameterfvNV glPathParameterfvNV u u a -- void
c-function glPathParameterfNV glPathParameterfNV u u r -- void
c-function glPathDashArrayNV glPathDashArrayNV u n a -- void
c-function glPathStencilFuncNV glPathStencilFuncNV u n u -- void
c-function glPathStencilDepthOffsetNV glPathStencilDepthOffsetNV r r -- void
c-function glStencilFillPathNV glStencilFillPathNV u u u -- void
c-function glStencilStrokePathNV glStencilStrokePathNV u n u -- void
c-function glStencilFillPathInstancedNV glStencilFillPathInstancedNV n u a u u u u a -- void
c-function glStencilStrokePathInstancedNV glStencilStrokePathInstancedNV n u a u n u u a -- void
c-function glPathCoverDepthFuncNV glPathCoverDepthFuncNV u -- void
c-function glCoverFillPathNV glCoverFillPathNV u u -- void
c-function glCoverStrokePathNV glCoverStrokePathNV u u -- void
c-function glCoverFillPathInstancedNV glCoverFillPathInstancedNV n u a u u u a -- void
c-function glCoverStrokePathInstancedNV glCoverStrokePathInstancedNV n u a u u u a -- void
c-function glGetPathParameterivNV glGetPathParameterivNV u u a -- void
c-function glGetPathParameterfvNV glGetPathParameterfvNV u u a -- void
c-function glGetPathCommandsNV glGetPathCommandsNV u a -- void
c-function glGetPathCoordsNV glGetPathCoordsNV u a -- void
c-function glGetPathDashArrayNV glGetPathDashArrayNV u a -- void
c-function glGetPathMetricsNV glGetPathMetricsNV u n u a u n a -- void
c-function glGetPathMetricRangeNV glGetPathMetricRangeNV u u n n a -- void
c-function glGetPathSpacingNV glGetPathSpacingNV u n u a u r r u a -- void
c-function glIsPointInFillPathNV glIsPointInFillPathNV u u r r -- n
c-function glIsPointInStrokePathNV glIsPointInStrokePathNV u r r -- n
c-function glGetPathLengthNV glGetPathLengthNV u n n -- r
c-function glPointAlongPathNV glPointAlongPathNV u n n r a a a a -- n
c-function glMatrixLoad3x2fNV glMatrixLoad3x2fNV u a -- void
c-function glMatrixLoad3x3fNV glMatrixLoad3x3fNV u a -- void
c-function glMatrixLoadTranspose3x3fNV glMatrixLoadTranspose3x3fNV u a -- void
c-function glMatrixMult3x2fNV glMatrixMult3x2fNV u a -- void
c-function glMatrixMult3x3fNV glMatrixMult3x3fNV u a -- void
c-function glMatrixMultTranspose3x3fNV glMatrixMultTranspose3x3fNV u a -- void
c-function glStencilThenCoverFillPathNV glStencilThenCoverFillPathNV u u u u -- void
c-function glStencilThenCoverStrokePathNV glStencilThenCoverStrokePathNV u n u u -- void
c-function glStencilThenCoverFillPathInstancedNV glStencilThenCoverFillPathInstancedNV n u a u u u u u a -- void
c-function glStencilThenCoverStrokePathInstancedNV glStencilThenCoverStrokePathInstancedNV n u a u n u u u a -- void
c-function glPathGlyphIndexRangeNV glPathGlyphIndexRangeNV u a u u r a -- u
c-function glPathGlyphIndexArrayNV glPathGlyphIndexArrayNV u u a u u n u r -- u
c-function glPathMemoryGlyphIndexArrayNV glPathMemoryGlyphIndexArrayNV u u n a n u n u r -- u
c-function glProgramPathFragmentInputGenNV glProgramPathFragmentInputGenNV u n u n a -- void
c-function glGetProgramResourcefvNV glGetProgramResourcefvNV u u u n a n a a -- void
c-function glPathColorGenNV glPathColorGenNV u u u a -- void
c-function glPathTexGenNV glPathTexGenNV u u n a -- void
c-function glPathFogGenNV glPathFogGenNV u -- void
c-function glGetPathColorGenivNV glGetPathColorGenivNV u u a -- void
c-function glGetPathColorGenfvNV glGetPathColorGenfvNV u u a -- void
c-function glGetPathTexGenivNV glGetPathTexGenivNV u u a -- void
c-function glGetPathTexGenfvNV glGetPathTexGenfvNV u u a -- void
c-function glPixelDataRangeNV glPixelDataRangeNV u n a -- void
c-function glFlushPixelDataRangeNV glFlushPixelDataRangeNV u -- void
c-function glPointParameteriNV glPointParameteriNV u n -- void
c-function glPointParameterivNV glPointParameterivNV u a -- void
c-function glPresentFrameKeyedNV glPresentFrameKeyedNV u d u u u u u u u u u -- void
c-function glPresentFrameDualFillNV glPresentFrameDualFillNV u d u u u u u u u u u u u -- void
c-function glGetVideoivNV glGetVideoivNV u u a -- void
c-function glGetVideouivNV glGetVideouivNV u u a -- void
c-function glGetVideoi64vNV glGetVideoi64vNV u u a -- void
c-function glGetVideoui64vNV glGetVideoui64vNV u u a -- void
c-function glPrimitiveRestartNV glPrimitiveRestartNV  -- void
c-function glPrimitiveRestartIndexNV glPrimitiveRestartIndexNV u -- void
c-function glCombinerParameterfvNV glCombinerParameterfvNV u a -- void
c-function glCombinerParameterfNV glCombinerParameterfNV u r -- void
c-function glCombinerParameterivNV glCombinerParameterivNV u a -- void
c-function glCombinerParameteriNV glCombinerParameteriNV u n -- void
c-function glCombinerInputNV glCombinerInputNV u u u u u u -- void
c-function glCombinerOutputNV glCombinerOutputNV u u u u u u u n n n -- void
c-function glFinalCombinerInputNV glFinalCombinerInputNV u u u u -- void
c-function glGetCombinerInputParameterfvNV glGetCombinerInputParameterfvNV u u u u a -- void
c-function glGetCombinerInputParameterivNV glGetCombinerInputParameterivNV u u u u a -- void
c-function glGetCombinerOutputParameterfvNV glGetCombinerOutputParameterfvNV u u u a -- void
c-function glGetCombinerOutputParameterivNV glGetCombinerOutputParameterivNV u u u a -- void
c-function glGetFinalCombinerInputParameterfvNV glGetFinalCombinerInputParameterfvNV u u a -- void
c-function glGetFinalCombinerInputParameterivNV glGetFinalCombinerInputParameterivNV u u a -- void
c-function glCombinerStageParameterfvNV glCombinerStageParameterfvNV u u a -- void
c-function glGetCombinerStageParameterfvNV glGetCombinerStageParameterfvNV u u a -- void
c-function glFramebufferSampleLocationsfvNV glFramebufferSampleLocationsfvNV u u n a -- void
c-function glNamedFramebufferSampleLocationsfvNV glNamedFramebufferSampleLocationsfvNV u u n a -- void
c-function glResolveDepthValuesNV glResolveDepthValuesNV  -- void
c-function glMakeBufferResidentNV glMakeBufferResidentNV u u -- void
c-function glMakeBufferNonResidentNV glMakeBufferNonResidentNV u -- void
c-function glIsBufferResidentNV glIsBufferResidentNV u -- n
c-function glMakeNamedBufferResidentNV glMakeNamedBufferResidentNV u u -- void
c-function glMakeNamedBufferNonResidentNV glMakeNamedBufferNonResidentNV u -- void
c-function glIsNamedBufferResidentNV glIsNamedBufferResidentNV u -- n
c-function glGetBufferParameterui64vNV glGetBufferParameterui64vNV u u a -- void
c-function glGetNamedBufferParameterui64vNV glGetNamedBufferParameterui64vNV u u a -- void
c-function glGetIntegerui64vNV glGetIntegerui64vNV u a -- void
c-function glUniformui64NV glUniformui64NV n d -- void
c-function glUniformui64vNV glUniformui64vNV n n a -- void
c-function glProgramUniformui64NV glProgramUniformui64NV u n d -- void
c-function glProgramUniformui64vNV glProgramUniformui64vNV u n n a -- void
c-function glTextureBarrierNV glTextureBarrierNV  -- void
c-function glTexImage2DMultisampleCoverageNV glTexImage2DMultisampleCoverageNV u n n n n n n -- void
c-function glTexImage3DMultisampleCoverageNV glTexImage3DMultisampleCoverageNV u n n n n n n n -- void
c-function glTextureImage2DMultisampleNV glTextureImage2DMultisampleNV u u n n n n n -- void
c-function glTextureImage3DMultisampleNV glTextureImage3DMultisampleNV u u n n n n n n -- void
c-function glTextureImage2DMultisampleCoverageNV glTextureImage2DMultisampleCoverageNV u u n n n n n n -- void
c-function glTextureImage3DMultisampleCoverageNV glTextureImage3DMultisampleCoverageNV u u n n n n n n n -- void
c-function glBeginTransformFeedbackNV glBeginTransformFeedbackNV u -- void
c-function glEndTransformFeedbackNV glEndTransformFeedbackNV  -- void
c-function glTransformFeedbackAttribsNV glTransformFeedbackAttribsNV n a u -- void
c-function glBindBufferRangeNV glBindBufferRangeNV u u u n n -- void
c-function glBindBufferOffsetNV glBindBufferOffsetNV u u u n -- void
c-function glBindBufferBaseNV glBindBufferBaseNV u u u -- void
c-function glTransformFeedbackVaryingsNV glTransformFeedbackVaryingsNV u n a u -- void
c-function glActiveVaryingNV glActiveVaryingNV u a -- void
c-function glGetVaryingLocationNV glGetVaryingLocationNV u a -- n
c-function glGetActiveVaryingNV glGetActiveVaryingNV u u n a a a a -- void
c-function glGetTransformFeedbackVaryingNV glGetTransformFeedbackVaryingNV u u a -- void
c-function glTransformFeedbackStreamAttribsNV glTransformFeedbackStreamAttribsNV n a n a u -- void
c-function glBindTransformFeedbackNV glBindTransformFeedbackNV u u -- void
c-function glDeleteTransformFeedbacksNV glDeleteTransformFeedbacksNV n a -- void
c-function glGenTransformFeedbacksNV glGenTransformFeedbacksNV n a -- void
c-function glIsTransformFeedbackNV glIsTransformFeedbackNV u -- n
c-function glPauseTransformFeedbackNV glPauseTransformFeedbackNV  -- void
c-function glResumeTransformFeedbackNV glResumeTransformFeedbackNV  -- void
c-function glDrawTransformFeedbackNV glDrawTransformFeedbackNV u u -- void
c-function glVDPAUInitNV glVDPAUInitNV a a -- void
c-function glVDPAUFiniNV glVDPAUFiniNV  -- void
c-function glVDPAURegisterVideoSurfaceNV glVDPAURegisterVideoSurfaceNV a u n a -- n
c-function glVDPAURegisterOutputSurfaceNV glVDPAURegisterOutputSurfaceNV a u n a -- n
c-function glVDPAUIsSurfaceNV glVDPAUIsSurfaceNV n -- n
c-function glVDPAUUnregisterSurfaceNV glVDPAUUnregisterSurfaceNV n -- void
c-function glVDPAUGetSurfaceivNV glVDPAUGetSurfaceivNV n u n a a -- void
c-function glVDPAUSurfaceAccessNV glVDPAUSurfaceAccessNV n u -- void
c-function glVDPAUMapSurfacesNV glVDPAUMapSurfacesNV n a -- void
c-function glVDPAUUnmapSurfacesNV glVDPAUUnmapSurfacesNV n a -- void
c-function glFlushVertexArrayRangeNV glFlushVertexArrayRangeNV  -- void
c-function glVertexArrayRangeNV glVertexArrayRangeNV n a -- void
c-function glVertexAttribL1i64NV glVertexAttribL1i64NV u d -- void
c-function glVertexAttribL2i64NV glVertexAttribL2i64NV u d d -- void
c-function glVertexAttribL3i64NV glVertexAttribL3i64NV u d d d -- void
c-function glVertexAttribL4i64NV glVertexAttribL4i64NV u d d d d -- void
c-function glVertexAttribL1i64vNV glVertexAttribL1i64vNV u a -- void
c-function glVertexAttribL2i64vNV glVertexAttribL2i64vNV u a -- void
c-function glVertexAttribL3i64vNV glVertexAttribL3i64vNV u a -- void
c-function glVertexAttribL4i64vNV glVertexAttribL4i64vNV u a -- void
c-function glVertexAttribL1ui64NV glVertexAttribL1ui64NV u d -- void
c-function glVertexAttribL2ui64NV glVertexAttribL2ui64NV u d d -- void
c-function glVertexAttribL3ui64NV glVertexAttribL3ui64NV u d d d -- void
c-function glVertexAttribL4ui64NV glVertexAttribL4ui64NV u d d d d -- void
c-function glVertexAttribL1ui64vNV glVertexAttribL1ui64vNV u a -- void
c-function glVertexAttribL2ui64vNV glVertexAttribL2ui64vNV u a -- void
c-function glVertexAttribL3ui64vNV glVertexAttribL3ui64vNV u a -- void
c-function glVertexAttribL4ui64vNV glVertexAttribL4ui64vNV u a -- void
c-function glGetVertexAttribLi64vNV glGetVertexAttribLi64vNV u u a -- void
c-function glGetVertexAttribLui64vNV glGetVertexAttribLui64vNV u u a -- void
c-function glVertexAttribLFormatNV glVertexAttribLFormatNV u n u n -- void
c-function glBufferAddressRangeNV glBufferAddressRangeNV u u d n -- void
c-function glVertexFormatNV glVertexFormatNV n u n -- void
c-function glNormalFormatNV glNormalFormatNV u n -- void
c-function glColorFormatNV glColorFormatNV n u n -- void
c-function glIndexFormatNV glIndexFormatNV u n -- void
c-function glTexCoordFormatNV glTexCoordFormatNV n u n -- void
c-function glEdgeFlagFormatNV glEdgeFlagFormatNV n -- void
c-function glSecondaryColorFormatNV glSecondaryColorFormatNV n u n -- void
c-function glFogCoordFormatNV glFogCoordFormatNV u n -- void
c-function glVertexAttribFormatNV glVertexAttribFormatNV u n u n n -- void
c-function glVertexAttribIFormatNV glVertexAttribIFormatNV u n u n -- void
c-function glGetIntegerui64i_vNV glGetIntegerui64i_vNV u u a -- void
c-function glAreProgramsResidentNV glAreProgramsResidentNV n a a -- n
c-function glBindProgramNV glBindProgramNV u u -- void
c-function glDeleteProgramsNV glDeleteProgramsNV n a -- void
c-function glExecuteProgramNV glExecuteProgramNV u u a -- void
c-function glGenProgramsNV glGenProgramsNV n a -- void
c-function glGetProgramParameterdvNV glGetProgramParameterdvNV u u u a -- void
c-function glGetProgramParameterfvNV glGetProgramParameterfvNV u u u a -- void
c-function glGetProgramivNV glGetProgramivNV u u a -- void
c-function glGetProgramStringNV glGetProgramStringNV u u a -- void
c-function glGetTrackMatrixivNV glGetTrackMatrixivNV u u u a -- void
c-function glGetVertexAttribdvNV glGetVertexAttribdvNV u u a -- void
c-function glGetVertexAttribfvNV glGetVertexAttribfvNV u u a -- void
c-function glGetVertexAttribivNV glGetVertexAttribivNV u u a -- void
c-function glGetVertexAttribPointervNV glGetVertexAttribPointervNV u u a -- void
c-function glIsProgramNV glIsProgramNV u -- n
c-function glLoadProgramNV glLoadProgramNV u u n a -- void
c-function glProgramParameter4dNV glProgramParameter4dNV u u r r r r -- void
c-function glProgramParameter4dvNV glProgramParameter4dvNV u u a -- void
c-function glProgramParameter4fNV glProgramParameter4fNV u u r r r r -- void
c-function glProgramParameter4fvNV glProgramParameter4fvNV u u a -- void
c-function glProgramParameters4dvNV glProgramParameters4dvNV u u n a -- void
c-function glProgramParameters4fvNV glProgramParameters4fvNV u u n a -- void
c-function glRequestResidentProgramsNV glRequestResidentProgramsNV n a -- void
c-function glTrackMatrixNV glTrackMatrixNV u u u u -- void
c-function glVertexAttribPointerNV glVertexAttribPointerNV u n u n a -- void
c-function glVertexAttrib1dNV glVertexAttrib1dNV u r -- void
c-function glVertexAttrib1dvNV glVertexAttrib1dvNV u a -- void
c-function glVertexAttrib1fNV glVertexAttrib1fNV u r -- void
c-function glVertexAttrib1fvNV glVertexAttrib1fvNV u a -- void
c-function glVertexAttrib1sNV glVertexAttrib1sNV u n -- void
c-function glVertexAttrib1svNV glVertexAttrib1svNV u a -- void
c-function glVertexAttrib2dNV glVertexAttrib2dNV u r r -- void
c-function glVertexAttrib2dvNV glVertexAttrib2dvNV u a -- void
c-function glVertexAttrib2fNV glVertexAttrib2fNV u r r -- void
c-function glVertexAttrib2fvNV glVertexAttrib2fvNV u a -- void
c-function glVertexAttrib2sNV glVertexAttrib2sNV u n n -- void
c-function glVertexAttrib2svNV glVertexAttrib2svNV u a -- void
c-function glVertexAttrib3dNV glVertexAttrib3dNV u r r r -- void
c-function glVertexAttrib3dvNV glVertexAttrib3dvNV u a -- void
c-function glVertexAttrib3fNV glVertexAttrib3fNV u r r r -- void
c-function glVertexAttrib3fvNV glVertexAttrib3fvNV u a -- void
c-function glVertexAttrib3sNV glVertexAttrib3sNV u n n n -- void
c-function glVertexAttrib3svNV glVertexAttrib3svNV u a -- void
c-function glVertexAttrib4dNV glVertexAttrib4dNV u r r r r -- void
c-function glVertexAttrib4dvNV glVertexAttrib4dvNV u a -- void
c-function glVertexAttrib4fNV glVertexAttrib4fNV u r r r r -- void
c-function glVertexAttrib4fvNV glVertexAttrib4fvNV u a -- void
c-function glVertexAttrib4sNV glVertexAttrib4sNV u n n n n -- void
c-function glVertexAttrib4svNV glVertexAttrib4svNV u a -- void
c-function glVertexAttrib4ubNV glVertexAttrib4ubNV u n n n n -- void
c-function glVertexAttrib4ubvNV glVertexAttrib4ubvNV u a -- void
c-function glVertexAttribs1dvNV glVertexAttribs1dvNV u n a -- void
c-function glVertexAttribs1fvNV glVertexAttribs1fvNV u n a -- void
c-function glVertexAttribs1svNV glVertexAttribs1svNV u n a -- void
c-function glVertexAttribs2dvNV glVertexAttribs2dvNV u n a -- void
c-function glVertexAttribs2fvNV glVertexAttribs2fvNV u n a -- void
c-function glVertexAttribs2svNV glVertexAttribs2svNV u n a -- void
c-function glVertexAttribs3dvNV glVertexAttribs3dvNV u n a -- void
c-function glVertexAttribs3fvNV glVertexAttribs3fvNV u n a -- void
c-function glVertexAttribs3svNV glVertexAttribs3svNV u n a -- void
c-function glVertexAttribs4dvNV glVertexAttribs4dvNV u n a -- void
c-function glVertexAttribs4fvNV glVertexAttribs4fvNV u n a -- void
c-function glVertexAttribs4svNV glVertexAttribs4svNV u n a -- void
c-function glVertexAttribs4ubvNV glVertexAttribs4ubvNV u n a -- void
c-function glVertexAttribI1iEXT glVertexAttribI1iEXT u n -- void
c-function glVertexAttribI2iEXT glVertexAttribI2iEXT u n n -- void
c-function glVertexAttribI3iEXT glVertexAttribI3iEXT u n n n -- void
c-function glVertexAttribI4iEXT glVertexAttribI4iEXT u n n n n -- void
c-function glVertexAttribI1uiEXT glVertexAttribI1uiEXT u u -- void
c-function glVertexAttribI2uiEXT glVertexAttribI2uiEXT u u u -- void
c-function glVertexAttribI3uiEXT glVertexAttribI3uiEXT u u u u -- void
c-function glVertexAttribI4uiEXT glVertexAttribI4uiEXT u u u u u -- void
c-function glVertexAttribI1ivEXT glVertexAttribI1ivEXT u a -- void
c-function glVertexAttribI2ivEXT glVertexAttribI2ivEXT u a -- void
c-function glVertexAttribI3ivEXT glVertexAttribI3ivEXT u a -- void
c-function glVertexAttribI4ivEXT glVertexAttribI4ivEXT u a -- void
c-function glVertexAttribI1uivEXT glVertexAttribI1uivEXT u a -- void
c-function glVertexAttribI2uivEXT glVertexAttribI2uivEXT u a -- void
c-function glVertexAttribI3uivEXT glVertexAttribI3uivEXT u a -- void
c-function glVertexAttribI4uivEXT glVertexAttribI4uivEXT u a -- void
c-function glVertexAttribI4bvEXT glVertexAttribI4bvEXT u a -- void
c-function glVertexAttribI4svEXT glVertexAttribI4svEXT u a -- void
c-function glVertexAttribI4ubvEXT glVertexAttribI4ubvEXT u a -- void
c-function glVertexAttribI4usvEXT glVertexAttribI4usvEXT u a -- void
c-function glVertexAttribIPointerEXT glVertexAttribIPointerEXT u n u n a -- void
c-function glGetVertexAttribIivEXT glGetVertexAttribIivEXT u u a -- void
c-function glGetVertexAttribIuivEXT glGetVertexAttribIuivEXT u u a -- void
c-function glBeginVideoCaptureNV glBeginVideoCaptureNV u -- void
c-function glBindVideoCaptureStreamBufferNV glBindVideoCaptureStreamBufferNV u u u n -- void
c-function glBindVideoCaptureStreamTextureNV glBindVideoCaptureStreamTextureNV u u u u u -- void
c-function glEndVideoCaptureNV glEndVideoCaptureNV u -- void
c-function glGetVideoCaptureivNV glGetVideoCaptureivNV u u a -- void
c-function glGetVideoCaptureStreamivNV glGetVideoCaptureStreamivNV u u u a -- void
c-function glGetVideoCaptureStreamfvNV glGetVideoCaptureStreamfvNV u u u a -- void
c-function glGetVideoCaptureStreamdvNV glGetVideoCaptureStreamdvNV u u u a -- void
c-function glVideoCaptureNV glVideoCaptureNV u a a -- u
c-function glVideoCaptureStreamParameterivNV glVideoCaptureStreamParameterivNV u u u a -- void
c-function glVideoCaptureStreamParameterfvNV glVideoCaptureStreamParameterfvNV u u u a -- void
c-function glVideoCaptureStreamParameterdvNV glVideoCaptureStreamParameterdvNV u u u a -- void
c-function glHintPGI glHintPGI u n -- void
c-function glDetailTexFuncSGIS glDetailTexFuncSGIS u n a -- void
c-function glGetDetailTexFuncSGIS glGetDetailTexFuncSGIS u a -- void
c-function glFogFuncSGIS glFogFuncSGIS n a -- void
c-function glGetFogFuncSGIS glGetFogFuncSGIS a -- void
c-function glSampleMaskSGIS glSampleMaskSGIS r n -- void
c-function glSamplePatternSGIS glSamplePatternSGIS u -- void
c-function glPixelTexGenParameteriSGIS glPixelTexGenParameteriSGIS u n -- void
c-function glPixelTexGenParameterivSGIS glPixelTexGenParameterivSGIS u a -- void
c-function glPixelTexGenParameterfSGIS glPixelTexGenParameterfSGIS u r -- void
c-function glPixelTexGenParameterfvSGIS glPixelTexGenParameterfvSGIS u a -- void
c-function glGetPixelTexGenParameterivSGIS glGetPixelTexGenParameterivSGIS u a -- void
c-function glGetPixelTexGenParameterfvSGIS glGetPixelTexGenParameterfvSGIS u a -- void
c-function glPointParameterfSGIS glPointParameterfSGIS u r -- void
c-function glPointParameterfvSGIS glPointParameterfvSGIS u a -- void
c-function glSharpenTexFuncSGIS glSharpenTexFuncSGIS u n a -- void
c-function glGetSharpenTexFuncSGIS glGetSharpenTexFuncSGIS u a -- void
c-function glTexImage4DSGIS glTexImage4DSGIS u n u n n n n n u u a -- void
c-function glTexSubImage4DSGIS glTexSubImage4DSGIS u n n n n n n n n n u u a -- void
c-function glTextureColorMaskSGIS glTextureColorMaskSGIS n n n n -- void
c-function glGetTexFilterFuncSGIS glGetTexFilterFuncSGIS u u a -- void
c-function glTexFilterFuncSGIS glTexFilterFuncSGIS u u n a -- void
c-function glAsyncMarkerSGIX glAsyncMarkerSGIX u -- void
c-function glFinishAsyncSGIX glFinishAsyncSGIX a -- n
c-function glPollAsyncSGIX glPollAsyncSGIX a -- n
c-function glGenAsyncMarkersSGIX glGenAsyncMarkersSGIX n -- u
c-function glDeleteAsyncMarkersSGIX glDeleteAsyncMarkersSGIX u n -- void
c-function glIsAsyncMarkerSGIX glIsAsyncMarkerSGIX u -- n
c-function glFlushRasterSGIX glFlushRasterSGIX  -- void
c-function glFragmentColorMaterialSGIX glFragmentColorMaterialSGIX u u -- void
c-function glFragmentLightfSGIX glFragmentLightfSGIX u u r -- void
c-function glFragmentLightfvSGIX glFragmentLightfvSGIX u u a -- void
c-function glFragmentLightiSGIX glFragmentLightiSGIX u u n -- void
c-function glFragmentLightivSGIX glFragmentLightivSGIX u u a -- void
c-function glFragmentLightModelfSGIX glFragmentLightModelfSGIX u r -- void
c-function glFragmentLightModelfvSGIX glFragmentLightModelfvSGIX u a -- void
c-function glFragmentLightModeliSGIX glFragmentLightModeliSGIX u n -- void
c-function glFragmentLightModelivSGIX glFragmentLightModelivSGIX u a -- void
c-function glFragmentMaterialfSGIX glFragmentMaterialfSGIX u u r -- void
c-function glFragmentMaterialfvSGIX glFragmentMaterialfvSGIX u u a -- void
c-function glFragmentMaterialiSGIX glFragmentMaterialiSGIX u u n -- void
c-function glFragmentMaterialivSGIX glFragmentMaterialivSGIX u u a -- void
c-function glGetFragmentLightfvSGIX glGetFragmentLightfvSGIX u u a -- void
c-function glGetFragmentLightivSGIX glGetFragmentLightivSGIX u u a -- void
c-function glGetFragmentMaterialfvSGIX glGetFragmentMaterialfvSGIX u u a -- void
c-function glGetFragmentMaterialivSGIX glGetFragmentMaterialivSGIX u u a -- void
c-function glLightEnviSGIX glLightEnviSGIX u n -- void
c-function glFrameZoomSGIX glFrameZoomSGIX n -- void
c-function glIglooInterfaceSGIX glIglooInterfaceSGIX u a -- void
c-function glGetInstrumentsSGIX glGetInstrumentsSGIX  -- n
c-function glInstrumentsBufferSGIX glInstrumentsBufferSGIX n a -- void
c-function glPollInstrumentsSGIX glPollInstrumentsSGIX a -- n
c-function glReadInstrumentsSGIX glReadInstrumentsSGIX n -- void
c-function glStartInstrumentsSGIX glStartInstrumentsSGIX  -- void
c-function glStopInstrumentsSGIX glStopInstrumentsSGIX n -- void
c-function glGetListParameterfvSGIX glGetListParameterfvSGIX u u a -- void
c-function glGetListParameterivSGIX glGetListParameterivSGIX u u a -- void
c-function glListParameterfSGIX glListParameterfSGIX u u r -- void
c-function glListParameterfvSGIX glListParameterfvSGIX u u a -- void
c-function glListParameteriSGIX glListParameteriSGIX u u n -- void
c-function glListParameterivSGIX glListParameterivSGIX u u a -- void
c-function glPixelTexGenSGIX glPixelTexGenSGIX u -- void
c-function glDeformationMap3dSGIX glDeformationMap3dSGIX u r r n n r r n n r r n n a -- void
c-function glDeformationMap3fSGIX glDeformationMap3fSGIX u r r n n r r n n r r n n a -- void
c-function glDeformSGIX glDeformSGIX u -- void
c-function glLoadIdentityDeformationMapSGIX glLoadIdentityDeformationMapSGIX u -- void
c-function glReferencePlaneSGIX glReferencePlaneSGIX a -- void
c-function glSpriteParameterfSGIX glSpriteParameterfSGIX u r -- void
c-function glSpriteParameterfvSGIX glSpriteParameterfvSGIX u a -- void
c-function glSpriteParameteriSGIX glSpriteParameteriSGIX u n -- void
c-function glSpriteParameterivSGIX glSpriteParameterivSGIX u a -- void
c-function glTagSampleBufferSGIX glTagSampleBufferSGIX  -- void
c-function glColorTableSGI glColorTableSGI u u n u u a -- void
c-function glColorTableParameterfvSGI glColorTableParameterfvSGI u u a -- void
c-function glColorTableParameterivSGI glColorTableParameterivSGI u u a -- void
c-function glCopyColorTableSGI glCopyColorTableSGI u u n n n -- void
c-function glGetColorTableSGI glGetColorTableSGI u u u a -- void
c-function glGetColorTableParameterfvSGI glGetColorTableParameterfvSGI u u a -- void
c-function glGetColorTableParameterivSGI glGetColorTableParameterivSGI u u a -- void
c-function glFinishTextureSUNX glFinishTextureSUNX  -- void
c-function glGlobalAlphaFactorbSUN glGlobalAlphaFactorbSUN n -- void
c-function glGlobalAlphaFactorsSUN glGlobalAlphaFactorsSUN n -- void
c-function glGlobalAlphaFactoriSUN glGlobalAlphaFactoriSUN n -- void
c-function glGlobalAlphaFactorfSUN glGlobalAlphaFactorfSUN r -- void
c-function glGlobalAlphaFactordSUN glGlobalAlphaFactordSUN r -- void
c-function glGlobalAlphaFactorubSUN glGlobalAlphaFactorubSUN n -- void
c-function glGlobalAlphaFactorusSUN glGlobalAlphaFactorusSUN n -- void
c-function glGlobalAlphaFactoruiSUN glGlobalAlphaFactoruiSUN u -- void
c-function glDrawMeshArraysSUN glDrawMeshArraysSUN u n n n -- void
c-function glReplacementCodeuiSUN glReplacementCodeuiSUN u -- void
c-function glReplacementCodeusSUN glReplacementCodeusSUN n -- void
c-function glReplacementCodeubSUN glReplacementCodeubSUN n -- void
c-function glReplacementCodeuivSUN glReplacementCodeuivSUN a -- void
c-function glReplacementCodeusvSUN glReplacementCodeusvSUN a -- void
c-function glReplacementCodeubvSUN glReplacementCodeubvSUN a -- void
c-function glReplacementCodePointerSUN glReplacementCodePointerSUN u n a -- void
c-function glColor4ubVertex2fSUN glColor4ubVertex2fSUN n n n n r r -- void
c-function glColor4ubVertex2fvSUN glColor4ubVertex2fvSUN a a -- void
c-function glColor4ubVertex3fSUN glColor4ubVertex3fSUN n n n n r r r -- void
c-function glColor4ubVertex3fvSUN glColor4ubVertex3fvSUN a a -- void
c-function glColor3fVertex3fSUN glColor3fVertex3fSUN r r r r r r -- void
c-function glColor3fVertex3fvSUN glColor3fVertex3fvSUN a a -- void
c-function glNormal3fVertex3fSUN glNormal3fVertex3fSUN r r r r r r -- void
c-function glNormal3fVertex3fvSUN glNormal3fVertex3fvSUN a a -- void
c-function glColor4fNormal3fVertex3fSUN glColor4fNormal3fVertex3fSUN r r r r r r r r r r -- void
c-function glColor4fNormal3fVertex3fvSUN glColor4fNormal3fVertex3fvSUN a a a -- void
c-function glTexCoord2fVertex3fSUN glTexCoord2fVertex3fSUN r r r r r -- void
c-function glTexCoord2fVertex3fvSUN glTexCoord2fVertex3fvSUN a a -- void
c-function glTexCoord4fVertex4fSUN glTexCoord4fVertex4fSUN r r r r r r r r -- void
c-function glTexCoord4fVertex4fvSUN glTexCoord4fVertex4fvSUN a a -- void
c-function glTexCoord2fColor4ubVertex3fSUN glTexCoord2fColor4ubVertex3fSUN r r n n n n r r r -- void
c-function glTexCoord2fColor4ubVertex3fvSUN glTexCoord2fColor4ubVertex3fvSUN a a a -- void
c-function glTexCoord2fColor3fVertex3fSUN glTexCoord2fColor3fVertex3fSUN r r r r r r r r -- void
c-function glTexCoord2fColor3fVertex3fvSUN glTexCoord2fColor3fVertex3fvSUN a a a -- void
c-function glTexCoord2fNormal3fVertex3fSUN glTexCoord2fNormal3fVertex3fSUN r r r r r r r r -- void
c-function glTexCoord2fNormal3fVertex3fvSUN glTexCoord2fNormal3fVertex3fvSUN a a a -- void
c-function glTexCoord2fColor4fNormal3fVertex3fSUN glTexCoord2fColor4fNormal3fVertex3fSUN r r r r r r r r r r r r -- void
c-function glTexCoord2fColor4fNormal3fVertex3fvSUN glTexCoord2fColor4fNormal3fVertex3fvSUN a a a a -- void
c-function glTexCoord4fColor4fNormal3fVertex4fSUN glTexCoord4fColor4fNormal3fVertex4fSUN r r r r r r r r r r r r r r r -- void
c-function glTexCoord4fColor4fNormal3fVertex4fvSUN glTexCoord4fColor4fNormal3fVertex4fvSUN a a a a -- void
c-function glReplacementCodeuiVertex3fSUN glReplacementCodeuiVertex3fSUN u r r r -- void
c-function glReplacementCodeuiVertex3fvSUN glReplacementCodeuiVertex3fvSUN a a -- void
c-function glReplacementCodeuiColor4ubVertex3fSUN glReplacementCodeuiColor4ubVertex3fSUN u n n n n r r r -- void
c-function glReplacementCodeuiColor4ubVertex3fvSUN glReplacementCodeuiColor4ubVertex3fvSUN a a a -- void
c-function glReplacementCodeuiColor3fVertex3fSUN glReplacementCodeuiColor3fVertex3fSUN u r r r r r r -- void
c-function glReplacementCodeuiColor3fVertex3fvSUN glReplacementCodeuiColor3fVertex3fvSUN a a a -- void
c-function glReplacementCodeuiNormal3fVertex3fSUN glReplacementCodeuiNormal3fVertex3fSUN u r r r r r r -- void
c-function glReplacementCodeuiNormal3fVertex3fvSUN glReplacementCodeuiNormal3fVertex3fvSUN a a a -- void
c-function glReplacementCodeuiColor4fNormal3fVertex3fSUN glReplacementCodeuiColor4fNormal3fVertex3fSUN u r r r r r r r r r r -- void
c-function glReplacementCodeuiColor4fNormal3fVertex3fvSUN glReplacementCodeuiColor4fNormal3fVertex3fvSUN a a a a -- void
c-function glReplacementCodeuiTexCoord2fVertex3fSUN glReplacementCodeuiTexCoord2fVertex3fSUN u r r r r r -- void
c-function glReplacementCodeuiTexCoord2fVertex3fvSUN glReplacementCodeuiTexCoord2fVertex3fvSUN a a a -- void
c-function glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN u r r r r r r r r -- void
c-function glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN a a a a -- void
c-function glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN u r r r r r r r r r r r r -- void
c-function glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN a a a a a -- void
