#include <gforth/0.7.9_20150820/libcc.h>
#define GL_GLEXT_PROTOTYPES
#include <w32api/GL/gl.h>
#include <w32api/GL/glext.h>
#include <w32api/GL/wglext.h>
ptrpair libgfopengl_LTX_gforth_c_glAccum_ur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=0;
  glAccum(sp[0],fp[0]);
  x.sp = sp+1;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glAlphaFunc_ur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=0;
  glAlphaFunc(sp[0],fp[0]);
  x.sp = sp+1;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glAreTexturesResident_naa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=glAreTexturesResident(sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glArrayElement_n_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glArrayElement(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBegin_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glBegin(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindTexture_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glBindTexture(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBitmap_nnrrrra_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=3;
  glBitmap(sp[2],sp[1],fp[3],fp[2],fp[1],fp[0],(void *)(sp[0]));
  x.sp = sp+3;
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBlendFunc_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glBlendFunc(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCallList_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glCallList(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCallLists_nua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glCallLists(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClear_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glClear(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClearAccum_rrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=3;
  glClearAccum(fp[3],fp[2],fp[1],fp[0]);
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClearColor_rrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=3;
  glClearColor(fp[3],fp[2],fp[1],fp[0]);
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClearDepth_r_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=0;
  glClearDepth(fp[0]);
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClearIndex_r_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=0;
  glClearIndex(fp[0]);
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClearStencil_n_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glClearStencil(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClipPlane_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glClipPlane(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor3b_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glColor3b(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor3bv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glColor3bv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor3d_rrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=2;
  glColor3d(fp[2],fp[1],fp[0]);
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor3dv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glColor3dv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor3f_rrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=2;
  glColor3f(fp[2],fp[1],fp[0]);
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor3fv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glColor3fv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor3i_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glColor3i(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor3iv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glColor3iv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor3s_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glColor3s(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor3sv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glColor3sv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor3ub_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glColor3ub(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor3ubv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glColor3ubv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor3ui_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glColor3ui(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor3uiv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glColor3uiv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor3us_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glColor3us(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor3usv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glColor3usv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor4b_nnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glColor4b(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor4bv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glColor4bv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor4d_rrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=3;
  glColor4d(fp[3],fp[2],fp[1],fp[0]);
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor4dv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glColor4dv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor4f_rrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=3;
  glColor4f(fp[3],fp[2],fp[1],fp[0]);
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor4fv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glColor4fv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor4i_nnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glColor4i(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor4iv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glColor4iv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor4s_nnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glColor4s(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor4sv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glColor4sv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor4ub_nnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glColor4ub(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor4ubv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glColor4ubv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor4ui_uuuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glColor4ui(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor4uiv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glColor4uiv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor4us_nnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glColor4us(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColor4usv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glColor4usv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColorMask_nnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glColorMask(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColorMaterial_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glColorMaterial(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColorPointer_nuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glColorPointer(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCopyPixels_nnnnu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glCopyPixels(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCopyTexImage1D_ununnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glCopyTexImage1D(sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCopyTexImage2D_ununnnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  glCopyTexImage2D(sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+8;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCopyTexSubImage1D_unnnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glCopyTexSubImage1D(sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCopyTexSubImage2D_unnnnnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  glCopyTexSubImage2D(sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+8;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCullFace_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glCullFace(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDeleteLists_un_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDeleteLists(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDeleteTextures_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDeleteTextures(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDepthFunc_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glDepthFunc(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDepthMask_n_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glDepthMask(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDepthRange_rr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=1;
  glDepthRange(fp[1],fp[0]);
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDisable_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glDisable(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDisableClientState_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glDisableClientState(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDrawArrays_unn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glDrawArrays(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDrawBuffer_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glDrawBuffer(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDrawElements_unua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glDrawElements(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDrawPixels_nnuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glDrawPixels(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEdgeFlag_n_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glEdgeFlag(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEdgeFlagPointer_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glEdgeFlagPointer(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEdgeFlagv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glEdgeFlagv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEnable_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glEnable(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEnableClientState_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glEnableClientState(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEnd__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glEnd();
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEndList__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glEndList();
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEvalCoord1d_r_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=0;
  glEvalCoord1d(fp[0]);
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEvalCoord1dv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glEvalCoord1dv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEvalCoord1f_r_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=0;
  glEvalCoord1f(fp[0]);
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEvalCoord1fv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glEvalCoord1fv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEvalCoord2d_rr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=1;
  glEvalCoord2d(fp[1],fp[0]);
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEvalCoord2dv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glEvalCoord2dv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEvalCoord2f_rr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=1;
  glEvalCoord2f(fp[1],fp[0]);
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEvalCoord2fv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glEvalCoord2fv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEvalMesh1_unn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glEvalMesh1(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEvalMesh2_unnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glEvalMesh2(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEvalPoint1_n_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glEvalPoint1(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEvalPoint2_nn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glEvalPoint2(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFeedbackBuffer_nua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glFeedbackBuffer(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFinish__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glFinish();
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFlush__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glFlush();
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFogf_ur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=0;
  glFogf(sp[0],fp[0]);
  x.sp = sp+1;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFogfv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glFogfv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFogi_un_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glFogi(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFogiv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glFogiv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFrontFace_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glFrontFace(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFrustum_rrrrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=5;
  glFrustum(fp[5],fp[4],fp[3],fp[2],fp[1],fp[0]);
  x.fp = fp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGenLists_n_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glGenLists(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGenTextures_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGenTextures(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetBooleanv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGetBooleanv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetClipPlane_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGetClipPlane(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetDoublev_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGetDoublev(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetError__u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=glGetError();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetFloatv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGetFloatv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetIntegerv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGetIntegerv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetLightfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetLightfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetLightiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetLightiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetMapdv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetMapdv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetMapfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetMapfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetMapiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetMapiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetMaterialfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetMaterialfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetMaterialiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetMaterialiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetPixelMapfv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGetPixelMapfv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetPixelMapuiv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGetPixelMapuiv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetPixelMapusv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGetPixelMapusv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetPointerv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGetPointerv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetPolygonStipple_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glGetPolygonStipple((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetString_u_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=(Cell)glGetString(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTexEnvfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetTexEnvfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTexEnviv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetTexEnviv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTexGendv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetTexGendv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTexGenfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetTexGenfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTexGeniv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetTexGeniv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTexImage_unuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glGetTexImage(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTexLevelParameterfv_unua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetTexLevelParameterfv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTexLevelParameteriv_unua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetTexLevelParameteriv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTexParameterfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetTexParameterfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTexParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetTexParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glHint_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glHint(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIndexMask_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glIndexMask(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIndexPointer_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glIndexPointer(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIndexd_r_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=0;
  glIndexd(fp[0]);
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIndexdv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glIndexdv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIndexf_r_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=0;
  glIndexf(fp[0]);
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIndexfv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glIndexfv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIndexi_n_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glIndexi(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIndexiv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glIndexiv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIndexs_n_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glIndexs(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIndexsv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glIndexsv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIndexub_n_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glIndexub(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIndexubv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glIndexubv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glInitNames__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glInitNames();
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glInterleavedArrays_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glInterleavedArrays(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIsEnabled_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsEnabled(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIsList_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsList(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIsTexture_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsTexture(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glLightModelf_ur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=0;
  glLightModelf(sp[0],fp[0]);
  x.sp = sp+1;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glLightModelfv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glLightModelfv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glLightModeli_un_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glLightModeli(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glLightModeliv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glLightModeliv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glLightf_uur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=0;
  glLightf(sp[1],sp[0],fp[0]);
  x.sp = sp+2;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glLightfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glLightfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glLighti_uun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glLighti(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glLightiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glLightiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glLineStipple_nn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glLineStipple(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glLineWidth_r_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=0;
  glLineWidth(fp[0]);
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glListBase_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glListBase(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glLoadIdentity__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glLoadIdentity();
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glLoadMatrixd_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glLoadMatrixd((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glLoadMatrixf_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glLoadMatrixf((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glLoadName_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glLoadName(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glLogicOp_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glLogicOp(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMap1d_urrnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=1;
  glMap1d(sp[3],fp[1],fp[0],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMap1f_urrnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=1;
  glMap1f(sp[3],fp[1],fp[0],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMap2d_urrnnrrnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=3;
  glMap2d(sp[5],fp[3],fp[2],sp[4],sp[3],fp[1],fp[0],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+6;
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMap2f_urrnnrrnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=3;
  glMap2f(sp[5],fp[3],fp[2],sp[4],sp[3],fp[1],fp[0],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+6;
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMapGrid1d_nrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=1;
  glMapGrid1d(sp[0],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMapGrid1f_nrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=1;
  glMapGrid1f(sp[0],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMapGrid2d_nrrnrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=3;
  glMapGrid2d(sp[1],fp[3],fp[2],sp[0],fp[1],fp[0]);
  x.sp = sp+2;
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMapGrid2f_nrrnrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=3;
  glMapGrid2f(sp[1],fp[3],fp[2],sp[0],fp[1],fp[0]);
  x.sp = sp+2;
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMaterialf_uur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=0;
  glMaterialf(sp[1],sp[0],fp[0]);
  x.sp = sp+2;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMaterialfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glMaterialfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMateriali_uun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glMateriali(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMaterialiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glMaterialiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMatrixMode_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glMatrixMode(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultMatrixd_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glMultMatrixd((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultMatrixf_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glMultMatrixf((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNewList_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glNewList(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNormal3b_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glNormal3b(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNormal3bv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glNormal3bv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNormal3d_rrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=2;
  glNormal3d(fp[2],fp[1],fp[0]);
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNormal3dv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glNormal3dv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNormal3f_rrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=2;
  glNormal3f(fp[2],fp[1],fp[0]);
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNormal3fv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glNormal3fv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNormal3i_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glNormal3i(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNormal3iv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glNormal3iv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNormal3s_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glNormal3s(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNormal3sv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glNormal3sv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNormalPointer_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glNormalPointer(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glOrtho_rrrrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=5;
  glOrtho(fp[5],fp[4],fp[3],fp[2],fp[1],fp[0]);
  x.fp = fp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPassThrough_r_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=0;
  glPassThrough(fp[0]);
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPixelMapfv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glPixelMapfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPixelMapuiv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glPixelMapuiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPixelMapusv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glPixelMapusv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPixelStoref_ur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=0;
  glPixelStoref(sp[0],fp[0]);
  x.sp = sp+1;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPixelStorei_un_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glPixelStorei(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPixelTransferf_ur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=0;
  glPixelTransferf(sp[0],fp[0]);
  x.sp = sp+1;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPixelTransferi_un_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glPixelTransferi(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPixelZoom_rr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=1;
  glPixelZoom(fp[1],fp[0]);
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPointSize_r_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=0;
  glPointSize(fp[0]);
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPolygonMode_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glPolygonMode(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPolygonOffset_rr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=1;
  glPolygonOffset(fp[1],fp[0]);
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPolygonStipple_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glPolygonStipple((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPopAttrib__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glPopAttrib();
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPopClientAttrib__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glPopClientAttrib();
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPopMatrix__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glPopMatrix();
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPopName__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glPopName();
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPrioritizeTextures_naa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glPrioritizeTextures(sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPushAttrib_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glPushAttrib(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPushClientAttrib_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glPushClientAttrib(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPushMatrix__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glPushMatrix();
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPushName_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glPushName(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos2d_rr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=1;
  glRasterPos2d(fp[1],fp[0]);
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos2dv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glRasterPos2dv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos2f_rr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=1;
  glRasterPos2f(fp[1],fp[0]);
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos2fv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glRasterPos2fv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos2i_nn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glRasterPos2i(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos2iv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glRasterPos2iv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos2s_nn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glRasterPos2s(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos2sv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glRasterPos2sv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos3d_rrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=2;
  glRasterPos3d(fp[2],fp[1],fp[0]);
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos3dv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glRasterPos3dv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos3f_rrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=2;
  glRasterPos3f(fp[2],fp[1],fp[0]);
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos3fv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glRasterPos3fv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos3i_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glRasterPos3i(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos3iv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glRasterPos3iv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos3s_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glRasterPos3s(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos3sv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glRasterPos3sv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos4d_rrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=3;
  glRasterPos4d(fp[3],fp[2],fp[1],fp[0]);
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos4dv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glRasterPos4dv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos4f_rrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=3;
  glRasterPos4f(fp[3],fp[2],fp[1],fp[0]);
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos4fv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glRasterPos4fv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos4i_nnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glRasterPos4i(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos4iv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glRasterPos4iv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos4s_nnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glRasterPos4s(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRasterPos4sv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glRasterPos4sv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glReadBuffer_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glReadBuffer(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glReadPixels_nnnnuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glReadPixels(sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRectd_rrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=3;
  glRectd(fp[3],fp[2],fp[1],fp[0]);
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRectdv_aa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glRectdv((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRectf_rrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=3;
  glRectf(fp[3],fp[2],fp[1],fp[0]);
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRectfv_aa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glRectfv((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRecti_nnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glRecti(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRectiv_aa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glRectiv((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRects_nnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glRects(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRectsv_aa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glRectsv((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRenderMode_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glRenderMode(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRotated_rrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=3;
  glRotated(fp[3],fp[2],fp[1],fp[0]);
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRotatef_rrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=3;
  glRotatef(fp[3],fp[2],fp[1],fp[0]);
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glScaled_rrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=2;
  glScaled(fp[2],fp[1],fp[0]);
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glScalef_rrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=2;
  glScalef(fp[2],fp[1],fp[0]);
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glScissor_nnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glScissor(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSelectBuffer_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glSelectBuffer(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glShadeModel_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glShadeModel(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glStencilFunc_unu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glStencilFunc(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glStencilMask_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glStencilMask(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glStencilOp_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glStencilOp(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord1d_r_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=0;
  glTexCoord1d(fp[0]);
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord1dv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glTexCoord1dv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord1f_r_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=0;
  glTexCoord1f(fp[0]);
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord1fv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glTexCoord1fv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord1i_n_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glTexCoord1i(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord1iv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glTexCoord1iv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord1s_n_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glTexCoord1s(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord1sv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glTexCoord1sv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord2d_rr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=1;
  glTexCoord2d(fp[1],fp[0]);
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord2dv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glTexCoord2dv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord2f_rr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=1;
  glTexCoord2f(fp[1],fp[0]);
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord2fv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glTexCoord2fv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord2i_nn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glTexCoord2i(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord2iv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glTexCoord2iv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord2s_nn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glTexCoord2s(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord2sv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glTexCoord2sv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord3d_rrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=2;
  glTexCoord3d(fp[2],fp[1],fp[0]);
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord3dv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glTexCoord3dv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord3f_rrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=2;
  glTexCoord3f(fp[2],fp[1],fp[0]);
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord3fv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glTexCoord3fv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord3i_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTexCoord3i(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord3iv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glTexCoord3iv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord3s_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTexCoord3s(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord3sv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glTexCoord3sv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord4d_rrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=3;
  glTexCoord4d(fp[3],fp[2],fp[1],fp[0]);
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord4dv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glTexCoord4dv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord4f_rrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=3;
  glTexCoord4f(fp[3],fp[2],fp[1],fp[0]);
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord4fv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glTexCoord4fv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord4i_nnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glTexCoord4i(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord4iv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glTexCoord4iv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord4s_nnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glTexCoord4s(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoord4sv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glTexCoord4sv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoordPointer_nuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glTexCoordPointer(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexEnvf_uur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=0;
  glTexEnvf(sp[1],sp[0],fp[0]);
  x.sp = sp+2;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexEnvfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTexEnvfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexEnvi_uun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTexEnvi(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexEnviv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTexEnviv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexGend_uur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=0;
  glTexGend(sp[1],sp[0],fp[0]);
  x.sp = sp+2;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexGendv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTexGendv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexGenf_uur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=0;
  glTexGenf(sp[1],sp[0],fp[0]);
  x.sp = sp+2;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexGenfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTexGenfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexGeni_uun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTexGeni(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexGeniv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTexGeniv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexImage1D_unnnnuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  glTexImage1D(sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+8;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexImage2D_unnnnnuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  glTexImage2D(sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+9;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexParameterf_uur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=0;
  glTexParameterf(sp[1],sp[0],fp[0]);
  x.sp = sp+2;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexParameterfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTexParameterfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexParameteri_uun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTexParameteri(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTexParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexSubImage1D_unnnuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glTexSubImage1D(sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexSubImage2D_unnnnnuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  glTexSubImage2D(sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+9;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTranslated_rrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=2;
  glTranslated(fp[2],fp[1],fp[0]);
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTranslatef_rrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=2;
  glTranslatef(fp[2],fp[1],fp[0]);
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex2d_rr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=1;
  glVertex2d(fp[1],fp[0]);
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex2dv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glVertex2dv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex2f_rr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=1;
  glVertex2f(fp[1],fp[0]);
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex2fv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glVertex2fv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex2i_nn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertex2i(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex2iv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glVertex2iv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex2s_nn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertex2s(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex2sv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glVertex2sv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex3d_rrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=2;
  glVertex3d(fp[2],fp[1],fp[0]);
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex3dv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glVertex3dv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex3f_rrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=2;
  glVertex3f(fp[2],fp[1],fp[0]);
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex3fv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glVertex3fv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex3i_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glVertex3i(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex3iv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glVertex3iv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex3s_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glVertex3s(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex3sv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glVertex3sv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex4d_rrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=3;
  glVertex4d(fp[3],fp[2],fp[1],fp[0]);
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex4dv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glVertex4dv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex4f_rrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=3;
  glVertex4f(fp[3],fp[2],fp[1],fp[0]);
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex4fv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glVertex4fv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex4i_nnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glVertex4i(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex4iv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glVertex4iv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex4s_nnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glVertex4s(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertex4sv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glVertex4sv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexPointer_nuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glVertexPointer(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glViewport_nnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glViewport(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDrawRangeElements_uuunua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glDrawRangeElements(sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexImage3D_unnnnnnuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=9, farg0=-1;
  glTexImage3D(sp[9],sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+10;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexSubImage3D_unnnnnnnuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=10, farg0=-1;
  glTexSubImage3D(sp[10],sp[9],sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+11;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCopyTexSubImage3D_unnnnnnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  glCopyTexSubImage3D(sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+9;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glActiveTexture_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glActiveTexture(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSampleCoverage_rn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=0;
  glSampleCoverage(fp[0],sp[0]);
  x.sp = sp+1;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCompressedTexImage3D_ununnnnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  glCompressedTexImage3D(sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+9;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCompressedTexImage2D_ununnnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  glCompressedTexImage2D(sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+8;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCompressedTexImage1D_ununnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glCompressedTexImage1D(sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCompressedTexSubImage3D_unnnnnnnuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=10, farg0=-1;
  glCompressedTexSubImage3D(sp[10],sp[9],sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+11;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCompressedTexSubImage2D_unnnnnuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  glCompressedTexSubImage2D(sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+9;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCompressedTexSubImage1D_unnnuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glCompressedTexSubImage1D(sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetCompressedTexImage_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetCompressedTexImage(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClientActiveTexture_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glClientActiveTexture(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord1d_ur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=0;
  glMultiTexCoord1d(sp[0],fp[0]);
  x.sp = sp+1;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord1dv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glMultiTexCoord1dv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord1f_ur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=0;
  glMultiTexCoord1f(sp[0],fp[0]);
  x.sp = sp+1;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord1fv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glMultiTexCoord1fv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord1i_un_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glMultiTexCoord1i(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord1iv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glMultiTexCoord1iv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord1s_un_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glMultiTexCoord1s(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord1sv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glMultiTexCoord1sv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord2d_urr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=1;
  glMultiTexCoord2d(sp[0],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord2dv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glMultiTexCoord2dv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord2f_urr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=1;
  glMultiTexCoord2f(sp[0],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord2fv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glMultiTexCoord2fv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord2i_unn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glMultiTexCoord2i(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord2iv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glMultiTexCoord2iv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord2s_unn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glMultiTexCoord2s(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord2sv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glMultiTexCoord2sv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord3d_urrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=2;
  glMultiTexCoord3d(sp[0],fp[2],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord3dv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glMultiTexCoord3dv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord3f_urrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=2;
  glMultiTexCoord3f(sp[0],fp[2],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord3fv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glMultiTexCoord3fv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord3i_unnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glMultiTexCoord3i(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord3iv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glMultiTexCoord3iv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord3s_unnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glMultiTexCoord3s(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord3sv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glMultiTexCoord3sv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord4d_urrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=3;
  glMultiTexCoord4d(sp[0],fp[3],fp[2],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord4dv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glMultiTexCoord4dv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord4f_urrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=3;
  glMultiTexCoord4f(sp[0],fp[3],fp[2],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord4fv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glMultiTexCoord4fv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord4i_unnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glMultiTexCoord4i(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord4iv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glMultiTexCoord4iv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord4s_unnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glMultiTexCoord4s(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoord4sv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glMultiTexCoord4sv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glLoadTransposeMatrixf_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glLoadTransposeMatrixf((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glLoadTransposeMatrixd_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glLoadTransposeMatrixd((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultTransposeMatrixf_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glMultTransposeMatrixf((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultTransposeMatrixd_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glMultTransposeMatrixd((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBlendFuncSeparate_uuuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glBlendFuncSeparate(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiDrawArrays_uaan_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glMultiDrawArrays(sp[3],(void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiDrawElements_uauan_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glMultiDrawElements(sp[4],(void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPointParameterf_ur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=0;
  glPointParameterf(sp[0],fp[0]);
  x.sp = sp+1;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPointParameterfv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glPointParameterfv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPointParameteri_un_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glPointParameteri(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPointParameteriv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glPointParameteriv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFogCoordf_r_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=0;
  glFogCoordf(fp[0]);
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFogCoordfv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glFogCoordfv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFogCoordd_r_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=0;
  glFogCoordd(fp[0]);
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFogCoorddv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glFogCoorddv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFogCoordPointer_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glFogCoordPointer(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSecondaryColor3b_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glSecondaryColor3b(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSecondaryColor3bv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glSecondaryColor3bv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSecondaryColor3d_rrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=2;
  glSecondaryColor3d(fp[2],fp[1],fp[0]);
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSecondaryColor3dv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glSecondaryColor3dv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSecondaryColor3f_rrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=2;
  glSecondaryColor3f(fp[2],fp[1],fp[0]);
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSecondaryColor3fv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glSecondaryColor3fv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSecondaryColor3i_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glSecondaryColor3i(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSecondaryColor3iv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glSecondaryColor3iv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSecondaryColor3s_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glSecondaryColor3s(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSecondaryColor3sv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glSecondaryColor3sv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSecondaryColor3ub_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glSecondaryColor3ub(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSecondaryColor3ubv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glSecondaryColor3ubv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSecondaryColor3ui_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glSecondaryColor3ui(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSecondaryColor3uiv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glSecondaryColor3uiv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSecondaryColor3us_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glSecondaryColor3us(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSecondaryColor3usv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glSecondaryColor3usv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSecondaryColorPointer_nuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glSecondaryColorPointer(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glWindowPos2d_rr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=1;
  glWindowPos2d(fp[1],fp[0]);
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glWindowPos2dv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glWindowPos2dv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glWindowPos2f_rr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=1;
  glWindowPos2f(fp[1],fp[0]);
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glWindowPos2fv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glWindowPos2fv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glWindowPos2i_nn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glWindowPos2i(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glWindowPos2iv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glWindowPos2iv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glWindowPos2s_nn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glWindowPos2s(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glWindowPos2sv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glWindowPos2sv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glWindowPos3d_rrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=2;
  glWindowPos3d(fp[2],fp[1],fp[0]);
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glWindowPos3dv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glWindowPos3dv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glWindowPos3f_rrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=2;
  glWindowPos3f(fp[2],fp[1],fp[0]);
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glWindowPos3fv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glWindowPos3fv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glWindowPos3i_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glWindowPos3i(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glWindowPos3iv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glWindowPos3iv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glWindowPos3s_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glWindowPos3s(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glWindowPos3sv_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glWindowPos3sv((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBlendColor_rrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=3;
  glBlendColor(fp[3],fp[2],fp[1],fp[0]);
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBlendEquation_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glBlendEquation(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGenQueries_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGenQueries(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDeleteQueries_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDeleteQueries(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIsQuery_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsQuery(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBeginQuery_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glBeginQuery(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEndQuery_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glEndQuery(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetQueryiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetQueryiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetQueryObjectiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetQueryObjectiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetQueryObjectuiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetQueryObjectuiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindBuffer_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glBindBuffer(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDeleteBuffers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDeleteBuffers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGenBuffers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGenBuffers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIsBuffer_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsBuffer(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBufferData_unau_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glBufferData(sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBufferSubData_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glBufferSubData(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetBufferSubData_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetBufferSubData(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMapBuffer_uu_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)glMapBuffer(sp[1],sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUnmapBuffer_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glUnmapBuffer(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetBufferParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetBufferParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetBufferPointerv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetBufferPointerv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBlendEquationSeparate_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glBlendEquationSeparate(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDrawBuffers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDrawBuffers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glStencilOpSeparate_uuuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glStencilOpSeparate(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glStencilFuncSeparate_uunu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glStencilFuncSeparate(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glStencilMaskSeparate_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glStencilMaskSeparate(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glAttachShader_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glAttachShader(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindAttribLocation_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glBindAttribLocation(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCompileShader_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glCompileShader(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCreateProgram__u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=glCreateProgram();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCreateShader_u_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glCreateShader(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDeleteProgram_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glDeleteProgram(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDeleteShader_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glDeleteShader(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDetachShader_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDetachShader(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDisableVertexAttribArray_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glDisableVertexAttribArray(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEnableVertexAttribArray_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glEnableVertexAttribArray(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetActiveAttrib_uunaaaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glGetActiveAttrib(sp[6],sp[5],sp[4],(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetActiveUniform_uunaaaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glGetActiveUniform(sp[6],sp[5],sp[4],(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetAttachedShaders_unaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetAttachedShaders(sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetAttribLocation_ua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=glGetAttribLocation(sp[1],(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetProgramiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetProgramiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetProgramInfoLog_unaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetProgramInfoLog(sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetShaderiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetShaderiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetShaderInfoLog_unaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetShaderInfoLog(sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetShaderSource_unaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetShaderSource(sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetUniformLocation_ua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=glGetUniformLocation(sp[1],(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetUniformfv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetUniformfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetUniformiv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetUniformiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetVertexAttribdv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetVertexAttribdv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetVertexAttribfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetVertexAttribfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetVertexAttribiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetVertexAttribiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetVertexAttribPointerv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetVertexAttribPointerv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIsProgram_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsProgram(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIsShader_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsShader(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glLinkProgram_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glLinkProgram(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glShaderSource_unaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glShaderSource(sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUseProgram_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glUseProgram(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform1f_nr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=0;
  glUniform1f(sp[0],fp[0]);
  x.sp = sp+1;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform2f_nrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=1;
  glUniform2f(sp[0],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform3f_nrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=2;
  glUniform3f(sp[0],fp[2],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform4f_nrrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=3;
  glUniform4f(sp[0],fp[3],fp[2],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform1i_nn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glUniform1i(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform2i_nnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform2i(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform3i_nnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniform3i(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform4i_nnnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glUniform4i(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform1fv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform1fv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform2fv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform2fv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform3fv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform3fv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform4fv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform4fv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform1iv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform1iv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform2iv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform2iv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform3iv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform3iv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform4iv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform4iv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniformMatrix2fv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix2fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniformMatrix3fv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix3fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniformMatrix4fv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix4fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glValidateProgram_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glValidateProgram(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib1d_ur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=0;
  glVertexAttrib1d(sp[0],fp[0]);
  x.sp = sp+1;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib1dv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib1dv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib1f_ur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=0;
  glVertexAttrib1f(sp[0],fp[0]);
  x.sp = sp+1;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib1fv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib1fv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib1s_un_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib1s(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib1sv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib1sv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib2d_urr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=1;
  glVertexAttrib2d(sp[0],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib2dv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib2dv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib2f_urr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=1;
  glVertexAttrib2f(sp[0],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib2fv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib2fv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib2s_unn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glVertexAttrib2s(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib2sv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib2sv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib3d_urrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=2;
  glVertexAttrib3d(sp[0],fp[2],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib3dv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib3dv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib3f_urrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=2;
  glVertexAttrib3f(sp[0],fp[2],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib3fv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib3fv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib3s_unnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glVertexAttrib3s(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib3sv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib3sv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib4Nbv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib4Nbv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib4Niv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib4Niv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib4Nsv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib4Nsv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib4Nub_unnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glVertexAttrib4Nub(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib4Nubv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib4Nubv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib4Nuiv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib4Nuiv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib4Nusv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib4Nusv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib4bv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib4bv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib4d_urrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=3;
  glVertexAttrib4d(sp[0],fp[3],fp[2],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib4dv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib4dv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib4f_urrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=3;
  glVertexAttrib4f(sp[0],fp[3],fp[2],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib4fv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib4fv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib4iv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib4iv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib4s_unnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glVertexAttrib4s(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib4sv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib4sv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib4ubv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib4ubv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib4uiv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib4uiv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttrib4usv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttrib4usv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribPointer_ununna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glVertexAttribPointer(sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniformMatrix2x3fv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix2x3fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniformMatrix3x2fv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix3x2fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniformMatrix2x4fv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix2x4fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniformMatrix4x2fv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix4x2fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniformMatrix3x4fv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix3x4fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniformMatrix4x3fv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix4x3fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColorMaski_unnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glColorMaski(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetBooleani_v_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetBooleani_v(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetIntegeri_v_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetIntegeri_v(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEnablei_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glEnablei(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDisablei_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDisablei(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIsEnabledi_uu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=glIsEnabledi(sp[1],sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBeginTransformFeedback_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glBeginTransformFeedback(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEndTransformFeedback__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glEndTransformFeedback();
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindBufferRange_uuunn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glBindBufferRange(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindBufferBase_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glBindBufferBase(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTransformFeedbackVaryings_unau_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glTransformFeedbackVaryings(sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTransformFeedbackVarying_uunaaaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glGetTransformFeedbackVarying(sp[6],sp[5],sp[4],(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClampColor_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glClampColor(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBeginConditionalRender_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glBeginConditionalRender(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEndConditionalRender__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glEndConditionalRender();
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribIPointer_ununa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glVertexAttribIPointer(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetVertexAttribIiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetVertexAttribIiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetVertexAttribIuiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetVertexAttribIuiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribI1i_un_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribI1i(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribI2i_unn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glVertexAttribI2i(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribI3i_unnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glVertexAttribI3i(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribI4i_unnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glVertexAttribI4i(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribI1ui_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribI1ui(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribI2ui_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glVertexAttribI2ui(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribI3ui_uuuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glVertexAttribI3ui(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribI4ui_uuuuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glVertexAttribI4ui(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribI1iv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribI1iv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribI2iv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribI2iv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribI3iv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribI3iv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribI4iv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribI4iv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribI1uiv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribI1uiv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribI2uiv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribI2uiv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribI3uiv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribI3uiv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribI4uiv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribI4uiv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribI4bv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribI4bv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribI4sv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribI4sv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribI4ubv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribI4ubv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribI4usv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribI4usv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetUniformuiv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetUniformuiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindFragDataLocation_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glBindFragDataLocation(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetFragDataLocation_ua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=glGetFragDataLocation(sp[1],(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform1ui_nu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glUniform1ui(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform2ui_nuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform2ui(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform3ui_nuuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniform3ui(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform4ui_nuuuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glUniform4ui(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform1uiv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform1uiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform2uiv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform2uiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform3uiv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform3uiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform4uiv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform4uiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexParameterIiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTexParameterIiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexParameterIuiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTexParameterIuiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTexParameterIiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetTexParameterIiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTexParameterIuiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetTexParameterIuiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClearBufferiv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glClearBufferiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClearBufferuiv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glClearBufferuiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClearBufferfv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glClearBufferfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClearBufferfi_unrn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=0;
  glClearBufferfi(sp[2],sp[1],fp[0],sp[0]);
  x.sp = sp+3;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetStringi_uu_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)glGetStringi(sp[1],sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIsRenderbuffer_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsRenderbuffer(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindRenderbuffer_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glBindRenderbuffer(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDeleteRenderbuffers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDeleteRenderbuffers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGenRenderbuffers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGenRenderbuffers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRenderbufferStorage_uunn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glRenderbufferStorage(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetRenderbufferParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetRenderbufferParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIsFramebuffer_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsFramebuffer(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindFramebuffer_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glBindFramebuffer(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDeleteFramebuffers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDeleteFramebuffers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGenFramebuffers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGenFramebuffers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCheckFramebufferStatus_u_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glCheckFramebufferStatus(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFramebufferTexture1D_uuuun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glFramebufferTexture1D(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFramebufferTexture2D_uuuun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glFramebufferTexture2D(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFramebufferTexture3D_uuuunn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glFramebufferTexture3D(sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFramebufferRenderbuffer_uuuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glFramebufferRenderbuffer(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetFramebufferAttachmentParameteriv_uuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetFramebufferAttachmentParameteriv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGenerateMipmap_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glGenerateMipmap(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBlitFramebuffer_nnnnnnnnuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=9, farg0=-1;
  glBlitFramebuffer(sp[9],sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+10;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glRenderbufferStorageMultisample_ununn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glRenderbufferStorageMultisample(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFramebufferTextureLayer_uuunn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glFramebufferTextureLayer(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMapBufferRange_unnu_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)glMapBufferRange(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFlushMappedBufferRange_unn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glFlushMappedBufferRange(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindVertexArray_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glBindVertexArray(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDeleteVertexArrays_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDeleteVertexArrays(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGenVertexArrays_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGenVertexArrays(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIsVertexArray_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsVertexArray(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDrawArraysInstanced_unnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glDrawArraysInstanced(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDrawElementsInstanced_unuan_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glDrawElementsInstanced(sp[4],sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexBuffer_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTexBuffer(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPrimitiveRestartIndex_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glPrimitiveRestartIndex(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCopyBufferSubData_uunnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glCopyBufferSubData(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetUniformIndices_unaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetUniformIndices(sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetActiveUniformsiv_unaua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glGetActiveUniformsiv(sp[4],sp[3],(void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetActiveUniformName_uunaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glGetActiveUniformName(sp[4],sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetUniformBlockIndex_ua_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=glGetUniformBlockIndex(sp[1],(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetActiveUniformBlockiv_uuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetActiveUniformBlockiv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetActiveUniformBlockName_uunaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glGetActiveUniformBlockName(sp[4],sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniformBlockBinding_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniformBlockBinding(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDrawElementsBaseVertex_unuan_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glDrawElementsBaseVertex(sp[4],sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDrawRangeElementsBaseVertex_uuunuan_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glDrawRangeElementsBaseVertex(sp[6],sp[5],sp[4],sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDrawElementsInstancedBaseVertex_unuann_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glDrawElementsInstancedBaseVertex(sp[5],sp[4],sp[3],(void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiDrawElementsBaseVertex_uauana_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glMultiDrawElementsBaseVertex(sp[5],(void *)(sp[4]),sp[3],(void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProvokingVertex_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glProvokingVertex(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFenceSync_uu_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)glFenceSync(sp[1],sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIsSync_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsSync((void *)(sp[0]));
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDeleteSync_a_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glDeleteSync((void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClientWaitSync_aud_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=glClientWaitSync((void *)(sp[3]),sp[2],gforth_d2ll(sp[1],sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glWaitSync_aud_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glWaitSync((void *)(sp[3]),sp[2],gforth_d2ll(sp[1],sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetInteger64v_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGetInteger64v(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetSynciv_aunaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glGetSynciv((void *)(sp[4]),sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetInteger64i_v_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetInteger64i_v(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetBufferParameteri64v_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetBufferParameteri64v(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFramebufferTexture_uuun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glFramebufferTexture(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexImage2DMultisample_ununnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glTexImage2DMultisample(sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexImage3DMultisample_ununnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glTexImage3DMultisample(sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetMultisamplefv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetMultisamplefv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSampleMaski_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glSampleMaski(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindFragDataLocationIndexed_uuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glBindFragDataLocationIndexed(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetFragDataIndex_ua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=glGetFragDataIndex(sp[1],(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGenSamplers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGenSamplers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDeleteSamplers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDeleteSamplers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIsSampler_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsSampler(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindSampler_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glBindSampler(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSamplerParameteri_uun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glSamplerParameteri(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSamplerParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glSamplerParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSamplerParameterf_uur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=0;
  glSamplerParameterf(sp[1],sp[0],fp[0]);
  x.sp = sp+2;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSamplerParameterfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glSamplerParameterfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSamplerParameterIiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glSamplerParameterIiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSamplerParameterIuiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glSamplerParameterIuiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetSamplerParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetSamplerParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetSamplerParameterIiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetSamplerParameterIiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetSamplerParameterfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetSamplerParameterfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetSamplerParameterIuiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetSamplerParameterIuiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glQueryCounter_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glQueryCounter(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetQueryObjecti64v_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetQueryObjecti64v(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetQueryObjectui64v_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetQueryObjectui64v(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribDivisor_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribDivisor(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribP1ui_uunu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glVertexAttribP1ui(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribP1uiv_uuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glVertexAttribP1uiv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribP2ui_uunu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glVertexAttribP2ui(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribP2uiv_uuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glVertexAttribP2uiv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribP3ui_uunu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glVertexAttribP3ui(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribP3uiv_uuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glVertexAttribP3uiv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribP4ui_uunu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glVertexAttribP4ui(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribP4uiv_uuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glVertexAttribP4uiv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexP2ui_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexP2ui(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexP2uiv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexP2uiv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexP3ui_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexP3ui(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexP3uiv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexP3uiv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexP4ui_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexP4ui(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexP4uiv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexP4uiv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoordP1ui_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glTexCoordP1ui(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoordP1uiv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glTexCoordP1uiv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoordP2ui_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glTexCoordP2ui(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoordP2uiv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glTexCoordP2uiv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoordP3ui_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glTexCoordP3ui(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoordP3uiv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glTexCoordP3uiv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoordP4ui_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glTexCoordP4ui(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexCoordP4uiv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glTexCoordP4uiv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoordP1ui_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glMultiTexCoordP1ui(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoordP1uiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glMultiTexCoordP1uiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoordP2ui_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glMultiTexCoordP2ui(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoordP2uiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glMultiTexCoordP2uiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoordP3ui_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glMultiTexCoordP3ui(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoordP3uiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glMultiTexCoordP3uiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoordP4ui_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glMultiTexCoordP4ui(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiTexCoordP4uiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glMultiTexCoordP4uiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNormalP3ui_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glNormalP3ui(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNormalP3uiv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glNormalP3uiv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColorP3ui_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glColorP3ui(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColorP3uiv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glColorP3uiv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColorP4ui_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glColorP4ui(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColorP4uiv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glColorP4uiv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSecondaryColorP3ui_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glSecondaryColorP3ui(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSecondaryColorP3uiv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glSecondaryColorP3uiv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMinSampleShading_r_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=0;
  glMinSampleShading(fp[0]);
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBlendEquationi_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glBlendEquationi(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBlendEquationSeparatei_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glBlendEquationSeparatei(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBlendFunci_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glBlendFunci(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBlendFuncSeparatei_uuuuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glBlendFuncSeparatei(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDrawArraysIndirect_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDrawArraysIndirect(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDrawElementsIndirect_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glDrawElementsIndirect(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform1d_nr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=0;
  glUniform1d(sp[0],fp[0]);
  x.sp = sp+1;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform2d_nrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=1;
  glUniform2d(sp[0],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform3d_nrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=2;
  glUniform3d(sp[0],fp[2],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform4d_nrrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=3;
  glUniform4d(sp[0],fp[3],fp[2],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform1dv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform1dv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform2dv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform2dv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform3dv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform3dv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniform4dv_nna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniform4dv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniformMatrix2dv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix2dv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniformMatrix3dv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix3dv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniformMatrix4dv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix4dv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniformMatrix2x3dv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix2x3dv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniformMatrix2x4dv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix2x4dv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniformMatrix3x2dv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix3x2dv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniformMatrix3x4dv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix3x4dv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniformMatrix4x2dv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix4x2dv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniformMatrix4x3dv_nnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glUniformMatrix4x3dv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetUniformdv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetUniformdv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetSubroutineUniformLocation_uua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=glGetSubroutineUniformLocation(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetSubroutineIndex_uua_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=glGetSubroutineIndex(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetActiveSubroutineUniformiv_uuuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glGetActiveSubroutineUniformiv(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetActiveSubroutineUniformName_uuunaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glGetActiveSubroutineUniformName(sp[5],sp[4],sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetActiveSubroutineName_uuunaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glGetActiveSubroutineName(sp[5],sp[4],sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUniformSubroutinesuiv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUniformSubroutinesuiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetUniformSubroutineuiv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetUniformSubroutineuiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetProgramStageiv_uuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetProgramStageiv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPatchParameteri_un_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glPatchParameteri(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPatchParameterfv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glPatchParameterfv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindTransformFeedback_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glBindTransformFeedback(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDeleteTransformFeedbacks_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDeleteTransformFeedbacks(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGenTransformFeedbacks_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGenTransformFeedbacks(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIsTransformFeedback_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsTransformFeedback(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPauseTransformFeedback__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glPauseTransformFeedback();
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glResumeTransformFeedback__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glResumeTransformFeedback();
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDrawTransformFeedback_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDrawTransformFeedback(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDrawTransformFeedbackStream_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glDrawTransformFeedbackStream(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBeginQueryIndexed_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glBeginQueryIndexed(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEndQueryIndexed_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glEndQueryIndexed(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetQueryIndexediv_uuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetQueryIndexediv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glReleaseShaderCompiler__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glReleaseShaderCompiler();
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glShaderBinary_nauan_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glShaderBinary(sp[4],(void *)(sp[3]),sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetShaderPrecisionFormat_uuaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetShaderPrecisionFormat(sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDepthRangef_rr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=1;
  glDepthRangef(fp[1],fp[0]);
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClearDepthf_r_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=0;
  glClearDepthf(fp[0]);
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetProgramBinary_unaaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glGetProgramBinary(sp[4],sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramBinary_uuan_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glProgramBinary(sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramParameteri_uun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glProgramParameteri(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUseProgramStages_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glUseProgramStages(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glActiveShaderProgram_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glActiveShaderProgram(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCreateShaderProgramv_una_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=glCreateShaderProgramv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindProgramPipeline_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glBindProgramPipeline(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDeleteProgramPipelines_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDeleteProgramPipelines(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGenProgramPipelines_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGenProgramPipelines(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glIsProgramPipeline_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glIsProgramPipeline(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetProgramPipelineiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetProgramPipelineiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform1i_unn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glProgramUniform1i(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform1iv_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glProgramUniform1iv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform1f_unr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=0;
  glProgramUniform1f(sp[1],sp[0],fp[0]);
  x.sp = sp+2;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform1fv_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glProgramUniform1fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform1d_unr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=0;
  glProgramUniform1d(sp[1],sp[0],fp[0]);
  x.sp = sp+2;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform1dv_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glProgramUniform1dv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform1ui_unu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glProgramUniform1ui(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform1uiv_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glProgramUniform1uiv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform2i_unnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glProgramUniform2i(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform2iv_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glProgramUniform2iv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform2f_unrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=1;
  glProgramUniform2f(sp[1],sp[0],fp[1],fp[0]);
  x.sp = sp+2;
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform2fv_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glProgramUniform2fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform2d_unrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=1;
  glProgramUniform2d(sp[1],sp[0],fp[1],fp[0]);
  x.sp = sp+2;
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform2dv_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glProgramUniform2dv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform2ui_unuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glProgramUniform2ui(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform2uiv_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glProgramUniform2uiv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform3i_unnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glProgramUniform3i(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform3iv_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glProgramUniform3iv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform3f_unrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=2;
  glProgramUniform3f(sp[1],sp[0],fp[2],fp[1],fp[0]);
  x.sp = sp+2;
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform3fv_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glProgramUniform3fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform3d_unrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=2;
  glProgramUniform3d(sp[1],sp[0],fp[2],fp[1],fp[0]);
  x.sp = sp+2;
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform3dv_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glProgramUniform3dv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform3ui_unuuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glProgramUniform3ui(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform3uiv_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glProgramUniform3uiv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform4i_unnnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glProgramUniform4i(sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform4iv_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glProgramUniform4iv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform4f_unrrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=3;
  glProgramUniform4f(sp[1],sp[0],fp[3],fp[2],fp[1],fp[0]);
  x.sp = sp+2;
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform4fv_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glProgramUniform4fv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform4d_unrrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=3;
  glProgramUniform4d(sp[1],sp[0],fp[3],fp[2],fp[1],fp[0]);
  x.sp = sp+2;
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform4dv_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glProgramUniform4dv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform4ui_unuuuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glProgramUniform4ui(sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniform4uiv_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glProgramUniform4uiv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniformMatrix2fv_unnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glProgramUniformMatrix2fv(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniformMatrix3fv_unnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glProgramUniformMatrix3fv(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniformMatrix4fv_unnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glProgramUniformMatrix4fv(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniformMatrix2dv_unnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glProgramUniformMatrix2dv(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniformMatrix3dv_unnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glProgramUniformMatrix3dv(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniformMatrix4dv_unnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glProgramUniformMatrix4dv(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniformMatrix2x3fv_unnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glProgramUniformMatrix2x3fv(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniformMatrix3x2fv_unnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glProgramUniformMatrix3x2fv(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniformMatrix2x4fv_unnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glProgramUniformMatrix2x4fv(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniformMatrix4x2fv_unnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glProgramUniformMatrix4x2fv(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniformMatrix3x4fv_unnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glProgramUniformMatrix3x4fv(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniformMatrix4x3fv_unnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glProgramUniformMatrix4x3fv(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniformMatrix2x3dv_unnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glProgramUniformMatrix2x3dv(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniformMatrix3x2dv_unnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glProgramUniformMatrix3x2dv(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniformMatrix2x4dv_unnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glProgramUniformMatrix2x4dv(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniformMatrix4x2dv_unnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glProgramUniformMatrix4x2dv(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniformMatrix3x4dv_unnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glProgramUniformMatrix3x4dv(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glProgramUniformMatrix4x3dv_unnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glProgramUniformMatrix4x3dv(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glValidateProgramPipeline_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glValidateProgramPipeline(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetProgramPipelineInfoLog_unaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetProgramPipelineInfoLog(sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribL1d_ur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=0;
  glVertexAttribL1d(sp[0],fp[0]);
  x.sp = sp+1;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribL2d_urr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=1;
  glVertexAttribL2d(sp[0],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribL3d_urrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=2;
  glVertexAttribL3d(sp[0],fp[2],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribL4d_urrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=3;
  glVertexAttribL4d(sp[0],fp[3],fp[2],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribL1dv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribL1dv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribL2dv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribL2dv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribL3dv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribL3dv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribL4dv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribL4dv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribLPointer_ununa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glVertexAttribLPointer(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetVertexAttribLdv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetVertexAttribLdv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glViewportArrayv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glViewportArrayv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glViewportIndexedf_urrrr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=3;
  glViewportIndexedf(sp[0],fp[3],fp[2],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glViewportIndexedfv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glViewportIndexedfv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glScissorArrayv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glScissorArrayv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glScissorIndexed_unnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glScissorIndexed(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glScissorIndexedv_ua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glScissorIndexedv(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDepthRangeArrayv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glDepthRangeArrayv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDepthRangeIndexed_urr_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=1;
  glDepthRangeIndexed(sp[0],fp[1],fp[0]);
  x.sp = sp+1;
  x.fp = fp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetFloati_v_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetFloati_v(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetDoublei_v_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetDoublei_v(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDrawArraysInstancedBaseInstance_unnnu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glDrawArraysInstancedBaseInstance(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDrawElementsInstancedBaseInstance_unuanu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glDrawElementsInstancedBaseInstance(sp[5],sp[4],sp[3],(void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDrawElementsInstancedBaseVertexBaseInstance_unuannu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glDrawElementsInstancedBaseVertexBaseInstance(sp[6],sp[5],sp[4],(void *)(sp[3]),sp[2],sp[1],sp[0]);
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetInternalformativ_uuuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glGetInternalformativ(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetActiveAtomicCounterBufferiv_uuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetActiveAtomicCounterBufferiv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindImageTexture_uunnnuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glBindImageTexture(sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMemoryBarrier_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glMemoryBarrier(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexStorage1D_unun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glTexStorage1D(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexStorage2D_ununn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glTexStorage2D(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexStorage3D_ununnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glTexStorage3D(sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDrawTransformFeedbackInstanced_uun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glDrawTransformFeedbackInstanced(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDrawTransformFeedbackStreamInstanced_uuun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glDrawTransformFeedbackStreamInstanced(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClearBufferData_uuuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glClearBufferData(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClearBufferSubData_uunnuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glClearBufferSubData(sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDispatchCompute_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glDispatchCompute(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDispatchComputeIndirect_n_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glDispatchComputeIndirect(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCopyImageSubData_uunnnnuunnnnnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=14, farg0=-1;
  glCopyImageSubData(sp[14],sp[13],sp[12],sp[11],sp[10],sp[9],sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+15;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFramebufferParameteri_uun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glFramebufferParameteri(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetFramebufferParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetFramebufferParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetInternalformati64v_uuuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glGetInternalformati64v(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glInvalidateTexSubImage_unnnnnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  glInvalidateTexSubImage(sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+8;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glInvalidateTexImage_un_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glInvalidateTexImage(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glInvalidateBufferSubData_unn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glInvalidateBufferSubData(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glInvalidateBufferData_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glInvalidateBufferData(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glInvalidateFramebuffer_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glInvalidateFramebuffer(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glInvalidateSubFramebuffer_unannnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glInvalidateSubFramebuffer(sp[6],sp[5],(void *)(sp[4]),sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiDrawArraysIndirect_uann_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glMultiDrawArraysIndirect(sp[3],(void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMultiDrawElementsIndirect_uuann_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glMultiDrawElementsIndirect(sp[4],sp[3],(void *)(sp[2]),sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetProgramInterfaceiv_uuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetProgramInterfaceiv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetProgramResourceIndex_uua_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=glGetProgramResourceIndex(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetProgramResourceName_uuunaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glGetProgramResourceName(sp[5],sp[4],sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetProgramResourceiv_uuunanaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  glGetProgramResourceiv(sp[7],sp[6],sp[5],sp[4],(void *)(sp[3]),sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+8;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetProgramResourceLocation_uua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=glGetProgramResourceLocation(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetProgramResourceLocationIndex_uua_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=glGetProgramResourceLocationIndex(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glShaderStorageBlockBinding_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glShaderStorageBlockBinding(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexBufferRange_uuunn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glTexBufferRange(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexStorage2DMultisample_ununnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glTexStorage2DMultisample(sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTexStorage3DMultisample_ununnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glTexStorage3DMultisample(sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTextureView_uuuuuuuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  glTextureView(sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+8;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindVertexBuffer_uunn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glBindVertexBuffer(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribFormat_ununu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glVertexAttribFormat(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribIFormat_unuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glVertexAttribIFormat(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribLFormat_unuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glVertexAttribLFormat(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexAttribBinding_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexAttribBinding(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexBindingDivisor_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexBindingDivisor(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDebugMessageControl_uuunan_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glDebugMessageControl(sp[5],sp[4],sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDebugMessageInsert_uuuuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glDebugMessageInsert(sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDebugMessageCallback_aa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDebugMessageCallback((void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetDebugMessageLog_unaaaaaa_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  sp[7]=glGetDebugMessageLog(sp[7],sp[6],(void *)(sp[5]),(void *)(sp[4]),(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPushDebugGroup_uuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glPushDebugGroup(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPopDebugGroup__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glPopDebugGroup();
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glObjectLabel_uuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glObjectLabel(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetObjectLabel_uunaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glGetObjectLabel(sp[4],sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glObjectPtrLabel_ana_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glObjectPtrLabel((void *)(sp[2]),sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetObjectPtrLabel_anaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetObjectPtrLabel((void *)(sp[3]),sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBufferStorage_unau_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glBufferStorage(sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClearTexImage_unuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glClearTexImage(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClearTexSubImage_unnnnnnnuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=10, farg0=-1;
  glClearTexSubImage(sp[10],sp[9],sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+11;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindBuffersBase_uuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glBindBuffersBase(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindBuffersRange_uunaaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glBindBuffersRange(sp[5],sp[4],sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindTextures_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glBindTextures(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindSamplers_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glBindSamplers(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindImageTextures_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glBindImageTextures(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindVertexBuffers_unaaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glBindVertexBuffers(sp[4],sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClipControl_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glClipControl(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCreateTransformFeedbacks_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glCreateTransformFeedbacks(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTransformFeedbackBufferBase_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTransformFeedbackBufferBase(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTransformFeedbackBufferRange_uuunn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glTransformFeedbackBufferRange(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTransformFeedbackiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetTransformFeedbackiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTransformFeedbacki_v_uuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetTransformFeedbacki_v(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTransformFeedbacki64_v_uuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetTransformFeedbacki64_v(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCreateBuffers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glCreateBuffers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNamedBufferStorage_unau_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glNamedBufferStorage(sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNamedBufferData_unau_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glNamedBufferData(sp[3],sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNamedBufferSubData_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glNamedBufferSubData(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCopyNamedBufferSubData_uunnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glCopyNamedBufferSubData(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClearNamedBufferData_uuuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glClearNamedBufferData(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClearNamedBufferSubData_uunnuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glClearNamedBufferSubData(sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMapNamedBuffer_uu_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=(Cell)glMapNamedBuffer(sp[1],sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMapNamedBufferRange_unnu_a(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=(Cell)glMapNamedBufferRange(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glUnmapNamedBuffer_u_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=glUnmapNamedBuffer(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glFlushMappedNamedBufferRange_unn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glFlushMappedNamedBufferRange(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetNamedBufferParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetNamedBufferParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetNamedBufferParameteri64v_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetNamedBufferParameteri64v(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetNamedBufferPointerv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetNamedBufferPointerv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetNamedBufferSubData_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetNamedBufferSubData(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCreateFramebuffers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glCreateFramebuffers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNamedFramebufferRenderbuffer_uuuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glNamedFramebufferRenderbuffer(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNamedFramebufferParameteri_uun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glNamedFramebufferParameteri(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNamedFramebufferTexture_uuun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glNamedFramebufferTexture(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNamedFramebufferTextureLayer_uuunn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glNamedFramebufferTextureLayer(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNamedFramebufferDrawBuffer_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glNamedFramebufferDrawBuffer(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNamedFramebufferDrawBuffers_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glNamedFramebufferDrawBuffers(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNamedFramebufferReadBuffer_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glNamedFramebufferReadBuffer(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glInvalidateNamedFramebufferData_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glInvalidateNamedFramebufferData(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glInvalidateNamedFramebufferSubData_unannnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glInvalidateNamedFramebufferSubData(sp[6],sp[5],(void *)(sp[4]),sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClearNamedFramebufferiv_uuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glClearNamedFramebufferiv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClearNamedFramebufferuiv_uuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glClearNamedFramebufferuiv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClearNamedFramebufferfv_uuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glClearNamedFramebufferfv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glClearNamedFramebufferfi_uurn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=0;
  glClearNamedFramebufferfi(sp[2],sp[1],fp[0],sp[0]);
  x.sp = sp+3;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBlitNamedFramebuffer_uunnnnnnnnuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=11, farg0=-1;
  glBlitNamedFramebuffer(sp[11],sp[10],sp[9],sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+12;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCheckNamedFramebufferStatus_uu_u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=glCheckNamedFramebufferStatus(sp[1],sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetNamedFramebufferParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetNamedFramebufferParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetNamedFramebufferAttachmentParameteriv_uuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetNamedFramebufferAttachmentParameteriv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCreateRenderbuffers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glCreateRenderbuffers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNamedRenderbufferStorage_uunn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glNamedRenderbufferStorage(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glNamedRenderbufferStorageMultisample_ununn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glNamedRenderbufferStorageMultisample(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetNamedRenderbufferParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetNamedRenderbufferParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCreateTextures_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glCreateTextures(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTextureBuffer_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTextureBuffer(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTextureBufferRange_uuunn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glTextureBufferRange(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTextureStorage1D_unun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glTextureStorage1D(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTextureStorage2D_ununn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glTextureStorage2D(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTextureStorage3D_ununnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glTextureStorage3D(sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTextureStorage2DMultisample_ununnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glTextureStorage2DMultisample(sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTextureStorage3DMultisample_ununnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glTextureStorage3DMultisample(sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTextureSubImage1D_unnnuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glTextureSubImage1D(sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTextureSubImage2D_unnnnnuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  glTextureSubImage2D(sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+9;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTextureSubImage3D_unnnnnnnuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=10, farg0=-1;
  glTextureSubImage3D(sp[10],sp[9],sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+11;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCompressedTextureSubImage1D_unnnuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glCompressedTextureSubImage1D(sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCompressedTextureSubImage2D_unnnnnuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  glCompressedTextureSubImage2D(sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+9;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCompressedTextureSubImage3D_unnnnnnnuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=10, farg0=-1;
  glCompressedTextureSubImage3D(sp[10],sp[9],sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+11;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCopyTextureSubImage1D_unnnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glCopyTextureSubImage1D(sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCopyTextureSubImage2D_unnnnnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  glCopyTextureSubImage2D(sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+8;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCopyTextureSubImage3D_unnnnnnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=8, farg0=-1;
  glCopyTextureSubImage3D(sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+9;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTextureParameterf_uur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=0;
  glTextureParameterf(sp[1],sp[0],fp[0]);
  x.sp = sp+2;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTextureParameterfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTextureParameterfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTextureParameteri_uun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTextureParameteri(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTextureParameterIiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTextureParameterIiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTextureParameterIuiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTextureParameterIuiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTextureParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glTextureParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGenerateTextureMipmap_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glGenerateTextureMipmap(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBindTextureUnit_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glBindTextureUnit(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTextureImage_unuuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glGetTextureImage(sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetCompressedTextureImage_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetCompressedTextureImage(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTextureLevelParameterfv_unua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetTextureLevelParameterfv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTextureLevelParameteriv_unua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetTextureLevelParameteriv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTextureParameterfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetTextureParameterfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTextureParameterIiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetTextureParameterIiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTextureParameterIuiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetTextureParameterIuiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTextureParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetTextureParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCreateVertexArrays_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glCreateVertexArrays(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glDisableVertexArrayAttrib_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glDisableVertexArrayAttrib(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glEnableVertexArrayAttrib_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glEnableVertexArrayAttrib(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexArrayElementBuffer_uu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glVertexArrayElementBuffer(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexArrayVertexBuffer_uuunn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glVertexArrayVertexBuffer(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexArrayVertexBuffers_uunaaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glVertexArrayVertexBuffers(sp[5],sp[4],sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexArrayAttribBinding_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glVertexArrayAttribBinding(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexArrayAttribFormat_uununu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glVertexArrayAttribFormat(sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexArrayAttribIFormat_uunuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glVertexArrayAttribIFormat(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexArrayAttribLFormat_uunuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glVertexArrayAttribLFormat(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glVertexArrayBindingDivisor_uuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glVertexArrayBindingDivisor(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetVertexArrayiv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetVertexArrayiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetVertexArrayIndexediv_uuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetVertexArrayIndexediv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetVertexArrayIndexed64iv_uuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetVertexArrayIndexed64iv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCreateSamplers_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glCreateSamplers(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCreateProgramPipelines_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glCreateProgramPipelines(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCreateQueries_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glCreateQueries(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetQueryBufferObjecti64v_uuun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetQueryBufferObjecti64v(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetQueryBufferObjectiv_uuun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetQueryBufferObjectiv(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetQueryBufferObjectui64v_uuun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetQueryBufferObjectui64v(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetQueryBufferObjectuiv_uuun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetQueryBufferObjectuiv(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMemoryBarrierByRegion_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glMemoryBarrierByRegion(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetTextureSubImage_unnnnnnnuuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=11, farg0=-1;
  glGetTextureSubImage(sp[11],sp[10],sp[9],sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+12;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetCompressedTextureSubImage_unnnnnnnna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=9, farg0=-1;
  glGetCompressedTextureSubImage(sp[9],sp[8],sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+10;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetGraphicsResetStatus__u(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=glGetGraphicsResetStatus();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetnCompressedTexImage_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetnCompressedTexImage(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetnTexImage_unuuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glGetnTexImage(sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetnUniformdv_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetnUniformdv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetnUniformfv_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetnUniformfv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetnUniformiv_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetnUniformiv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetnUniformuiv_unna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetnUniformuiv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glReadnPixels_nnnnuuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  glReadnPixels(sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+8;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetnMapdv_uuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetnMapdv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetnMapfv_uuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetnMapfv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetnMapiv_uuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetnMapiv(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetnPixelMapfv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetnPixelMapfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetnPixelMapuiv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetnPixelMapuiv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetnPixelMapusv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetnPixelMapusv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetnPolygonStipple_na_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glGetnPolygonStipple(sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetnColorTable_uuuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glGetnColorTable(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetnConvolutionFilter_uuuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glGetnConvolutionFilter(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetnSeparableFilter_uuunanaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  glGetnSeparableFilter(sp[7],sp[6],sp[5],sp[4],(void *)(sp[3]),sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+8;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetnHistogram_unuuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glGetnHistogram(sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetnMinmax_unuuna_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glGetnMinmax(sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glTextureBarrier__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glTextureBarrier();
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColorTable_uunuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glColorTable(sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColorTableParameterfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glColorTableParameterfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColorTableParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glColorTableParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCopyColorTable_uunnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glCopyColorTable(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetColorTable_uuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetColorTable(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetColorTableParameterfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetColorTableParameterfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetColorTableParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetColorTableParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glColorSubTable_unnuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glColorSubTable(sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCopyColorSubTable_unnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glCopyColorSubTable(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glConvolutionFilter1D_uunuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glConvolutionFilter1D(sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glConvolutionFilter2D_uunnuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  glConvolutionFilter2D(sp[6],sp[5],sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+7;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glConvolutionParameterf_uur_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=0;
  glConvolutionParameterf(sp[1],sp[0],fp[0]);
  x.sp = sp+2;
  x.fp = fp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glConvolutionParameterfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glConvolutionParameterfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glConvolutionParameteri_uun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glConvolutionParameteri(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glConvolutionParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glConvolutionParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCopyConvolutionFilter1D_uunnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glCopyConvolutionFilter1D(sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glCopyConvolutionFilter2D_uunnnn_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glCopyConvolutionFilter2D(sp[5],sp[4],sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetConvolutionFilter_uuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glGetConvolutionFilter(sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetConvolutionParameterfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetConvolutionParameterfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetConvolutionParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetConvolutionParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetSeparableFilter_uuuaaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  glGetSeparableFilter(sp[5],sp[4],sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glSeparableFilter2D_uunnuuaa_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  glSeparableFilter2D(sp[7],sp[6],sp[5],sp[4],sp[3],sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+8;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetHistogram_unuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glGetHistogram(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetHistogramParameterfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetHistogramParameterfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetHistogramParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetHistogramParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetMinmax_unuua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  glGetMinmax(sp[4],sp[3],sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetMinmaxParameterfv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetMinmaxParameterfv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetMinmaxParameteriv_uua_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetMinmaxParameteriv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glHistogram_unun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glHistogram(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glMinmax_uun_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glMinmax(sp[2],sp[1],sp[0]);
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glResetHistogram_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glResetHistogram(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glResetMinmax_u_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  glResetMinmax(sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBlendBarrierKHR__v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  glBlendBarrierKHR();
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glGetPixelMapxv_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glGetPixelMapxv(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPixelMapx_una_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  glPixelMapx(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glPixelStorex_un_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glPixelStorex(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glBlendFuncSeparateINGR_uuuu_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  glBlendFuncSeparateINGR(sp[3],sp[2],sp[1],sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_glHintPGI_un_v(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  glHintPGI(sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
#define CALLBACK_PFNWGLCREATEBUFFERREGIONARBPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLCREATEBUFFERREGIONARBPROC__##I (Cell x0, Cell x1, UCell x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLCREATEBUFFERREGIONARBPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLCREATEBUFFERREGIONARBPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLCREATEBUFFERREGIONARBPROC_(0)
CALLBACK_PFNWGLCREATEBUFFERREGIONARBPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLCREATEBUFFERREGIONARBPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCREATEBUFFERREGIONARBPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCREATEBUFFERREGIONARBPROC__1,
};
#define CALLBACK_PFNWGLDELETEBUFFERREGIONARBPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLDELETEBUFFERREGIONARBPROC__##I (Cell x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLDELETEBUFFERREGIONARBPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLDELETEBUFFERREGIONARBPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLDELETEBUFFERREGIONARBPROC_(0)
CALLBACK_PFNWGLDELETEBUFFERREGIONARBPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLDELETEBUFFERREGIONARBPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDELETEBUFFERREGIONARBPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDELETEBUFFERREGIONARBPROC__1,
};
#define CALLBACK_PFNWGLSAVEBUFFERREGIONARBPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLSAVEBUFFERREGIONARBPROC__##I (Cell x0, Cell x1, Cell x2, Cell x3, Cell x4) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(x2); \
  sp[-4]=(x3); \
  sp[-5]=(x4); \
  sp+=-5; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLSAVEBUFFERREGIONARBPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLSAVEBUFFERREGIONARBPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLSAVEBUFFERREGIONARBPROC_(0)
CALLBACK_PFNWGLSAVEBUFFERREGIONARBPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLSAVEBUFFERREGIONARBPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLSAVEBUFFERREGIONARBPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLSAVEBUFFERREGIONARBPROC__1,
};
#define CALLBACK_PFNWGLRESTOREBUFFERREGIONARBPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLRESTOREBUFFERREGIONARBPROC__##I (Cell x0, Cell x1, Cell x2, Cell x3, Cell x4, Cell x5, Cell x6) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(x2); \
  sp[-4]=(x3); \
  sp[-5]=(x4); \
  sp[-6]=(x5); \
  sp[-7]=(x6); \
  sp+=-7; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLRESTOREBUFFERREGIONARBPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLRESTOREBUFFERREGIONARBPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLRESTOREBUFFERREGIONARBPROC_(0)
CALLBACK_PFNWGLRESTOREBUFFERREGIONARBPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLRESTOREBUFFERREGIONARBPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLRESTOREBUFFERREGIONARBPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLRESTOREBUFFERREGIONARBPROC__1,
};
#define CALLBACK_PFNWGLCREATECONTEXTATTRIBSARBPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLCREATECONTEXTATTRIBSARBPROC__##I (Cell x0, Cell x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLCREATECONTEXTATTRIBSARBPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLCREATECONTEXTATTRIBSARBPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLCREATECONTEXTATTRIBSARBPROC_(0)
CALLBACK_PFNWGLCREATECONTEXTATTRIBSARBPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLCREATECONTEXTATTRIBSARBPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCREATECONTEXTATTRIBSARBPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCREATECONTEXTATTRIBSARBPROC__1,
};
#define CALLBACK_PFNWGLGETEXTENSIONSSTRINGARBPROC_(I) \
void* libgfopengl_LTX_gforth_cb_PFNWGLGETEXTENSIONSSTRINGARBPROC__##I (Cell x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETEXTENSIONSSTRINGARBPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return (void *)(sp[-1]); \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETEXTENSIONSSTRINGARBPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETEXTENSIONSSTRINGARBPROC_(0)
CALLBACK_PFNWGLGETEXTENSIONSSTRINGARBPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETEXTENSIONSSTRINGARBPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETEXTENSIONSSTRINGARBPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETEXTENSIONSSTRINGARBPROC__1,
};
#define CALLBACK_PFNWGLMAKECONTEXTCURRENTARBPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLMAKECONTEXTCURRENTARBPROC__##I (Cell x0, Cell x1, Cell x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLMAKECONTEXTCURRENTARBPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLMAKECONTEXTCURRENTARBPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLMAKECONTEXTCURRENTARBPROC_(0)
CALLBACK_PFNWGLMAKECONTEXTCURRENTARBPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLMAKECONTEXTCURRENTARBPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLMAKECONTEXTCURRENTARBPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLMAKECONTEXTCURRENTARBPROC__1,
};
#define CALLBACK_PFNWGLGETCURRENTREADDCARBPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETCURRENTREADDCARBPROC__##I () \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETCURRENTREADDCARBPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETCURRENTREADDCARBPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETCURRENTREADDCARBPROC_(0)
CALLBACK_PFNWGLGETCURRENTREADDCARBPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETCURRENTREADDCARBPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETCURRENTREADDCARBPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETCURRENTREADDCARBPROC__1,
};
#define CALLBACK_PFNWGLCREATEPBUFFERARBPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLCREATEPBUFFERARBPROC__##I (Cell x0, Cell x1, Cell x2, Cell x3, void* x4) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(x2); \
  sp[-4]=(x3); \
  sp[-5]=(Cell)(x4); \
  sp+=-5; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLCREATEPBUFFERARBPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLCREATEPBUFFERARBPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLCREATEPBUFFERARBPROC_(0)
CALLBACK_PFNWGLCREATEPBUFFERARBPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLCREATEPBUFFERARBPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCREATEPBUFFERARBPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCREATEPBUFFERARBPROC__1,
};
#define CALLBACK_PFNWGLGETPBUFFERDCARBPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETPBUFFERDCARBPROC__##I (Cell x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETPBUFFERDCARBPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETPBUFFERDCARBPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETPBUFFERDCARBPROC_(0)
CALLBACK_PFNWGLGETPBUFFERDCARBPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETPBUFFERDCARBPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETPBUFFERDCARBPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETPBUFFERDCARBPROC__1,
};
#define CALLBACK_PFNWGLRELEASEPBUFFERDCARBPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLRELEASEPBUFFERDCARBPROC__##I (Cell x0, Cell x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLRELEASEPBUFFERDCARBPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLRELEASEPBUFFERDCARBPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLRELEASEPBUFFERDCARBPROC_(0)
CALLBACK_PFNWGLRELEASEPBUFFERDCARBPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLRELEASEPBUFFERDCARBPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLRELEASEPBUFFERDCARBPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLRELEASEPBUFFERDCARBPROC__1,
};
#define CALLBACK_PFNWGLDESTROYPBUFFERARBPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLDESTROYPBUFFERARBPROC__##I (Cell x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLDESTROYPBUFFERARBPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLDESTROYPBUFFERARBPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLDESTROYPBUFFERARBPROC_(0)
CALLBACK_PFNWGLDESTROYPBUFFERARBPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLDESTROYPBUFFERARBPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDESTROYPBUFFERARBPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDESTROYPBUFFERARBPROC__1,
};
#define CALLBACK_PFNWGLQUERYPBUFFERARBPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLQUERYPBUFFERARBPROC__##I (Cell x0, Cell x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLQUERYPBUFFERARBPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLQUERYPBUFFERARBPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLQUERYPBUFFERARBPROC_(0)
CALLBACK_PFNWGLQUERYPBUFFERARBPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLQUERYPBUFFERARBPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLQUERYPBUFFERARBPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLQUERYPBUFFERARBPROC__1,
};
#define CALLBACK_PFNWGLGETPIXELFORMATATTRIBIVARBPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETPIXELFORMATATTRIBIVARBPROC__##I (Cell x0, Cell x1, Cell x2, UCell x3, void* x4, void* x5) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(x2); \
  sp[-4]=(x3); \
  sp[-5]=(Cell)(x4); \
  sp[-6]=(Cell)(x5); \
  sp+=-6; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETPIXELFORMATATTRIBIVARBPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETPIXELFORMATATTRIBIVARBPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETPIXELFORMATATTRIBIVARBPROC_(0)
CALLBACK_PFNWGLGETPIXELFORMATATTRIBIVARBPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETPIXELFORMATATTRIBIVARBPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETPIXELFORMATATTRIBIVARBPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETPIXELFORMATATTRIBIVARBPROC__1,
};
#define CALLBACK_PFNWGLGETPIXELFORMATATTRIBFVARBPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETPIXELFORMATATTRIBFVARBPROC__##I (Cell x0, Cell x1, Cell x2, UCell x3, void* x4, void* x5) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(x2); \
  sp[-4]=(x3); \
  sp[-5]=(Cell)(x4); \
  sp[-6]=(Cell)(x5); \
  sp+=-6; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETPIXELFORMATATTRIBFVARBPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETPIXELFORMATATTRIBFVARBPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETPIXELFORMATATTRIBFVARBPROC_(0)
CALLBACK_PFNWGLGETPIXELFORMATATTRIBFVARBPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETPIXELFORMATATTRIBFVARBPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETPIXELFORMATATTRIBFVARBPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETPIXELFORMATATTRIBFVARBPROC__1,
};
#define CALLBACK_PFNWGLCHOOSEPIXELFORMATARBPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLCHOOSEPIXELFORMATARBPROC__##I (Cell x0, void* x1, void* x2, UCell x3, void* x4, void* x5) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp[-3]=(Cell)(x2); \
  sp[-4]=(x3); \
  sp[-5]=(Cell)(x4); \
  sp[-6]=(Cell)(x5); \
  sp+=-6; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLCHOOSEPIXELFORMATARBPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLCHOOSEPIXELFORMATARBPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLCHOOSEPIXELFORMATARBPROC_(0)
CALLBACK_PFNWGLCHOOSEPIXELFORMATARBPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLCHOOSEPIXELFORMATARBPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCHOOSEPIXELFORMATARBPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCHOOSEPIXELFORMATARBPROC__1,
};
#define CALLBACK_PFNWGLBINDTEXIMAGEARBPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLBINDTEXIMAGEARBPROC__##I (Cell x0, Cell x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLBINDTEXIMAGEARBPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLBINDTEXIMAGEARBPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLBINDTEXIMAGEARBPROC_(0)
CALLBACK_PFNWGLBINDTEXIMAGEARBPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLBINDTEXIMAGEARBPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLBINDTEXIMAGEARBPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLBINDTEXIMAGEARBPROC__1,
};
#define CALLBACK_PFNWGLRELEASETEXIMAGEARBPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLRELEASETEXIMAGEARBPROC__##I (Cell x0, Cell x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLRELEASETEXIMAGEARBPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLRELEASETEXIMAGEARBPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLRELEASETEXIMAGEARBPROC_(0)
CALLBACK_PFNWGLRELEASETEXIMAGEARBPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLRELEASETEXIMAGEARBPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLRELEASETEXIMAGEARBPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLRELEASETEXIMAGEARBPROC__1,
};
#define CALLBACK_PFNWGLSETPBUFFERATTRIBARBPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLSETPBUFFERATTRIBARBPROC__##I (Cell x0, void* x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLSETPBUFFERATTRIBARBPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLSETPBUFFERATTRIBARBPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLSETPBUFFERATTRIBARBPROC_(0)
CALLBACK_PFNWGLSETPBUFFERATTRIBARBPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLSETPBUFFERATTRIBARBPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLSETPBUFFERATTRIBARBPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLSETPBUFFERATTRIBARBPROC__1,
};
#define CALLBACK_PFNWGLSETSTEREOEMITTERSTATE3DLPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLSETSTEREOEMITTERSTATE3DLPROC__##I (Cell x0, UCell x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLSETSTEREOEMITTERSTATE3DLPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLSETSTEREOEMITTERSTATE3DLPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLSETSTEREOEMITTERSTATE3DLPROC_(0)
CALLBACK_PFNWGLSETSTEREOEMITTERSTATE3DLPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLSETSTEREOEMITTERSTATE3DLPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLSETSTEREOEMITTERSTATE3DLPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLSETSTEREOEMITTERSTATE3DLPROC__1,
};
#define CALLBACK_PFNWGLGETGPUIDSAMDPROC_(I) \
UCell libgfopengl_LTX_gforth_cb_PFNWGLGETGPUIDSAMDPROC__##I (UCell x0, void* x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETGPUIDSAMDPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETGPUIDSAMDPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETGPUIDSAMDPROC_(0)
CALLBACK_PFNWGLGETGPUIDSAMDPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETGPUIDSAMDPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETGPUIDSAMDPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETGPUIDSAMDPROC__1,
};
#define CALLBACK_PFNWGLGETGPUINFOAMDPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETGPUINFOAMDPROC__##I (UCell x0, Cell x1, Cell x2, UCell x3, void* x4) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(x2); \
  sp[-4]=(x3); \
  sp[-5]=(Cell)(x4); \
  sp+=-5; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETGPUINFOAMDPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETGPUINFOAMDPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETGPUINFOAMDPROC_(0)
CALLBACK_PFNWGLGETGPUINFOAMDPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETGPUINFOAMDPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETGPUINFOAMDPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETGPUINFOAMDPROC__1,
};
#define CALLBACK_PFNWGLGETCONTEXTGPUIDAMDPROC_(I) \
UCell libgfopengl_LTX_gforth_cb_PFNWGLGETCONTEXTGPUIDAMDPROC__##I (Cell x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETCONTEXTGPUIDAMDPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETCONTEXTGPUIDAMDPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETCONTEXTGPUIDAMDPROC_(0)
CALLBACK_PFNWGLGETCONTEXTGPUIDAMDPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETCONTEXTGPUIDAMDPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETCONTEXTGPUIDAMDPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETCONTEXTGPUIDAMDPROC__1,
};
#define CALLBACK_PFNWGLCREATEASSOCIATEDCONTEXTAMDPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLCREATEASSOCIATEDCONTEXTAMDPROC__##I (UCell x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLCREATEASSOCIATEDCONTEXTAMDPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLCREATEASSOCIATEDCONTEXTAMDPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLCREATEASSOCIATEDCONTEXTAMDPROC_(0)
CALLBACK_PFNWGLCREATEASSOCIATEDCONTEXTAMDPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLCREATEASSOCIATEDCONTEXTAMDPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCREATEASSOCIATEDCONTEXTAMDPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCREATEASSOCIATEDCONTEXTAMDPROC__1,
};
#define CALLBACK_PFNWGLCREATEASSOCIATEDCONTEXTATTRIBSAMDPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLCREATEASSOCIATEDCONTEXTATTRIBSAMDPROC__##I (UCell x0, Cell x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLCREATEASSOCIATEDCONTEXTATTRIBSAMDPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLCREATEASSOCIATEDCONTEXTATTRIBSAMDPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLCREATEASSOCIATEDCONTEXTATTRIBSAMDPROC_(0)
CALLBACK_PFNWGLCREATEASSOCIATEDCONTEXTATTRIBSAMDPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLCREATEASSOCIATEDCONTEXTATTRIBSAMDPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCREATEASSOCIATEDCONTEXTATTRIBSAMDPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCREATEASSOCIATEDCONTEXTATTRIBSAMDPROC__1,
};
#define CALLBACK_PFNWGLDELETEASSOCIATEDCONTEXTAMDPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLDELETEASSOCIATEDCONTEXTAMDPROC__##I (Cell x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLDELETEASSOCIATEDCONTEXTAMDPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLDELETEASSOCIATEDCONTEXTAMDPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLDELETEASSOCIATEDCONTEXTAMDPROC_(0)
CALLBACK_PFNWGLDELETEASSOCIATEDCONTEXTAMDPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLDELETEASSOCIATEDCONTEXTAMDPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDELETEASSOCIATEDCONTEXTAMDPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDELETEASSOCIATEDCONTEXTAMDPROC__1,
};
#define CALLBACK_PFNWGLMAKEASSOCIATEDCONTEXTCURRENTAMDPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLMAKEASSOCIATEDCONTEXTCURRENTAMDPROC__##I (Cell x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLMAKEASSOCIATEDCONTEXTCURRENTAMDPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLMAKEASSOCIATEDCONTEXTCURRENTAMDPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLMAKEASSOCIATEDCONTEXTCURRENTAMDPROC_(0)
CALLBACK_PFNWGLMAKEASSOCIATEDCONTEXTCURRENTAMDPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLMAKEASSOCIATEDCONTEXTCURRENTAMDPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLMAKEASSOCIATEDCONTEXTCURRENTAMDPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLMAKEASSOCIATEDCONTEXTCURRENTAMDPROC__1,
};
#define CALLBACK_PFNWGLGETCURRENTASSOCIATEDCONTEXTAMDPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETCURRENTASSOCIATEDCONTEXTAMDPROC__##I () \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETCURRENTASSOCIATEDCONTEXTAMDPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETCURRENTASSOCIATEDCONTEXTAMDPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETCURRENTASSOCIATEDCONTEXTAMDPROC_(0)
CALLBACK_PFNWGLGETCURRENTASSOCIATEDCONTEXTAMDPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETCURRENTASSOCIATEDCONTEXTAMDPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETCURRENTASSOCIATEDCONTEXTAMDPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETCURRENTASSOCIATEDCONTEXTAMDPROC__1,
};
#define CALLBACK_PFNWGLBLITCONTEXTFRAMEBUFFERAMDPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLBLITCONTEXTFRAMEBUFFERAMDPROC__##I (Cell x0, Cell x1, Cell x2, Cell x3, Cell x4, Cell x5, Cell x6, Cell x7, Cell x8, Cell x9, Cell x10) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(x2); \
  sp[-4]=(x3); \
  sp[-5]=(x4); \
  sp[-6]=(x5); \
  sp[-7]=(x6); \
  sp[-8]=(x7); \
  sp[-9]=(x8); \
  sp[-10]=(x9); \
  sp[-11]=(x10); \
  sp+=-11; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLBLITCONTEXTFRAMEBUFFERAMDPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLBLITCONTEXTFRAMEBUFFERAMDPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLBLITCONTEXTFRAMEBUFFERAMDPROC_(0)
CALLBACK_PFNWGLBLITCONTEXTFRAMEBUFFERAMDPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLBLITCONTEXTFRAMEBUFFERAMDPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLBLITCONTEXTFRAMEBUFFERAMDPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLBLITCONTEXTFRAMEBUFFERAMDPROC__1,
};
#define CALLBACK_PFNWGLCREATEDISPLAYCOLORTABLEEXTPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLCREATEDISPLAYCOLORTABLEEXTPROC__##I (Cell x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLCREATEDISPLAYCOLORTABLEEXTPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLCREATEDISPLAYCOLORTABLEEXTPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLCREATEDISPLAYCOLORTABLEEXTPROC_(0)
CALLBACK_PFNWGLCREATEDISPLAYCOLORTABLEEXTPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLCREATEDISPLAYCOLORTABLEEXTPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCREATEDISPLAYCOLORTABLEEXTPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCREATEDISPLAYCOLORTABLEEXTPROC__1,
};
#define CALLBACK_PFNWGLLOADDISPLAYCOLORTABLEEXTPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLLOADDISPLAYCOLORTABLEEXTPROC__##I (void* x0, UCell x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(Cell)(x0); \
  sp[-2]=(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLLOADDISPLAYCOLORTABLEEXTPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLLOADDISPLAYCOLORTABLEEXTPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLLOADDISPLAYCOLORTABLEEXTPROC_(0)
CALLBACK_PFNWGLLOADDISPLAYCOLORTABLEEXTPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLLOADDISPLAYCOLORTABLEEXTPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLLOADDISPLAYCOLORTABLEEXTPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLLOADDISPLAYCOLORTABLEEXTPROC__1,
};
#define CALLBACK_PFNWGLBINDDISPLAYCOLORTABLEEXTPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLBINDDISPLAYCOLORTABLEEXTPROC__##I (Cell x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLBINDDISPLAYCOLORTABLEEXTPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLBINDDISPLAYCOLORTABLEEXTPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLBINDDISPLAYCOLORTABLEEXTPROC_(0)
CALLBACK_PFNWGLBINDDISPLAYCOLORTABLEEXTPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLBINDDISPLAYCOLORTABLEEXTPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLBINDDISPLAYCOLORTABLEEXTPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLBINDDISPLAYCOLORTABLEEXTPROC__1,
};
#define CALLBACK_PFNWGLDESTROYDISPLAYCOLORTABLEEXTPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLDESTROYDISPLAYCOLORTABLEEXTPROC__##I (Cell x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLDESTROYDISPLAYCOLORTABLEEXTPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLDESTROYDISPLAYCOLORTABLEEXTPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLDESTROYDISPLAYCOLORTABLEEXTPROC_(0)
CALLBACK_PFNWGLDESTROYDISPLAYCOLORTABLEEXTPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLDESTROYDISPLAYCOLORTABLEEXTPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDESTROYDISPLAYCOLORTABLEEXTPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDESTROYDISPLAYCOLORTABLEEXTPROC__1,
};
#define CALLBACK_PFNWGLGETEXTENSIONSSTRINGEXTPROC_(I) \
void* libgfopengl_LTX_gforth_cb_PFNWGLGETEXTENSIONSSTRINGEXTPROC__##I () \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETEXTENSIONSSTRINGEXTPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return (void *)(sp[-1]); \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETEXTENSIONSSTRINGEXTPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETEXTENSIONSSTRINGEXTPROC_(0)
CALLBACK_PFNWGLGETEXTENSIONSSTRINGEXTPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETEXTENSIONSSTRINGEXTPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETEXTENSIONSSTRINGEXTPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETEXTENSIONSSTRINGEXTPROC__1,
};
#define CALLBACK_PFNWGLMAKECONTEXTCURRENTEXTPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLMAKECONTEXTCURRENTEXTPROC__##I (Cell x0, Cell x1, Cell x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLMAKECONTEXTCURRENTEXTPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLMAKECONTEXTCURRENTEXTPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLMAKECONTEXTCURRENTEXTPROC_(0)
CALLBACK_PFNWGLMAKECONTEXTCURRENTEXTPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLMAKECONTEXTCURRENTEXTPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLMAKECONTEXTCURRENTEXTPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLMAKECONTEXTCURRENTEXTPROC__1,
};
#define CALLBACK_PFNWGLGETCURRENTREADDCEXTPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETCURRENTREADDCEXTPROC__##I () \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETCURRENTREADDCEXTPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETCURRENTREADDCEXTPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETCURRENTREADDCEXTPROC_(0)
CALLBACK_PFNWGLGETCURRENTREADDCEXTPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETCURRENTREADDCEXTPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETCURRENTREADDCEXTPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETCURRENTREADDCEXTPROC__1,
};
#define CALLBACK_PFNWGLCREATEPBUFFEREXTPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLCREATEPBUFFEREXTPROC__##I (Cell x0, Cell x1, Cell x2, Cell x3, void* x4) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(x2); \
  sp[-4]=(x3); \
  sp[-5]=(Cell)(x4); \
  sp+=-5; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLCREATEPBUFFEREXTPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLCREATEPBUFFEREXTPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLCREATEPBUFFEREXTPROC_(0)
CALLBACK_PFNWGLCREATEPBUFFEREXTPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLCREATEPBUFFEREXTPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCREATEPBUFFEREXTPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCREATEPBUFFEREXTPROC__1,
};
#define CALLBACK_PFNWGLGETPBUFFERDCEXTPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETPBUFFERDCEXTPROC__##I (Cell x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETPBUFFERDCEXTPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETPBUFFERDCEXTPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETPBUFFERDCEXTPROC_(0)
CALLBACK_PFNWGLGETPBUFFERDCEXTPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETPBUFFERDCEXTPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETPBUFFERDCEXTPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETPBUFFERDCEXTPROC__1,
};
#define CALLBACK_PFNWGLRELEASEPBUFFERDCEXTPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLRELEASEPBUFFERDCEXTPROC__##I (Cell x0, Cell x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLRELEASEPBUFFERDCEXTPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLRELEASEPBUFFERDCEXTPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLRELEASEPBUFFERDCEXTPROC_(0)
CALLBACK_PFNWGLRELEASEPBUFFERDCEXTPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLRELEASEPBUFFERDCEXTPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLRELEASEPBUFFERDCEXTPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLRELEASEPBUFFERDCEXTPROC__1,
};
#define CALLBACK_PFNWGLDESTROYPBUFFEREXTPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLDESTROYPBUFFEREXTPROC__##I (Cell x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLDESTROYPBUFFEREXTPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLDESTROYPBUFFEREXTPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLDESTROYPBUFFEREXTPROC_(0)
CALLBACK_PFNWGLDESTROYPBUFFEREXTPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLDESTROYPBUFFEREXTPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDESTROYPBUFFEREXTPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDESTROYPBUFFEREXTPROC__1,
};
#define CALLBACK_PFNWGLQUERYPBUFFEREXTPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLQUERYPBUFFEREXTPROC__##I (Cell x0, Cell x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLQUERYPBUFFEREXTPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLQUERYPBUFFEREXTPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLQUERYPBUFFEREXTPROC_(0)
CALLBACK_PFNWGLQUERYPBUFFEREXTPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLQUERYPBUFFEREXTPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLQUERYPBUFFEREXTPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLQUERYPBUFFEREXTPROC__1,
};
#define CALLBACK_PFNWGLGETPIXELFORMATATTRIBIVEXTPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETPIXELFORMATATTRIBIVEXTPROC__##I (Cell x0, Cell x1, Cell x2, UCell x3, void* x4, void* x5) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(x2); \
  sp[-4]=(x3); \
  sp[-5]=(Cell)(x4); \
  sp[-6]=(Cell)(x5); \
  sp+=-6; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETPIXELFORMATATTRIBIVEXTPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETPIXELFORMATATTRIBIVEXTPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETPIXELFORMATATTRIBIVEXTPROC_(0)
CALLBACK_PFNWGLGETPIXELFORMATATTRIBIVEXTPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETPIXELFORMATATTRIBIVEXTPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETPIXELFORMATATTRIBIVEXTPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETPIXELFORMATATTRIBIVEXTPROC__1,
};
#define CALLBACK_PFNWGLGETPIXELFORMATATTRIBFVEXTPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETPIXELFORMATATTRIBFVEXTPROC__##I (Cell x0, Cell x1, Cell x2, UCell x3, void* x4, void* x5) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(x2); \
  sp[-4]=(x3); \
  sp[-5]=(Cell)(x4); \
  sp[-6]=(Cell)(x5); \
  sp+=-6; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETPIXELFORMATATTRIBFVEXTPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETPIXELFORMATATTRIBFVEXTPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETPIXELFORMATATTRIBFVEXTPROC_(0)
CALLBACK_PFNWGLGETPIXELFORMATATTRIBFVEXTPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETPIXELFORMATATTRIBFVEXTPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETPIXELFORMATATTRIBFVEXTPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETPIXELFORMATATTRIBFVEXTPROC__1,
};
#define CALLBACK_PFNWGLCHOOSEPIXELFORMATEXTPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLCHOOSEPIXELFORMATEXTPROC__##I (Cell x0, void* x1, void* x2, UCell x3, void* x4, void* x5) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp[-3]=(Cell)(x2); \
  sp[-4]=(x3); \
  sp[-5]=(Cell)(x4); \
  sp[-6]=(Cell)(x5); \
  sp+=-6; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLCHOOSEPIXELFORMATEXTPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLCHOOSEPIXELFORMATEXTPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLCHOOSEPIXELFORMATEXTPROC_(0)
CALLBACK_PFNWGLCHOOSEPIXELFORMATEXTPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLCHOOSEPIXELFORMATEXTPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCHOOSEPIXELFORMATEXTPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCHOOSEPIXELFORMATEXTPROC__1,
};
#define CALLBACK_PFNWGLSWAPINTERVALEXTPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLSWAPINTERVALEXTPROC__##I (Cell x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLSWAPINTERVALEXTPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLSWAPINTERVALEXTPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLSWAPINTERVALEXTPROC_(0)
CALLBACK_PFNWGLSWAPINTERVALEXTPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLSWAPINTERVALEXTPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLSWAPINTERVALEXTPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLSWAPINTERVALEXTPROC__1,
};
#define CALLBACK_PFNWGLGETSWAPINTERVALEXTPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETSWAPINTERVALEXTPROC__##I () \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETSWAPINTERVALEXTPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETSWAPINTERVALEXTPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETSWAPINTERVALEXTPROC_(0)
CALLBACK_PFNWGLGETSWAPINTERVALEXTPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETSWAPINTERVALEXTPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETSWAPINTERVALEXTPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETSWAPINTERVALEXTPROC__1,
};
#define CALLBACK_PFNWGLGETDIGITALVIDEOPARAMETERSI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETDIGITALVIDEOPARAMETERSI3DPROC__##I (Cell x0, Cell x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETDIGITALVIDEOPARAMETERSI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETDIGITALVIDEOPARAMETERSI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETDIGITALVIDEOPARAMETERSI3DPROC_(0)
CALLBACK_PFNWGLGETDIGITALVIDEOPARAMETERSI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETDIGITALVIDEOPARAMETERSI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETDIGITALVIDEOPARAMETERSI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETDIGITALVIDEOPARAMETERSI3DPROC__1,
};
#define CALLBACK_PFNWGLSETDIGITALVIDEOPARAMETERSI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLSETDIGITALVIDEOPARAMETERSI3DPROC__##I (Cell x0, Cell x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLSETDIGITALVIDEOPARAMETERSI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLSETDIGITALVIDEOPARAMETERSI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLSETDIGITALVIDEOPARAMETERSI3DPROC_(0)
CALLBACK_PFNWGLSETDIGITALVIDEOPARAMETERSI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLSETDIGITALVIDEOPARAMETERSI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLSETDIGITALVIDEOPARAMETERSI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLSETDIGITALVIDEOPARAMETERSI3DPROC__1,
};
#define CALLBACK_PFNWGLGETGAMMATABLEPARAMETERSI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETGAMMATABLEPARAMETERSI3DPROC__##I (Cell x0, Cell x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETGAMMATABLEPARAMETERSI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETGAMMATABLEPARAMETERSI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETGAMMATABLEPARAMETERSI3DPROC_(0)
CALLBACK_PFNWGLGETGAMMATABLEPARAMETERSI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETGAMMATABLEPARAMETERSI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETGAMMATABLEPARAMETERSI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETGAMMATABLEPARAMETERSI3DPROC__1,
};
#define CALLBACK_PFNWGLSETGAMMATABLEPARAMETERSI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLSETGAMMATABLEPARAMETERSI3DPROC__##I (Cell x0, Cell x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLSETGAMMATABLEPARAMETERSI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLSETGAMMATABLEPARAMETERSI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLSETGAMMATABLEPARAMETERSI3DPROC_(0)
CALLBACK_PFNWGLSETGAMMATABLEPARAMETERSI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLSETGAMMATABLEPARAMETERSI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLSETGAMMATABLEPARAMETERSI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLSETGAMMATABLEPARAMETERSI3DPROC__1,
};
#define CALLBACK_PFNWGLGETGAMMATABLEI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETGAMMATABLEI3DPROC__##I (Cell x0, Cell x1, void* x2, void* x3, void* x4) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(Cell)(x2); \
  sp[-4]=(Cell)(x3); \
  sp[-5]=(Cell)(x4); \
  sp+=-5; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETGAMMATABLEI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETGAMMATABLEI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETGAMMATABLEI3DPROC_(0)
CALLBACK_PFNWGLGETGAMMATABLEI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETGAMMATABLEI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETGAMMATABLEI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETGAMMATABLEI3DPROC__1,
};
#define CALLBACK_PFNWGLSETGAMMATABLEI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLSETGAMMATABLEI3DPROC__##I (Cell x0, Cell x1, void* x2, void* x3, void* x4) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(Cell)(x2); \
  sp[-4]=(Cell)(x3); \
  sp[-5]=(Cell)(x4); \
  sp+=-5; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLSETGAMMATABLEI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLSETGAMMATABLEI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLSETGAMMATABLEI3DPROC_(0)
CALLBACK_PFNWGLSETGAMMATABLEI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLSETGAMMATABLEI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLSETGAMMATABLEI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLSETGAMMATABLEI3DPROC__1,
};
#define CALLBACK_PFNWGLENABLEGENLOCKI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLENABLEGENLOCKI3DPROC__##I (Cell x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLENABLEGENLOCKI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLENABLEGENLOCKI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLENABLEGENLOCKI3DPROC_(0)
CALLBACK_PFNWGLENABLEGENLOCKI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLENABLEGENLOCKI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLENABLEGENLOCKI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLENABLEGENLOCKI3DPROC__1,
};
#define CALLBACK_PFNWGLDISABLEGENLOCKI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLDISABLEGENLOCKI3DPROC__##I (Cell x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLDISABLEGENLOCKI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLDISABLEGENLOCKI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLDISABLEGENLOCKI3DPROC_(0)
CALLBACK_PFNWGLDISABLEGENLOCKI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLDISABLEGENLOCKI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDISABLEGENLOCKI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDISABLEGENLOCKI3DPROC__1,
};
#define CALLBACK_PFNWGLISENABLEDGENLOCKI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLISENABLEDGENLOCKI3DPROC__##I (Cell x0, void* x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLISENABLEDGENLOCKI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLISENABLEDGENLOCKI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLISENABLEDGENLOCKI3DPROC_(0)
CALLBACK_PFNWGLISENABLEDGENLOCKI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLISENABLEDGENLOCKI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLISENABLEDGENLOCKI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLISENABLEDGENLOCKI3DPROC__1,
};
#define CALLBACK_PFNWGLGENLOCKSOURCEI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGENLOCKSOURCEI3DPROC__##I (Cell x0, UCell x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGENLOCKSOURCEI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGENLOCKSOURCEI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGENLOCKSOURCEI3DPROC_(0)
CALLBACK_PFNWGLGENLOCKSOURCEI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGENLOCKSOURCEI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGENLOCKSOURCEI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGENLOCKSOURCEI3DPROC__1,
};
#define CALLBACK_PFNWGLGETGENLOCKSOURCEI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETGENLOCKSOURCEI3DPROC__##I (Cell x0, void* x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETGENLOCKSOURCEI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETGENLOCKSOURCEI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETGENLOCKSOURCEI3DPROC_(0)
CALLBACK_PFNWGLGETGENLOCKSOURCEI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETGENLOCKSOURCEI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETGENLOCKSOURCEI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETGENLOCKSOURCEI3DPROC__1,
};
#define CALLBACK_PFNWGLGENLOCKSOURCEEDGEI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGENLOCKSOURCEEDGEI3DPROC__##I (Cell x0, UCell x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGENLOCKSOURCEEDGEI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGENLOCKSOURCEEDGEI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGENLOCKSOURCEEDGEI3DPROC_(0)
CALLBACK_PFNWGLGENLOCKSOURCEEDGEI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGENLOCKSOURCEEDGEI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGENLOCKSOURCEEDGEI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGENLOCKSOURCEEDGEI3DPROC__1,
};
#define CALLBACK_PFNWGLGETGENLOCKSOURCEEDGEI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETGENLOCKSOURCEEDGEI3DPROC__##I (Cell x0, void* x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETGENLOCKSOURCEEDGEI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETGENLOCKSOURCEEDGEI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETGENLOCKSOURCEEDGEI3DPROC_(0)
CALLBACK_PFNWGLGETGENLOCKSOURCEEDGEI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETGENLOCKSOURCEEDGEI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETGENLOCKSOURCEEDGEI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETGENLOCKSOURCEEDGEI3DPROC__1,
};
#define CALLBACK_PFNWGLGENLOCKSAMPLERATEI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGENLOCKSAMPLERATEI3DPROC__##I (Cell x0, UCell x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGENLOCKSAMPLERATEI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGENLOCKSAMPLERATEI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGENLOCKSAMPLERATEI3DPROC_(0)
CALLBACK_PFNWGLGENLOCKSAMPLERATEI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGENLOCKSAMPLERATEI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGENLOCKSAMPLERATEI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGENLOCKSAMPLERATEI3DPROC__1,
};
#define CALLBACK_PFNWGLGETGENLOCKSAMPLERATEI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETGENLOCKSAMPLERATEI3DPROC__##I (Cell x0, void* x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETGENLOCKSAMPLERATEI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETGENLOCKSAMPLERATEI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETGENLOCKSAMPLERATEI3DPROC_(0)
CALLBACK_PFNWGLGETGENLOCKSAMPLERATEI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETGENLOCKSAMPLERATEI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETGENLOCKSAMPLERATEI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETGENLOCKSAMPLERATEI3DPROC__1,
};
#define CALLBACK_PFNWGLGENLOCKSOURCEDELAYI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGENLOCKSOURCEDELAYI3DPROC__##I (Cell x0, UCell x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGENLOCKSOURCEDELAYI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGENLOCKSOURCEDELAYI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGENLOCKSOURCEDELAYI3DPROC_(0)
CALLBACK_PFNWGLGENLOCKSOURCEDELAYI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGENLOCKSOURCEDELAYI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGENLOCKSOURCEDELAYI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGENLOCKSOURCEDELAYI3DPROC__1,
};
#define CALLBACK_PFNWGLGETGENLOCKSOURCEDELAYI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETGENLOCKSOURCEDELAYI3DPROC__##I (Cell x0, void* x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETGENLOCKSOURCEDELAYI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETGENLOCKSOURCEDELAYI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETGENLOCKSOURCEDELAYI3DPROC_(0)
CALLBACK_PFNWGLGETGENLOCKSOURCEDELAYI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETGENLOCKSOURCEDELAYI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETGENLOCKSOURCEDELAYI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETGENLOCKSOURCEDELAYI3DPROC__1,
};
#define CALLBACK_PFNWGLQUERYGENLOCKMAXSOURCEDELAYI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLQUERYGENLOCKMAXSOURCEDELAYI3DPROC__##I (Cell x0, void* x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLQUERYGENLOCKMAXSOURCEDELAYI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLQUERYGENLOCKMAXSOURCEDELAYI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLQUERYGENLOCKMAXSOURCEDELAYI3DPROC_(0)
CALLBACK_PFNWGLQUERYGENLOCKMAXSOURCEDELAYI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLQUERYGENLOCKMAXSOURCEDELAYI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLQUERYGENLOCKMAXSOURCEDELAYI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLQUERYGENLOCKMAXSOURCEDELAYI3DPROC__1,
};
#define CALLBACK_PFNWGLCREATEIMAGEBUFFERI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLCREATEIMAGEBUFFERI3DPROC__##I (Cell x0, Cell x1, UCell x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLCREATEIMAGEBUFFERI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLCREATEIMAGEBUFFERI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLCREATEIMAGEBUFFERI3DPROC_(0)
CALLBACK_PFNWGLCREATEIMAGEBUFFERI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLCREATEIMAGEBUFFERI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCREATEIMAGEBUFFERI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCREATEIMAGEBUFFERI3DPROC__1,
};
#define CALLBACK_PFNWGLDESTROYIMAGEBUFFERI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLDESTROYIMAGEBUFFERI3DPROC__##I (Cell x0, Cell x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLDESTROYIMAGEBUFFERI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLDESTROYIMAGEBUFFERI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLDESTROYIMAGEBUFFERI3DPROC_(0)
CALLBACK_PFNWGLDESTROYIMAGEBUFFERI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLDESTROYIMAGEBUFFERI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDESTROYIMAGEBUFFERI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDESTROYIMAGEBUFFERI3DPROC__1,
};
#define CALLBACK_PFNWGLASSOCIATEIMAGEBUFFEREVENTSI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLASSOCIATEIMAGEBUFFEREVENTSI3DPROC__##I (Cell x0, void* x1, void* x2, void* x3, UCell x4) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp[-3]=(Cell)(x2); \
  sp[-4]=(Cell)(x3); \
  sp[-5]=(x4); \
  sp+=-5; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLASSOCIATEIMAGEBUFFEREVENTSI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLASSOCIATEIMAGEBUFFEREVENTSI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLASSOCIATEIMAGEBUFFEREVENTSI3DPROC_(0)
CALLBACK_PFNWGLASSOCIATEIMAGEBUFFEREVENTSI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLASSOCIATEIMAGEBUFFEREVENTSI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLASSOCIATEIMAGEBUFFEREVENTSI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLASSOCIATEIMAGEBUFFEREVENTSI3DPROC__1,
};
#define CALLBACK_PFNWGLRELEASEIMAGEBUFFEREVENTSI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLRELEASEIMAGEBUFFEREVENTSI3DPROC__##I (Cell x0, void* x1, UCell x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp[-3]=(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLRELEASEIMAGEBUFFEREVENTSI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLRELEASEIMAGEBUFFEREVENTSI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLRELEASEIMAGEBUFFEREVENTSI3DPROC_(0)
CALLBACK_PFNWGLRELEASEIMAGEBUFFEREVENTSI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLRELEASEIMAGEBUFFEREVENTSI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLRELEASEIMAGEBUFFEREVENTSI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLRELEASEIMAGEBUFFEREVENTSI3DPROC__1,
};
#define CALLBACK_PFNWGLENABLEFRAMELOCKI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLENABLEFRAMELOCKI3DPROC__##I () \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLENABLEFRAMELOCKI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLENABLEFRAMELOCKI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLENABLEFRAMELOCKI3DPROC_(0)
CALLBACK_PFNWGLENABLEFRAMELOCKI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLENABLEFRAMELOCKI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLENABLEFRAMELOCKI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLENABLEFRAMELOCKI3DPROC__1,
};
#define CALLBACK_PFNWGLDISABLEFRAMELOCKI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLDISABLEFRAMELOCKI3DPROC__##I () \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLDISABLEFRAMELOCKI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLDISABLEFRAMELOCKI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLDISABLEFRAMELOCKI3DPROC_(0)
CALLBACK_PFNWGLDISABLEFRAMELOCKI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLDISABLEFRAMELOCKI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDISABLEFRAMELOCKI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDISABLEFRAMELOCKI3DPROC__1,
};
#define CALLBACK_PFNWGLISENABLEDFRAMELOCKI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLISENABLEDFRAMELOCKI3DPROC__##I (void* x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(Cell)(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLISENABLEDFRAMELOCKI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLISENABLEDFRAMELOCKI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLISENABLEDFRAMELOCKI3DPROC_(0)
CALLBACK_PFNWGLISENABLEDFRAMELOCKI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLISENABLEDFRAMELOCKI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLISENABLEDFRAMELOCKI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLISENABLEDFRAMELOCKI3DPROC__1,
};
#define CALLBACK_PFNWGLQUERYFRAMELOCKMASTERI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLQUERYFRAMELOCKMASTERI3DPROC__##I (void* x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(Cell)(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLQUERYFRAMELOCKMASTERI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLQUERYFRAMELOCKMASTERI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLQUERYFRAMELOCKMASTERI3DPROC_(0)
CALLBACK_PFNWGLQUERYFRAMELOCKMASTERI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLQUERYFRAMELOCKMASTERI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLQUERYFRAMELOCKMASTERI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLQUERYFRAMELOCKMASTERI3DPROC__1,
};
#define CALLBACK_PFNWGLGETFRAMEUSAGEI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETFRAMEUSAGEI3DPROC__##I (void* x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(Cell)(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETFRAMEUSAGEI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETFRAMEUSAGEI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETFRAMEUSAGEI3DPROC_(0)
CALLBACK_PFNWGLGETFRAMEUSAGEI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETFRAMEUSAGEI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETFRAMEUSAGEI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETFRAMEUSAGEI3DPROC__1,
};
#define CALLBACK_PFNWGLBEGINFRAMETRACKINGI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLBEGINFRAMETRACKINGI3DPROC__##I () \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLBEGINFRAMETRACKINGI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLBEGINFRAMETRACKINGI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLBEGINFRAMETRACKINGI3DPROC_(0)
CALLBACK_PFNWGLBEGINFRAMETRACKINGI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLBEGINFRAMETRACKINGI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLBEGINFRAMETRACKINGI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLBEGINFRAMETRACKINGI3DPROC__1,
};
#define CALLBACK_PFNWGLENDFRAMETRACKINGI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLENDFRAMETRACKINGI3DPROC__##I () \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLENDFRAMETRACKINGI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLENDFRAMETRACKINGI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLENDFRAMETRACKINGI3DPROC_(0)
CALLBACK_PFNWGLENDFRAMETRACKINGI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLENDFRAMETRACKINGI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLENDFRAMETRACKINGI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLENDFRAMETRACKINGI3DPROC__1,
};
#define CALLBACK_PFNWGLQUERYFRAMETRACKINGI3DPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLQUERYFRAMETRACKINGI3DPROC__##I (void* x0, void* x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(Cell)(x0); \
  sp[-2]=(Cell)(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLQUERYFRAMETRACKINGI3DPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLQUERYFRAMETRACKINGI3DPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLQUERYFRAMETRACKINGI3DPROC_(0)
CALLBACK_PFNWGLQUERYFRAMETRACKINGI3DPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLQUERYFRAMETRACKINGI3DPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLQUERYFRAMETRACKINGI3DPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLQUERYFRAMETRACKINGI3DPROC__1,
};
#define CALLBACK_PFNWGLDXSETRESOURCESHAREHANDLENVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLDXSETRESOURCESHAREHANDLENVPROC__##I (void* x0, Cell x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(Cell)(x0); \
  sp[-2]=(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLDXSETRESOURCESHAREHANDLENVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLDXSETRESOURCESHAREHANDLENVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLDXSETRESOURCESHAREHANDLENVPROC_(0)
CALLBACK_PFNWGLDXSETRESOURCESHAREHANDLENVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLDXSETRESOURCESHAREHANDLENVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDXSETRESOURCESHAREHANDLENVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDXSETRESOURCESHAREHANDLENVPROC__1,
};
#define CALLBACK_PFNWGLDXOPENDEVICENVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLDXOPENDEVICENVPROC__##I (void* x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(Cell)(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLDXOPENDEVICENVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLDXOPENDEVICENVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLDXOPENDEVICENVPROC_(0)
CALLBACK_PFNWGLDXOPENDEVICENVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLDXOPENDEVICENVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDXOPENDEVICENVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDXOPENDEVICENVPROC__1,
};
#define CALLBACK_PFNWGLDXCLOSEDEVICENVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLDXCLOSEDEVICENVPROC__##I (Cell x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLDXCLOSEDEVICENVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLDXCLOSEDEVICENVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLDXCLOSEDEVICENVPROC_(0)
CALLBACK_PFNWGLDXCLOSEDEVICENVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLDXCLOSEDEVICENVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDXCLOSEDEVICENVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDXCLOSEDEVICENVPROC__1,
};
#define CALLBACK_PFNWGLDXREGISTEROBJECTNVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLDXREGISTEROBJECTNVPROC__##I (Cell x0, void* x1, UCell x2, Cell x3, Cell x4) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp[-3]=(x2); \
  sp[-4]=(x3); \
  sp[-5]=(x4); \
  sp+=-5; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLDXREGISTEROBJECTNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLDXREGISTEROBJECTNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLDXREGISTEROBJECTNVPROC_(0)
CALLBACK_PFNWGLDXREGISTEROBJECTNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLDXREGISTEROBJECTNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDXREGISTEROBJECTNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDXREGISTEROBJECTNVPROC__1,
};
#define CALLBACK_PFNWGLDXUNREGISTEROBJECTNVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLDXUNREGISTEROBJECTNVPROC__##I (Cell x0, Cell x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLDXUNREGISTEROBJECTNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLDXUNREGISTEROBJECTNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLDXUNREGISTEROBJECTNVPROC_(0)
CALLBACK_PFNWGLDXUNREGISTEROBJECTNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLDXUNREGISTEROBJECTNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDXUNREGISTEROBJECTNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDXUNREGISTEROBJECTNVPROC__1,
};
#define CALLBACK_PFNWGLDXOBJECTACCESSNVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLDXOBJECTACCESSNVPROC__##I (Cell x0, Cell x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLDXOBJECTACCESSNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLDXOBJECTACCESSNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLDXOBJECTACCESSNVPROC_(0)
CALLBACK_PFNWGLDXOBJECTACCESSNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLDXOBJECTACCESSNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDXOBJECTACCESSNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDXOBJECTACCESSNVPROC__1,
};
#define CALLBACK_PFNWGLDXLOCKOBJECTSNVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLDXLOCKOBJECTSNVPROC__##I (Cell x0, Cell x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLDXLOCKOBJECTSNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLDXLOCKOBJECTSNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLDXLOCKOBJECTSNVPROC_(0)
CALLBACK_PFNWGLDXLOCKOBJECTSNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLDXLOCKOBJECTSNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDXLOCKOBJECTSNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDXLOCKOBJECTSNVPROC__1,
};
#define CALLBACK_PFNWGLDXUNLOCKOBJECTSNVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLDXUNLOCKOBJECTSNVPROC__##I (Cell x0, Cell x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLDXUNLOCKOBJECTSNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLDXUNLOCKOBJECTSNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLDXUNLOCKOBJECTSNVPROC_(0)
CALLBACK_PFNWGLDXUNLOCKOBJECTSNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLDXUNLOCKOBJECTSNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDXUNLOCKOBJECTSNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDXUNLOCKOBJECTSNVPROC__1,
};
#define CALLBACK_PFNWGLCOPYIMAGESUBDATANVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLCOPYIMAGESUBDATANVPROC__##I (Cell x0, UCell x1, Cell x2, Cell x3, Cell x4, Cell x5, Cell x6, Cell x7, UCell x8, Cell x9, Cell x10, Cell x11, Cell x12, Cell x13, Cell x14, Cell x15, Cell x16) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(x2); \
  sp[-4]=(x3); \
  sp[-5]=(x4); \
  sp[-6]=(x5); \
  sp[-7]=(x6); \
  sp[-8]=(x7); \
  sp[-9]=(x8); \
  sp[-10]=(x9); \
  sp[-11]=(x10); \
  sp[-12]=(x11); \
  sp[-13]=(x12); \
  sp[-14]=(x13); \
  sp[-15]=(x14); \
  sp[-16]=(x15); \
  sp[-17]=(x16); \
  sp+=-17; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLCOPYIMAGESUBDATANVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLCOPYIMAGESUBDATANVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLCOPYIMAGESUBDATANVPROC_(0)
CALLBACK_PFNWGLCOPYIMAGESUBDATANVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLCOPYIMAGESUBDATANVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCOPYIMAGESUBDATANVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCOPYIMAGESUBDATANVPROC__1,
};
#define CALLBACK_PFNWGLDELAYBEFORESWAPNVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLDELAYBEFORESWAPNVPROC__##I (Cell x0, Float x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  fp[-1]=(x1); \
  sp+=-1; \
  fp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLDELAYBEFORESWAPNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLDELAYBEFORESWAPNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLDELAYBEFORESWAPNVPROC_(0)
CALLBACK_PFNWGLDELAYBEFORESWAPNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLDELAYBEFORESWAPNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDELAYBEFORESWAPNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDELAYBEFORESWAPNVPROC__1,
};
#define CALLBACK_PFNWGLENUMGPUSNVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLENUMGPUSNVPROC__##I (UCell x0, void* x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLENUMGPUSNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLENUMGPUSNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLENUMGPUSNVPROC_(0)
CALLBACK_PFNWGLENUMGPUSNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLENUMGPUSNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLENUMGPUSNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLENUMGPUSNVPROC__1,
};
#define CALLBACK_PFNWGLENUMGPUDEVICESNVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLENUMGPUDEVICESNVPROC__##I (Cell x0, UCell x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLENUMGPUDEVICESNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLENUMGPUDEVICESNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLENUMGPUDEVICESNVPROC_(0)
CALLBACK_PFNWGLENUMGPUDEVICESNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLENUMGPUDEVICESNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLENUMGPUDEVICESNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLENUMGPUDEVICESNVPROC__1,
};
#define CALLBACK_PFNWGLCREATEAFFINITYDCNVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLCREATEAFFINITYDCNVPROC__##I (void* x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(Cell)(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLCREATEAFFINITYDCNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLCREATEAFFINITYDCNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLCREATEAFFINITYDCNVPROC_(0)
CALLBACK_PFNWGLCREATEAFFINITYDCNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLCREATEAFFINITYDCNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCREATEAFFINITYDCNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLCREATEAFFINITYDCNVPROC__1,
};
#define CALLBACK_PFNWGLENUMGPUSFROMAFFINITYDCNVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLENUMGPUSFROMAFFINITYDCNVPROC__##I (Cell x0, UCell x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLENUMGPUSFROMAFFINITYDCNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLENUMGPUSFROMAFFINITYDCNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLENUMGPUSFROMAFFINITYDCNVPROC_(0)
CALLBACK_PFNWGLENUMGPUSFROMAFFINITYDCNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLENUMGPUSFROMAFFINITYDCNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLENUMGPUSFROMAFFINITYDCNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLENUMGPUSFROMAFFINITYDCNVPROC__1,
};
#define CALLBACK_PFNWGLDELETEDCNVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLDELETEDCNVPROC__##I (Cell x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLDELETEDCNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLDELETEDCNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLDELETEDCNVPROC_(0)
CALLBACK_PFNWGLDELETEDCNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLDELETEDCNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDELETEDCNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLDELETEDCNVPROC__1,
};
#define CALLBACK_PFNWGLENUMERATEVIDEODEVICESNVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLENUMERATEVIDEODEVICESNVPROC__##I (Cell x0, void* x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLENUMERATEVIDEODEVICESNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLENUMERATEVIDEODEVICESNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLENUMERATEVIDEODEVICESNVPROC_(0)
CALLBACK_PFNWGLENUMERATEVIDEODEVICESNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLENUMERATEVIDEODEVICESNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLENUMERATEVIDEODEVICESNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLENUMERATEVIDEODEVICESNVPROC__1,
};
#define CALLBACK_PFNWGLBINDVIDEODEVICENVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLBINDVIDEODEVICENVPROC__##I (Cell x0, UCell x1, Cell x2, void* x3) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(x2); \
  sp[-4]=(Cell)(x3); \
  sp+=-4; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLBINDVIDEODEVICENVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLBINDVIDEODEVICENVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLBINDVIDEODEVICENVPROC_(0)
CALLBACK_PFNWGLBINDVIDEODEVICENVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLBINDVIDEODEVICENVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLBINDVIDEODEVICENVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLBINDVIDEODEVICENVPROC__1,
};
#define CALLBACK_PFNWGLQUERYCURRENTCONTEXTNVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLQUERYCURRENTCONTEXTNVPROC__##I (Cell x0, void* x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLQUERYCURRENTCONTEXTNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLQUERYCURRENTCONTEXTNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLQUERYCURRENTCONTEXTNVPROC_(0)
CALLBACK_PFNWGLQUERYCURRENTCONTEXTNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLQUERYCURRENTCONTEXTNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLQUERYCURRENTCONTEXTNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLQUERYCURRENTCONTEXTNVPROC__1,
};
#define CALLBACK_PFNWGLJOINSWAPGROUPNVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLJOINSWAPGROUPNVPROC__##I (Cell x0, UCell x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLJOINSWAPGROUPNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLJOINSWAPGROUPNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLJOINSWAPGROUPNVPROC_(0)
CALLBACK_PFNWGLJOINSWAPGROUPNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLJOINSWAPGROUPNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLJOINSWAPGROUPNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLJOINSWAPGROUPNVPROC__1,
};
#define CALLBACK_PFNWGLBINDSWAPBARRIERNVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLBINDSWAPBARRIERNVPROC__##I (UCell x0, UCell x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLBINDSWAPBARRIERNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLBINDSWAPBARRIERNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLBINDSWAPBARRIERNVPROC_(0)
CALLBACK_PFNWGLBINDSWAPBARRIERNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLBINDSWAPBARRIERNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLBINDSWAPBARRIERNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLBINDSWAPBARRIERNVPROC__1,
};
#define CALLBACK_PFNWGLQUERYSWAPGROUPNVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLQUERYSWAPGROUPNVPROC__##I (Cell x0, void* x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLQUERYSWAPGROUPNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLQUERYSWAPGROUPNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLQUERYSWAPGROUPNVPROC_(0)
CALLBACK_PFNWGLQUERYSWAPGROUPNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLQUERYSWAPGROUPNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLQUERYSWAPGROUPNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLQUERYSWAPGROUPNVPROC__1,
};
#define CALLBACK_PFNWGLQUERYMAXSWAPGROUPSNVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLQUERYMAXSWAPGROUPSNVPROC__##I (Cell x0, void* x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLQUERYMAXSWAPGROUPSNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLQUERYMAXSWAPGROUPSNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLQUERYMAXSWAPGROUPSNVPROC_(0)
CALLBACK_PFNWGLQUERYMAXSWAPGROUPSNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLQUERYMAXSWAPGROUPSNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLQUERYMAXSWAPGROUPSNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLQUERYMAXSWAPGROUPSNVPROC__1,
};
#define CALLBACK_PFNWGLQUERYFRAMECOUNTNVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLQUERYFRAMECOUNTNVPROC__##I (Cell x0, void* x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLQUERYFRAMECOUNTNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLQUERYFRAMECOUNTNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLQUERYFRAMECOUNTNVPROC_(0)
CALLBACK_PFNWGLQUERYFRAMECOUNTNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLQUERYFRAMECOUNTNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLQUERYFRAMECOUNTNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLQUERYFRAMECOUNTNVPROC__1,
};
#define CALLBACK_PFNWGLRESETFRAMECOUNTNVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLRESETFRAMECOUNTNVPROC__##I (Cell x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLRESETFRAMECOUNTNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLRESETFRAMECOUNTNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLRESETFRAMECOUNTNVPROC_(0)
CALLBACK_PFNWGLRESETFRAMECOUNTNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLRESETFRAMECOUNTNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLRESETFRAMECOUNTNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLRESETFRAMECOUNTNVPROC__1,
};
#define CALLBACK_PFNWGLALLOCATEMEMORYNVPROC_(I) \
void* libgfopengl_LTX_gforth_cb_PFNWGLALLOCATEMEMORYNVPROC__##I (Cell x0, Float x1, Float x2, Float x3) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  fp[-1]=(x1); \
  fp[-2]=(x2); \
  fp[-3]=(x3); \
  sp+=-1; \
  fp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLALLOCATEMEMORYNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return (void *)(sp[-1]); \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLALLOCATEMEMORYNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLALLOCATEMEMORYNVPROC_(0)
CALLBACK_PFNWGLALLOCATEMEMORYNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLALLOCATEMEMORYNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLALLOCATEMEMORYNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLALLOCATEMEMORYNVPROC__1,
};
#define CALLBACK_PFNWGLFREEMEMORYNVPROC_(I) \
void libgfopengl_LTX_gforth_cb_PFNWGLFREEMEMORYNVPROC__##I (void* x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(Cell)(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLFREEMEMORYNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLFREEMEMORYNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLFREEMEMORYNVPROC_(0)
CALLBACK_PFNWGLFREEMEMORYNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLFREEMEMORYNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLFREEMEMORYNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLFREEMEMORYNVPROC__1,
};
#define CALLBACK_PFNWGLBINDVIDEOCAPTUREDEVICENVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLBINDVIDEOCAPTUREDEVICENVPROC__##I (UCell x0, Cell x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLBINDVIDEOCAPTUREDEVICENVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLBINDVIDEOCAPTUREDEVICENVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLBINDVIDEOCAPTUREDEVICENVPROC_(0)
CALLBACK_PFNWGLBINDVIDEOCAPTUREDEVICENVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLBINDVIDEOCAPTUREDEVICENVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLBINDVIDEOCAPTUREDEVICENVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLBINDVIDEOCAPTUREDEVICENVPROC__1,
};
#define CALLBACK_PFNWGLENUMERATEVIDEOCAPTUREDEVICESNVPROC_(I) \
UCell libgfopengl_LTX_gforth_cb_PFNWGLENUMERATEVIDEOCAPTUREDEVICESNVPROC__##I (Cell x0, void* x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLENUMERATEVIDEOCAPTUREDEVICESNVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLENUMERATEVIDEOCAPTUREDEVICESNVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLENUMERATEVIDEOCAPTUREDEVICESNVPROC_(0)
CALLBACK_PFNWGLENUMERATEVIDEOCAPTUREDEVICESNVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLENUMERATEVIDEOCAPTUREDEVICESNVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLENUMERATEVIDEOCAPTUREDEVICESNVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLENUMERATEVIDEOCAPTUREDEVICESNVPROC__1,
};
#define CALLBACK_PFNWGLLOCKVIDEOCAPTUREDEVICENVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLLOCKVIDEOCAPTUREDEVICENVPROC__##I (Cell x0, Cell x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLLOCKVIDEOCAPTUREDEVICENVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLLOCKVIDEOCAPTUREDEVICENVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLLOCKVIDEOCAPTUREDEVICENVPROC_(0)
CALLBACK_PFNWGLLOCKVIDEOCAPTUREDEVICENVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLLOCKVIDEOCAPTUREDEVICENVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLLOCKVIDEOCAPTUREDEVICENVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLLOCKVIDEOCAPTUREDEVICENVPROC__1,
};
#define CALLBACK_PFNWGLQUERYVIDEOCAPTUREDEVICENVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLQUERYVIDEOCAPTUREDEVICENVPROC__##I (Cell x0, Cell x1, Cell x2, void* x3) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(x2); \
  sp[-4]=(Cell)(x3); \
  sp+=-4; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLQUERYVIDEOCAPTUREDEVICENVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLQUERYVIDEOCAPTUREDEVICENVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLQUERYVIDEOCAPTUREDEVICENVPROC_(0)
CALLBACK_PFNWGLQUERYVIDEOCAPTUREDEVICENVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLQUERYVIDEOCAPTUREDEVICENVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLQUERYVIDEOCAPTUREDEVICENVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLQUERYVIDEOCAPTUREDEVICENVPROC__1,
};
#define CALLBACK_PFNWGLRELEASEVIDEOCAPTUREDEVICENVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLRELEASEVIDEOCAPTUREDEVICENVPROC__##I (Cell x0, Cell x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLRELEASEVIDEOCAPTUREDEVICENVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLRELEASEVIDEOCAPTUREDEVICENVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLRELEASEVIDEOCAPTUREDEVICENVPROC_(0)
CALLBACK_PFNWGLRELEASEVIDEOCAPTUREDEVICENVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLRELEASEVIDEOCAPTUREDEVICENVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLRELEASEVIDEOCAPTUREDEVICENVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLRELEASEVIDEOCAPTUREDEVICENVPROC__1,
};
#define CALLBACK_PFNWGLGETVIDEODEVICENVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETVIDEODEVICENVPROC__##I (Cell x0, Cell x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETVIDEODEVICENVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETVIDEODEVICENVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETVIDEODEVICENVPROC_(0)
CALLBACK_PFNWGLGETVIDEODEVICENVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETVIDEODEVICENVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETVIDEODEVICENVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETVIDEODEVICENVPROC__1,
};
#define CALLBACK_PFNWGLRELEASEVIDEODEVICENVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLRELEASEVIDEODEVICENVPROC__##I (Cell x0) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp+=-1; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLRELEASEVIDEODEVICENVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLRELEASEVIDEODEVICENVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLRELEASEVIDEODEVICENVPROC_(0)
CALLBACK_PFNWGLRELEASEVIDEODEVICENVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLRELEASEVIDEODEVICENVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLRELEASEVIDEODEVICENVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLRELEASEVIDEODEVICENVPROC__1,
};
#define CALLBACK_PFNWGLBINDVIDEOIMAGENVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLBINDVIDEOIMAGENVPROC__##I (Cell x0, Cell x1, Cell x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLBINDVIDEOIMAGENVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLBINDVIDEOIMAGENVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLBINDVIDEOIMAGENVPROC_(0)
CALLBACK_PFNWGLBINDVIDEOIMAGENVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLBINDVIDEOIMAGENVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLBINDVIDEOIMAGENVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLBINDVIDEOIMAGENVPROC__1,
};
#define CALLBACK_PFNWGLRELEASEVIDEOIMAGENVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLRELEASEVIDEOIMAGENVPROC__##I (Cell x0, Cell x1) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp+=-2; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLRELEASEVIDEOIMAGENVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLRELEASEVIDEOIMAGENVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLRELEASEVIDEOIMAGENVPROC_(0)
CALLBACK_PFNWGLRELEASEVIDEOIMAGENVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLRELEASEVIDEOIMAGENVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLRELEASEVIDEOIMAGENVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLRELEASEVIDEOIMAGENVPROC__1,
};
#define CALLBACK_PFNWGLSENDPBUFFERTOVIDEONVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLSENDPBUFFERTOVIDEONVPROC__##I (Cell x0, Cell x1, void* x2, Cell x3) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  sp[-3]=(Cell)(x2); \
  sp[-4]=(x3); \
  sp+=-4; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLSENDPBUFFERTOVIDEONVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLSENDPBUFFERTOVIDEONVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLSENDPBUFFERTOVIDEONVPROC_(0)
CALLBACK_PFNWGLSENDPBUFFERTOVIDEONVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLSENDPBUFFERTOVIDEONVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLSENDPBUFFERTOVIDEONVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLSENDPBUFFERTOVIDEONVPROC__1,
};
#define CALLBACK_PFNWGLGETVIDEOINFONVPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETVIDEOINFONVPROC__##I (Cell x0, void* x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETVIDEOINFONVPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETVIDEOINFONVPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETVIDEOINFONVPROC_(0)
CALLBACK_PFNWGLGETVIDEOINFONVPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETVIDEOINFONVPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETVIDEOINFONVPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETVIDEOINFONVPROC__1,
};
#define CALLBACK_PFNWGLGETSYNCVALUESOMLPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETSYNCVALUESOMLPROC__##I (Cell x0, void* x1, void* x2, void* x3) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp[-3]=(Cell)(x2); \
  sp[-4]=(Cell)(x3); \
  sp+=-4; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETSYNCVALUESOMLPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETSYNCVALUESOMLPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETSYNCVALUESOMLPROC_(0)
CALLBACK_PFNWGLGETSYNCVALUESOMLPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETSYNCVALUESOMLPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETSYNCVALUESOMLPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETSYNCVALUESOMLPROC__1,
};
#define CALLBACK_PFNWGLGETMSCRATEOMLPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLGETMSCRATEOMLPROC__##I (Cell x0, void* x1, void* x2) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(Cell)(x1); \
  sp[-3]=(Cell)(x2); \
  sp+=-3; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLGETMSCRATEOMLPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLGETMSCRATEOMLPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLGETMSCRATEOMLPROC_(0)
CALLBACK_PFNWGLGETMSCRATEOMLPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLGETMSCRATEOMLPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETMSCRATEOMLPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLGETMSCRATEOMLPROC__1,
};
#define CALLBACK_PFNWGLSWAPBUFFERSMSCOMLPROC_(I) \
Clongest libgfopengl_LTX_gforth_cb_PFNWGLSWAPBUFFERSMSCOMLPROC__##I (Cell x0, Clongest x1, Clongest x2, Clongest x3) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  gforth_ll2d((x1),sp[-2],sp[-3]); \
  gforth_ll2d((x2),sp[-4],sp[-5]); \
  gforth_ll2d((x3),sp[-6],sp[-7]); \
  sp+=-7; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLSWAPBUFFERSMSCOMLPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
gforth_d2ll(sp[-1],sp[-2]); \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLSWAPBUFFERSMSCOMLPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLSWAPBUFFERSMSCOMLPROC_(0)
CALLBACK_PFNWGLSWAPBUFFERSMSCOMLPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLSWAPBUFFERSMSCOMLPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLSWAPBUFFERSMSCOMLPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLSWAPBUFFERSMSCOMLPROC__1,
};
#define CALLBACK_PFNWGLSWAPLAYERBUFFERSMSCOMLPROC_(I) \
Clongest libgfopengl_LTX_gforth_cb_PFNWGLSWAPLAYERBUFFERSMSCOMLPROC__##I (Cell x0, Cell x1, Clongest x2, Clongest x3, Clongest x4) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  sp[-2]=(x1); \
  gforth_ll2d((x2),sp[-3],sp[-4]); \
  gforth_ll2d((x3),sp[-5],sp[-6]); \
  gforth_ll2d((x4),sp[-7],sp[-8]); \
  sp+=-8; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLSWAPLAYERBUFFERSMSCOMLPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
gforth_d2ll(sp[-1],sp[-2]); \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLSWAPLAYERBUFFERSMSCOMLPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLSWAPLAYERBUFFERSMSCOMLPROC_(0)
CALLBACK_PFNWGLSWAPLAYERBUFFERSMSCOMLPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLSWAPLAYERBUFFERSMSCOMLPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLSWAPLAYERBUFFERSMSCOMLPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLSWAPLAYERBUFFERSMSCOMLPROC__1,
};
#define CALLBACK_PFNWGLWAITFORMSCOMLPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLWAITFORMSCOMLPROC__##I (Cell x0, Clongest x1, Clongest x2, Clongest x3, void* x4, void* x5, void* x6) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  gforth_ll2d((x1),sp[-2],sp[-3]); \
  gforth_ll2d((x2),sp[-4],sp[-5]); \
  gforth_ll2d((x3),sp[-6],sp[-7]); \
  sp[-8]=(Cell)(x4); \
  sp[-9]=(Cell)(x5); \
  sp[-10]=(Cell)(x6); \
  sp+=-10; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLWAITFORMSCOMLPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLWAITFORMSCOMLPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLWAITFORMSCOMLPROC_(0)
CALLBACK_PFNWGLWAITFORMSCOMLPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLWAITFORMSCOMLPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLWAITFORMSCOMLPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLWAITFORMSCOMLPROC__1,
};
#define CALLBACK_PFNWGLWAITFORSBCOMLPROC_(I) \
Cell libgfopengl_LTX_gforth_cb_PFNWGLWAITFORSBCOMLPROC__##I (Cell x0, Clongest x1, void* x2, void* x3, void* x4) \
{ \
  stackpointers * SPs = get_gforth_SPs(); \
  Cell *oldsp=SPs->spx; Cell *oldrp=SPs->rpx; char *oldlp=SPs->lpx; \
  Float *oldfp=SPs->fpx; user_area *oldup=SPs->upx; Cell old_magic=SPs->magic; \
  Cell stack[GFSS], rstack[GFSS], lstack[GFSS]; Float fstack[GFSS]; \
  SPs->spx=stack+GFSS-1; SPs->rpx=rstack+GFSS; SPs->lpx=(char*)(lstack+GFSS); SPs->fpx=fstack+GFSS-1; SPs->upx=gforth_main_UP; SPs->magic=GFORTH_MAGIC; \
  Cell*  sp=SPs->spx; \
  Float* fp=SPs->fpx; \
  sp[-1]=(x0); \
  gforth_ll2d((x1),sp[-2],sp[-3]); \
  sp[-4]=(Cell)(x2); \
  sp[-5]=(Cell)(x3); \
  sp[-6]=(Cell)(x4); \
  sp+=-6; \
  SPs->spx=sp; SPs->fpx=fp; gforth_engine(libgfopengl_LTX_gforth_cbips_PFNWGLWAITFORSBCOMLPROC_[I], SPs); \
  SPs->spx=oldsp; SPs->rpx=oldrp; SPs->lpx=oldlp; SPs->fpx=oldfp; SPs->upx=oldup; SPs->magic=old_magic; \
  return sp[-1]; \
}
Xt* libgfopengl_LTX_gforth_cbips_PFNWGLWAITFORSBCOMLPROC_[2] = {
  0, 0,};
CALLBACK_PFNWGLWAITFORSBCOMLPROC_(0)
CALLBACK_PFNWGLWAITFORSBCOMLPROC_(1)
const Address libgfopengl_LTX_gforth_callbacks_PFNWGLWAITFORSBCOMLPROC_[2] = {
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLWAITFORSBCOMLPROC__0,
  (Address)libgfopengl_LTX_gforth_cb_PFNWGLWAITFORSBCOMLPROC__1,
};
ptrpair libgfopengl_LTX_gforth_c_wglSetStereoEmitterState3DL_nu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=wglSetStereoEmitterState3DL(sp[1],sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglGetDigitalVideoParametersI3D_nna_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=wglGetDigitalVideoParametersI3D(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglSetDigitalVideoParametersI3D_nna_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=wglSetDigitalVideoParametersI3D(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglGetGammaTableParametersI3D_nna_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=wglGetGammaTableParametersI3D(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglSetGammaTableParametersI3D_nna_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=wglSetGammaTableParametersI3D(sp[2],sp[1],(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglGetGammaTableI3D_nnaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=wglGetGammaTableI3D(sp[4],sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglSetGammaTableI3D_nnaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=wglSetGammaTableI3D(sp[4],sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglEnableGenlockI3D_n_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=wglEnableGenlockI3D(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglDisableGenlockI3D_n_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=wglDisableGenlockI3D(sp[0]);
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglIsEnabledGenlockI3D_na_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=wglIsEnabledGenlockI3D(sp[1],(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglGenlockSourceI3D_nu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=wglGenlockSourceI3D(sp[1],sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglGetGenlockSourceI3D_na_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=wglGetGenlockSourceI3D(sp[1],(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglGenlockSourceEdgeI3D_nu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=wglGenlockSourceEdgeI3D(sp[1],sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglGetGenlockSourceEdgeI3D_na_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=wglGetGenlockSourceEdgeI3D(sp[1],(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglGenlockSampleRateI3D_nu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=wglGenlockSampleRateI3D(sp[1],sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglGetGenlockSampleRateI3D_na_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=wglGetGenlockSampleRateI3D(sp[1],(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglGenlockSourceDelayI3D_nu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=wglGenlockSourceDelayI3D(sp[1],sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglGetGenlockSourceDelayI3D_na_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=wglGetGenlockSourceDelayI3D(sp[1],(void *)(sp[0]));
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglQueryGenlockMaxSourceDelayI3D_naa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=wglQueryGenlockMaxSourceDelayI3D(sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglCreateImageBufferI3D_nnu_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=wglCreateImageBufferI3D(sp[2],sp[1],sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglDestroyImageBufferI3D_nn_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=1, farg0=-1;
  sp[1]=wglDestroyImageBufferI3D(sp[1],sp[0]);
  x.sp = sp+1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglAssociateImageBufferEventsI3D_naaau_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=4, farg0=-1;
  sp[4]=wglAssociateImageBufferEventsI3D(sp[4],(void *)(sp[3]),(void *)(sp[2]),(void *)(sp[1]),sp[0]);
  x.sp = sp+4;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglReleaseImageBufferEventsI3D_nau_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=wglReleaseImageBufferEventsI3D(sp[2],(void *)(sp[1]),sp[0]);
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglEnableFrameLockI3D__n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=wglEnableFrameLockI3D();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglDisableFrameLockI3D__n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=wglDisableFrameLockI3D();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglIsEnabledFrameLockI3D_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=wglIsEnabledFrameLockI3D((void *)(sp[0]));
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglQueryFrameLockMasterI3D_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=wglQueryFrameLockMasterI3D((void *)(sp[0]));
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglGetFrameUsageI3D_a_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=0, farg0=-1;
  sp[0]=wglGetFrameUsageI3D((void *)(sp[0]));
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglBeginFrameTrackingI3D__n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=wglBeginFrameTrackingI3D();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglEndFrameTrackingI3D__n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=-1, farg0=-1;
  sp[-1]=wglEndFrameTrackingI3D();
  x.sp = sp+-1;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglQueryFrameTrackingI3D_aaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=wglQueryFrameTrackingI3D((void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglGetSyncValuesOML_naaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=3, farg0=-1;
  sp[3]=wglGetSyncValuesOML(sp[3],(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+3;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglGetMscRateOML_naa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=2, farg0=-1;
  sp[2]=wglGetMscRateOML(sp[2],(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+2;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglSwapBuffersMscOML_nddd_d(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=6, farg0=-1;
  gforth_ll2d(wglSwapBuffersMscOML(sp[6],gforth_d2ll(sp[5],sp[4]),gforth_d2ll(sp[3],sp[2]),gforth_d2ll(sp[1],sp[0])),sp[6],sp[5]);
  x.sp = sp+5;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglSwapLayerBuffersMscOML_nnddd_d(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=7, farg0=-1;
  gforth_ll2d(wglSwapLayerBuffersMscOML(sp[7],sp[6],gforth_d2ll(sp[5],sp[4]),gforth_d2ll(sp[3],sp[2]),gforth_d2ll(sp[1],sp[0])),sp[7],sp[6]);
  x.sp = sp+6;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglWaitForMscOML_ndddaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=9, farg0=-1;
  sp[9]=wglWaitForMscOML(sp[9],gforth_d2ll(sp[8],sp[7]),gforth_d2ll(sp[6],sp[5]),gforth_d2ll(sp[4],sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+9;
  return x;
}
ptrpair libgfopengl_LTX_gforth_c_wglWaitForSbcOML_ndaaa_n(GFORTH_ARGS)
{
  Cell MAYBE_UNUSED *sp = x.sp;
  Float MAYBE_UNUSED *fp = x.fp;
  int MAYBE_UNUSED arg0=5, farg0=-1;
  sp[5]=wglWaitForSbcOML(sp[5],gforth_d2ll(sp[4],sp[3]),(void *)(sp[2]),(void *)(sp[1]),(void *)(sp[0]));
  x.sp = sp+5;
  return x;
}
hash_128 gflibcc_hash_opengl = "\xD2\x3D\x69\x07\x7A\x8F\xE3\x2F\x5B\x8A\x01\x18\xE9\x1B\x86\xEF";
